DatexExpression

Enum DatexExpression 

pub enum DatexExpression {
Show 36 variants Recover, Null, Boolean(bool), Text(String), Decimal(Decimal), TypedDecimal(TypedDecimal), Integer(Integer), TypedInteger(TypedInteger), Identifier(String), Endpoint(Endpoint), List(Vec<DatexExpression>), Map(Vec<(DatexExpression, DatexExpression)>), Statements(Vec<Statement>), Variable(VariableId, String), GetReference(PointerAddress), Conditional { condition: Box<DatexExpression>, then_branch: Box<DatexExpression>, else_branch: Option<Box<DatexExpression>>, }, VariableDeclaration { id: Option<VariableId>, kind: VariableKind, name: String, type_annotation: Option<TypeExpression>, init_expression: Box<DatexExpression>, }, TypeDeclaration { id: Option<VariableId>, name: String, value: TypeExpression, hoisted: bool, }, TypeExpression(TypeExpression), Type(TypeExpression), FunctionDeclaration { name: String, parameters: Vec<(String, TypeExpression)>, return_type: Option<TypeExpression>, body: Box<DatexExpression>, }, CreateRef(Box<DatexExpression>), CreateRefMut(Box<DatexExpression>), CreateRefFinal(Box<DatexExpression>), Deref(Box<DatexExpression>), Slot(Slot), SlotAssignment(Slot, Box<DatexExpression>), PointerAddress(PointerAddress), BinaryOperation(BinaryOperator, Box<DatexExpression>, Box<DatexExpression>, Option<Type>), ComparisonOperation(ComparisonOperator, Box<DatexExpression>, Box<DatexExpression>), VariableAssignment(AssignmentOperator, Option<VariableId>, String, Box<DatexExpression>), DerefAssignment { operator: AssignmentOperator, deref_count: usize, deref_expression: Box<DatexExpression>, assigned_expression: Box<DatexExpression>, }, UnaryOperation(UnaryOperator, Box<DatexExpression>), ApplyChain(Box<DatexExpression>, Vec<ApplyOperation>), Placeholder, RemoteExecution(Box<DatexExpression>, Box<DatexExpression>),
}

Variants



Recover

This is a marker for recovery from parse errors. We should never use this manually.



Null

null



Boolean(bool)

Boolean (true or false)



Text(String)

Text, e.g “Hello, world!”



Decimal(Decimal)

Decimal, e.g 123.456789123456



TypedDecimal(TypedDecimal)

Typed Decimal, e.g. 123.456i8



Integer(Integer)

Integer, e.g 123456789123456789



TypedInteger(TypedInteger)

Typed Integer, e.g. 123i8



Identifier(String)

Identifier (variable / core type usage)



Endpoint(Endpoint)

Endpoint, e.g. @test_a or @test_b



List(Vec<DatexExpression>)

List, e.g [1, 2, 3, "text"]



Map(Vec<(DatexExpression, DatexExpression)>)

Map, e.g {“xy”: 2, (3): 4, xy: “xy”}



Statements(Vec<Statement>)

One or more statements, e.g (1; 2; 3)



Variable(VariableId, String)

Variable name - only generated by the precompiler, not by the parser



GetReference(PointerAddress)

reference access, e.g. &



Conditional

Conditional expression, e.g. if (true) { 1 } else { 2 }

Fields

then_branch: Box<DatexExpression>


VariableDeclaration

Variable declaration, e.g. const x = 1, const mut x = 1, or var y = 2. VariableId is always set to 0 by the ast parser.

Fields

name: String
type_annotation: Option<TypeExpression>
init_expression: Box<DatexExpression>


TypeDeclaration

Type declaration, e.g. type MyType = { x: 42, y: “John” };

Fields

name: String
hoisted: bool


TypeExpression(TypeExpression)

Type expression, e.g. { x: 42, y: “John” }



Type(TypeExpression)

Type keyword, e.g. type(…)



FunctionDeclaration

Fields

name: String
parameters: Vec<(String, TypeExpression)>
return_type: Option<TypeExpression>


CreateRef(Box<DatexExpression>)

Reference, e.g. &x



CreateRefMut(Box<DatexExpression>)

Mutable reference, e.g. &mut x



CreateRefFinal(Box<DatexExpression>)

Final reference, e.g. &final x



Deref(Box<DatexExpression>)

Deref



Slot(Slot)

Slot, e.g. #1, #endpoint



SlotAssignment(Slot, Box<DatexExpression>)

Slot assignment



PointerAddress(PointerAddress)



BinaryOperation(BinaryOperator, Box<DatexExpression>, Box<DatexExpression>, Option<Type>)



ComparisonOperation(ComparisonOperator, Box<DatexExpression>, Box<DatexExpression>)



VariableAssignment(AssignmentOperator, Option<VariableId>, String, Box<DatexExpression>)



DerefAssignment

Fields

deref_count: usize
deref_expression: Box<DatexExpression>
assigned_expression: Box<DatexExpression>


UnaryOperation(UnaryOperator, Box<DatexExpression>)



ApplyChain(Box<DatexExpression>, Vec<ApplyOperation>)



Placeholder



RemoteExecution(Box<DatexExpression>, Box<DatexExpression>)