DatexExpressionData

Enum DatexExpressionData 

pub enum DatexExpressionData {
Show 39 variants Noop, Recover, NativeImplementationIndicator, Null, Boolean(bool), Text(String), Decimal(Decimal), TypedDecimal(TypedDecimal), Integer(Integer), TypedInteger(TypedInteger), Identifier(String), Endpoint(Endpoint), List(List), Map(Map), Statements(Statements), GetReference(PointerAddress), Conditional(Conditional), VariableDeclaration(VariableDeclaration), VariableAssignment(VariableAssignment), VariableAccess(VariableAccess), TypeDeclaration(TypeDeclaration), TypeExpression(TypeExpression), CallableDeclaration(CallableDeclaration), CreateRef(CreateRef), Deref(Deref), Slot(Slot), SlotAssignment(SlotAssignment), PointerAddress(PointerAddress), BinaryOperation(BinaryOperation), ComparisonOperation(ComparisonOperation), DerefAssignment(DerefAssignment), PropertyAssignment(PropertyAssignment), UnaryOperation(UnaryOperation), Apply(Apply), PropertyAccess(PropertyAccess), GenericInstantiation(GenericInstantiation), Placeholder, RemoteExecution(RemoteExecution), VariantAccess(VariantAccess),
}
The different kinds of type expressions in the AST

Variants



Noop

This is a marker for recovery from parse errors. We should never use this manually.



Recover



NativeImplementationIndicator



Null

null



Boolean(bool)

Boolean (true or false)



Text(String)

Text, e.g “Hello, world!”



Decimal(Decimal)

Decimal, e.g 123.456789123456



TypedDecimal(TypedDecimal)

Typed Decimal, e.g. 123.456i8



Integer(Integer)

Integer, e.g 123456789123456789



TypedInteger(TypedInteger)

Typed Integer, e.g. 123i8



Identifier(String)

Identifier (variable / core type usage)



Endpoint(Endpoint)

Endpoint, e.g. @test_a or @test_b



List(List)

List, e.g [1, 2, 3, "text"]



Map(Map)

Map, e.g {“xy”: 2, (3): 4, xy: “xy”}



Statements(Statements)

One or more statements, e.g (1; 2; 3)



GetReference(PointerAddress)

reference access, e.g. &



Conditional(Conditional)

Conditional expression, e.g. if (true) { 1 } else { 2 }



VariableDeclaration(VariableDeclaration)

Variable declaration, e.g. const x = 1, const mut x = 1, or var y = 2. VariableId is always set to 0 by the ast parser.



VariableAssignment(VariableAssignment)

Variable assignment, e.g. x = 42 or y += 1



VariableAccess(VariableAccess)

Variable access - only generated by the precompiler, not by the parser



TypeDeclaration(TypeDeclaration)

Type declaration, e.g. type MyType = { x: 42, y: “John” };



TypeExpression(TypeExpression)

Type expression, e.g. type(1 | 2)



CallableDeclaration(CallableDeclaration)

callable (function/procedure) declaration, e.g. function my_function() -> type ( … )



CreateRef(CreateRef)

Reference, e.g. &x or &mut x



Deref(Deref)

Deref



Slot(Slot)

Slot, e.g. #1, #endpoint



SlotAssignment(SlotAssignment)

Slot assignment



PointerAddress(PointerAddress)

Pointer address $



BinaryOperation(BinaryOperation)

Binary operation, e.g. x + y



ComparisonOperation(ComparisonOperation)

Comparison operation, e.g. x < y



DerefAssignment(DerefAssignment)

Deref assignment, e.g. *x = y, **x += y



PropertyAssignment(PropertyAssignment)

Property assignment, e.g. obj.property = value



UnaryOperation(UnaryOperation)

Unary operation, e.g. -x, !x



Apply(Apply)

Apply a value to another value, e.g. function call or type cast



PropertyAccess(PropertyAccess)

Apply a property access to an argument



GenericInstantiation(GenericInstantiation)

Generic instantiation, e.g. MyType



Placeholder

The ‘?’ placeholder expression



RemoteExecution(RemoteExecution)

Remote execution, e.g. @example :: 41 + 1



VariantAccess(VariantAccess)

Variant access, e.g. integer/u8