Module compiler

Module compiler 

Modules

context
error
metadata
precompiler
scope
type_compiler
workspace

Structs

CompileOptions
Variable
Represents a variable in the DATEX script.

Enums

StaticValueOrDXB
VariableModel
VariableRepresentation

Functions

compile_block
Compiles a DATEX script text into a single DXB block including routing and block headers. This function is used to create a block that can be sent over the network.
compile_rich_ast
compile_script
Compiles a DATEX script text into a DXB body
compile_script_or_return_static_value
Converts a DATEX script template text with inserted values into an AST with metadata If the script does not contain any dynamic values or operations, the static result value is directly returned instead of the AST.
compile_template
Compiles a DATEX script template text with inserted values into a DXB body
extract_static_value_from_script
Directly extracts a static value from a DATEX script as a ValueContainer. This only works if the script does not contain any dynamic values or operations. All JSON-files can be compiled to static values, but not all DATEX scripts.
parse_datex_script_to_rich_ast_detailed_errors
Parses and precompiles a DATEX script template text with inserted values into an AST with metadata Returns all occurring errors and the AST if one or more errors occur.
parse_datex_script_to_rich_ast_simple_error
Parses and precompiles a DATEX script template text with inserted values into an AST with metadata Only returns the first occurring error