pub struct CompilationContext {
pub inserted_value_index: usize,
pub buffer: Vec<u8>,
pub inserted_values: Vec<ValueContainer>,
pub has_non_static_value: bool,
pub execution_mode: ExecutionMode,
/* private fields */
}Expand description
compilation context, created for each compiler call, even if compiling a script for the same scope
Fields
inserted_value_index: usizebuffer: Vec<u8>inserted_values: Vec<ValueContainer>has_non_static_value: boolthis flag is set to true if any non-static value is encountered
execution_mode: ExecutionModeImplementations
Sourceimpl CompilationContext
impl CompilationContext
pub fn new( buffer: Vec<u8>, inserted_values: Vec<ValueContainer>, execution_mode: ExecutionMode, ) -> Self
pub fn buffer_index(&self) -> usize
pub fn external_slots(&self) -> Vec<VirtualSlot>
Sourcepub fn get_slot_byte_indices(&self, match_externals: bool) -> Vec<Vec<u32>>
pub fn get_slot_byte_indices(&self, match_externals: bool) -> Vec<Vec<u32>>
Gets all slots for either local or external slots depending on the value of external
pub fn remap_virtual_slots(&mut self)
pub fn insert_virtual_slot_address(&mut self, virtual_slot: VirtualSlot)
pub fn set_u32_at_index(&mut self, u32: u32, index: usize)
pub fn mark_has_non_static_value(&mut self)
pub fn append_instruction_code(&mut self, code: InstructionCode)
Sourceimpl CompilationContext
Compilation functions for type expressions.
impl CompilationContext
Compilation functions for type expressions.
pub fn append_type_instruction_code(&mut self, code: TypeInstructionCode)
pub fn insert_type_literal_integer(&mut self, integer: &Integer)
pub fn insert_type_literal_text(&mut self, text: &str)