VariableModel

Enum VariableModel 

pub enum VariableModel {
    Constant,
    VariableSlot,
    VariableReference,
}

Variants



Constant

A variable that is declared once and never reassigned afterward e.g. const a = 42;



VariableSlot

A variable that can be reassigned by updating the slot value e.g. var a = 42; a = 69;



VariableReference

A variable that can be reassigned by updating a reference value. The slot always point to this reference. When variables are transferred across realms, VariableReference is used for var variables instead of VariableSlot. e.g. `var a = 42; x :: (a)

Implementations

Source

impl VariableModel

pub fn infer( variable_kind: VariableKind, variable_metadata: Option<VariableMetadata>, execution_mode: ExecutionMode, ) -> Self

Determines the variable model based on the variable kind and metadata.

pub fn infer_from_ast_metadata_and_type( ast_metadata: &AstMetadata, variable_id: Option<VariableId>, variable_kind: VariableKind, execution_mode: ExecutionMode, ) -> Self