pub enum VariableRepresentation {
Constant(VirtualSlot),
VariableSlot(VirtualSlot),
VariableReference {
variable_slot: VirtualSlot,
container_slot: VirtualSlot,
},
}Variants
Constant(VirtualSlot)
VariableSlot(VirtualSlot)
VariableReference
Fields

variable_slot: VirtualSlotThe slot that contains the reference that is used as the variable

container_slot: VirtualSlotThe slot that contains the actual value container used in the script (Note: the value container may also be a reference)