PrecompilerOptions

Struct PrecompilerOptions 

pub struct PrecompilerOptions {
    pub detailed_errors: bool,
}

Fields

detailed_errors: bool

If enabled, all collected errors as well as the RichAst are returned if one or multiple errors occurred. Otherwise, only the first error is returned (fast failing)