pub struct CompilationScope {
pub precompiler_data: Option<PrecompilerData>,
pub once: bool,
pub was_used: bool,
/* private fields */
}Fields
precompiler_data: Option<PrecompilerData>optional precompiler data, only on the root scope
once: boolIf once is true, the scope can only be used for compilation once. E.g. for a REPL, this needs to be false, so that the scope can be reused
was_used: boolIf was_used is true, the scope has been used for compilation and should not be reused if once is true.
Implementations
Sourceimpl CompilationScope
impl CompilationScope
pub fn new(once: bool) -> CompilationScope
pub fn new_with_external_parent_scope( parent_context: CompilationScope, ) -> CompilationScope
pub fn has_external_parent_scope(&self) -> bool
pub fn register_variable_slot(&mut self, variable: Variable)
pub fn get_next_virtual_slot(&mut self) -> u32
pub fn resolve_variable_name_to_virtual_slot( &self, name: &str, ) -> Option<(VirtualSlot, VariableKind)>
Sourcepub fn push(self) -> CompilationScope
pub fn push(self) -> CompilationScope
Creates a new CompileScope that is a child of the current scope.
Sourcepub fn pop(self) -> Option<(CompilationScope, Vec<VirtualSlot>)>
pub fn pop(self) -> Option<(CompilationScope, Vec<VirtualSlot>)>
Drops the current scope and returns to the parent scope and a list of all slot addresses that should be dropped.
pub fn pop_external(self) -> Option<CompilationScope>