Module value

Module value 

Structs

DIFReferenceNotFoundError
DIFValue
Represents a value in the Datex Interface Format (DIF).

Enums

DIFValueContainer
Holder for either a value or a reference to a value in DIF