pub enum DIFValueContainer {
Value(DIFValue),
Reference(PointerAddress),
}Expand description
Holder for either a value or a reference to a value in DIF
Variants
Value(DIFValue)
Reference(PointerAddress)
Implementations
Sourceimpl DIFValueContainer
impl DIFValueContainer
Sourcepub fn to_value_container(
&self,
memory: &RefCell<Memory>,
) -> Result<ValueContainer, DIFReferenceNotFoundError>
pub fn to_value_container( &self, memory: &RefCell<Memory>, ) -> Result<ValueContainer, DIFReferenceNotFoundError>
Converts the DIFValueContainer into a ValueContainer, resolving references using the provided memory. Returns an error if a reference cannot be resolved.
Sourceimpl DIFValueContainer
impl DIFValueContainer
pub fn from_value_container(value_container: &ValueContainer) -> Self