FormattingOptions

Struct FormattingOptions 

pub struct FormattingOptions {
    pub indent: usize,
    pub max_width: usize,
    pub trailing_comma: bool,
    pub spaced_collections: bool,
    pub space_in_collection: bool,
    pub spaces_around_operators: bool,
    pub type_declaration_formatting: TypeDeclarationFormatting,
    pub statement_formatting: StatementFormatting,
    pub variant_formatting: VariantFormatting,
    pub bracket_style: BracketStyle,
}

Fields

indent: usize

Number of spaces to use for indentation.

max_width: usize

Maximum line width before wrapping occurs.

trailing_comma: bool

Whether to add trailing commas in collections like lists and maps. E.g., [1, 2, 3,] instead of [1, 2, 3].

spaced_collections: bool

Whether to add spaces inside brackets of collections like lists and maps. E.g., [ 1,2,3 ] instead of [1,2,3].

space_in_collection: bool

Whether to add spaces inside collections like lists and maps. E.g., [1, 2, 3] instead of [1,2,3].

spaces_around_operators: bool

Whether to add spaces around operators. E.g., 1 + 2 instead of 1+2.

type_declaration_formatting: TypeDeclarationFormatting

Formatting style for type declarations. Determines how type annotations are spaced and aligned.

statement_formatting: StatementFormatting

Whether to add newlines between statements.

variant_formatting: VariantFormatting

Formatting style for type variant suffixes.

bracket_style: BracketStyle

Bracketing style for expressions.

Implementations