pub struct Formatter<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Formatter<'a>
impl<'a> Formatter<'a>
Sourcepub fn handle_bracketing(
&'a self,
expression: &'a DatexExpression,
doc: Format<'a>,
parent_ctx: Option<ParentContext<'a>>,
is_left_child_of_parent: bool,
) -> Format<'a>
pub fn handle_bracketing( &'a self, expression: &'a DatexExpression, doc: Format<'a>, parent_ctx: Option<ParentContext<'a>>, is_left_child_of_parent: bool, ) -> Format<'a>
Handles bracketing of an expression based on the current formatting options.
Sourcepub fn maybe_wrap_by_parent(
&'a self,
expression: &'a DatexExpression,
inner: Format<'a>,
parent_ctx: Option<ParentContext<'a>>,
is_left_child_of_parent: bool,
) -> Format<'a>
pub fn maybe_wrap_by_parent( &'a self, expression: &'a DatexExpression, inner: Format<'a>, parent_ctx: Option<ParentContext<'a>>, is_left_child_of_parent: bool, ) -> Format<'a>
Decides whether to wrap an expression in parentheses based on its parent context.
Sourcepub fn binary_operator_info(&self, op: &BinaryOperator) -> (u8, Assoc, bool)
pub fn binary_operator_info(&self, op: &BinaryOperator) -> (u8, Assoc, bool)
Returns information about a binary operator: (precedence, associativity, is_associative)
Sourceimpl<'a> Formatter<'a>
impl<'a> Formatter<'a>
pub fn datex_expression_to_source_code( &'a self, expr: &'a DatexExpression, ) -> Format<'a>