Module block_header

Module block_header 

Structs

BlockHeader
FlagsAndTimestamp
has_side_effects: If set, the block can have side effects that change external state. Default is true has_only_data: If set, the block does only contain data and no executable instructions. Default is false

Enums

BlockType