FlagsAndTimestamp

Struct FlagsAndTimestamp 

pub struct FlagsAndTimestamp { /* private fields */ }
has_side_effects: If set, the block can have side effects that change external state. Default is true has_only_data: If set, the block does only contain data and no executable instructions. Default is false

Implementations

Source

impl FlagsAndTimestamp

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl FlagsAndTimestamp

pub const fn into_bytes(self) -> [u8; 8]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 8]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl FlagsAndTimestamp

pub fn block_type(&self) -> <BlockType as Specifier>::InOut

Returns the value of block_type.

pub fn block_type_or_err( &self, ) -> Result<<BlockType as Specifier>::InOut, InvalidBitPattern<<BlockType as Specifier>::Bytes>>

Returns the value of block_type.

Errors

If the returned value contains an invalid bit pattern for block_type.

pub fn with_block_type(self, new_val: <BlockType as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of block_type set to the given value.

Panics

If the given value is out of bounds for block_type.

pub fn with_block_type_checked( self, new_val: <BlockType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of block_type set to the given value.

Errors

If the given value is out of bounds for block_type.

pub fn set_block_type(&mut self, new_val: <BlockType as Specifier>::InOut)

Sets the value of block_type to the given value.

Panics

If the given value is out of bounds for block_type.

pub fn set_block_type_checked( &mut self, new_val: <BlockType as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of block_type to the given value.

Errors

If the given value is out of bounds for block_type.

pub fn has_side_effects(&self) -> <bool as Specifier>::InOut

Returns the value of has_side_effects.

pub fn has_side_effects_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_side_effects.

Errors

If the returned value contains an invalid bit pattern for has_side_effects.

pub fn with_has_side_effects(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_side_effects set to the given value.

Panics

If the given value is out of bounds for has_side_effects.

pub fn with_has_side_effects_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_side_effects set to the given value.

Errors

If the given value is out of bounds for has_side_effects.

pub fn set_has_side_effects(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_side_effects to the given value.

Panics

If the given value is out of bounds for has_side_effects.

pub fn set_has_side_effects_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_side_effects to the given value.

Errors

If the given value is out of bounds for has_side_effects.

pub fn has_only_data(&self) -> <bool as Specifier>::InOut

Returns the value of has_only_data.

pub fn has_only_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_only_data.

Errors

If the returned value contains an invalid bit pattern for has_only_data.

pub fn with_has_only_data(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_only_data set to the given value.

Panics

If the given value is out of bounds for has_only_data.

pub fn with_has_only_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_only_data set to the given value.

Errors

If the given value is out of bounds for has_only_data.

pub fn set_has_only_data(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_only_data to the given value.

Panics

If the given value is out of bounds for has_only_data.

pub fn set_has_only_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_only_data to the given value.

Errors

If the given value is out of bounds for has_only_data.

pub fn is_end_of_section(&self) -> <bool as Specifier>::InOut

Returns the value of is_end_of_section.

pub fn is_end_of_section_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_end_of_section.

Errors

If the returned value contains an invalid bit pattern for is_end_of_section.

pub fn with_is_end_of_section(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of is_end_of_section set to the given value.

Panics

If the given value is out of bounds for is_end_of_section.

pub fn with_is_end_of_section_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_end_of_section set to the given value.

Errors

If the given value is out of bounds for is_end_of_section.

pub fn set_is_end_of_section(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of is_end_of_section to the given value.

Panics

If the given value is out of bounds for is_end_of_section.

pub fn set_is_end_of_section_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_end_of_section to the given value.

Errors

If the given value is out of bounds for is_end_of_section.

pub fn is_end_of_context(&self) -> <bool as Specifier>::InOut

Returns the value of is_end_of_context.

pub fn is_end_of_context_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_end_of_context.

Errors

If the returned value contains an invalid bit pattern for is_end_of_context.

pub fn with_is_end_of_context(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of is_end_of_context set to the given value.

Panics

If the given value is out of bounds for is_end_of_context.

pub fn with_is_end_of_context_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_end_of_context set to the given value.

Errors

If the given value is out of bounds for is_end_of_context.

pub fn set_is_end_of_context(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of is_end_of_context to the given value.

Panics

If the given value is out of bounds for is_end_of_context.

pub fn set_is_end_of_context_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_end_of_context to the given value.

Errors

If the given value is out of bounds for is_end_of_context.

pub fn has_lifetime(&self) -> <bool as Specifier>::InOut

Returns the value of has_lifetime.

pub fn has_lifetime_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_lifetime.

Errors

If the returned value contains an invalid bit pattern for has_lifetime.

pub fn with_has_lifetime(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_lifetime set to the given value.

Panics

If the given value is out of bounds for has_lifetime.

pub fn with_has_lifetime_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_lifetime set to the given value.

Errors

If the given value is out of bounds for has_lifetime.

pub fn set_has_lifetime(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_lifetime to the given value.

Panics

If the given value is out of bounds for has_lifetime.

pub fn set_has_lifetime_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_lifetime to the given value.

Errors

If the given value is out of bounds for has_lifetime.

pub fn has_represented_by(&self) -> <bool as Specifier>::InOut

Returns the value of has_represented_by.

pub fn has_represented_by_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_represented_by.

Errors

If the returned value contains an invalid bit pattern for has_represented_by.

pub fn with_has_represented_by( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of has_represented_by set to the given value.

Panics

If the given value is out of bounds for has_represented_by.

pub fn with_has_represented_by_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_represented_by set to the given value.

Errors

If the given value is out of bounds for has_represented_by.

pub fn set_has_represented_by(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_represented_by to the given value.

Panics

If the given value is out of bounds for has_represented_by.

pub fn set_has_represented_by_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_represented_by to the given value.

Errors

If the given value is out of bounds for has_represented_by.

pub fn has_iv(&self) -> <bool as Specifier>::InOut

Returns the value of has_iv.

pub fn has_iv_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_iv.

Errors

If the returned value contains an invalid bit pattern for has_iv.

pub fn with_has_iv(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_iv set to the given value.

Panics

If the given value is out of bounds for has_iv.

pub fn with_has_iv_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_iv set to the given value.

Errors

If the given value is out of bounds for has_iv.

pub fn set_has_iv(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_iv to the given value.

Panics

If the given value is out of bounds for has_iv.

pub fn set_has_iv_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_iv to the given value.

Errors

If the given value is out of bounds for has_iv.

pub fn is_compressed(&self) -> <bool as Specifier>::InOut

Returns the value of is_compressed.

pub fn is_compressed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_compressed.

Errors

If the returned value contains an invalid bit pattern for is_compressed.

pub fn with_is_compressed(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of is_compressed set to the given value.

Panics

If the given value is out of bounds for is_compressed.

pub fn with_is_compressed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_compressed set to the given value.

Errors

If the given value is out of bounds for is_compressed.

pub fn set_is_compressed(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of is_compressed to the given value.

Panics

If the given value is out of bounds for is_compressed.

pub fn set_is_compressed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_compressed to the given value.

Errors

If the given value is out of bounds for is_compressed.

pub fn is_signature_in_last_subblock(&self) -> <bool as Specifier>::InOut

Returns the value of is_signature_in_last_subblock.

pub fn is_signature_in_last_subblock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_signature_in_last_subblock.

Errors

If the returned value contains an invalid bit pattern for is_signature_in_last_subblock.

pub fn with_is_signature_in_last_subblock( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of is_signature_in_last_subblock set to the given value.

Panics

If the given value is out of bounds for is_signature_in_last_subblock.

pub fn with_is_signature_in_last_subblock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_signature_in_last_subblock set to the given value.

Errors

If the given value is out of bounds for is_signature_in_last_subblock.

pub fn set_is_signature_in_last_subblock( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of is_signature_in_last_subblock to the given value.

Panics

If the given value is out of bounds for is_signature_in_last_subblock.

pub fn set_is_signature_in_last_subblock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_signature_in_last_subblock to the given value.

Errors

If the given value is out of bounds for is_signature_in_last_subblock.

pub fn creation_timestamp(&self) -> <B43 as Specifier>::InOut

Returns the value of creation_timestamp.

pub fn creation_timestamp_or_err( &self, ) -> Result<<B43 as Specifier>::InOut, InvalidBitPattern<<B43 as Specifier>::Bytes>>

Returns the value of creation_timestamp.

Errors

If the returned value contains an invalid bit pattern for creation_timestamp.

pub fn with_creation_timestamp(self, new_val: <B43 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of creation_timestamp set to the given value.

Panics

If the given value is out of bounds for creation_timestamp.

pub fn with_creation_timestamp_checked( self, new_val: <B43 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of creation_timestamp set to the given value.

Errors

If the given value is out of bounds for creation_timestamp.

pub fn set_creation_timestamp(&mut self, new_val: <B43 as Specifier>::InOut)

Sets the value of creation_timestamp to the given value.

Panics

If the given value is out of bounds for creation_timestamp.

pub fn set_creation_timestamp_checked( &mut self, new_val: <B43 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of creation_timestamp to the given value.

Errors

If the given value is out of bounds for creation_timestamp.