Struct ReceiverFlags

pub struct ReceiverFlags { /* private fields */ }

Implementations

Source

impl ReceiverFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl ReceiverFlags

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl ReceiverFlags

pub fn has_pointer_id(&self) -> <bool as Specifier>::InOut

Returns the value of has_pointer_id.

pub fn has_pointer_id_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_pointer_id.

Errors

If the returned value contains an invalid bit pattern for has_pointer_id.

pub fn with_has_pointer_id(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_pointer_id set to the given value.

Panics

If the given value is out of bounds for has_pointer_id.

pub fn with_has_pointer_id_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_pointer_id set to the given value.

Errors

If the given value is out of bounds for has_pointer_id.

pub fn set_has_pointer_id(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_pointer_id to the given value.

Panics

If the given value is out of bounds for has_pointer_id.

pub fn set_has_pointer_id_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_pointer_id to the given value.

Errors

If the given value is out of bounds for has_pointer_id.

pub fn has_endpoints(&self) -> <bool as Specifier>::InOut

Returns the value of has_endpoints.

pub fn has_endpoints_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_endpoints.

Errors

If the returned value contains an invalid bit pattern for has_endpoints.

pub fn with_has_endpoints(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_endpoints set to the given value.

Panics

If the given value is out of bounds for has_endpoints.

pub fn with_has_endpoints_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_endpoints set to the given value.

Errors

If the given value is out of bounds for has_endpoints.

pub fn set_has_endpoints(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_endpoints to the given value.

Panics

If the given value is out of bounds for has_endpoints.

pub fn set_has_endpoints_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_endpoints to the given value.

Errors

If the given value is out of bounds for has_endpoints.

pub fn has_endpoint_keys(&self) -> <bool as Specifier>::InOut

Returns the value of has_endpoint_keys.

pub fn has_endpoint_keys_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_endpoint_keys.

Errors

If the returned value contains an invalid bit pattern for has_endpoint_keys.

pub fn with_has_endpoint_keys(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_endpoint_keys set to the given value.

Panics

If the given value is out of bounds for has_endpoint_keys.

pub fn with_has_endpoint_keys_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_endpoint_keys set to the given value.

Errors

If the given value is out of bounds for has_endpoint_keys.

pub fn set_has_endpoint_keys(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_endpoint_keys to the given value.

Panics

If the given value is out of bounds for has_endpoint_keys.

pub fn set_has_endpoint_keys_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_endpoint_keys to the given value.

Errors

If the given value is out of bounds for has_endpoint_keys.