Module core

Module core 

Enums

CoreLibPointerId

Statics

CORE_LIB_TYPES
CORE_LIB_VALS

Functions

boolean
callable
create_core_lib_types
Creates a new instance of the core library as a ValueContainer including all core types as properties.
create_core_lib_vals
decimal
decimal_variant
endpoint
get_core_lib_type
get_core_lib_type_definition
get_core_lib_type_reference
get_core_lib_value
Retrieves either a core library type or value by its CoreLibPointerId.
integer
integer_variant
list
load_core_lib
Loads the core library into the provided memory instance.
map
never
null
print
range
text
ty
unit
unknown