run_async_thread

Macro run_async_thread 

macro_rules! run_async_thread {
    ($($body:tt)*) => { ... };
}
Spawns a thread that runs an async block using the Tokio runtime. The behavior is similar to run_async! {}, with the only difference being that it runs in a separate thread.