pub struct BlockHistoryData {
pub original_socket_uuid: Option<ComInterfaceSocketUUID>,
}Fields
original_socket_uuid: Option<ComInterfaceSocketUUID>if block originated from local endpoint, the socket uuid is None, otherwise it is the uuid of the incoming socket