ScopeContext

Struct ScopeContext 

pub struct ScopeContext {
    pub next_section_index: IncomingSectionIndex,
    pub next_block_number: IncomingBlockNumber,
    pub keep_alive_timestamp: u64,
    pub current_queue_sender: Option<UnboundedSender<DXBBlock>>,
    pub cached_blocks: BTreeMap<IncomingBlockNumber, DXBBlock>,
}

Fields

next_section_index: IncomingSectionIndexnext_block_number: IncomingBlockNumberkeep_alive_timestamp: u64

timestamp of the last keep alive block when a specific time has passed since the timestamp, the scope context is disposed TODO #171: implement dispose of scope context

current_queue_sender: Option<UnboundedSender<DXBBlock>>cached_blocks: BTreeMap<IncomingBlockNumber, DXBBlock>