pub enum InterfacePriority {
None,
Priority(u16),
}Variants
None
The interface will not be used for fallback routing if no other interface is available This is useful for interfaces which cannot communicate with the outside world or are not capable of redirecting large amounts of data
Priority(u16)
The interface will be used for fallback routing if no other interface is available, depending on the defined priority A higher number means a higher priority