pub enum ResponseResolutionStrategy {
ReturnAfterAllSettled,
ReturnOnAnyError,
ReturnOnFirstResponse,
ReturnOnFirstResult,
}Variants
ReturnAfterAllSettled
Promise.allSettled
- For know fixed receivers: return after all known sends are finished (either success or error if block could not be sent / timed out)
- For unknown receiver count: return after timeout
ReturnOnAnyError
Promise.all
- For know fixed receivers: return after all known sends are finished successfully return immediately if one send fails early (e.g. endpoint not reachable)
- For unknown receiver count: return after timeout
ReturnOnFirstResponse
Promise.any Return after first successful response received
ReturnOnFirstResult
Promise.race Return after first response received (success or error)