pub struct Parser { /* private fields */ }Implementations
Sourceimpl Parser
impl Parser
pub fn parse_list(&mut self) -> Result<DatexExpression, SpannedParserError>
Sourceimpl Parser
impl Parser
pub fn parse_map(&mut self) -> Result<DatexExpression, SpannedParserError>
Sourceimpl Parser
impl Parser
pub fn parse_type_list(&mut self) -> Result<TypeExpression, SpannedParserError>
Sourceimpl Parser
impl Parser
pub fn parse_type_map(&mut self) -> Result<TypeExpression, SpannedParserError>
Sourceimpl Parser
impl Parser
Sourcepub fn parse_collecting(src: &str, options: ParserOptions) -> ParserResult
pub fn parse_collecting(src: &str, options: ParserOptions) -> ParserResult
Parses the given source code. Collects all lexing and parsing errors encountered.
Sourcepub fn parse(
src: &str,
options: ParserOptions,
) -> Result<DatexExpression, SpannedParserError>
pub fn parse( src: &str, options: ParserOptions, ) -> Result<DatexExpression, SpannedParserError>
Parses the given source code. Aborts on the first lexing or parsing error encountered.
Sourcepub fn parse_with_default_options(
src: &str,
) -> Result<DatexExpression, SpannedParserError>
pub fn parse_with_default_options( src: &str, ) -> Result<DatexExpression, SpannedParserError>
Parses the given source code. Aborts on the first lexing or parsing error encountered. Uses default parser options.
Sourcepub fn parse_collecting_with_default_options(src: &str) -> ParserResult
pub fn parse_collecting_with_default_options(src: &str) -> ParserResult
Parses the given source code. Collects all lexing and parsing errors encountered. Uses default parser options.