Module utils

Module utils 

Enums

IntegerOrDecimal
IntegerOrTypedInteger

Functions

parse_integer_literal
Parses an integer literal with an integer part, an optional exponent part, and an optional variant suffix. Returns either an Integer or a Decimal value.
parse_integer_with_variant
unescape_text
Takes a literal text string input, e.g. ““Hello, world!”“ or “‘Hello, world!’ or ““x"”“ and returns the unescaped text, e.g. “Hello, world!” or ‘Hello, world!’ or “x"”