Module context

Module context 

Structs

LocalExecutionContext
RemoteExecutionContext

Enums

ExecutionContext
An execution context holds the persistent state for executing multiple scripts sequentially within the same context. This can be either a local context, which is used for executing scripts in the same process, or a remote context, which is used for executing scripts on a remote endpoint.
ExecutionMode
ScriptExecutionError