ExecutionContext

Enum ExecutionContext 

pub enum ExecutionContext {
    Local(LocalExecutionContext),
    Remote(RemoteExecutionContext),
}
An execution context holds the persistent state for executing multiple scripts sequentially within the same context. This can be either a local context, which is used for executing scripts in the same process, or a remote context, which is used for executing scripts on a remote endpoint.

Variants

Implementations

Source

impl ExecutionContext

pub fn local( execution_mode: ExecutionMode, runtime: Rc<RuntimeInternal>, ) -> Self

pub fn local_static(runtime: Rc<RuntimeInternal>) -> Self

Creates a new local static execution context (can only be used once).

pub fn local_unbounded(runtime: Rc<RuntimeInternal>) -> Self

Creates a new local execution context (can be used multiple times).

pub fn local_debug( execution_mode: ExecutionMode, runtime: Rc<RuntimeInternal>, ) -> Self

Creates a new local execution context with verbose mode enabled, providing more log outputs for debugging purposes.

Source

impl ExecutionContext

pub fn remote(endpoint: impl Into<Endpoint>) -> Self

pub fn remote_unbounded(endpoint: impl Into<Endpoint>) -> Self

Source

impl ExecutionContext

pub fn execute_dxb_sync( &mut self, dxb: &[u8], ) -> Result<Option<ValueContainer>, ExecutionError>

Executes DXB in a local execution context.

pub async fn execute_dxb( &mut self, dxb: &[u8], ) -> Result<Option<ValueContainer>, ExecutionError>

pub fn memory_dump(&self) -> Option<MemoryDump>

Returns a memory dump of the current state of the execution context if available.