Module execution_loop

Module execution_loop 

Modules

interrupts
state

Functions

execution_loop
Main execution loop that drives the execution of the DXB body The interrupt_provider is used to provide results for synchronous or asynchronous I/O operations
inner_execution_loop