pub enum ExecutionContext {
Local(LocalExecutionContext),
Remote(RemoteExecutionContext),
}Expand description
An execution context holds the persistent state for executing multiple scripts sequentially within the same context. This can be either a local context, which is used for executing scripts in the same process, or a remote context, which is used for executing scripts on a remote endpoint.
Variants
Local(LocalExecutionContext)
Remote(RemoteExecutionContext)
Implementations
Sourceimpl ExecutionContext
impl ExecutionContext
Sourcepub fn local_once() -> Self
pub fn local_once() -> Self
Creates a new local execution context (can only be used once).
Sourcepub fn local_with_runtime_internal(
runtime_internal: Rc<RuntimeInternal>,
once: bool,
) -> Self
pub fn local_with_runtime_internal( runtime_internal: Rc<RuntimeInternal>, once: bool, ) -> Self
Creates a new local execution context with a runtime.
Sourcepub fn local_debug(once: bool) -> Self
pub fn local_debug(once: bool) -> Self
Creates a new local execution context with verbose mode enabled, providing more log outputs for debugging purposes.
Sourcepub fn local_debug_with_runtime_internal(
runtime_internal: Rc<RuntimeInternal>,
once: bool,
) -> Self
pub fn local_debug_with_runtime_internal( runtime_internal: Rc<RuntimeInternal>, once: bool, ) -> Self
Creates a new local execution context with verbose mode enabled and a runtime.
pub fn remote_once(endpoint: impl Into<Endpoint>) -> Self
pub fn remote(endpoint: impl Into<Endpoint>) -> Self
Sourcepub fn compile(
&mut self,
script: &str,
inserted_values: &[ValueContainer],
) -> Result<Vec<u8>, CompilerError>
pub fn compile( &mut self, script: &str, inserted_values: &[ValueContainer], ) -> Result<Vec<u8>, CompilerError>
Compiles a script using the compile scope of the execution context
Sourcepub fn execute_dxb_sync(
&mut self,
dxb: &[u8],
end_execution: bool,
) -> Result<Option<ValueContainer>, ExecutionError>
pub fn execute_dxb_sync( &mut self, dxb: &[u8], end_execution: bool, ) -> Result<Option<ValueContainer>, ExecutionError>
Executes DXB in a local execution context.
Sourcepub fn execute_sync(
&mut self,
script: &str,
inserted_values: &[ValueContainer],
) -> Result<Option<ValueContainer>, ScriptExecutionError>
pub fn execute_sync( &mut self, script: &str, inserted_values: &[ValueContainer], ) -> Result<Option<ValueContainer>, ScriptExecutionError>
Executes a script in a local execution context.
pub async fn execute_dxb( &mut self, dxb: &[u8], end_execution: bool, ) -> Result<Option<ValueContainer>, ExecutionError>
pub async fn execute( &mut self, script: &str, inserted_values: &[ValueContainer], ) -> Result<Option<ValueContainer>, ScriptExecutionError>
Sourcepub fn memory_dump(&self) -> Option<MemoryDump>
pub fn memory_dump(&self) -> Option<MemoryDump>
Returns a memory dump of the current state of the execution context if available.