pub struct LocalExecutionContext { /* private fields */ }Implementations
Sourceimpl LocalExecutionContext
impl LocalExecutionContext
pub fn new(once: bool) -> Self
Sourcepub fn debug(once: bool) -> Self
pub fn debug(once: bool) -> Self
Creates a new local execution context with the given compile scope.
pub fn debug_with_runtime_internal( runtime_internal: Rc<RuntimeInternal>, once: bool, ) -> Self
pub fn new_with_runtime_internal( runtime_internal: Rc<RuntimeInternal>, once: bool, ) -> Self
pub fn set_runtime_internal(&mut self, runtime_internal: Rc<RuntimeInternal>)
Sourcepub fn memory_dump(&self) -> MemoryDump
pub fn memory_dump(&self) -> MemoryDump
Returns a memory dump of the current state of the execution context.