pub struct RuntimeRunner {
pub runtime: Runtime,
pub task_future: Pin<Box<dyn Future<Output = ()>>>,
}Fields
runtime: Runtimetask_future: Pin<Box<dyn Future<Output = ()>>>Implementations
Sourceimpl RuntimeRunner
impl RuntimeRunner
Sourcepub fn new(config: RuntimeConfig) -> RuntimeRunner
pub fn new(config: RuntimeConfig) -> RuntimeRunner
Creates a new runtime instance with the given configuration and global context. Note: If the endpoint is not specified in the config, a random endpoint will be generated.
pub async fn run<AppReturn, AppFuture>(
self,
app_logic: impl FnOnce(Runtime) -> AppFuture,
) -> AppReturnwhere
AppFuture: Future<Output = AppReturn>,