Module std_sync

Module std_sync 

Reexport of Mutex that works in both std and no_std environments.

Type Aliases

Mutex
A primitive that synchronizes the execution of multiple threads. See mutex::Mutex for documentation.