Ord

Trait Ord 

1.0.0 (const: unstable) · Source
pub trait Ord: Eq + PartialOrd {
    // Required method
    fn cmp(&self, other: &Self) -> Ordering;

    // Provided methods
    fn max(self, other: Self) -> Self
       where Self: Sized { ... }
    fn min(self, other: Self) -> Self
       where Self: Sized { ... }
    fn clamp(self, min: Self, max: Self) -> Self
       where Self: Sized { ... }
}
Trait for types that form a total order.

Implementations must be consistent with the PartialOrd implementation, and ensure max, min, and clamp are consistent with cmp:

  • partial_cmp(a, b) == Some(cmp(a, b)).
  • max(a, b) == max_by(a, b, cmp) (ensured by the default implementation).
  • min(a, b) == min_by(a, b, cmp) (ensured by the default implementation).
  • For a.clamp(min, max), see the method docs (ensured by the default implementation).

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Corollaries

From the above and the requirements of PartialOrd, it follows that for all a, b and c:

  • exactly one of a < b, a == b or a > b is true; and
  • < is transitive: a < b and b < c implies a < c. The same must hold for both == and >.

Mathematically speaking, the < operator defines a strict weak order. In cases where == conforms to mathematical equality, it also defines a strict total order.

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are ordered primarily by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

Lexicographical comparison

Lexicographical comparison is an operation with the following properties:

  • Two sequences are compared element by element.
  • The first mismatching element defines which sequence is lexicographically less or greater than the other.
  • If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
  • If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
  • An empty sequence is lexicographically less than any non-empty sequence.
  • Two empty sequences are lexicographically equal.

How can I implement Ord?

Ord requires that the type also be PartialOrd, PartialEq, and Eq.

Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and PartialOrd must agree, you must choose how to implement Ord first. You can choose to derive it, or implement it manually. If you derive it, you should derive all four traits. If you implement it manually, you should manually implement all four traits, based on the implementation of Ord.

Here’s an example where you want to define the Character comparison by health and experience only, disregarding the field mana:

use std::cmp::Ordering;

struct Character {
    health: u32,
    experience: u32,
    mana: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> Ordering {
        self.experience
            .cmp(&other.experience)
            .then(self.health.cmp(&other.health))
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health && self.experience == other.experience
    }
}

impl Eq for Character {}

If all you need is to slice::sort a type by a field value, it can be simpler to use slice::sort_by_key.

Examples of incorrect Ord implementations

use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < other.health {
            Ordering::Less
        } else if self.health > other.health {
            Ordering::Greater
        } else {
            Ordering::Equal
        }
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health
    }
}

impl Eq for Character {}

let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };

// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.

// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);
use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < 50 {
            self.health.cmp(&other.health)
        } else {
            self.experience.cmp(&other.experience)
        }
    }
}

// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.cmp(other) == Ordering::Equal
    }
}

impl Eq for Character {}

let a = Character {
    health: 3,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};
let c = Character {
    health: 143,
    experience: 2,
};

// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.

// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);

The documentation of PartialOrd contains further examples, for example it’s wrong for PartialOrd and PartialEq to disagree.

Required Methods

1.0.0 · Source

fn cmp(&self, other: &Self) -> Ordering

This method returns an Ordering between self and other.

By convention, self.cmp(&other) returns the ordering matching the expression self <operator> other if true.

Examples
use std::cmp::Ordering;

assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);

Provided Methods

1.21.0 · Source

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values.

Returns the second argument if the comparison determines them to be equal.

Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").max(Equal("other")).0, "other");
1.21.0 · Source

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values.

Returns the first argument if the comparison determines them to be equal.

Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").min(Equal("other")).0, "self");
1.50.0 · Source

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval.

Returns max if self is greater than max, and min if self is less than min. Otherwise this returns self.

Panics

Panics if min > max.

Examples
assert_eq!((-3).clamp(-2, 1), -2);
assert_eq!(0.clamp(-2, 1), 0);
assert_eq!(2.clamp(-2, 1), 1);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Ord for InterfacePriority

Source

impl Ord for AsciiChar

1.34.0 (const: unstable) · Source

impl Ord for Infallible

1.0.0 · Source

impl Ord for ErrorKind

1.7.0 · Source

impl Ord for IpAddr

1.0.0 · Source

impl Ord for SocketAddr

1.0.0 (const: unstable) · Source

impl Ord for Ordering

Source

impl Ord for ASN1TimeZone

Source

impl Ord for LineEnding

Source

impl Ord for byteorder::BigEndian

Source

impl Ord for byteorder::LittleEndian

Source

impl Ord for chrono::month::Month

Source

impl Ord for const_oid::error::Error

Source

impl Ord for Class

Source

impl Ord for der::tag::Tag

Source

impl Ord for TagMode

Source

impl Ord for ExtensionType

Source

impl Ord for GeneralCategory

Source

impl Ord for IpAddrRange

Source

impl Ord for IpNet

Source

impl Ord for IpSubnets

Source

impl Ord for log::Level

Source

impl Ord for log::LevelFilter

Source

impl Ord for GlobPattern

Source

impl Ord for InsertError

Source

impl Ord for PosixFadviseAdvice

Source

impl Ord for AioFsyncMode

Source

impl Ord for LioMode

Source

impl Ord for MmapAdvise

Source

impl Ord for Event

Source

impl Ord for Request

Source

impl Ord for QuotaFmt

Source

impl Ord for QuotaType

Source

impl Ord for RebootMode

Source

impl Ord for Resource

Source

impl Ord for UsageWho

Source

impl Ord for SigmaskHow

Source

impl Ord for Signal

Source

impl Ord for BaudRate

Source

impl Ord for FlowArg

Source

impl Ord for FlushArg

Source

impl Ord for SetArg

Source

impl Ord for SpecialCharacterIndices

Source

impl Ord for nix::sys::timerfd::ClockId

Source

impl Ord for nix::sys::wait::Id

Source

impl Ord for Sign

Source

impl Ord for Utf8Sequence

Source

impl Ord for Contract

Source

impl Ord for time::month::Month

Source

impl Ord for Yaml

Source

impl Ord for PCBit

Source

impl Ord for TagClass

Source

impl Ord for BERMode

Source

impl Ord for zerocopy::byteorder::BigEndian

Source

impl Ord for zerocopy::byteorder::LittleEndian

1.0.0 (const: unstable) · Source

impl Ord for bool

1.0.0 (const: unstable) · Source

impl Ord for char

1.0.0 (const: unstable) · Source

impl Ord for i8

1.0.0 (const: unstable) · Source

impl Ord for i16

1.0.0 (const: unstable) · Source

impl Ord for i32

1.0.0 (const: unstable) · Source

impl Ord for i64

1.0.0 (const: unstable) · Source

impl Ord for i128

1.0.0 (const: unstable) · Source

impl Ord for isize

Source

impl Ord for !

1.0.0 · Source

impl Ord for str

Implements ordering of strings.

Strings are ordered lexicographically by their byte values. This orders Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Sorting strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl Ord for u8

1.0.0 (const: unstable) · Source

impl Ord for u16

1.0.0 (const: unstable) · Source

impl Ord for u32

1.0.0 (const: unstable) · Source

impl Ord for u64

1.0.0 (const: unstable) · Source

impl Ord for u128

1.0.0 (const: unstable) · Source

impl Ord for ()

1.0.0 (const: unstable) · Source

impl Ord for usize

1.3.0 · Source

impl Ord for datex_core::time::Duration

1.8.0 · Source

impl Ord for datex_core::time::Instant

1.8.0 · Source

impl Ord for SystemTime

1.0.0 · Source

impl Ord for TypeId

1.27.0 · Source

impl Ord for CpuidResult

Source

impl Ord for ByteStr

Source

impl Ord for ByteString

1.0.0 · Source

impl Ord for CStr

1.64.0 · Source

impl Ord for CString

1.0.0 · Source

impl Ord for OsStr

1.0.0 · Source

impl Ord for OsString

1.0.0 · Source

impl Ord for datex_core::stdlib::fmt::Error

1.33.0 · Source

impl Ord for PhantomPinned

1.0.0 · Source

impl Ord for Ipv4Addr

1.0.0 · Source

impl Ord for Ipv6Addr

1.0.0 · Source

impl Ord for SocketAddrV4

1.0.0 · Source

impl Ord for SocketAddrV6

1.10.0 · Source

impl Ord for Location<'_>

1.0.0 · Source

impl Ord for Components<'_>

1.0.0 · Source

impl Ord for Path

1.0.0 · Source

impl Ord for PathBuf

1.0.0 · Source

impl Ord for PrefixComponent<'_>

Source

impl Ord for Alignment

1.0.0 · Source

impl Ord for String

Source

impl Ord for aead::Error

Source

impl Ord for aho_corasick::util::primitives::PatternID

Source

impl Ord for aho_corasick::util::primitives::StateID

Source

impl Ord for asn1_rs::asn1_types::generalizedtime::GeneralizedTime

Source

impl Ord for asn1_rs::asn1_types::utctime::UtcTime

Source

impl Ord for ASN1DateTime

Source

impl Ord for Base64Bcrypt

Source

impl Ord for Base64Crypt

Source

impl Ord for Base64ShaCrypt

Source

impl Ord for Base64

Source

impl Ord for Base64Unpadded

Source

impl Ord for Base64Url

Source

impl Ord for Base64UrlUnpadded

Source

impl Ord for BigDecimal

Source

impl Ord for BigDecimalRef<'_>

Source

impl Ord for Bytes

Source

impl Ord for BytesMut

Source

impl Ord for Months

Source

impl Ord for NaiveDate

Source

impl Ord for NaiveDateDaysIterator

Source

impl Ord for NaiveDateWeeksIterator

Source

impl Ord for NaiveDateTime

Source

impl Ord for IsoWeek

Source

impl Ord for Days

Source

impl Ord for NaiveTime

Source

impl Ord for TimeDelta

Source

impl Ord for WeekdaySet

Source

impl Ord for const_oid::ObjectIdentifier

Source

impl Ord for Limb

Source

impl Ord for Any

Source

impl Ord for BitString

Source

impl Ord for BmpString

Source

impl Ord for der::asn1::generalized_time::GeneralizedTime

Source

impl Ord for Ia5String

Source

impl Ord for Int

Source

impl Ord for der::asn1::integer::uint::allocating::Uint

Source

impl Ord for Null

Source

impl Ord for OctetString

Source

impl Ord for PrintableString

Source

impl Ord for TeletexString

Source

impl Ord for der::asn1::utc_time::UtcTime

Source

impl Ord for der::datetime::DateTime

Source

impl Ord for IndefiniteLength

Source

impl Ord for Length

Source

impl Ord for TagNumber

Source

impl Ord for RecoveryId

Source

impl Ord for Errno

Source

impl Ord for HeaderValue

Source

impl Ord for StatusCode

Source

impl Ord for Version

Source

impl Ord for HttpDate

Source

impl Ord for ReasonPhrase

Source

impl Ord for Other

Source

impl Ord for icu_locale_core::extensions::private::other::Subtag

Source

impl Ord for Private

Source

impl Ord for Fields

Source

impl Ord for icu_locale_core::extensions::transform::key::Key

Source

impl Ord for icu_locale_core::extensions::transform::value::Value

Source

impl Ord for Attribute

Source

impl Ord for Attributes

Source

impl Ord for icu_locale_core::extensions::unicode::key::Key

Source

impl Ord for Keywords

Source

impl Ord for SubdivisionId

Source

impl Ord for SubdivisionSuffix

Source

impl Ord for icu_locale_core::extensions::unicode::value::Value

Source

impl Ord for Language

Source

impl Ord for Region

Source

impl Ord for icu_locale_core::subtags::script::Script

Source

impl Ord for icu_locale_core::subtags::Subtag

Source

impl Ord for Variant

Source

impl Ord for Variants

Source

impl Ord for GeneralCategoryULE

Source

impl Ord for BidiClass

Source

impl Ord for CanonicalCombiningClass

Source

impl Ord for EastAsianWidth

Source

impl Ord for GeneralCategoryOutOfBoundsError

Source

impl Ord for GraphemeClusterBreak

Source

impl Ord for HangulSyllableType

Source

impl Ord for IndicConjunctBreak

Source

impl Ord for IndicSyllabicCategory

Source

impl Ord for JoiningType

Source

impl Ord for LineBreak

Source

impl Ord for icu_properties::props::Script

Source

impl Ord for SentenceBreak

Source

impl Ord for VerticalOrientation

Source

impl Ord for WordBreak

Source

impl Ord for DataMarkerId

Source

impl Ord for DataMarkerIdHash

Source

impl Ord for DataMarkerInfo

Source

impl Ord for DataMarkerAttributes

Source

impl Ord for DataRequestMetadata

Source

impl Ord for Ipv4AddrRange

Source

impl Ord for Ipv6AddrRange

Source

impl Ord for Ipv4Net

Source

impl Ord for Ipv4Subnets

Source

impl Ord for Ipv6Net

Source

impl Ord for Ipv6Subnets

Source

impl Ord for DiagnosticSeverity

Source

impl Ord for DidChangeWatchedFilesRegistrationOptions

Source

impl Ord for FileSystemWatcher

Source

impl Ord for lsp_types::Position

Source

impl Ord for RelativePattern

Source

impl Ord for WatchKind

Source

impl Ord for WorkspaceFolder

Source

impl Ord for Mime

Source

impl Ord for Interest

Source

impl Ord for Token

Source

impl Ord for AtFlags

Source

impl Ord for FallocateFlags

Source

impl Ord for FdFlag

Source

impl Ord for OFlag

Source

impl Ord for RenameFlags

Source

impl Ord for SealFlag

Source

impl Ord for SpliceFFlags

Source

impl Ord for DeleteModuleFlags

Source

impl Ord for ModuleInitFlags

Source

impl Ord for MntFlags

Source

impl Ord for nix::mount::linux::MsFlags

Source

impl Ord for MQ_OFlag

Source

impl Ord for InterfaceFlags

Source

impl Ord for PollFlags

Source

impl Ord for CloneFlags

Source

impl Ord for EpollCreateFlags

Source

impl Ord for EpollFlags

Source

impl Ord for EfdFlags

Source

impl Ord for AddWatchFlags

Source

impl Ord for InitFlags

Source

impl Ord for WatchDescriptor

Source

impl Ord for MemFdCreateFlag

Source

impl Ord for MRemapFlags

Source

impl Ord for MapFlags

Source

impl Ord for MlockAllFlags

Source

impl Ord for nix::sys::mman::MsFlags

Source

impl Ord for ProtFlags

Source

impl Ord for Persona

Source

impl Ord for Options

Source

impl Ord for QuotaValidFlags

Source

impl Ord for SaFlags

Source

impl Ord for SfdFlags

Source

impl Ord for MsgFlags

Source

impl Ord for SockFlag

Source

impl Ord for TimestampingFlag

Source

impl Ord for Mode

Source

impl Ord for SFlag

Source

impl Ord for FsFlags

Source

impl Ord for ControlFlags

Source

impl Ord for InputFlags

Source

impl Ord for LocalFlags

Source

impl Ord for OutputFlags

Source

impl Ord for TimeSpec

Source

impl Ord for TimeVal

Source

impl Ord for TimerSetTimeFlags

Source

impl Ord for TimerFlags

Source

impl Ord for WaitPidFlag

Source

impl Ord for nix::time::ClockId

Source

impl Ord for AccessFlags

Source

impl Ord for Pid

Source

impl Ord for BigInt

Source

impl Ord for BigUint

Source

impl Ord for Asn1Integer

Source

impl Ord for Asn1IntegerRef

Source

impl Ord for BigNum

Source

impl Ord for BigNumRef

Source

impl Ord for CMSOptions

Source

impl Ord for OcspFlag

Source

impl Ord for Pkcs7Flags

Source

impl Ord for ExtensionContext

Source

impl Ord for ShutdownState

Source

impl Ord for SslMode

Source

impl Ord for SslOptions

Source

impl Ord for SslSessionCacheMode

Source

impl Ord for SslVerifyMode

Source

impl Ord for X509

Source

impl Ord for X509Ref

Source

impl Ord for X509CheckFlags

Source

impl Ord for X509VerifyFlags

Source

impl Ord for p256::arithmetic::scalar::Scalar

Source

impl Ord for NistP256

Source

impl Ord for p384::arithmetic::scalar::Scalar

Source

impl Ord for NistP384

Source

impl Ord for Integer

Source

impl Ord for PotentialCodePoint

Source

impl Ord for PotentialUtf8

Source

impl Ord for PotentialUtf16

Source

impl Ord for LazyStateID

Source

impl Ord for Unit

Source

impl Ord for NonMaxUsize

Source

impl Ord for regex_automata::util::primitives::PatternID

Source

impl Ord for SmallIndex

Source

impl Ord for regex_automata::util::primitives::StateID

Source

impl Ord for regex_syntax::ast::Position

Source

impl Ord for Span

Source

impl Ord for Literal

Source

impl Ord for ClassBytesRange

Source

impl Ord for ClassUnicodeRange

Source

impl Ord for Utf8Range

Source

impl Ord for UnixTime

Source

impl Ord for SigId

Source

impl Ord for SmolStr

Source

impl Ord for FontStyle

Source

impl Ord for MatchPower

Source

impl Ord for Scope

Source

impl Ord for time::date::Date

Source

impl Ord for time::duration::Duration

Source

impl Ord for OffsetDateTime

Source

impl Ord for PrimitiveDateTime

Source

impl Ord for Time

Source

impl Ord for UtcDateTime

Source

impl Ord for UtcOffset

Source

impl Ord for AnyDelimiterCodec

Source

impl Ord for BytesCodec

Source

impl Ord for LinesCodec

Source

impl Ord for Ready

Source

impl Ord for tokio::runtime::task::id::Id

Source

impl Ord for tokio::time::instant::Instant

Source

impl Ord for tracing_core::metadata::Level

Source

impl Ord for tracing_core::metadata::LevelFilter

Source

impl Ord for ATerm

Source

impl Ord for B0

Source

impl Ord for B1

Source

impl Ord for Z0

Source

impl Ord for Equal

Source

impl Ord for Greater

Source

impl Ord for Less

Source

impl Ord for UTerm

Source

impl Ord for Url

URLs compare like their serialization.

Source

impl Ord for Braced

Source

impl Ord for Hyphenated

Source

impl Ord for Simple

Source

impl Ord for Urn

Source

impl Ord for Uuid

Source

impl Ord for ASN1Time

Source

impl Ord for TaggedDerValue

Source

impl Ord for yasna::models::oid::ObjectIdentifier

Source

impl Ord for yasna::models::time::GeneralizedTime

Source

impl Ord for UTCTime

Source

impl Ord for yasna::Tag

Source

impl Ord for CharULE

Source

impl Ord for Index8

Source

impl Ord for Index16

Source

impl Ord for Index32

1.0.0 · Source

impl<'a> Ord for Component<'a>

1.0.0 · Source

impl<'a> Ord for datex_core::stdlib::path::Prefix<'a>

Source

impl<'a> Ord for PrefixDeclaration<'a>

Source

impl<'a> Ord for PhantomContravariantLifetime<'a>

Source

impl<'a> Ord for PhantomCovariantLifetime<'a>

Source

impl<'a> Ord for PhantomInvariantLifetime<'a>

Source

impl<'a> Ord for AnyRef<'a>

Source

impl<'a> Ord for BitStringRef<'a>

Source

impl<'a> Ord for Ia5StringRef<'a>

Source

impl<'a> Ord for IntRef<'a>

Source

impl<'a> Ord for UintRef<'a>

Source

impl<'a> Ord for OctetStringRef<'a>

Source

impl<'a> Ord for PrintableStringRef<'a>

Source

impl<'a> Ord for TeletexStringRef<'a>

Source

impl<'a> Ord for Utf8StringRef<'a>

Source

impl<'a> Ord for VideotexStringRef<'a>

Source

impl<'a> Ord for Metadata<'a>

Source

impl<'a> Ord for MetadataBuilder<'a>

Source

impl<'a> Ord for Name<'a>

Source

impl<'a> Ord for LocalName<'a>

Source

impl<'a> Ord for Namespace<'a>

Source

impl<'a> Ord for quick_xml::name::Prefix<'a>

Source

impl<'a> Ord for QName<'a>

Source

impl<'a, T> Ord for ContextSpecificRef<'a, T>
where T: Ord,

Source

impl<'a, T> Ord for ZeroVec<'a, T>
where T: AsULE + Ord,

Source

impl<'a, T, F> Ord for VarZeroVec<'a, T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,

Source

impl<'a, V> Ord for VarZeroCow<'a, V>
where V: VarULE + Ord + ?Sized,

Source

impl<'k, 'v> Ord for Params<'k, 'v>

1.0.0 (const: unstable) · Source

impl<A> Ord for &A
where A: Ord + ?Sized,

1.0.0 (const: unstable) · Source

impl<A> Ord for &mut A
where A: Ord + ?Sized,

Source

impl<A> Ord for ArrayString<A>
where A: Array<Item = u8> + Copy,

Source

impl<A> Ord for ArrayVec<A>
where A: Array, <A as Array>::Item: Ord,

Source

impl<A> Ord for SmallVec<A>
where A: Array, <A as Array>::Item: Ord,

Source

impl<A, B> Ord for OneOf<A, B>
where A: Ord, B: Ord,

Source

impl<A, B> Ord for Tuple2ULE<A, B>
where A: Ord + ULE, B: Ord + ULE,

Source

impl<A, B> Ord for VarTuple<A, B>
where A: Ord, B: Ord,

Source

impl<A, B, C> Ord for Tuple3ULE<A, B, C>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE,

Source

impl<A, B, C, D> Ord for Tuple4ULE<A, B, C, D>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE,

Source

impl<A, B, C, D, E> Ord for Tuple5ULE<A, B, C, D, E>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE,

Source

impl<A, B, C, D, E, F> Ord for Tuple6ULE<A, B, C, D, E, F>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE, F: Ord + ULE,

Source

impl<A, B, C, D, E, F, Format> Ord for Tuple6VarULE<A, B, C, D, E, F, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, F: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, D, E, Format> Ord for Tuple5VarULE<A, B, C, D, E, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, D, Format> Ord for Tuple4VarULE<A, B, C, D, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, Format> Ord for Tuple3VarULE<A, B, C, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, Format> Ord for Tuple2VarULE<A, B, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, V> Ord for VarTupleULE<A, V>
where A: Ord + AsULE, V: Ord + VarULE + ?Sized, <A as AsULE>::ULE: Ord,

1.0.0 · Source

impl<B> Ord for Cow<'_, B>
where B: Ord + ToOwned + ?Sized,

Source

impl<B> Ord for BitSet<B>
where B: BitBlock,

Source

impl<B> Ord for BitVec<B>
where B: BitBlock,

Source

impl<C> Ord for VerifyingKey<C>

Source

impl<C> Ord for PublicKey<C>

Available on crate feature sec1 only.
Source

impl<C> Ord for ScalarPrimitive<C>
where C: Curve,

Source

impl<Dyn> Ord for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Ord for F
where F: FnPtr,

Source

impl<K, V> Ord for indexmap::map::slice::Slice<K, V>
where K: Ord, V: Ord,

Source

impl<K, V> Ord for ringmap::map::slice::Slice<K, V>
where K: Ord, V: Ord,

1.0.0 · Source

impl<K, V, A> Ord for BTreeMap<K, V, A>
where K: Ord, V: Ord, A: Allocator + Clone,

Source

impl<K, V, S> Ord for LinkedHashMap<K, V, S>
where K: Hash + Eq + Ord, V: Ord, S: BuildHasher,

Source

impl<K, V, S> Ord for LiteMap<K, V, S>
where K: Ord + ?Sized, V: Ord + ?Sized, S: Ord,

Source

impl<K, V, S> Ord for RingMap<K, V, S>
where K: Ord, V: Ord,

Source

impl<L, R> Ord for Either<L, R>
where L: Ord, R: Ord,

Source

impl<O> Ord for I16<O>
where O: ByteOrder,

Source

impl<O> Ord for I32<O>
where O: ByteOrder,

Source

impl<O> Ord for I64<O>
where O: ByteOrder,

Source

impl<O> Ord for I128<O>
where O: ByteOrder,

Source

impl<O> Ord for Isize<O>
where O: ByteOrder,

Source

impl<O> Ord for U16<O>
where O: ByteOrder,

Source

impl<O> Ord for U32<O>
where O: ByteOrder,

Source

impl<O> Ord for U64<O>
where O: ByteOrder,

Source

impl<O> Ord for U128<O>
where O: ByteOrder,

Source

impl<O> Ord for Usize<O>
where O: ByteOrder,

Source

impl<Params> Ord for AlgorithmIdentifier<Params>
where Params: Ord,

1.41.0 · Source

impl<Ptr> Ord for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Ord,

Source

impl<S> Ord for Host<S>
where S: Ord,

Source

impl<Size> Ord for EncodedPoint<Size>
where Size: ModulusSize,

1.0.0 (const: unstable) · Source

impl<T> Ord for Option<T>
where T: Ord,

1.36.0 · Source

impl<T> Ord for Poll<T>
where T: Ord,

Source

impl<T> Ord for Attr<T>
where T: Ord,

1.0.0 · Source

impl<T> Ord for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> Ord for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 · Source

impl<T> Ord for [T]
where T: Ord,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> Ord for (T₁, T₂, …, Tₙ)
where T: Ord,

This trait is implemented for tuples up to twelve items long.

1.10.0 · Source

impl<T> Ord for Cell<T>
where T: Ord + Copy,

1.10.0 · Source

impl<T> Ord for RefCell<T>
where T: Ord + ?Sized,

Source

impl<T> Ord for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Ord for PhantomData<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Ord for ManuallyDrop<T>
where T: Ord + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> Ord for datex_core::stdlib::num::NonZero<T>

1.74.0 · Source

impl<T> Ord for Saturating<T>
where T: Ord,

1.0.0 · Source

impl<T> Ord for datex_core::stdlib::num::Wrapping<T>
where T: Ord,

1.25.0 · Source

impl<T> Ord for NonNull<T>
where T: ?Sized,

Source

impl<T> Ord for Exclusive<T>
where T: Sync + Ord + ?Sized,

Source

impl<T> Ord for Constant<T>
where T: Ord,

Source

impl<T> Ord for CapacityError<T>
where T: Ord,

Source

impl<T> Ord for crypto_bigint::non_zero::NonZero<T>
where T: Ord + Zero,

Source

impl<T> Ord for crypto_bigint::wrapping::Wrapping<T>
where T: Ord,

Source

impl<T> Ord for ContextSpecific<T>
where T: Ord,

Source

impl<T> Ord for SetOfVec<T>
where T: Ord + DerOrd,

Source

impl<T> Ord for AllowStdIo<T>
where T: Ord,

Source

impl<T> Ord for indexmap::set::slice::Slice<T>
where T: Ord,

Source

impl<T> Ord for Intern<T>
where T: Eq + Hash + Send + Sync + Ord + ?Sized,

Source

impl<T> Ord for Ratio<T>
where T: Clone + Integer,

Source

impl<T> Ord for NotNan<T>
where T: FloatCore,

Source

impl<T> Ord for OrderedFloat<T>
where T: FloatCore,

Source

impl<T> Ord for ringmap::set::slice::Slice<T>
where T: Ord,

Source

impl<T> Ord for TryWriteableInfallibleAsWriteable<T>
where T: Ord,

Source

impl<T> Ord for WriteableAsTryWriteableInfallible<T>
where T: Ord,

Source

impl<T> Ord for Unalign<T>
where T: Unaligned + Ord,

Source

impl<T> Ord for ZeroSlice<T>
where T: AsULE + Ord,

1.19.0 (const: unstable) · Source

impl<T> Ord for Reverse<T>
where T: Ord,

1.0.0 · Source

impl<T, A> Ord for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Ord for LinkedList<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for VecDeque<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for datex_core::stdlib::boxed::Box<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Rc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueRc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Arc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueArc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for datex_core::stdlib::vec::Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

Source

impl<T, A> Ord for allocator_api2::stable::boxed::Box<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for allocator_api2::stable::vec::Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

Source

impl<T, B> Ord for Ref<B, T>

1.0.0 (const: unstable) · Source

impl<T, E> Ord for Result<T, E>
where T: Ord, E: Ord,

Source

impl<T, F> Ord for VarZeroSlice<T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,

Source

impl<T, N> Ord for GenericArray<T, N>
where T: Ord, N: ArrayLength<T>,

Source

impl<T, S> Ord for RingSet<T, S>
where T: Ord,

1.0.0 · Source

impl<T, const N: usize> Ord for [T; N]
where T: Ord,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> Ord for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<T, const N: usize> Ord for SetOf<T, N>
where T: Ord + DerOrd,

Source

impl<Tz> Ord for chrono::date::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz> Ord for chrono::datetime::DateTime<Tz>
where Tz: TimeZone,

Source

impl<U> Ord for NInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U> Ord for PInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U> Ord for OptionVarULE<U>
where U: VarULE + Ord + ?Sized,

Source

impl<U, B> Ord for UInt<U, B>
where U: Ord, B: Ord,

Source

impl<U, const N: usize> Ord for NichedOption<U, N>
where U: Ord,

Source

impl<V, A> Ord for TArr<V, A>
where V: Ord, A: Ord,

Source

impl<Y, R> Ord for CoroutineState<Y, R>
where Y: Ord, R: Ord,

Source

impl<const LIMBS: usize> Ord for crypto_bigint::uint::Uint<LIMBS>

Source

impl<const MIN: i8, const MAX: i8> Ord for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Ord for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Ord for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Ord for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Ord for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Ord for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Ord for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Ord for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Ord for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Ord for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Ord for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Ord for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Ord for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Ord for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Ord for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Ord for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Ord for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Ord for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Ord for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Ord for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Ord for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Ord for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Ord for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Ord for RangedUsize<MIN, MAX>

Source

impl<const N: usize> Ord for TinyAsciiStr<N>

Source

impl<const N: usize> Ord for UnvalidatedTinyAsciiStr<N>

Source

impl<const N: usize> Ord for RawBytesULE<N>

Source

impl<const SIZE: usize> Ord for WriteBuffer<SIZE>