PartialOrd

Trait PartialOrd 

1.0.0 (const: unstable) · Source
pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>
where Rhs: ?Sized,
{ // Required method fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>; // Provided methods fn lt(&self, other: &Rhs) -> bool { ... } fn le(&self, other: &Rhs) -> bool { ... } fn gt(&self, other: &Rhs) -> bool { ... } fn ge(&self, other: &Rhs) -> bool { ... } }
Trait for types that form a partial order.

The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and >= operators, respectively.

This trait should only contain the comparison logic for a type if one plans on only implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord and this trait implemented with Some(self.cmp(other)).

The methods of this trait must be consistent with each other and with those of PartialEq. The following conditions must hold:

  1. a == b if and only if partial_cmp(a, b) == Some(Equal).
  2. a < b if and only if partial_cmp(a, b) == Some(Less)
  3. a > b if and only if partial_cmp(a, b) == Some(Greater)
  4. a <= b if and only if a < b || a == b
  5. a >= b if and only if a > b || a == b
  6. a != b if and only if !(a == b).

Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured by PartialEq.

If Ord is also implemented for Self and Rhs, it must also be consistent with partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The comparison relations must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Transitivity: if A: PartialOrd<B> and B: PartialOrd<C> and A: PartialOrd<C>, then a < b and b < c implies a < c. The same must hold for both == and >. This must also work for longer chains, such as when A: PartialOrd<B>, B: PartialOrd<C>, C: PartialOrd<D>, and A: PartialOrd<D> all exist.
  • Duality: if A: PartialOrd<B> and B: PartialOrd<A>, then a < b if and only if b > a.

Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialOrd for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should not do impl PartialOrd<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T < U. In other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that “stitch together” comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialOrd implementations can cause build failures in downstream crates.

Corollaries

The following corollaries follow from the above requirements:

  • irreflexivity of < and >: !(a < a), !(a > a)
  • transitivity of >: if a > b and b > c then a > c
  • duality of partial_cmp: partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)

Strict and non-strict partial orders

The < and > operators behave according to a strict partial order. However, <= and >= do not behave according to a non-strict partial order. That is because mathematically, a non-strict partial order would require reflexivity, i.e. a <= a would need to be true for every a. This isn’t always the case for types that implement PartialOrd, for example:

let a = f64::sqrt(-1.0);
assert_eq!(a <= a, false);

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are primarily ordered by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, PartialOrd)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

How can I implement PartialOrd?

PartialOrd only requires implementation of the partial_cmp method, with the others generated from default implementations.

However it remains possible to implement the others separately for types which do not have a total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false (cf. IEEE 754-2008 section 5.11).

PartialOrd requires your type to be PartialEq.

If your type is Ord, you can implement partial_cmp by using cmp:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: u32,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Person {
    fn cmp(&self, other: &Self) -> Ordering {
        self.height.cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

impl Eq for Person {}

You may also find it useful to use partial_cmp on your type’s fields. Here is an example of Person types who have a floating-point height field that is the only field to be used for sorting:

use std::cmp::Ordering;

struct Person {
    id: u32,
    name: String,
    height: f64,
}

impl PartialOrd for Person {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        self.height.partial_cmp(&other.height)
    }
}

impl PartialEq for Person {
    fn eq(&self, other: &Self) -> bool {
        self.height == other.height
    }
}

Examples of incorrect PartialOrd implementations

use std::cmp::Ordering;

#[derive(PartialEq, Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.health.cmp(&other.health))
    }
}

let a = Character {
    health: 10,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};

// Mistake: `PartialEq` and `PartialOrd` disagree with each other.

assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);

Required Methods

1.0.0 · Source

fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>

This method returns an ordering between self and other values if one exists.

Examples
use std::cmp::Ordering;

let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));

let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));

let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));

When comparison is impossible:

let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);

Provided Methods

1.0.0 · Source

fn lt(&self, other: &Rhs) -> bool

Tests less than (for self and other) and is used by the < operator.

Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);
1.0.0 · Source

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator.

Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);
1.0.0 · Source

fn gt(&self, other: &Rhs) -> bool

Tests greater than (for self and other) and is used by the > operator.

Examples
assert_eq!(1.0 > 1.0, false);
assert_eq!(1.0 > 2.0, false);
assert_eq!(2.0 > 1.0, true);
1.0.0 · Source

fn ge(&self, other: &Rhs) -> bool

Tests greater than or equal to (for self and other) and is used by the >= operator.

Examples
assert_eq!(1.0 >= 1.0, true);
assert_eq!(1.0 >= 2.0, false);
assert_eq!(2.0 >= 1.0, true);

Implementors

Source

impl PartialOrd for InterfacePriority

Source

impl PartialOrd for AsciiChar

1.34.0 (const: unstable) · Source

impl PartialOrd for Infallible

1.0.0 · Source

impl PartialOrd for ErrorKind

1.7.0 · Source

impl PartialOrd for IpAddr

1.0.0 · Source

impl PartialOrd for SocketAddr

1.0.0 (const: unstable) · Source

impl PartialOrd for Ordering

Source

impl PartialOrd for ASN1TimeZone

Source

impl PartialOrd for LineEnding

Source

impl PartialOrd for byteorder::BigEndian

Source

impl PartialOrd for byteorder::LittleEndian

Source

impl PartialOrd for chrono::month::Month

Source

impl PartialOrd for const_oid::error::Error

Source

impl PartialOrd for Class

Source

impl PartialOrd for der::tag::Tag

Source

impl PartialOrd for TagMode

Source

impl PartialOrd for ExtensionType

Source

impl PartialOrd for GeneralCategory

Source

impl PartialOrd for IpAddrRange

Source

impl PartialOrd for IpNet

Source

impl PartialOrd for IpSubnets

Source

impl PartialOrd for log::Level

Source

impl PartialOrd for log::LevelFilter

Source

impl PartialOrd for GlobPattern

Source

impl PartialOrd for InsertError

Source

impl PartialOrd for PosixFadviseAdvice

Source

impl PartialOrd for AioFsyncMode

Source

impl PartialOrd for LioMode

Source

impl PartialOrd for MmapAdvise

Source

impl PartialOrd for Event

Source

impl PartialOrd for Request

Source

impl PartialOrd for QuotaFmt

Source

impl PartialOrd for QuotaType

Source

impl PartialOrd for RebootMode

Source

impl PartialOrd for Resource

Source

impl PartialOrd for UsageWho

Source

impl PartialOrd for SigmaskHow

Source

impl PartialOrd for Signal

Source

impl PartialOrd for BaudRate

Source

impl PartialOrd for FlowArg

Source

impl PartialOrd for FlushArg

Source

impl PartialOrd for SetArg

Source

impl PartialOrd for SpecialCharacterIndices

Source

impl PartialOrd for nix::sys::timerfd::ClockId

Source

impl PartialOrd for nix::sys::wait::Id

Source

impl PartialOrd for Sign

Source

impl PartialOrd for Utf8Sequence

Source

impl PartialOrd for Contract

Source

impl PartialOrd for time::month::Month

Source

impl PartialOrd for Section

Source

impl PartialOrd for Yaml

Source

impl PartialOrd for PCBit

Source

impl PartialOrd for TagClass

Source

impl PartialOrd for BERMode

Source

impl PartialOrd for zerocopy::byteorder::BigEndian

Source

impl PartialOrd for zerocopy::byteorder::LittleEndian

1.0.0 (const: unstable) · Source

impl PartialOrd for bool

1.0.0 (const: unstable) · Source

impl PartialOrd for char

1.0.0 (const: unstable) · Source

impl PartialOrd for f16

1.0.0 (const: unstable) · Source

impl PartialOrd for f32

1.0.0 (const: unstable) · Source

impl PartialOrd for f64

1.0.0 (const: unstable) · Source

impl PartialOrd for f128

1.0.0 (const: unstable) · Source

impl PartialOrd for i8

1.0.0 (const: unstable) · Source

impl PartialOrd for i16

1.0.0 (const: unstable) · Source

impl PartialOrd for i32

1.0.0 (const: unstable) · Source

impl PartialOrd for i64

1.0.0 (const: unstable) · Source

impl PartialOrd for i128

1.0.0 (const: unstable) · Source

impl PartialOrd for isize

Source

impl PartialOrd for !

1.0.0 · Source

impl PartialOrd for str

Implements comparison operations on strings.

Strings are compared lexicographically by their byte values. This compares Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Comparing strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl PartialOrd for u8

1.0.0 (const: unstable) · Source

impl PartialOrd for u16

1.0.0 (const: unstable) · Source

impl PartialOrd for u32

1.0.0 (const: unstable) · Source

impl PartialOrd for u64

1.0.0 (const: unstable) · Source

impl PartialOrd for u128

1.0.0 (const: unstable) · Source

impl PartialOrd for ()

1.0.0 (const: unstable) · Source

impl PartialOrd for usize

1.3.0 · Source

impl PartialOrd for datex_core::time::Duration

1.8.0 · Source

impl PartialOrd for datex_core::time::Instant

1.8.0 · Source

impl PartialOrd for SystemTime

1.0.0 · Source

impl PartialOrd for TypeId

1.27.0 · Source

impl PartialOrd for CpuidResult

Source

impl PartialOrd for ByteStr

Source

impl PartialOrd for ByteString

1.0.0 · Source

impl PartialOrd for CStr

1.64.0 · Source

impl PartialOrd for CString

1.0.0 · Source

impl PartialOrd for OsStr

1.0.0 · Source

impl PartialOrd for OsString

1.0.0 · Source

impl PartialOrd for datex_core::stdlib::fmt::Error

1.33.0 · Source

impl PartialOrd for PhantomPinned

1.0.0 · Source

impl PartialOrd for Ipv4Addr

1.0.0 · Source

impl PartialOrd for Ipv6Addr

1.0.0 · Source

impl PartialOrd for SocketAddrV4

1.0.0 · Source

impl PartialOrd for SocketAddrV6

1.10.0 · Source

impl PartialOrd for Location<'_>

1.0.0 · Source

impl PartialOrd for Path

1.0.0 · Source

impl PartialOrd for PathBuf

Source

impl PartialOrd for Alignment

1.0.0 · Source

impl PartialOrd for String

Source

impl PartialOrd for aead::Error

Source

impl PartialOrd for aho_corasick::util::primitives::PatternID

Source

impl PartialOrd for aho_corasick::util::primitives::StateID

Source

impl PartialOrd for asn1_rs::asn1_types::generalizedtime::GeneralizedTime

Source

impl PartialOrd for asn1_rs::asn1_types::utctime::UtcTime

Source

impl PartialOrd for ASN1DateTime

Source

impl PartialOrd for Base64Bcrypt

Source

impl PartialOrd for Base64Crypt

Source

impl PartialOrd for Base64ShaCrypt

Source

impl PartialOrd for Base64

Source

impl PartialOrd for Base64Unpadded

Source

impl PartialOrd for Base64Url

Source

impl PartialOrd for Base64UrlUnpadded

Source

impl PartialOrd for BigDecimal

Source

impl PartialOrd for BigDecimalRef<'_>

Source

impl PartialOrd for Bytes

Source

impl PartialOrd for BytesMut

Source

impl PartialOrd for Months

Source

impl PartialOrd for NaiveDate

Source

impl PartialOrd for NaiveDateDaysIterator

Source

impl PartialOrd for NaiveDateWeeksIterator

Source

impl PartialOrd for NaiveDateTime

Source

impl PartialOrd for IsoWeek

Source

impl PartialOrd for Days

Source

impl PartialOrd for NaiveTime

Source

impl PartialOrd for TimeDelta

Source

impl PartialOrd for WeekdaySet

Source

impl PartialOrd for const_oid::ObjectIdentifier

Source

impl PartialOrd for Limb

Source

impl PartialOrd for Any

Source

impl PartialOrd for BitString

Source

impl PartialOrd for BmpString

Source

impl PartialOrd for der::asn1::generalized_time::GeneralizedTime

Source

impl PartialOrd for Ia5String

Source

impl PartialOrd for Int

Source

impl PartialOrd for der::asn1::integer::uint::allocating::Uint

Source

impl PartialOrd for Null

Source

impl PartialOrd for OctetString

Source

impl PartialOrd for PrintableString

Source

impl PartialOrd for TeletexString

Source

impl PartialOrd for der::asn1::utc_time::UtcTime

Source

impl PartialOrd for der::datetime::DateTime

Source

impl PartialOrd for IndefiniteLength

Source

impl PartialOrd for Length

Source

impl PartialOrd for TagNumber

Source

impl PartialOrd for RecoveryId

Source

impl PartialOrd for Errno

Source

impl PartialOrd for HeaderValue

Source

impl PartialOrd for StatusCode

Source

impl PartialOrd for Authority

Case-insensitive ordering

Examples

let authority: Authority = "DEF.com".parse().unwrap();
assert!(authority < "ghi.com");
assert!(authority > "abc.com");
Source

impl PartialOrd for PathAndQuery

Source

impl PartialOrd for Version

Source

impl PartialOrd for HttpDate

Source

impl PartialOrd for ReasonPhrase

Source

impl PartialOrd for Other

Source

impl PartialOrd for icu_locale_core::extensions::private::other::Subtag

Source

impl PartialOrd for Private

Source

impl PartialOrd for Fields

Source

impl PartialOrd for icu_locale_core::extensions::transform::key::Key

Source

impl PartialOrd for icu_locale_core::extensions::transform::value::Value

Source

impl PartialOrd for Attribute

Source

impl PartialOrd for Attributes

Source

impl PartialOrd for icu_locale_core::extensions::unicode::key::Key

Source

impl PartialOrd for Keywords

Source

impl PartialOrd for SubdivisionId

Source

impl PartialOrd for SubdivisionSuffix

Source

impl PartialOrd for icu_locale_core::extensions::unicode::value::Value

Source

impl PartialOrd for Language

Source

impl PartialOrd for Region

Source

impl PartialOrd for icu_locale_core::subtags::script::Script

Source

impl PartialOrd for icu_locale_core::subtags::Subtag

Source

impl PartialOrd for Variant

Source

impl PartialOrd for Variants

Source

impl PartialOrd for GeneralCategoryULE

Source

impl PartialOrd for BidiClass

Source

impl PartialOrd for CanonicalCombiningClass

Source

impl PartialOrd for EastAsianWidth

Source

impl PartialOrd for GeneralCategoryOutOfBoundsError

Source

impl PartialOrd for GraphemeClusterBreak

Source

impl PartialOrd for HangulSyllableType

Source

impl PartialOrd for IndicConjunctBreak

Source

impl PartialOrd for IndicSyllabicCategory

Source

impl PartialOrd for JoiningType

Source

impl PartialOrd for LineBreak

Source

impl PartialOrd for icu_properties::props::Script

Source

impl PartialOrd for SentenceBreak

Source

impl PartialOrd for VerticalOrientation

Source

impl PartialOrd for WordBreak

Source

impl PartialOrd for DataMarkerId

Source

impl PartialOrd for DataMarkerIdHash

Source

impl PartialOrd for DataMarkerInfo

Source

impl PartialOrd for DataMarkerAttributes

Source

impl PartialOrd for DataRequestMetadata

Source

impl PartialOrd for Ipv4AddrRange

Source

impl PartialOrd for Ipv6AddrRange

Source

impl PartialOrd for Ipv4Net

Source

impl PartialOrd for Ipv4Subnets

Source

impl PartialOrd for Ipv6Net

Source

impl PartialOrd for Ipv6Subnets

Source

impl PartialOrd for CodeActionKind

Source

impl PartialOrd for SemanticTokenModifier

Source

impl PartialOrd for SemanticTokenType

Source

impl PartialOrd for TokenFormat

Source

impl PartialOrd for DiagnosticSeverity

Source

impl PartialOrd for DidChangeWatchedFilesRegistrationOptions

Source

impl PartialOrd for FileSystemWatcher

Source

impl PartialOrd for lsp_types::Position

Source

impl PartialOrd for PositionEncodingKind

Source

impl PartialOrd for RelativePattern

Source

impl PartialOrd for WatchKind

Source

impl PartialOrd for WorkspaceFolder

Source

impl PartialOrd for Mime

Source

impl PartialOrd for Interest

Source

impl PartialOrd for Token

Source

impl PartialOrd for AtFlags

Source

impl PartialOrd for FallocateFlags

Source

impl PartialOrd for FdFlag

Source

impl PartialOrd for OFlag

Source

impl PartialOrd for RenameFlags

Source

impl PartialOrd for SealFlag

Source

impl PartialOrd for SpliceFFlags

Source

impl PartialOrd for DeleteModuleFlags

Source

impl PartialOrd for ModuleInitFlags

Source

impl PartialOrd for MntFlags

Source

impl PartialOrd for nix::mount::linux::MsFlags

Source

impl PartialOrd for MQ_OFlag

Source

impl PartialOrd for InterfaceFlags

Source

impl PartialOrd for PollFlags

Source

impl PartialOrd for CloneFlags

Source

impl PartialOrd for EpollCreateFlags

Source

impl PartialOrd for EpollFlags

Source

impl PartialOrd for EfdFlags

Source

impl PartialOrd for AddWatchFlags

Source

impl PartialOrd for InitFlags

Source

impl PartialOrd for WatchDescriptor

Source

impl PartialOrd for MemFdCreateFlag

Source

impl PartialOrd for MRemapFlags

Source

impl PartialOrd for MapFlags

Source

impl PartialOrd for MlockAllFlags

Source

impl PartialOrd for nix::sys::mman::MsFlags

Source

impl PartialOrd for ProtFlags

Source

impl PartialOrd for Persona

Source

impl PartialOrd for Options

Source

impl PartialOrd for QuotaValidFlags

Source

impl PartialOrd for SaFlags

Source

impl PartialOrd for SfdFlags

Source

impl PartialOrd for MsgFlags

Source

impl PartialOrd for SockFlag

Source

impl PartialOrd for TimestampingFlag

Source

impl PartialOrd for Mode

Source

impl PartialOrd for SFlag

Source

impl PartialOrd for FsFlags

Source

impl PartialOrd for ControlFlags

Source

impl PartialOrd for InputFlags

Source

impl PartialOrd for LocalFlags

Source

impl PartialOrd for OutputFlags

Source

impl PartialOrd for TimeSpec

Source

impl PartialOrd for TimeVal

Source

impl PartialOrd for TimerSetTimeFlags

Source

impl PartialOrd for TimerFlags

Source

impl PartialOrd for WaitPidFlag

Source

impl PartialOrd for nix::time::ClockId

Source

impl PartialOrd for AccessFlags

Source

impl PartialOrd for Pid

Source

impl PartialOrd for BigInt

Source

impl PartialOrd for BigUint

Source

impl PartialOrd for Asn1Integer

Source

impl PartialOrd for Asn1IntegerRef

Source

impl PartialOrd for Asn1Time

Source

impl PartialOrd for Asn1TimeRef

Source

impl PartialOrd for BigNum

Source

impl PartialOrd for BigNumRef

Source

impl PartialOrd for CMSOptions

Source

impl PartialOrd for OcspFlag

Source

impl PartialOrd for Pkcs7Flags

Source

impl PartialOrd for ExtensionContext

Source

impl PartialOrd for ShutdownState

Source

impl PartialOrd for SslMode

Source

impl PartialOrd for SslOptions

Source

impl PartialOrd for SslSessionCacheMode

Source

impl PartialOrd for SslVerifyMode

Source

impl PartialOrd for X509

Source

impl PartialOrd for X509Ref

Source

impl PartialOrd for X509CheckFlags

Source

impl PartialOrd for X509VerifyFlags

Source

impl PartialOrd for p256::arithmetic::scalar::Scalar

Source

impl PartialOrd for NistP256

Source

impl PartialOrd for p384::arithmetic::scalar::Scalar

Source

impl PartialOrd for NistP384

Source

impl PartialOrd for Integer

Source

impl PartialOrd for PotentialCodePoint

Source

impl PartialOrd for PotentialUtf8

Source

impl PartialOrd for PotentialUtf16

Source

impl PartialOrd for LazyStateID

Source

impl PartialOrd for Unit

Source

impl PartialOrd for NonMaxUsize

Source

impl PartialOrd for regex_automata::util::primitives::PatternID

Source

impl PartialOrd for SmallIndex

Source

impl PartialOrd for regex_automata::util::primitives::StateID

Source

impl PartialOrd for regex_syntax::ast::Position

Source

impl PartialOrd for Span

Source

impl PartialOrd for Literal

Source

impl PartialOrd for ClassBytesRange

Source

impl PartialOrd for ClassUnicodeRange

Source

impl PartialOrd for Utf8Range

Source

impl PartialOrd for UnixTime

Source

impl PartialOrd for SigId

Source

impl PartialOrd for SmolStr

Source

impl PartialOrd for FontStyle

Source

impl PartialOrd for MatchPower

Source

impl PartialOrd for Scope

Source

impl PartialOrd for time::date::Date

Source

impl PartialOrd for time::duration::Duration

Source

impl PartialOrd for OffsetDateTime

Source

impl PartialOrd for PrimitiveDateTime

Source

impl PartialOrd for Time

Source

impl PartialOrd for UtcDateTime

Source

impl PartialOrd for UtcOffset

Source

impl PartialOrd for AnyDelimiterCodec

Source

impl PartialOrd for BytesCodec

Source

impl PartialOrd for LinesCodec

Source

impl PartialOrd for Ready

Source

impl PartialOrd for tokio::runtime::task::id::Id

Source

impl PartialOrd for tokio::time::instant::Instant

Source

impl PartialOrd for tracing_core::metadata::Level

Source

impl PartialOrd for tracing_core::metadata::LevelFilter

Source

impl PartialOrd for ATerm

Source

impl PartialOrd for B0

Source

impl PartialOrd for B1

Source

impl PartialOrd for Z0

Source

impl PartialOrd for Equal

Source

impl PartialOrd for Greater

Source

impl PartialOrd for Less

Source

impl PartialOrd for UTerm

Source

impl PartialOrd for Url

URLs compare like their serialization.

Source

impl PartialOrd for Braced

Source

impl PartialOrd for Hyphenated

Source

impl PartialOrd for Simple

Source

impl PartialOrd for Urn

Source

impl PartialOrd for Uuid

Source

impl PartialOrd for ASN1Time

Source

impl PartialOrd for TaggedDerValue

Source

impl PartialOrd for yasna::models::oid::ObjectIdentifier

Source

impl PartialOrd for yasna::models::time::GeneralizedTime

Source

impl PartialOrd for UTCTime

Source

impl PartialOrd for yasna::Tag

Source

impl PartialOrd for CharULE

Source

impl PartialOrd for Index8

Source

impl PartialOrd for Index16

Source

impl PartialOrd for Index32

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialOrd<IpAddr> for Ipv6Addr

Source

impl PartialOrd<Level> for log::LevelFilter

Source

impl PartialOrd<LevelFilter> for log::Level

Source

impl PartialOrd<char> for PotentialCodePoint

Source

impl PartialOrd<i8> for &BigDecimal

Source

impl PartialOrd<i8> for BigDecimal

Source

impl PartialOrd<i8> for BigDecimalRef<'_>

Source

impl PartialOrd<i16> for &BigDecimal

Source

impl PartialOrd<i16> for BigDecimal

Source

impl PartialOrd<i16> for BigDecimalRef<'_>

Source

impl PartialOrd<i32> for &BigDecimal

Source

impl PartialOrd<i32> for BigDecimal

Source

impl PartialOrd<i32> for BigDecimalRef<'_>

Source

impl PartialOrd<i64> for &BigDecimal

Source

impl PartialOrd<i64> for BigDecimal

Source

impl PartialOrd<i64> for BigDecimalRef<'_>

Source

impl PartialOrd<i128> for &BigDecimal

Source

impl PartialOrd<i128> for BigDecimal

Source

impl PartialOrd<i128> for BigDecimalRef<'_>

1.0.0 · Source

impl PartialOrd<str> for OsStr

1.0.0 · Source

impl PartialOrd<str> for OsString

Source

impl PartialOrd<str> for Bytes

Source

impl PartialOrd<str> for BytesMut

Source

impl PartialOrd<str> for HeaderValue

Source

impl PartialOrd<str> for Authority

Source

impl PartialOrd<str> for PathAndQuery

Source

impl PartialOrd<str> for PotentialUtf8

Source

impl PartialOrd<u8> for &BigDecimal

Source

impl PartialOrd<u8> for BigDecimal

Source

impl PartialOrd<u8> for BigDecimalRef<'_>

Source

impl PartialOrd<u16> for &BigDecimal

Source

impl PartialOrd<u16> for BigDecimal

Source

impl PartialOrd<u16> for BigDecimalRef<'_>

Source

impl PartialOrd<u32> for &BigDecimal

Source

impl PartialOrd<u32> for BigDecimal

Source

impl PartialOrd<u32> for BigDecimalRef<'_>

Source

impl PartialOrd<u64> for &BigDecimal

Source

impl PartialOrd<u64> for BigDecimal

Source

impl PartialOrd<u64> for BigDecimalRef<'_>

Source

impl PartialOrd<u128> for &BigDecimal

Source

impl PartialOrd<u128> for BigDecimal

Source

impl PartialOrd<u128> for BigDecimalRef<'_>

Source

impl PartialOrd<Duration> for time::duration::Duration

Source

impl PartialOrd<SystemTime> for OffsetDateTime

Source

impl PartialOrd<SystemTime> for UtcDateTime

1.8.0 · Source

impl PartialOrd<OsStr> for Path

1.8.0 · Source

impl PartialOrd<OsStr> for PathBuf

1.8.0 · Source

impl PartialOrd<OsString> for Path

1.8.0 · Source

impl PartialOrd<OsString> for PathBuf

1.16.0 · Source

impl PartialOrd<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialOrd<Ipv6Addr> for IpAddr

1.8.0 · Source

impl PartialOrd<Path> for OsStr

1.8.0 · Source

impl PartialOrd<Path> for OsString

1.8.0 · Source

impl PartialOrd<Path> for PathBuf

1.8.0 · Source

impl PartialOrd<PathBuf> for OsStr

1.8.0 · Source

impl PartialOrd<PathBuf> for OsString

1.8.0 · Source

impl PartialOrd<PathBuf> for Path

Source

impl PartialOrd<String> for Bytes

Source

impl PartialOrd<String> for BytesMut

Source

impl PartialOrd<String> for HeaderValue

Source

impl PartialOrd<String> for Authority

Source

impl PartialOrd<String> for PathAndQuery

Source

impl PartialOrd<Vec<u8>> for Bytes

Source

impl PartialOrd<Vec<u8>> for BytesMut

Source

impl PartialOrd<Bytes> for &str

Source

impl PartialOrd<Bytes> for &[u8]

Source

impl PartialOrd<Bytes> for str

Source

impl PartialOrd<Bytes> for String

Source

impl PartialOrd<Bytes> for datex_core::stdlib::vec::Vec<u8>

Source

impl PartialOrd<Bytes> for [u8]

Source

impl PartialOrd<BytesMut> for &str

Source

impl PartialOrd<BytesMut> for &[u8]

Source

impl PartialOrd<BytesMut> for str

Source

impl PartialOrd<BytesMut> for String

Source

impl PartialOrd<BytesMut> for datex_core::stdlib::vec::Vec<u8>

Source

impl PartialOrd<BytesMut> for [u8]

Source

impl PartialOrd<HeaderValue> for str

Source

impl PartialOrd<HeaderValue> for String

Source

impl PartialOrd<HeaderValue> for [u8]

Source

impl PartialOrd<Authority> for str

Source

impl PartialOrd<Authority> for String

Source

impl PartialOrd<PathAndQuery> for str

Source

impl PartialOrd<PathAndQuery> for String

Source

impl PartialOrd<Asn1Time> for &Asn1TimeRef

Source

impl PartialOrd<Asn1Time> for Asn1TimeRef

Source

impl PartialOrd<Asn1TimeRef> for Asn1Time

Source

impl PartialOrd<BigNum> for BigNumRef

Source

impl PartialOrd<BigNumRef> for BigNum

Source

impl PartialOrd<X509> for X509Ref

Source

impl PartialOrd<X509Ref> for X509

Source

impl PartialOrd<PotentialCodePoint> for char

Source

impl PartialOrd<PotentialUtf8> for str

Source

impl PartialOrd<Duration> for datex_core::time::Duration

Source

impl PartialOrd<OffsetDateTime> for SystemTime

Source

impl PartialOrd<OffsetDateTime> for UtcDateTime

Source

impl PartialOrd<UtcDateTime> for SystemTime

Source

impl PartialOrd<UtcDateTime> for OffsetDateTime

Source

impl PartialOrd<Level> for tracing_core::metadata::LevelFilter

Source

impl PartialOrd<LevelFilter> for tracing_core::metadata::Level

Source

impl PartialOrd<[u8]> for Bytes

Source

impl PartialOrd<[u8]> for BytesMut

Source

impl PartialOrd<[u8]> for HeaderValue

1.0.0 · Source

impl<'a> PartialOrd for Component<'a>

1.0.0 · Source

impl<'a> PartialOrd for datex_core::stdlib::path::Prefix<'a>

Source

impl<'a> PartialOrd for PrefixDeclaration<'a>

Source

impl<'a> PartialOrd for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialOrd for PhantomInvariantLifetime<'a>

1.0.0 · Source

impl<'a> PartialOrd for Components<'a>

1.0.0 · Source

impl<'a> PartialOrd for PrefixComponent<'a>

Source

impl<'a> PartialOrd for AnyRef<'a>

Source

impl<'a> PartialOrd for BitStringRef<'a>

Source

impl<'a> PartialOrd for Ia5StringRef<'a>

Source

impl<'a> PartialOrd for IntRef<'a>

Source

impl<'a> PartialOrd for UintRef<'a>

Source

impl<'a> PartialOrd for OctetStringRef<'a>

Source

impl<'a> PartialOrd for PrintableStringRef<'a>

Source

impl<'a> PartialOrd for TeletexStringRef<'a>

Source

impl<'a> PartialOrd for Utf8StringRef<'a>

Source

impl<'a> PartialOrd for VideotexStringRef<'a>

Source

impl<'a> PartialOrd for Metadata<'a>

Source

impl<'a> PartialOrd for MetadataBuilder<'a>

Source

impl<'a> PartialOrd for Name<'a>

Source

impl<'a> PartialOrd for LocalName<'a>

Source

impl<'a> PartialOrd for Namespace<'a>

Source

impl<'a> PartialOrd for quick_xml::name::Prefix<'a>

Source

impl<'a> PartialOrd for QName<'a>

Source

impl<'a> PartialOrd<&'a str> for Authority

Source

impl<'a> PartialOrd<&'a str> for PathAndQuery

Source

impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, str>

Source

impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, ByteStr>

Source

impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, [u8]>

1.8.0 · Source

impl<'a> PartialOrd<&'a OsStr> for Path

1.8.0 · Source

impl<'a> PartialOrd<&'a OsStr> for PathBuf

1.8.0 · Source

impl<'a> PartialOrd<&'a Path> for OsStr

1.8.0 · Source

impl<'a> PartialOrd<&'a Path> for OsString

1.8.0 · Source

impl<'a> PartialOrd<&'a Path> for PathBuf

Source

impl<'a> PartialOrd<&'a Asn1TimeRef> for Asn1Time

Source

impl<'a> PartialOrd<&ByteStr> for ByteString

Source

impl<'a> PartialOrd<Cow<'_, str>> for ByteString

Source

impl<'a> PartialOrd<Cow<'_, ByteStr>> for ByteString

Source

impl<'a> PartialOrd<Cow<'_, [u8]>> for ByteString

Source

impl<'a> PartialOrd<Cow<'a, str>> for &'a ByteStr

Source

impl<'a> PartialOrd<Cow<'a, ByteStr>> for &'a ByteStr

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, OsStr>> for Path

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, OsStr>> for PathBuf

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, Path>> for OsStr

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, Path>> for OsString

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, Path>> for Path

1.8.0 · Source

impl<'a> PartialOrd<Cow<'a, Path>> for PathBuf

Source

impl<'a> PartialOrd<Cow<'a, [u8]>> for &'a ByteStr

Source

impl<'a> PartialOrd<ByteStr> for ByteString

Source

impl<'a> PartialOrd<ByteString> for &ByteStr

Source

impl<'a> PartialOrd<ByteString> for Cow<'_, str>

Source

impl<'a> PartialOrd<ByteString> for Cow<'_, ByteStr>

Source

impl<'a> PartialOrd<ByteString> for Cow<'_, [u8]>

Source

impl<'a> PartialOrd<ByteString> for ByteStr

1.8.0 · Source

impl<'a> PartialOrd<OsStr> for &'a Path

1.8.0 · Source

impl<'a> PartialOrd<OsStr> for Cow<'a, Path>

1.8.0 · Source

impl<'a> PartialOrd<OsString> for &'a Path

1.8.0 · Source

impl<'a> PartialOrd<OsString> for Cow<'a, Path>

1.8.0 · Source

impl<'a> PartialOrd<Path> for &'a OsStr

1.8.0 · Source

impl<'a> PartialOrd<Path> for Cow<'a, OsStr>

1.8.0 · Source

impl<'a> PartialOrd<Path> for Cow<'a, Path>

1.8.0 · Source

impl<'a> PartialOrd<PathBuf> for &'a OsStr

1.8.0 · Source

impl<'a> PartialOrd<PathBuf> for &'a Path

1.8.0 · Source

impl<'a> PartialOrd<PathBuf> for Cow<'a, OsStr>

1.8.0 · Source

impl<'a> PartialOrd<PathBuf> for Cow<'a, Path>

Source

impl<'a> PartialOrd<HeaderValue> for &'a str

Source

impl<'a> PartialOrd<HeaderValue> for &'a HeaderValue

Source

impl<'a> PartialOrd<Authority> for &'a str

Source

impl<'a> PartialOrd<PathAndQuery> for &'a str

1.8.0 · Source

impl<'a, 'b> PartialOrd<&'a OsStr> for OsString

1.8.0 · Source

impl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>

1.8.0 · Source

impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, OsStr>

1.8.0 · Source

impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, Path>

1.8.0 · Source

impl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for &'b OsStr

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsStr

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsString

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b OsStr

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path

1.8.0 · Source

impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path

1.8.0 · Source

impl<'a, 'b> PartialOrd<OsStr> for Cow<'a, OsStr>

1.8.0 · Source

impl<'a, 'b> PartialOrd<OsStr> for OsString

1.8.0 · Source

impl<'a, 'b> PartialOrd<OsString> for &'a OsStr

1.8.0 · Source

impl<'a, 'b> PartialOrd<OsString> for Cow<'a, OsStr>

1.8.0 · Source

impl<'a, 'b> PartialOrd<OsString> for OsStr

1.0.0 · Source

impl<'a, B> PartialOrd for Cow<'a, B>
where B: PartialOrd + ToOwned + ?Sized,

Source

impl<'a, T> PartialOrd for ContextSpecificRef<'a, T>
where T: PartialOrd,

Source

impl<'a, T> PartialOrd for ZeroVec<'a, T>
where T: AsULE + PartialOrd,

Source

impl<'a, T> PartialOrd<&'a T> for Bytes
where Bytes: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T> PartialOrd<&'a T> for BytesMut
where BytesMut: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T> PartialOrd<&'a T> for HeaderValue
where HeaderValue: PartialOrd<T>, T: ?Sized,

Source

impl<'a, T, F> PartialOrd for VarZeroVec<'a, T, F>

Source

impl<'a, V> PartialOrd for VarZeroCow<'a, V>
where V: VarULE + PartialOrd + ?Sized,

Source

impl<'k, 'v> PartialOrd for Params<'k, 'v>

Source

impl<A> PartialOrd for ArrayString<A>
where A: Array<Item = u8> + Copy,

Source

impl<A> PartialOrd for ArrayVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

Source

impl<A> PartialOrd for SmallVec<A>
where A: Array, <A as Array>::Item: PartialOrd,

Source

impl<A> PartialOrd<str> for ArrayString<A>
where A: Array<Item = u8> + Copy,

Source

impl<A> PartialOrd<ArrayString<A>> for str
where A: Array<Item = u8> + Copy,

Source

impl<A, B> PartialOrd for OneOf<A, B>
where A: PartialOrd, B: PartialOrd,

Source

impl<A, B> PartialOrd for Tuple2ULE<A, B>
where A: PartialOrd + ULE, B: PartialOrd + ULE,

Source

impl<A, B> PartialOrd for VarTuple<A, B>
where A: PartialOrd, B: PartialOrd,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&B> for &A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialOrd<&mut B> for &mut A
where A: PartialOrd<B> + ?Sized, B: ?Sized,

Source

impl<A, B, C> PartialOrd for Tuple3ULE<A, B, C>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE,

Source

impl<A, B, C, D> PartialOrd for Tuple4ULE<A, B, C, D>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE,

Source

impl<A, B, C, D, E> PartialOrd for Tuple5ULE<A, B, C, D, E>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE, E: PartialOrd + ULE,

Source

impl<A, B, C, D, E, F> PartialOrd for Tuple6ULE<A, B, C, D, E, F>
where A: PartialOrd + ULE, B: PartialOrd + ULE, C: PartialOrd + ULE, D: PartialOrd + ULE, E: PartialOrd + ULE, F: PartialOrd + ULE,

Source

impl<A, B, C, D, E, F, Format> PartialOrd for Tuple6VarULE<A, B, C, D, E, F, Format>

Source

impl<A, B, C, D, E, Format> PartialOrd for Tuple5VarULE<A, B, C, D, E, Format>

Source

impl<A, B, C, D, Format> PartialOrd for Tuple4VarULE<A, B, C, D, Format>

Source

impl<A, B, C, Format> PartialOrd for Tuple3VarULE<A, B, C, Format>

Source

impl<A, B, Format> PartialOrd for Tuple2VarULE<A, B, Format>
where A: PartialOrd + VarULE + ?Sized, B: PartialOrd + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, V> PartialOrd for VarTupleULE<A, V>
where A: PartialOrd + AsULE, V: PartialOrd + VarULE + ?Sized, <A as AsULE>::ULE: PartialOrd,

Source

impl<B> PartialOrd for BitSet<B>
where B: BitBlock,

Source

impl<B> PartialOrd for BitVec<B>
where B: BitBlock,

Source

impl<C> PartialOrd for VerifyingKey<C>

Source

impl<C> PartialOrd for PublicKey<C>

Available on crate feature sec1 only.
Source

impl<C> PartialOrd for ScalarPrimitive<C>
where C: Curve,

Source

impl<Dyn> PartialOrd for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> PartialOrd for F
where F: FnPtr,

Source

impl<K, V> PartialOrd for indexmap::map::slice::Slice<K, V>
where K: PartialOrd, V: PartialOrd,

Source

impl<K, V> PartialOrd for ringmap::map::slice::Slice<K, V>
where K: PartialOrd, V: PartialOrd,

1.0.0 · Source

impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
where K: PartialOrd, V: PartialOrd, A: Allocator + Clone,

Source

impl<K, V, S1, S2> PartialOrd<RingMap<K, V, S2>> for RingMap<K, V, S1>
where K: PartialOrd, V: PartialOrd,

Source

impl<K, V, S> PartialOrd for LinkedHashMap<K, V, S>
where K: Hash + Eq + PartialOrd, V: PartialOrd, S: BuildHasher,

Source

impl<K, V, S> PartialOrd for LiteMap<K, V, S>
where K: PartialOrd + ?Sized, V: PartialOrd + ?Sized, S: PartialOrd,

Source

impl<L, R> PartialOrd for Either<L, R>
where L: PartialOrd, R: PartialOrd,

Source

impl<O> PartialOrd for F32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for F64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for I128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for Isize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for U128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd for Usize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i16> for I16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i32> for I32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i64> for I64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<i128> for I128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<isize> for Isize<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u16> for U16<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u32> for U32<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u64> for U64<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<u128> for U128<O>
where O: ByteOrder,

Source

impl<O> PartialOrd<usize> for Usize<O>
where O: ByteOrder,

Source

impl<Params> PartialOrd for AlgorithmIdentifier<Params>
where Params: PartialOrd,

1.41.0 · Source

impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialOrd<<Q as Deref>::Target>,

Source

impl<S> PartialOrd for Host<S>
where S: PartialOrd,

Source

impl<Size> PartialOrd for EncodedPoint<Size>
where Size: ModulusSize,

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for Option<T>
where T: PartialOrd,

1.36.0 · Source

impl<T> PartialOrd for Poll<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for Attr<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> PartialOrd for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 · Source

impl<T> PartialOrd for [T]
where T: PartialOrd,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> PartialOrd for (T₁, T₂, …, Tₙ)
where T: PartialOrd,

This trait is implemented for tuples up to twelve items long.

1.10.0 · Source

impl<T> PartialOrd for Cell<T>
where T: PartialOrd + Copy,

1.10.0 · Source

impl<T> PartialOrd for RefCell<T>
where T: PartialOrd + ?Sized,

Source

impl<T> PartialOrd for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialOrd for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialOrd for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> PartialOrd for ManuallyDrop<T>
where T: PartialOrd + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialOrd for datex_core::stdlib::num::NonZero<T>

1.74.0 · Source

impl<T> PartialOrd for Saturating<T>
where T: PartialOrd,

1.0.0 · Source

impl<T> PartialOrd for datex_core::stdlib::num::Wrapping<T>
where T: PartialOrd,

1.25.0 · Source

impl<T> PartialOrd for NonNull<T>
where T: ?Sized,

Source

impl<T> PartialOrd for Constant<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for CapacityError<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for crypto_bigint::non_zero::NonZero<T>
where T: PartialOrd + Zero,

Source

impl<T> PartialOrd for crypto_bigint::wrapping::Wrapping<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for ContextSpecific<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for SetOfVec<T>
where T: PartialOrd + DerOrd,

Source

impl<T> PartialOrd for AllowStdIo<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for indexmap::set::slice::Slice<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for Intern<T>
where T: Eq + Hash + Send + Sync + PartialOrd + ?Sized,

Source

impl<T> PartialOrd for Ratio<T>
where T: Clone + Integer,

Source

impl<T> PartialOrd for NotNan<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for OrderedFloat<T>
where T: FloatCore,

Source

impl<T> PartialOrd for ringmap::set::slice::Slice<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for TryWriteableInfallibleAsWriteable<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for WriteableAsTryWriteableInfallible<T>
where T: PartialOrd,

Source

impl<T> PartialOrd for Unalign<T>
where T: Unaligned + PartialOrd,

Source

impl<T> PartialOrd for ZeroSlice<T>
where T: AsULE + PartialOrd,

1.19.0 (const: unstable) · Source

impl<T> PartialOrd for Reverse<T>
where T: PartialOrd,

1.0.0 · Source

impl<T, A1, A2> PartialOrd<Vec<T, A2>> for datex_core::stdlib::vec::Vec<T, A1>
where T: PartialOrd, A1: Allocator, A2: Allocator,

Implements comparison of vectors, lexicographically.

1.0.0 · Source

impl<T, A> PartialOrd for BTreeSet<T, A>
where T: PartialOrd, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> PartialOrd for LinkedList<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for VecDeque<T, A>
where T: PartialOrd, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for datex_core::stdlib::boxed::Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Rc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueRc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialOrd for Arc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for UniqueArc<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for allocator_api2::stable::boxed::Box<T, A>
where T: PartialOrd + ?Sized, A: Allocator,

Source

impl<T, A> PartialOrd for allocator_api2::stable::vec::Vec<T, A>
where T: PartialOrd, A: Allocator,

Implements comparison of vectors, lexicographically.

Source

impl<T, B> PartialOrd for Ref<B, T>

1.0.0 (const: unstable) · Source

impl<T, E> PartialOrd for Result<T, E>
where T: PartialOrd, E: PartialOrd,

Source

impl<T, F> PartialOrd for VarZeroSlice<T, F>

Source

impl<T, N> PartialOrd for GenericArray<T, N>
where T: PartialOrd, N: ArrayLength<T>,

Source

impl<T, S1, S2> PartialOrd<RingSet<T, S2>> for RingSet<T, S1>
where T: PartialOrd,

Source

impl<T, U> PartialOrd<Exclusive<U>> for Exclusive<T>
where T: Sync + PartialOrd<U> + ?Sized, U: Sync + ?Sized,

1.0.0 · Source

impl<T, const N: usize> PartialOrd for [T; N]
where T: PartialOrd,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> PartialOrd for Mask<T, N>

Source

impl<T, const N: usize> PartialOrd for Simd<T, N>

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<T, const N: usize> PartialOrd for SetOf<T, N>
where T: PartialOrd + DerOrd,

Source

impl<Tz> PartialOrd for chrono::date::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz, Tz2> PartialOrd<DateTime<Tz2>> for chrono::datetime::DateTime<Tz>
where Tz: TimeZone, Tz2: TimeZone,

Source

impl<U> PartialOrd for NInt<U>

Source

impl<U> PartialOrd for PInt<U>

Source

impl<U> PartialOrd for OptionVarULE<U>
where U: VarULE + PartialOrd + ?Sized,

Source

impl<U, B> PartialOrd for UInt<U, B>
where U: PartialOrd, B: PartialOrd,

Source

impl<U, const N: usize> PartialOrd for NichedOption<U, N>
where U: PartialOrd,

Source

impl<V, A> PartialOrd for TArr<V, A>
where V: PartialOrd, A: PartialOrd,

Source

impl<Y, R> PartialOrd for CoroutineState<Y, R>
where Y: PartialOrd, R: PartialOrd,

Source

impl<const LEFT_SIZE: usize, const RIGHT_SIZE: usize> PartialOrd<WriteBuffer<RIGHT_SIZE>> for WriteBuffer<LEFT_SIZE>

Source

impl<const LIMBS: usize> PartialOrd for crypto_bigint::uint::Uint<LIMBS>

Source

impl<const MIN_A: i8, const MAX_A: i8, const MIN_B: i8, const MAX_B: i8> PartialOrd<OptionRangedI8<MIN_B, MAX_B>> for OptionRangedI8<MIN_A, MAX_A>

Source

impl<const MIN_A: i8, const MAX_A: i8, const MIN_B: i8, const MAX_B: i8> PartialOrd<RangedI8<MIN_B, MAX_B>> for RangedI8<MIN_A, MAX_A>

Source

impl<const MIN_A: i16, const MAX_A: i16, const MIN_B: i16, const MAX_B: i16> PartialOrd<OptionRangedI16<MIN_B, MAX_B>> for OptionRangedI16<MIN_A, MAX_A>

Source

impl<const MIN_A: i16, const MAX_A: i16, const MIN_B: i16, const MAX_B: i16> PartialOrd<RangedI16<MIN_B, MAX_B>> for RangedI16<MIN_A, MAX_A>

Source

impl<const MIN_A: i32, const MAX_A: i32, const MIN_B: i32, const MAX_B: i32> PartialOrd<OptionRangedI32<MIN_B, MAX_B>> for OptionRangedI32<MIN_A, MAX_A>

Source

impl<const MIN_A: i32, const MAX_A: i32, const MIN_B: i32, const MAX_B: i32> PartialOrd<RangedI32<MIN_B, MAX_B>> for RangedI32<MIN_A, MAX_A>

Source

impl<const MIN_A: i64, const MAX_A: i64, const MIN_B: i64, const MAX_B: i64> PartialOrd<OptionRangedI64<MIN_B, MAX_B>> for OptionRangedI64<MIN_A, MAX_A>

Source

impl<const MIN_A: i64, const MAX_A: i64, const MIN_B: i64, const MAX_B: i64> PartialOrd<RangedI64<MIN_B, MAX_B>> for RangedI64<MIN_A, MAX_A>

Source

impl<const MIN_A: i128, const MAX_A: i128, const MIN_B: i128, const MAX_B: i128> PartialOrd<OptionRangedI128<MIN_B, MAX_B>> for OptionRangedI128<MIN_A, MAX_A>

Source

impl<const MIN_A: i128, const MAX_A: i128, const MIN_B: i128, const MAX_B: i128> PartialOrd<RangedI128<MIN_B, MAX_B>> for RangedI128<MIN_A, MAX_A>

Source

impl<const MIN_A: isize, const MAX_A: isize, const MIN_B: isize, const MAX_B: isize> PartialOrd<OptionRangedIsize<MIN_B, MAX_B>> for OptionRangedIsize<MIN_A, MAX_A>

Source

impl<const MIN_A: isize, const MAX_A: isize, const MIN_B: isize, const MAX_B: isize> PartialOrd<RangedIsize<MIN_B, MAX_B>> for RangedIsize<MIN_A, MAX_A>

Source

impl<const MIN_A: u8, const MAX_A: u8, const MIN_B: u8, const MAX_B: u8> PartialOrd<OptionRangedU8<MIN_B, MAX_B>> for OptionRangedU8<MIN_A, MAX_A>

Source

impl<const MIN_A: u8, const MAX_A: u8, const MIN_B: u8, const MAX_B: u8> PartialOrd<RangedU8<MIN_B, MAX_B>> for RangedU8<MIN_A, MAX_A>

Source

impl<const MIN_A: u16, const MAX_A: u16, const MIN_B: u16, const MAX_B: u16> PartialOrd<OptionRangedU16<MIN_B, MAX_B>> for OptionRangedU16<MIN_A, MAX_A>

Source

impl<const MIN_A: u16, const MAX_A: u16, const MIN_B: u16, const MAX_B: u16> PartialOrd<RangedU16<MIN_B, MAX_B>> for RangedU16<MIN_A, MAX_A>

Source

impl<const MIN_A: u32, const MAX_A: u32, const MIN_B: u32, const MAX_B: u32> PartialOrd<OptionRangedU32<MIN_B, MAX_B>> for OptionRangedU32<MIN_A, MAX_A>

Source

impl<const MIN_A: u32, const MAX_A: u32, const MIN_B: u32, const MAX_B: u32> PartialOrd<RangedU32<MIN_B, MAX_B>> for RangedU32<MIN_A, MAX_A>

Source

impl<const MIN_A: u64, const MAX_A: u64, const MIN_B: u64, const MAX_B: u64> PartialOrd<OptionRangedU64<MIN_B, MAX_B>> for OptionRangedU64<MIN_A, MAX_A>

Source

impl<const MIN_A: u64, const MAX_A: u64, const MIN_B: u64, const MAX_B: u64> PartialOrd<RangedU64<MIN_B, MAX_B>> for RangedU64<MIN_A, MAX_A>

Source

impl<const MIN_A: u128, const MAX_A: u128, const MIN_B: u128, const MAX_B: u128> PartialOrd<OptionRangedU128<MIN_B, MAX_B>> for OptionRangedU128<MIN_A, MAX_A>

Source

impl<const MIN_A: u128, const MAX_A: u128, const MIN_B: u128, const MAX_B: u128> PartialOrd<RangedU128<MIN_B, MAX_B>> for RangedU128<MIN_A, MAX_A>

Source

impl<const MIN_A: usize, const MAX_A: usize, const MIN_B: usize, const MAX_B: usize> PartialOrd<OptionRangedUsize<MIN_B, MAX_B>> for OptionRangedUsize<MIN_A, MAX_A>

Source

impl<const MIN_A: usize, const MAX_A: usize, const MIN_B: usize, const MAX_B: usize> PartialOrd<RangedUsize<MIN_B, MAX_B>> for RangedUsize<MIN_A, MAX_A>

Source

impl<const N: usize> PartialOrd for TinyAsciiStr<N>

Source

impl<const N: usize> PartialOrd for UnvalidatedTinyAsciiStr<N>

Source

impl<const N: usize> PartialOrd for RawBytesULE<N>