pub struct VaList<'a> { /* private fields */ }🔬This is a nightly-only experimental API. (
c_variadic)Expand description
A variable argument list, equivalent to va_list in C.
Implementations
Sourceimpl<'f> VaList<'f>
impl<'f> VaList<'f>
Sourcepub unsafe fn arg<T>(&mut self) -> Twhere
T: VaArgSafe,
🔬This is a nightly-only experimental API. (c_variadic)
pub unsafe fn arg<T>(&mut self) -> Twhere
T: VaArgSafe,
c_variadic)Advance to and read the next variable argument.
Safety
This function is only sound to call when:
- there is a next variable argument available.
- the next argument’s type must be ABI-compatible with the type
T. - the next argument must have a properly initialized value of type
T.
Calling this function with an incompatible type, an invalid value, or when there are no more variable arguments, is unsound.