Binary

Trait Binary 

1.0.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize

Source

impl Binary for WatchKind

Source

impl Binary for AtFlags

Source

impl Binary for FallocateFlags

Source

impl Binary for FdFlag

Source

impl Binary for OFlag

Source

impl Binary for RenameFlags

Source

impl Binary for SealFlag

Source

impl Binary for SpliceFFlags

Source

impl Binary for DeleteModuleFlags

Source

impl Binary for ModuleInitFlags

Source

impl Binary for MntFlags

Source

impl Binary for nix::mount::linux::MsFlags

Source

impl Binary for MQ_OFlag

Source

impl Binary for InterfaceFlags

Source

impl Binary for PollFlags

Source

impl Binary for CloneFlags

Source

impl Binary for EpollCreateFlags

Source

impl Binary for EpollFlags

Source

impl Binary for EfdFlags

Source

impl Binary for AddWatchFlags

Source

impl Binary for InitFlags

Source

impl Binary for MemFdCreateFlag

Source

impl Binary for MRemapFlags

Source

impl Binary for MapFlags

Source

impl Binary for MlockAllFlags

Source

impl Binary for nix::sys::mman::MsFlags

Source

impl Binary for ProtFlags

Source

impl Binary for Persona

Source

impl Binary for Options

Source

impl Binary for QuotaValidFlags

Source

impl Binary for SaFlags

Source

impl Binary for SfdFlags

Source

impl Binary for MsgFlags

Source

impl Binary for SockFlag

Source

impl Binary for TimestampingFlag

Source

impl Binary for Mode

Source

impl Binary for SFlag

Source

impl Binary for FsFlags

Source

impl Binary for ControlFlags

Source

impl Binary for InputFlags

Source

impl Binary for LocalFlags

Source

impl Binary for OutputFlags

Source

impl Binary for TimerSetTimeFlags

Source

impl Binary for TimerFlags

Source

impl Binary for WaitPidFlag

Source

impl Binary for AccessFlags

Source

impl Binary for BigInt

Source

impl Binary for BigUint

Source

impl Binary for CipherCtxFlags

Source

impl Binary for CMSOptions

Source

impl Binary for OcspFlag

Source

impl Binary for Pkcs7Flags

Source

impl Binary for ExtensionContext

Source

impl Binary for ShutdownState

Source

impl Binary for SslMode

Source

impl Binary for SslOptions

Source

impl Binary for SslSessionCacheMode

Source

impl Binary for SslVerifyMode

Source

impl Binary for X509CheckFlags

Source

impl Binary for X509VerifyFlags

Source

impl Binary for FontStyle

Source

impl Binary for Z0

Source

impl Binary for UInt<UTerm, B0>

Source

impl Binary for UInt<UTerm, B1>

Source

impl Binary for UTerm

Source

impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,

Source

impl<O> Binary for I16<O>
where O: ByteOrder,

Source

impl<O> Binary for I32<O>
where O: ByteOrder,

Source

impl<O> Binary for I64<O>
where O: ByteOrder,

Source

impl<O> Binary for I128<O>
where O: ByteOrder,

Source

impl<O> Binary for Isize<O>
where O: ByteOrder,

Source

impl<O> Binary for U16<O>
where O: ByteOrder,

Source

impl<O> Binary for U32<O>
where O: ByteOrder,

Source

impl<O> Binary for U64<O>
where O: ByteOrder,

Source

impl<O> Binary for U128<O>
where O: ByteOrder,

Source

impl<O> Binary for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

1.28.0 · Source

impl<T> Binary for datex_core::stdlib::num::NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for datex_core::stdlib::num::Wrapping<T>
where T: Binary,

Source

impl<T> Binary for crypto_bigint::non_zero::NonZero<T>
where T: Binary + Zero,

Source

impl<T> Binary for crypto_bigint::wrapping::Wrapping<T>
where T: Binary,

Source

impl<T> Binary for Complex<T>
where T: Binary + Num + PartialOrd + Clone,

Source

impl<T> Binary for Ratio<T>
where T: Binary + Clone + Integer,

Source

impl<U> Binary for NInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U> Binary for PInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B0>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<const MIN: i8, const MAX: i8> Binary for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Binary for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Binary for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Binary for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Binary for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Binary for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Binary for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Binary for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Binary for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Binary for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Binary for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Binary for RangedUsize<MIN, MAX>