Octal

Trait Octal 

1.0.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize

Source

impl Octal for WatchKind

Source

impl Octal for AtFlags

Source

impl Octal for FallocateFlags

Source

impl Octal for FdFlag

Source

impl Octal for OFlag

Source

impl Octal for RenameFlags

Source

impl Octal for SealFlag

Source

impl Octal for SpliceFFlags

Source

impl Octal for DeleteModuleFlags

Source

impl Octal for ModuleInitFlags

Source

impl Octal for MntFlags

Source

impl Octal for nix::mount::linux::MsFlags

Source

impl Octal for MQ_OFlag

Source

impl Octal for InterfaceFlags

Source

impl Octal for PollFlags

Source

impl Octal for CloneFlags

Source

impl Octal for EpollCreateFlags

Source

impl Octal for EpollFlags

Source

impl Octal for EfdFlags

Source

impl Octal for AddWatchFlags

Source

impl Octal for InitFlags

Source

impl Octal for MemFdCreateFlag

Source

impl Octal for MRemapFlags

Source

impl Octal for MapFlags

Source

impl Octal for MlockAllFlags

Source

impl Octal for nix::sys::mman::MsFlags

Source

impl Octal for ProtFlags

Source

impl Octal for Persona

Source

impl Octal for Options

Source

impl Octal for QuotaValidFlags

Source

impl Octal for SaFlags

Source

impl Octal for SfdFlags

Source

impl Octal for MsgFlags

Source

impl Octal for SockFlag

Source

impl Octal for TimestampingFlag

Source

impl Octal for Mode

Source

impl Octal for SFlag

Source

impl Octal for FsFlags

Source

impl Octal for ControlFlags

Source

impl Octal for InputFlags

Source

impl Octal for LocalFlags

Source

impl Octal for OutputFlags

Source

impl Octal for TimerSetTimeFlags

Source

impl Octal for TimerFlags

Source

impl Octal for WaitPidFlag

Source

impl Octal for AccessFlags

Source

impl Octal for BigInt

Source

impl Octal for BigUint

Source

impl Octal for CipherCtxFlags

Source

impl Octal for CMSOptions

Source

impl Octal for OcspFlag

Source

impl Octal for Pkcs7Flags

Source

impl Octal for ExtensionContext

Source

impl Octal for ShutdownState

Source

impl Octal for SslMode

Source

impl Octal for SslOptions

Source

impl Octal for SslSessionCacheMode

Source

impl Octal for SslVerifyMode

Source

impl Octal for X509CheckFlags

Source

impl Octal for X509VerifyFlags

Source

impl Octal for FontStyle

Source

impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,

Source

impl<O> Octal for I16<O>
where O: ByteOrder,

Source

impl<O> Octal for I32<O>
where O: ByteOrder,

Source

impl<O> Octal for I64<O>
where O: ByteOrder,

Source

impl<O> Octal for I128<O>
where O: ByteOrder,

Source

impl<O> Octal for Isize<O>
where O: ByteOrder,

Source

impl<O> Octal for U16<O>
where O: ByteOrder,

Source

impl<O> Octal for U32<O>
where O: ByteOrder,

Source

impl<O> Octal for U64<O>
where O: ByteOrder,

Source

impl<O> Octal for U128<O>
where O: ByteOrder,

Source

impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

1.28.0 · Source

impl<T> Octal for datex_core::stdlib::num::NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for datex_core::stdlib::num::Wrapping<T>
where T: Octal,

Source

impl<T> Octal for crypto_bigint::non_zero::NonZero<T>
where T: Octal + Zero,

Source

impl<T> Octal for crypto_bigint::wrapping::Wrapping<T>
where T: Octal,

Source

impl<T> Octal for Complex<T>
where T: Octal + Num + PartialOrd + Clone,

Source

impl<T> Octal for Ratio<T>
where T: Octal + Clone + Integer,

Source

impl<const MIN: i8, const MAX: i8> Octal for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Octal for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Octal for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Octal for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Octal for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Octal for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Octal for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Octal for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Octal for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Octal for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Octal for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Octal for RangedUsize<MIN, MAX>