Hash

Trait Hash 

1.0.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Hash for VariableKind

Source

impl Hash for ResolvedVariable

Source

impl Hash for VariableShape

Source

impl Hash for ArithmeticOperator

Source

impl Hash for CoreLibPointerId

Source

impl Hash for Reference

Source

impl Hash for ReferenceCreationError

Source

impl Hash for ReferenceMutability

Source

impl Hash for TypeError

Source

impl Hash for CollectionTypeDefinition

Source

impl Hash for TypeDefinition

Source

impl Hash for StructuralTypeDefinition

Source

impl Hash for CoreValue

Source

impl Hash for CallableBody

Source

impl Hash for CallableKind

Source

impl Hash for Decimal

Source

impl Hash for DecimalTypeVariant

Source

impl Hash for TypedDecimal

Source

impl Hash for EndpointInstance

Source

impl Hash for EndpointType

Source

impl Hash for IntegerTypeVariant

Source

impl Hash for TypedInteger

Source

impl Hash for BorrowedMapKey<'_>

Source

impl Hash for datex_core::values::core_values::map::Map

Source

impl Hash for PointerAddress

Source

impl Hash for ValueContainer

Source

impl Hash for AsciiChar

1.0.0 · Source

impl Hash for datex_core::stdlib::cmp::Ordering

1.44.0 · Source

impl Hash for Infallible

Source

impl Hash for Locality

1.0.0 · Source

impl Hash for datex_core::stdlib::io::ErrorKind

1.7.0 · Source

impl Hash for datex_core::stdlib::net::IpAddr

Source

impl Hash for Ipv6MulticastScope

1.0.0 · Source

impl Hash for SocketAddr

1.55.0 · Source

impl Hash for IntErrorKind

1.0.0 · Source

impl Hash for datex_core::stdlib::sync::atomic::Ordering

Source

impl Hash for RoundingMode

Source

impl Hash for CheckedCastError

Source

impl Hash for PodCastError

Source

impl Hash for byteorder::BigEndian

Source

impl Hash for byteorder::LittleEndian

Source

impl Hash for Colons

Source

impl Hash for Fixed

Source

impl Hash for Numeric

Source

impl Hash for OffsetPrecision

Source

impl Hash for Pad

Source

impl Hash for ParseErrorKind

Source

impl Hash for SecondsFormat

Source

impl Hash for chrono::month::Month

Source

impl Hash for chrono::weekday::Weekday

Source

impl Hash for PollNext

Source

impl Hash for ExtensionType

Source

impl Hash for CalendarAlgorithm

Source

impl Hash for HijriCalendarAlgorithm

Source

impl Hash for CollationCaseFirst

Source

impl Hash for CollationNumericOrdering

Source

impl Hash for CollationType

Source

impl Hash for CurrencyFormatStyle

Source

impl Hash for EmojiPresentationStyle

Source

impl Hash for FirstDay

Source

impl Hash for HourCycle

Source

impl Hash for LineBreakStyle

Source

impl Hash for LineBreakWordHandling

Source

impl Hash for MeasurementSystem

Source

impl Hash for MeasurementUnitOverride

Source

impl Hash for SentenceBreakSupressions

Source

impl Hash for CommonVariantType

Source

impl Hash for GeneralCategory

Source

impl Hash for BufferFormat

Source

impl Hash for IpAddrRange

Source

impl Hash for IpNet

Source

impl Hash for IpSubnets

Source

impl Hash for tpacket_versions

Source

impl Hash for log::Level

Source

impl Hash for log::LevelFilter

Source

impl Hash for NumberOrString

Source

impl Hash for InsertError

Source

impl Hash for CompressionStrategy

Source

impl Hash for TDEFLFlush

Source

impl Hash for TDEFLStatus

Source

impl Hash for CompressionLevel

Source

impl Hash for DataFormat

Source

impl Hash for MZError

Source

impl Hash for MZFlush

Source

impl Hash for MZStatus

Source

impl Hash for TINFLStatus

Source

impl Hash for nix::dir::Type

Source

impl Hash for FlockArg

Source

impl Hash for PosixFadviseAdvice

Source

impl Hash for AioCancelStat

Source

impl Hash for AioFsyncMode

Source

impl Hash for LioMode

Source

impl Hash for EpollOp

Source

impl Hash for MmapAdvise

Source

impl Hash for Event

Source

impl Hash for Request

Source

impl Hash for QuotaFmt

Source

impl Hash for QuotaType

Source

impl Hash for RebootMode

Source

impl Hash for Resource

Source

impl Hash for UsageWho

Source

impl Hash for SigHandler

Source

impl Hash for SigevNotify

Source

impl Hash for SigmaskHow

Source

impl Hash for Signal

Source

impl Hash for AddressFamily

Source

impl Hash for InetAddr

Source

impl Hash for nix::sys::socket::addr::IpAddr

Source

impl Hash for nix::sys::socket::addr::SockAddr

Source

impl Hash for Shutdown

Source

impl Hash for SockProtocol

Source

impl Hash for BaudRate

Source

impl Hash for FlowArg

Source

impl Hash for FlushArg

Source

impl Hash for SetArg

Source

impl Hash for SpecialCharacterIndices

Source

impl Hash for nix::sys::timerfd::ClockId

Source

impl Hash for nix::sys::wait::Id

Source

impl Hash for WaitStatus

Source

impl Hash for PathconfVar

Source

impl Hash for SysconfVar

Source

impl Hash for nom::error::ErrorKind

Source

impl Hash for Sign

Source

impl Hash for BasicConstraints

Source

impl Hash for CidrSubnet

Source

impl Hash for DnType

Source

impl Hash for ExtendedKeyUsagePurpose

Source

impl Hash for IsCa

Source

impl Hash for DnValue

Source

impl Hash for KeyIdMethod

Source

impl Hash for KeyUsagePurpose

Source

impl Hash for OtherNameValue

Source

impl Hash for SanType

Source

impl Hash for realhydroper_lsp::jsonrpc::Id

Source

impl Hash for UnitType

Source

impl Hash for rustls_pki_types::server_name::IpAddr

Source

impl Hash for serde_json::value::Value

Source

impl Hash for strum::ParseError

Source

impl Hash for time::month::Month

Source

impl Hash for time::weekday::Weekday

Source

impl Hash for Origin

Source

impl Hash for HandshakeType

Source

impl Hash for NetworkType

Source

impl Hash for Yaml

Source

impl Hash for PCBit

Source

impl Hash for TagClass

Source

impl Hash for BERMode

Source

impl Hash for zerocopy::byteorder::BigEndian

Source

impl Hash for zerocopy::byteorder::LittleEndian

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

1.0.0 · Source

impl Hash for i128

1.0.0 · Source

impl Hash for isize

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

1.0.0 · Source

impl Hash for u128

1.0.0 · Source

impl Hash for ()

1.0.0 · Source

impl Hash for usize

Source

impl Hash for SrcId

Source

impl Hash for VirtualSlot

Source

impl Hash for BlockId

Source

impl Hash for IncomingEndpointContextId

Source

impl Hash for IncomingEndpointContextSectionId

Source

impl Hash for ComInterfaceUUID

Source

impl Hash for ComInterfaceSocketUUID

Source

impl Hash for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common::structures::RTCIceServer

Source

impl Hash for Loc

Source

impl Hash for NominalTypeDeclaration

Source

impl Hash for TypeReference

1.3.0 · Source

impl Hash for datex_core::time::Duration

1.8.0 · Source

impl Hash for datex_core::time::Instant

1.8.0 · Source

impl Hash for SystemTime

Source

impl Hash for UUID

Source

impl Hash for Boolean

Source

impl Hash for Callable

Source

impl Hash for CallableSignature

Source

impl Hash for Rational

Source

impl Hash for Endpoint

Source

impl Hash for datex_core::values::core_values::integer::Integer

Source

impl Hash for List

Source

impl Hash for Text

Source

impl Hash for datex_core::values::core_values::type::Type

Source

impl Hash for datex_core::values::value::Value

1.28.0 · Source

impl Hash for Layout

1.0.0 · Source

impl Hash for TypeId

Source

impl Hash for ByteStr

Source

impl Hash for ByteString

1.64.0 · Source

impl Hash for CStr

1.64.0 · Source

impl Hash for CString

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

1.0.0 · Source

impl Hash for datex_core::stdlib::fmt::Error

1.1.0 · Source

impl Hash for FileType

1.33.0 · Source

impl Hash for PhantomPinned

1.0.0 · Source

impl Hash for datex_core::stdlib::net::Ipv4Addr

1.0.0 · Source

impl Hash for datex_core::stdlib::net::Ipv6Addr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

1.0.0 · Source

impl Hash for RangeFull

Source

impl Hash for datex_core::stdlib::os::unix::net::UCred

1.10.0 · Source

impl Hash for Location<'_>

1.0.0 · Source

impl Hash for Path

1.0.0 · Source

impl Hash for PathBuf

1.0.0 · Source

impl Hash for PrefixComponent<'_>

Source

impl Hash for Alignment

1.0.0 · Source

impl Hash for String

1.19.0 · Source

impl Hash for ThreadId

Source

impl Hash for aead::Error

Source

impl Hash for aho_corasick::util::primitives::PatternID

Source

impl Hash for aho_corasick::util::primitives::StateID

Source

impl Hash for aho_corasick::util::search::Match

Source

impl Hash for aho_corasick::util::search::Span

Source

impl Hash for Base64Bcrypt

Source

impl Hash for Base64Crypt

Source

impl Hash for Base64ShaCrypt

Source

impl Hash for Base64

Source

impl Hash for Base64Unpadded

Source

impl Hash for Base64Url

Source

impl Hash for Base64UrlUnpadded

Source

impl Hash for BigDecimal

Source

impl Hash for Bytes

Source

impl Hash for BytesMut

Source

impl Hash for Parsed

Source

impl Hash for InternalFixed

Source

impl Hash for InternalNumeric

Source

impl Hash for OffsetFormat

Source

impl Hash for chrono::format::ParseError

Source

impl Hash for Months

Source

impl Hash for NaiveDate

Source

impl Hash for NaiveDateDaysIterator

Source

impl Hash for NaiveDateWeeksIterator

Source

impl Hash for NaiveDateTime

Source

impl Hash for IsoWeek

Source

impl Hash for Days

Source

impl Hash for NaiveWeek

Source

impl Hash for NaiveTime

Source

impl Hash for FixedOffset

Source

impl Hash for Utc

Source

impl Hash for OutOfRange

Source

impl Hash for TimeDelta

Source

impl Hash for WeekdaySet

Source

impl Hash for const_oid::ObjectIdentifier

Source

impl Hash for Limb

Source

impl Hash for CompressedEdwardsY

Source

impl Hash for MontgomeryPoint

Source

impl Hash for CompressedRistretto

Source

impl Hash for Scalar

Source

impl Hash for Errno

Source

impl Hash for HeaderName

Source

impl Hash for HeaderValue

Source

impl Hash for Method

Source

impl Hash for StatusCode

Source

impl Hash for Authority

Case-insensitive hashing

Examples


let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();

let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();

let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();

assert_eq!(a, b);
Source

impl Hash for PathAndQuery

Source

impl Hash for Scheme

Case-insensitive hashing

Source

impl Hash for Uri

Source

impl Hash for Version

Source

impl Hash for HttpDate

Source

impl Hash for ReasonPhrase

Source

impl Hash for DataLocale

Source

impl Hash for Other

Source

impl Hash for icu_locale_core::extensions::private::other::Subtag

Source

impl Hash for Private

Source

impl Hash for Extensions

Source

impl Hash for Fields

Source

impl Hash for icu_locale_core::extensions::transform::key::Key

Source

impl Hash for Transform

Source

impl Hash for icu_locale_core::extensions::transform::value::Value

Source

impl Hash for icu_locale_core::extensions::unicode::attribute::Attribute

Source

impl Hash for Attributes

Source

impl Hash for icu_locale_core::extensions::unicode::key::Key

Source

impl Hash for Keywords

Source

impl Hash for Unicode

Source

impl Hash for SubdivisionId

Source

impl Hash for SubdivisionSuffix

Source

impl Hash for icu_locale_core::extensions::unicode::value::Value

Source

impl Hash for LanguageIdentifier

Source

impl Hash for Locale

Source

impl Hash for CurrencyType

Source

impl Hash for NumberingSystem

Source

impl Hash for RegionOverride

Source

impl Hash for RegionalSubdivision

Source

impl Hash for TimeZoneShortId

Source

impl Hash for LocalePreferences

Source

impl Hash for Language

Source

impl Hash for Region

Source

impl Hash for icu_locale_core::subtags::script::Script

Source

impl Hash for icu_locale_core::subtags::Subtag

Source

impl Hash for Variant

Source

impl Hash for Variants

Source

impl Hash for BidiClass

Source

impl Hash for CanonicalCombiningClass

Source

impl Hash for EastAsianWidth

Source

impl Hash for GeneralCategoryOutOfBoundsError

Source

impl Hash for GraphemeClusterBreak

Source

impl Hash for HangulSyllableType

Source

impl Hash for IndicConjunctBreak

Source

impl Hash for IndicSyllabicCategory

Source

impl Hash for JoiningType

Source

impl Hash for LineBreak

Source

impl Hash for icu_properties::props::Script

Source

impl Hash for SentenceBreak

Source

impl Hash for VerticalOrientation

Source

impl Hash for WordBreak

Source

impl Hash for DataMarkerId

Source

impl Hash for DataMarkerIdHash

Source

impl Hash for DataMarkerInfo

Source

impl Hash for DataMarkerAttributes

Source

impl Hash for Ipv4AddrRange

Source

impl Hash for Ipv6AddrRange

Source

impl Hash for Ipv4Net

Source

impl Hash for Ipv4Subnets

Source

impl Hash for Ipv6Net

Source

impl Hash for Ipv6Subnets

Source

impl Hash for rtentry

Source

impl Hash for bcm_msg_head

Source

impl Hash for bcm_timeval

Source

impl Hash for j1939_filter

Source

impl Hash for __c_anonymous_sockaddr_can_j1939

Source

impl Hash for __c_anonymous_sockaddr_can_tp

Source

impl Hash for can_filter

Source

impl Hash for can_frame

Source

impl Hash for canfd_frame

Source

impl Hash for canxl_frame

Source

impl Hash for termios2

Source

impl Hash for msqid_ds

Source

impl Hash for semid_ds

Source

impl Hash for sigset_t

Source

impl Hash for sysinfo

Source

impl Hash for timex

Source

impl Hash for statvfs

Source

impl Hash for _libc_fpstate

Source

impl Hash for _libc_fpxreg

Source

impl Hash for _libc_xmmreg

Source

impl Hash for clone_args

Source

impl Hash for flock64

Source

impl Hash for flock

Source

impl Hash for ipc_perm

Source

impl Hash for mcontext_t

Source

impl Hash for pthread_attr_t

Source

impl Hash for ptrace_rseq_configuration

Source

impl Hash for shmid_ds

Source

impl Hash for sigaction

Source

impl Hash for siginfo_t

Source

impl Hash for stack_t

Source

impl Hash for stat64

Source

impl Hash for stat

Source

impl Hash for statfs64

Source

impl Hash for statfs

Source

impl Hash for statvfs64

Source

impl Hash for ucontext_t

Source

impl Hash for user

Source

impl Hash for user_fpregs_struct

Source

impl Hash for user_regs_struct

Source

impl Hash for Elf32_Chdr

Source

impl Hash for Elf64_Chdr

Source

impl Hash for __c_anonymous_ptrace_syscall_info_entry

Source

impl Hash for __c_anonymous_ptrace_syscall_info_exit

Source

impl Hash for __c_anonymous_ptrace_syscall_info_seccomp

Source

impl Hash for __exit_status

Source

impl Hash for __timeval

Source

impl Hash for aiocb

Source

impl Hash for cmsghdr

Source

impl Hash for fanotify_event_info_error

Source

impl Hash for fanotify_event_info_pidfd

Source

impl Hash for fpos64_t

Source

impl Hash for fpos_t

Source

impl Hash for glob64_t

Source

impl Hash for iocb

Source

impl Hash for mallinfo2

Source

impl Hash for mallinfo

Source

impl Hash for mbstate_t

Source

impl Hash for msghdr

Source

impl Hash for nl_mmap_hdr

Source

impl Hash for nl_mmap_req

Source

impl Hash for nl_pktinfo

Source

impl Hash for ntptimeval

Source

impl Hash for ptrace_peeksiginfo_args

Source

impl Hash for ptrace_sud_config

Source

impl Hash for ptrace_syscall_info

Source

impl Hash for regex_t

Source

impl Hash for sem_t

Source

impl Hash for seminfo

Source

impl Hash for tcp_info

Source

impl Hash for termios

Source

impl Hash for timespec

Source

impl Hash for utmpx

Source

impl Hash for __c_anonymous__kernel_fsid_t

Source

impl Hash for af_alg_iv

Available on crate feature extra_traits only.
Source

impl Hash for dmabuf_cmsg

Source

impl Hash for dmabuf_token

Source

impl Hash for dqblk

Source

impl Hash for epoll_params

Source

impl Hash for fanotify_event_info_fid

Source

impl Hash for fanotify_event_info_header

Source

impl Hash for fanotify_event_metadata

Source

impl Hash for fanotify_response

Source

impl Hash for fanout_args

Source

impl Hash for ff_condition_effect

Source

impl Hash for ff_constant_effect

Source

impl Hash for ff_effect

Source

impl Hash for ff_envelope

Source

impl Hash for ff_periodic_effect

Source

impl Hash for ff_ramp_effect

Source

impl Hash for ff_replay

Source

impl Hash for ff_rumble_effect

Source

impl Hash for ff_trigger

Source

impl Hash for genlmsghdr

Source

impl Hash for hwtstamp_config

Source

impl Hash for in6_ifreq

Source

impl Hash for inotify_event

Source

impl Hash for input_absinfo

Source

impl Hash for input_event

Source

impl Hash for input_id

Source

impl Hash for input_keymap_entry

Source

impl Hash for input_mask

Source

impl Hash for iw_discarded

Source

impl Hash for iw_encode_ext

Source

impl Hash for iw_freq

Source

impl Hash for iw_michaelmicfailure

Source

impl Hash for iw_missed

Source

impl Hash for iw_mlme

Source

impl Hash for iw_param

Source

impl Hash for iw_pmkid_cand

Source

impl Hash for iw_pmksa

Source

impl Hash for iw_point

Source

impl Hash for iw_priv_args

Source

impl Hash for iw_quality

Source

impl Hash for iw_range

Source

impl Hash for iw_scan_req

Source

impl Hash for iw_statistics

Source

impl Hash for iw_thrspy

Source

impl Hash for mnt_ns_info

Source

impl Hash for mount_attr

Source

impl Hash for mq_attr

Source

impl Hash for msginfo

Source

impl Hash for nlattr

Source

impl Hash for nlmsgerr

Source

impl Hash for nlmsghdr

Source

impl Hash for open_how

Source

impl Hash for pidfd_info

Source

impl Hash for posix_spawn_file_actions_t

Source

impl Hash for posix_spawnattr_t

Source

impl Hash for pthread_barrier_t

Source

impl Hash for pthread_barrierattr_t

Source

impl Hash for pthread_cond_t

Source

impl Hash for pthread_condattr_t

Source

impl Hash for pthread_mutex_t

Source

impl Hash for pthread_mutexattr_t

Source

impl Hash for pthread_rwlock_t

Source

impl Hash for pthread_rwlockattr_t

Source

impl Hash for ptp_clock_caps

Source

impl Hash for ptp_clock_time

Source

impl Hash for ptp_extts_event

Source

impl Hash for ptp_extts_request

Source

impl Hash for ptp_pin_desc

Source

impl Hash for ptp_sys_offset

Source

impl Hash for ptp_sys_offset_extended

Source

impl Hash for ptp_sys_offset_precise

Source

impl Hash for sched_attr

Source

impl Hash for sctp_authinfo

Source

impl Hash for sctp_initmsg

Source

impl Hash for sctp_nxtinfo

Source

impl Hash for sctp_prinfo

Source

impl Hash for sctp_rcvinfo

Source

impl Hash for sctp_sndinfo

Source

impl Hash for sctp_sndrcvinfo

Source

impl Hash for seccomp_data

Source

impl Hash for seccomp_notif

Source

impl Hash for seccomp_notif_addfd

Source

impl Hash for seccomp_notif_resp

Source

impl Hash for seccomp_notif_sizes

Source

impl Hash for signalfd_siginfo

Source

impl Hash for sock_extended_err

Source

impl Hash for sockaddr_alg

Source

impl Hash for sockaddr_nl

Source

impl Hash for sockaddr_pkt

Source

impl Hash for sockaddr_vm

Source

impl Hash for sockaddr_xdp

Source

impl Hash for tls12_crypto_info_aes_ccm_128

Source

impl Hash for tls12_crypto_info_aes_gcm_128

Source

impl Hash for tls12_crypto_info_aes_gcm_256

Source

impl Hash for tls12_crypto_info_aria_gcm_128

Source

impl Hash for tls12_crypto_info_aria_gcm_256

Source

impl Hash for tls12_crypto_info_chacha20_poly1305

Source

impl Hash for tls12_crypto_info_sm4_ccm

Source

impl Hash for tls12_crypto_info_sm4_gcm

Source

impl Hash for tls_crypto_info

Source

impl Hash for tpacket2_hdr

Source

impl Hash for tpacket3_hdr

Source

impl Hash for tpacket_auxdata

Source

impl Hash for tpacket_bd_ts

Source

impl Hash for tpacket_hdr

Source

impl Hash for tpacket_hdr_v1

Source

impl Hash for tpacket_hdr_variant1

Source

impl Hash for tpacket_req3

Source

impl Hash for tpacket_req

Source

impl Hash for tpacket_rollover_stats

Source

impl Hash for tpacket_stats

Source

impl Hash for tpacket_stats_v3

Source

impl Hash for uinput_abs_setup

Source

impl Hash for uinput_ff_erase

Source

impl Hash for uinput_ff_upload

Source

impl Hash for uinput_setup

Source

impl Hash for uinput_user_dev

Source

impl Hash for xdp_desc

Source

impl Hash for xdp_mmap_offsets

Source

impl Hash for xdp_mmap_offsets_v1

Source

impl Hash for xdp_options

Source

impl Hash for xdp_ring_offset

Source

impl Hash for xdp_ring_offset_v1

Source

impl Hash for xdp_statistics

Source

impl Hash for xdp_statistics_v1

Source

impl Hash for xdp_umem_reg

Source

impl Hash for xdp_umem_reg_v1

Source

impl Hash for xsk_tx_metadata_completion

Source

impl Hash for xsk_tx_metadata_request

Source

impl Hash for Elf32_Ehdr

Source

impl Hash for Elf32_Phdr

Source

impl Hash for Elf32_Shdr

Source

impl Hash for Elf32_Sym

Source

impl Hash for Elf64_Ehdr

Source

impl Hash for Elf64_Phdr

Source

impl Hash for Elf64_Shdr

Source

impl Hash for Elf64_Sym

Source

impl Hash for __c_anonymous_elf32_rel

Source

impl Hash for __c_anonymous_elf32_rela

Source

impl Hash for __c_anonymous_elf64_rel

Source

impl Hash for __c_anonymous_elf64_rela

Source

impl Hash for __c_anonymous_ifru_map

Source

impl Hash for arpd_request

Source

impl Hash for cpu_set_t

Source

impl Hash for dirent64

Source

impl Hash for dirent

Source

impl Hash for dl_phdr_info

Source

impl Hash for fsid_t

Source

impl Hash for glob_t

Source

impl Hash for in6_pktinfo

Source

impl Hash for itimerspec

Source

impl Hash for mntent

Source

impl Hash for option

Source

impl Hash for packet_mreq

Source

impl Hash for passwd

Source

impl Hash for regmatch_t

Source

impl Hash for rlimit64

Source

impl Hash for sembuf

Source

impl Hash for spwd

Source

impl Hash for ucred

Source

impl Hash for Dl_info

Source

impl Hash for addrinfo

Source

impl Hash for arphdr

Source

impl Hash for arpreq

Source

impl Hash for arpreq_old

Source

impl Hash for epoll_event

Available on crate feature extra_traits and non-L4Re only.
Source

impl Hash for fd_set

Source

impl Hash for file_clone_range

Source

impl Hash for if_nameindex

Source

impl Hash for ifaddrs

Source

impl Hash for in6_rtmsg

Source

impl Hash for in_addr

Source

impl Hash for in_pktinfo

Source

impl Hash for ip_mreq

Source

impl Hash for ip_mreq_source

Source

impl Hash for ip_mreqn

Source

impl Hash for lconv

Source

impl Hash for mmsghdr

Source

impl Hash for sched_param

Source

impl Hash for sigevent

Available on crate feature extra_traits and non-L4Re only.
Source

impl Hash for sock_filter

Source

impl Hash for sock_fprog

Source

impl Hash for sockaddr

Source

impl Hash for sockaddr_in6

Source

impl Hash for sockaddr_in

Source

impl Hash for sockaddr_ll

Source

impl Hash for sockaddr_storage

Source

impl Hash for sockaddr_un

Source

impl Hash for statx

Source

impl Hash for statx_timestamp

Source

impl Hash for tm

Source

impl Hash for utsname

Source

impl Hash for group

Source

impl Hash for hostent

Source

impl Hash for in6_addr

Source

impl Hash for iovec

Source

impl Hash for ipv6_mreq

Source

impl Hash for itimerval

Source

impl Hash for linger

Source

impl Hash for pollfd

Source

impl Hash for protoent

Source

impl Hash for rlimit

Source

impl Hash for rusage

Source

impl Hash for servent

Source

impl Hash for sigval

Source

impl Hash for timeval

Source

impl Hash for tms

Source

impl Hash for utimbuf

Source

impl Hash for winsize

Source

impl Hash for CodeActionKind

Source

impl Hash for SemanticTokenModifier

Source

impl Hash for SemanticTokenType

Source

impl Hash for TokenFormat

Source

impl Hash for FileChangeType

Source

impl Hash for FileEvent

Source

impl Hash for PositionEncodingKind

Source

impl Hash for WatchKind

Source

impl Hash for Mime

Source

impl Hash for StreamResult

Source

impl Hash for Token

Source

impl Hash for Dir

Source

impl Hash for Entry

Source

impl Hash for OwningIter

Source

impl Hash for AtFlags

Source

impl Hash for FallocateFlags

Source

impl Hash for FdFlag

Source

impl Hash for OFlag

Source

impl Hash for RenameFlags

Source

impl Hash for SealFlag

Source

impl Hash for SpliceFFlags

Source

impl Hash for InterfaceAddress

Source

impl Hash for InterfaceAddressIterator

Source

impl Hash for DeleteModuleFlags

Source

impl Hash for ModuleInitFlags

Source

impl Hash for MntFlags

Source

impl Hash for nix::mount::linux::MsFlags

Source

impl Hash for MQ_OFlag

Source

impl Hash for MqAttr

Source

impl Hash for InterfaceFlags

Source

impl Hash for PollFd

Source

impl Hash for PollFlags

Source

impl Hash for OpenptyResult

Source

impl Hash for PtyMaster

Source

impl Hash for CpuSet

Source

impl Hash for CloneFlags

Source

impl Hash for EpollCreateFlags

Source

impl Hash for EpollEvent

Source

impl Hash for EpollFlags

Source

impl Hash for EfdFlags

Source

impl Hash for AddWatchFlags

Source

impl Hash for InitFlags

Source

impl Hash for WatchDescriptor

Source

impl Hash for MemFdCreateFlag

Source

impl Hash for MRemapFlags

Source

impl Hash for MapFlags

Source

impl Hash for MlockAllFlags

Source

impl Hash for nix::sys::mman::MsFlags

Source

impl Hash for ProtFlags

Source

impl Hash for Persona

Source

impl Hash for Options

Source

impl Hash for Dqblk

Source

impl Hash for QuotaValidFlags

Source

impl Hash for Usage

Source

impl Hash for FdSet

Source

impl Hash for SigEvent

Source

impl Hash for SaFlags

Source

impl Hash for SigAction

Source

impl Hash for SigSet

Source

impl Hash for SignalIterator

Source

impl Hash for SfdFlags

Source

impl Hash for SignalFd

Source

impl Hash for AlgAddr

Source

impl Hash for LinkAddr

Source

impl Hash for NetlinkAddr

Source

impl Hash for nix::sys::socket::addr::Ipv4Addr

Source

impl Hash for nix::sys::socket::addr::Ipv6Addr

Source

impl Hash for SockaddrIn6

Source

impl Hash for SockaddrIn

Source

impl Hash for UnixAddr

Source

impl Hash for VsockAddr

Source

impl Hash for AcceptConn

Source

impl Hash for BindToDevice

Source

impl Hash for Broadcast

Source

impl Hash for DontRoute

Source

impl Hash for Ip6tOriginalDst

Source

impl Hash for IpAddMembership

Source

impl Hash for IpDropMembership

Source

impl Hash for IpFreebind

Source

impl Hash for IpMtu

Source

impl Hash for IpMulticastLoop

Source

impl Hash for IpMulticastTtl

Source

impl Hash for IpTos

Source

impl Hash for IpTransparent

Source

impl Hash for Ipv4OrigDstAddr

Source

impl Hash for Ipv4PacketInfo

Source

impl Hash for Ipv4RecvErr

Source

impl Hash for Ipv4Ttl

Source

impl Hash for Ipv6AddMembership

Source

impl Hash for Ipv6DontFrag

Source

impl Hash for Ipv6DropMembership

Source

impl Hash for Ipv6OrigDstAddr

Source

impl Hash for Ipv6RecvErr

Source

impl Hash for Ipv6RecvPacketInfo

Source

impl Hash for Ipv6TClass

Source

impl Hash for Ipv6Ttl

Source

impl Hash for Ipv6V6Only

Source

impl Hash for KeepAlive

Source

impl Hash for Linger

Source

impl Hash for Mark

Source

impl Hash for OobInline

Source

impl Hash for OriginalDst

Source

impl Hash for PassCred

Source

impl Hash for PeerCredentials

Source

impl Hash for Priority

Source

impl Hash for RcvBuf

Source

impl Hash for RcvBufForce

Source

impl Hash for ReceiveTimeout

Source

impl Hash for ReceiveTimestamp

Source

impl Hash for ReceiveTimestampns

Source

impl Hash for ReuseAddr

Source

impl Hash for ReusePort

Source

impl Hash for RxqOvfl

Source

impl Hash for SendTimeout

Source

impl Hash for SndBuf

Source

impl Hash for SndBufForce

Source

impl Hash for SockType

Source

impl Hash for SocketError

Source

impl Hash for TcpCongestion

Source

impl Hash for TcpKeepCount

Source

impl Hash for TcpKeepIdle

Source

impl Hash for TcpKeepInterval

Source

impl Hash for TcpMaxSeg

Source

impl Hash for TcpNoDelay

Source

impl Hash for TcpRepair

Source

impl Hash for TcpUserTimeout

Source

impl Hash for Timestamping

Source

impl Hash for TxTime

Source

impl Hash for UdpGroSegment

Source

impl Hash for UdpGsoSegment

Source

impl Hash for MsgFlags

Source

impl Hash for SockFlag

Source

impl Hash for TimestampingFlag

Source

impl Hash for Mode

Source

impl Hash for SFlag

Source

impl Hash for FsFlags

Source

impl Hash for Statvfs

Source

impl Hash for SysInfo

Source

impl Hash for ControlFlags

Source

impl Hash for InputFlags

Source

impl Hash for LocalFlags

Source

impl Hash for OutputFlags

Source

impl Hash for TimeSpec

Source

impl Hash for TimeVal

Source

impl Hash for TimerSetTimeFlags

Source

impl Hash for TimerFlags

Source

impl Hash for RemoteIoVec

Source

impl Hash for UtsName

Source

impl Hash for WaitPidFlag

Source

impl Hash for nix::time::ClockId

Source

impl Hash for UContext

Source

impl Hash for AccessFlags

Source

impl Hash for Gid

Source

impl Hash for Pid

Source

impl Hash for nix::unistd::Uid

Source

impl Hash for BigInt

Source

impl Hash for BigUint

Source

impl Hash for TimeDiff

Source

impl Hash for CMSOptions

Source

impl Hash for Nid

Source

impl Hash for OcspFlag

Source

impl Hash for KeyIvPair

Source

impl Hash for Pkcs7Flags

Source

impl Hash for ExtensionContext

Source

impl Hash for ShutdownState

Source

impl Hash for SslMode

Source

impl Hash for SslOptions

Source

impl Hash for SslSessionCacheMode

Source

impl Hash for SslVerifyMode

Source

impl Hash for X509CheckFlags

Source

impl Hash for X509VerifyFlags

Source

impl Hash for plist::date::Date

Source

impl Hash for plist::integer::Integer

Source

impl Hash for plist::uid::Uid

Source

impl Hash for PotentialCodePoint

Source

impl Hash for rcgen::certificate::Attribute

Source

impl Hash for CustomExtension

Source

impl Hash for rcgen::csr::PublicKey

Source

impl Hash for SignatureAlgorithm

The Hash trait is not derived, but implemented according to impl of the PartialEq trait

Source

impl Hash for BmpString

Source

impl Hash for Ia5String

Source

impl Hash for PrintableString

Source

impl Hash for TeletexString

Source

impl Hash for UniversalString

Source

impl Hash for SerialNumber

Source

impl Hash for LazyStateID

Source

impl Hash for Transition

Source

impl Hash for NonMaxUsize

Source

impl Hash for regex_automata::util::primitives::PatternID

Source

impl Hash for SmallIndex

Source

impl Hash for regex_automata::util::primitives::StateID

Source

impl Hash for HalfMatch

Source

impl Hash for regex_automata::util::search::Match

Source

impl Hash for regex_automata::util::search::Span

Source

impl Hash for rustls_pki_types::server_name::Ipv4Addr

Source

impl Hash for rustls_pki_types::server_name::Ipv6Addr

Source

impl Hash for UnixTime

Source

impl Hash for Handle

Source

impl Hash for serde_json::map::Map<String, Value>

Source

impl Hash for Number

Source

impl Hash for SigId

Source

impl Hash for SmolStr

Source

impl Hash for socket2::sockaddr::SockAddr

Source

impl Hash for socket2::sockaddr::SockAddr

Source

impl Hash for TransactionId

Source

impl Hash for ErrorCode

Source

impl Hash for Color

Source

impl Hash for FontStyle

Source

impl Hash for Style

Source

impl Hash for Scope

Source

impl Hash for ContextId

Source

impl Hash for time::date::Date

Source

impl Hash for time::duration::Duration

Source

impl Hash for ComponentRange

Source

impl Hash for OffsetDateTime

Source

impl Hash for PrimitiveDateTime

Source

impl Hash for Time

Source

impl Hash for UtcDateTime

Source

impl Hash for UtcOffset

Source

impl Hash for AnyDelimiterCodec

Source

impl Hash for BytesCodec

Source

impl Hash for LinesCodec

Source

impl Hash for tokio::net::unix::ucred::UCred

Source

impl Hash for tokio::runtime::id::Id

Source

impl Hash for tokio::runtime::task::id::Id

Source

impl Hash for SignalKind

Source

impl Hash for tokio::time::instant::Instant

Source

impl Hash for Identifier

Source

impl Hash for Field

Source

impl Hash for tracing_core::metadata::Level

Source

impl Hash for tracing_core::metadata::LevelFilter

Source

impl Hash for tracing_core::span::Id

Source

impl Hash for tracing::span::Span

Source

impl Hash for FiveTuple

Source

impl Hash for ChannelNumber

Source

impl Hash for Protocol

Source

impl Hash for ATerm

Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for Z0

Source

impl Hash for Equal

Source

impl Hash for Greater

Source

impl Hash for Less

Source

impl Hash for UTerm

Source

impl Hash for OpaqueOrigin

Source

impl Hash for Url

URLs hash like their serialization.

Source

impl Hash for uuid::error::Error

Source

impl Hash for Braced

Source

impl Hash for Hyphenated

Source

impl Hash for Simple

Source

impl Hash for Urn

Source

impl Hash for NonNilUuid

Source

impl Hash for Uuid

Source

impl Hash for Timestamp

Source

impl Hash for webrtc::ice_transport::ice_server::RTCIceServer

Source

impl Hash for ASN1Time

Source

impl Hash for x25519_dalek::x25519::PublicKey

Source

impl Hash for TaggedDerValue

Source

impl Hash for yasna::models::oid::ObjectIdentifier

Source

impl Hash for GeneralizedTime

Source

impl Hash for UTCTime

Source

impl Hash for Tag

Source

impl Hash for CharULE

Source

impl Hash for Index8

Source

impl Hash for Index16

Source

impl Hash for Index32

Source

impl Hash for __c_anonymous_ptrace_syscall_info_data

Available on crate feature extra_traits only.
Source

impl Hash for SockaddrStorage

Source

impl Hash for dyn ComInterface

Source

impl<'a> Hash for ValueKey<'a>

1.0.0 · Source

impl<'a> Hash for Component<'a>

1.0.0 · Source

impl<'a> Hash for datex_core::stdlib::path::Prefix<'a>

Source

impl<'a> Hash for Item<'a>

Source

impl<'a> Hash for FcntlArg<'a>

Source

impl<'a> Hash for PrefixDeclaration<'a>

Source

impl<'a> Hash for ServerName<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

Source

impl<'a> Hash for Oid<'a>

Source

impl<'a> Hash for Metadata<'a>

Source

impl<'a> Hash for MetadataBuilder<'a>

Source

impl<'a> Hash for Name<'a>

Source

impl<'a> Hash for LocalName<'a>

Source

impl<'a> Hash for Namespace<'a>

Source

impl<'a> Hash for quick_xml::name::Prefix<'a>

Source

impl<'a> Hash for QName<'a>

Source

impl<'a> Hash for DnsName<'a>

Source

impl<'a> Hash for CertificateDer<'a>

Source

impl<'a> Hash for CertificateRevocationListDer<'a>

Source

impl<'a> Hash for CertificateSigningRequestDer<'a>

Source

impl<'a> Hash for Der<'a>

Source

impl<'a> Hash for EchConfigListBytes<'a>

Source

impl<'a> Hash for SubjectPublicKeyInfoDer<'a>

Source

impl<'a> Hash for TrustAnchor<'a>

Source

impl<'d> Hash for Iter<'d>

Source

impl<'ns> Hash for ResolveResult<'ns>

Source

impl<A> Hash for ArrayString<A>
where A: Array<Item = u8> + Copy,

Source

impl<A> Hash for ArrayVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A, B> Hash for EitherOrBoth<A, B>
where A: Hash, B: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

Source

impl<B> Hash for BitSet<B>
where B: BitBlock,

Source

impl<B> Hash for BitVec<B>
where B: BitBlock,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

Source

impl<DataStruct> Hash for ErasedMarker<DataStruct>
where DataStruct: Hash + for<'a> Yokeable<'a>,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for datex_core::stdlib::ops::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for datex_core::stdlib::ops::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for datex_core::stdlib::ops::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for datex_core::stdlib::ops::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for datex_core::stdlib::range::Range<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for datex_core::stdlib::range::RangeFrom<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for datex_core::stdlib::range::RangeInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for datex_core::stdlib::range::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

Source

impl<K, V> Hash for ringmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<K, V, S> Hash for LinkedHashMap<K, V, S>
where K: Hash + Eq, V: Hash, S: BuildHasher,

Source

impl<K, V, S> Hash for LiteMap<K, V, S>
where K: Hash + ?Sized, V: Hash + ?Sized, S: Hash,

Source

impl<K, V, S> Hash for RingMap<K, V, S>
where K: Hash, V: Hash,

Source

impl<L, R> Hash for Either<L, R>
where L: Hash, R: Hash,

Source

impl<O> Hash for F32<O>
where O: Hash,

Source

impl<O> Hash for F64<O>
where O: Hash,

Source

impl<O> Hash for I16<O>
where O: Hash,

Source

impl<O> Hash for I32<O>
where O: Hash,

Source

impl<O> Hash for I64<O>
where O: Hash,

Source

impl<O> Hash for I128<O>
where O: Hash,

Source

impl<O> Hash for Isize<O>
where O: Hash,

Source

impl<O> Hash for U16<O>
where O: Hash,

Source

impl<O> Hash for U32<O>
where O: Hash,

Source

impl<O> Hash for U64<O>
where O: Hash,

Source

impl<O> Hash for U128<O>
where O: Hash,

Source

impl<O> Hash for Usize<O>
where O: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<S> Hash for Host<S>
where S: Hash,

Source

impl<Size> Hash for EncodedPoint<Size>
where Size: ModulusSize,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

Source

impl<T> Hash for LocalResult<T>
where T: Hash,

Source

impl<T> Hash for Attr<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

Source

impl<T> Hash for Exclusive<T>
where T: Sync + Hash + ?Sized,

Source

impl<T> Hash for Constant<T>
where T: Hash,

Source

impl<T> Hash for AllowStdIo<T>
where T: Hash,

Source

impl<T> Hash for indexmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for Intern<T>
where T: Eq + Hash + Send + Sync + ?Sized,

The hash implementation returns the hash of the pointer value, not the hash of the value pointed to. This should be irrelevant, since there is a unique pointer for every value, but it is observable, since you could compare the hash of the pointer with hash of the data itself.

Source

impl<T> Hash for IoVec<T>
where T: Hash,

Source

impl<T> Hash for Complex<T>
where T: Hash,

Source

impl<T> Hash for Ratio<T>
where T: Clone + Integer + Hash,

Source

impl<T> Hash for NotNan<T>
where T: PrimitiveFloat,

Source

impl<T> Hash for OrderedFloat<T>
where T: PrimitiveFloat,

Source

impl<T> Hash for ringmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for TryWriteableInfallibleAsWriteable<T>
where T: Hash,

Source

impl<T> Hash for WriteableAsTryWriteableInfallible<T>
where T: Hash,

Source

impl<T> Hash for Unalign<T>
where T: Unaligned + Hash,

1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for datex_core::stdlib::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for datex_core::stdlib::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
Source

impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;

let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, N> Hash for GenericArray<T, N>
where T: Hash, N: ArrayLength<T>,

Source

impl<T, S> Hash for RingSet<T, S>
where T: Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const N: usize> Hash for Simd<T, N>

Source

impl<Tz> Hash for chrono::date::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz> Hash for DateTime<Tz>
where Tz: TimeZone,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<U, const N: usize> Hash for NichedOption<U, N>
where U: Hash,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const LIMBS: usize> Hash for Uint<LIMBS>

Source

impl<const MIN: i8, const MAX: i8> Hash for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Hash for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for RangedUsize<MIN, MAX>

Source

impl<const N: usize> Hash for TinyAsciiStr<N>

Source

impl<const N: usize> Hash for RawBytesULE<N>

Source

impl<const SIZE: usize> Hash for WriteBuffer<SIZE>