Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
๐Ÿ”ฌThis is a nightly-only experimental API. (freeze)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Implementors

Source

impl<T> !Freeze for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Freeze for *const T is !null
where T: ?Sized,

Source

impl<T> Freeze for *const T
where T: ?Sized,

Source

impl<T> Freeze for *mut T is !null
where T: ?Sized,

Source

impl<T> Freeze for *mut T
where T: ?Sized,

Source

impl<T> Freeze for &T
where T: ?Sized,

Source

impl<T> Freeze for &mut T
where T: ?Sized,

1.28.0 ยท Source

impl<T> Freeze for NonZero<T>

Source

impl<T> Freeze for PhantomData<T>
where T: ?Sized,

Auto implementors



impl !Freeze for ExecutionContext



impl !Freeze for CompilationScope



impl !Freeze for PrecompilerData



impl !Freeze for CompileOptions



impl !Freeze for LanguageServerBackend



impl !Freeze for BlockHandler



impl !Freeze for ComHub



impl !Freeze for ComInterfaceInfo



impl !Freeze for BaseInterface



impl !Freeze for HTTPServerNativeInterface



impl !Freeze for LocalLoopbackInterface



impl !Freeze for SerialNativeInterface



impl !Freeze for TCPClientNativeInterface



impl !Freeze for TCPServerNativeInterface



impl !Freeze for WebRTCNativeInterface



impl !Freeze for WebSocketClientNativeInterface



impl !Freeze for WebSocketServerNativeInterface



impl !Freeze for LocalExecutionContext



impl !Freeze for RemoteExecutionContext



impl !Freeze for RuntimeInternal



impl !Freeze for Backtrace



impl !Freeze for AtomicBool



impl !Freeze for AtomicI8



impl !Freeze for AtomicI16



impl !Freeze for AtomicI32



impl !Freeze for AtomicI64



impl !Freeze for AtomicIsize



impl !Freeze for AtomicU8



impl !Freeze for AtomicU16



impl !Freeze for AtomicU32



impl !Freeze for AtomicU64



impl !Freeze for AtomicUsize



impl !Freeze for datex_core::stdlib::sync::nonpoison::Condvar



impl !Freeze for Barrier



impl !Freeze for datex_core::stdlib::sync::Condvar



impl !Freeze for datex_core::stdlib::sync::Once



impl !Freeze for OnceState



impl<'a> !Freeze for Request<'a>



impl<T> !Freeze for DataChannel<T>



impl<T> !Freeze for MediaTrack<T>



impl<T> !Freeze for datex_core::std_sync::Mutex<T>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> !Freeze for UnsafePinned<T>



impl<T> !Freeze for AtomicPtr<T>



impl<T> !Freeze for datex_core::stdlib::sync::nonpoison::Mutex<T>



impl<T> !Freeze for datex_core::stdlib::sync::nonpoison::RwLock<T>



impl<T> !Freeze for OnceLock<T>



impl<T> !Freeze for ReentrantLock<T>



impl<T> !Freeze for datex_core::stdlib::sync::RwLock<T>



impl<T> !Freeze for Storage<T>



impl<T, D> !Freeze for Storage<T, D>



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F = fn() -> T> !Freeze for LazyLock<T, F>



impl Freeze for DatexExpressionData



impl Freeze for Slot



impl Freeze for TypeDeclarationKind



impl Freeze for VariableKind



impl Freeze for ResolvedVariable



impl Freeze for TypeExpressionData



impl Freeze for TryReserveErrorKind



impl Freeze for StaticValueOrDXB



impl Freeze for VariableModel



impl Freeze for VariableRepresentation



impl Freeze for CompilerError



impl Freeze for SimpleCompilerErrorOrDetailedCompilerErrorWithRichAst



impl Freeze for SimpleOrDetailedCompilerError



impl Freeze for VariableShape



impl Freeze for NewScopeType



impl Freeze for CryptoError



impl Freeze for FormattingMode



impl Freeze for IndentType



impl Freeze for DIFApplyError



impl Freeze for DIFCreatePointerError



impl Freeze for DIFObserveError



impl Freeze for DIFResolveReferenceError



impl Freeze for DIFUpdateError



impl Freeze for DIFTypeRepresentation



impl Freeze for DIFValueRepresentation



impl Freeze for DIFTypeDefinition



impl Freeze for DIFTypeDefinitionKind



impl Freeze for DIFKey



impl Freeze for DIFUpdateData



impl Freeze for DIFValueContainer



impl Freeze for Assoc



impl Freeze for BracketStyle



impl Freeze for StatementFormatting



impl Freeze for TypeDeclarationFormatting



impl Freeze for VariantFormatting



impl Freeze for HeaderParsingError



impl Freeze for IncomingSection



impl Freeze for InstructionCode



impl Freeze for AssignmentOperator



impl Freeze for ArithmeticOperator



impl Freeze for BinaryOperator



impl Freeze for BitwiseOperator



impl Freeze for LogicalOperator



impl Freeze for ComparisonOperator



impl Freeze for ArithmeticUnaryOperator



impl Freeze for BitwiseUnaryOperator



impl Freeze for LogicalUnaryOperator



impl Freeze for ReferenceUnaryOperator



impl Freeze for UnaryOperator



impl Freeze for BlockType



impl Freeze for UserAgent



impl Freeze for Instruction



impl Freeze for RawPointerAddress



impl Freeze for RegularInstruction



impl Freeze for TypeInstruction



impl Freeze for EncryptionType



impl Freeze for ReceiverType



impl Freeze for Receivers



impl Freeze for SignatureType



impl Freeze for InternalSlot



impl Freeze for TypeInstructionCode



impl Freeze for TypeMutabilityCode



impl Freeze for CoreLibPointerId



impl Freeze for ComHubError



impl Freeze for InterfacePriority



impl Freeze for Response



impl Freeze for ResponseError



impl Freeze for ResponseResolutionStrategy



impl Freeze for ResponseTimeout



impl Freeze for SocketEndpointRegistrationError



impl Freeze for NetworkTraceHopDirection



impl Freeze for ComInterfaceError



impl Freeze for ComInterfaceState



impl Freeze for InterfaceDirection



impl Freeze for ReconnectionConfig



impl Freeze for SocketState



impl Freeze for BaseInterfaceError



impl Freeze for HTTPError



impl Freeze for SerialError



impl Freeze for TCPError



impl Freeze for MediaKind



impl Freeze for MediaTrackCodec



impl Freeze for RTCSdpTypeDX



impl Freeze for WebRTCError



impl Freeze for URLError



impl Freeze for WebSocketError



impl Freeze for WebSocketServerError



impl Freeze for ParserError



impl Freeze for Token



impl Freeze for ParserResult



impl Freeze for IntegerOrDecimal



impl Freeze for IntegerOrTypedInteger



impl Freeze for ObserverError



impl Freeze for datex_core::references::reference::AccessError



impl Freeze for AssignmentError



impl Freeze for Reference



impl Freeze for ReferenceCreationError



impl Freeze for ReferenceMutability



impl Freeze for datex_core::references::reference::TypeError



impl Freeze for ExecutionMode



impl Freeze for ScriptExecutionError



impl Freeze for ExecutionError



impl Freeze for InvalidProgramError



impl Freeze for ExecutionInterrupt



impl Freeze for ExternalExecutionInterrupt



impl Freeze for InterruptResult



impl Freeze for DeserializationError



impl Freeze for SerializationError



impl Freeze for InferOutcome



impl Freeze for SimpleOrDetailedTypeError



impl Freeze for datex_core::type_inference::error::TypeError



impl Freeze for ErrorHandling



impl Freeze for CollectionTypeDefinition



impl Freeze for TypeDefinition



impl Freeze for IllegalTypeError



impl Freeze for StructuralTypeDefinition



impl Freeze for Color



impl Freeze for CoreValue



impl Freeze for CallableBody



impl Freeze for CallableKind



impl Freeze for BigDecimalType



impl Freeze for Decimal



impl Freeze for DecimalTypeVariant



impl Freeze for TypedDecimal



impl Freeze for EndpointInstance



impl Freeze for EndpointType



impl Freeze for InvalidEndpointError



impl Freeze for NumberParseError



impl Freeze for IntegerTypeVariant



impl Freeze for TypedInteger



impl Freeze for datex_core::values::core_values::map::Map



impl Freeze for MapAccessError



impl Freeze for MapKey



impl Freeze for PointerAddress



impl Freeze for OwnedValueKey



impl Freeze for ValueContainer



impl Freeze for ValueError



impl Freeze for AsciiChar



impl Freeze for BacktraceStatus



impl Freeze for datex_core::stdlib::cmp::Ordering



impl Freeze for Infallible



impl Freeze for VarError



impl Freeze for FromBytesWithNulError



impl Freeze for c_void



impl Freeze for datex_core::stdlib::fmt::Alignment



impl Freeze for DebugAsHex



impl Freeze for Sign



impl Freeze for datex_core::stdlib::fs::TryLockError



impl Freeze for Locality



impl Freeze for AtomicOrdering



impl Freeze for BasicBlock



impl Freeze for UnwindTerminateReason



impl Freeze for SimdAlign



impl Freeze for ErrorKind



impl Freeze for SeekFrom



impl Freeze for IpAddr



impl Freeze for Ipv6MulticastScope



impl Freeze for Shutdown



impl Freeze for datex_core::stdlib::net::SocketAddr



impl Freeze for FpCategory



impl Freeze for IntErrorKind



impl Freeze for OneSidedRangeBound



impl Freeze for AncillaryError



impl Freeze for BacktraceStyle



impl Freeze for GetDisjointMutError



impl Freeze for SearchStep



impl Freeze for datex_core::stdlib::sync::atomic::Ordering



impl Freeze for RecvTimeoutError



impl Freeze for TryRecvError



impl Freeze for Apply



impl Freeze for BinaryOperation



impl Freeze for CallableDeclaration



impl Freeze for ComparisonOperation



impl Freeze for Conditional



impl Freeze for CreateRef



impl Freeze for DatexExpression



impl Freeze for Deref



impl Freeze for DerefAssignment



impl Freeze for GenericInstantiation



impl Freeze for datex_core::ast::expressions::List



impl Freeze for datex_core::ast::expressions::Map



impl Freeze for PropertyAccess



impl Freeze for PropertyAssignment



impl Freeze for RemoteExecution



impl Freeze for SlotAssignment



impl Freeze for Statements



impl Freeze for TypeDeclaration



impl Freeze for UnaryOperation



impl Freeze for UnboundedStatement



impl Freeze for VariableAccess



impl Freeze for VariableAssignment



impl Freeze for VariableDeclaration



impl Freeze for VariantAccess



impl Freeze for SrcId



impl Freeze for CallableTypeExpression



impl Freeze for FixedSizeList



impl Freeze for GenericAccess



impl Freeze for datex_core::ast::type_expressions::Intersection



impl Freeze for SliceList



impl Freeze for StructuralList



impl Freeze for StructuralMap



impl Freeze for TypeExpression



impl Freeze for TypeVariantAccess



impl Freeze for datex_core::ast::type_expressions::Union



impl Freeze for UnorderedKeyError



impl Freeze for TryReserveError



impl Freeze for CompilationContext



impl Freeze for VirtualSlot



impl Freeze for DetailedCompilerErrors



impl Freeze for DetailedCompilerErrorsWithMaybeRichAst



impl Freeze for DetailedCompilerErrorsWithRichAst



impl Freeze for SpannedCompilerError



impl Freeze for CompileMetadata



impl Freeze for PrecompilerOptions



impl Freeze for AstMetadata



impl Freeze for RichAst



impl Freeze for VariableMetadata



impl Freeze for PrecompilerScope



impl Freeze for PrecompilerScopeStack



impl Freeze for Variable



impl Freeze for CompilerWorkspace



impl Freeze for WorkspaceFile



impl Freeze for Crypto



impl Freeze for CryptoNative



impl Freeze for DecompileOptions



impl Freeze for datex_core::decompiler::FormattingOptions



impl Freeze for DIFReference



impl Freeze for DIFStructuralTypeDefinition



impl Freeze for DIFType



impl Freeze for DIFReferenceNotFoundError



impl Freeze for DIFValue



impl Freeze for datex_core::fmt::options::FormattingOptions



impl Freeze for BlockId



impl Freeze for DXBBlock



impl Freeze for IncomingEndpointContextId



impl Freeze for IncomingEndpointContextSectionId



impl Freeze for InstructionCodeIter



impl Freeze for BlockHeader



impl Freeze for FlagsAndTimestamp



impl Freeze for EncryptedHeader



impl Freeze for datex_core::global::protocol_structures::encrypted_header::Flags



impl Freeze for ApplyData



impl Freeze for DecimalData



impl Freeze for Float32Data



impl Freeze for Float64Data



impl Freeze for FloatAsInt16Data



impl Freeze for FloatAsInt32Data



impl Freeze for GetOrCreateRefData



impl Freeze for ImplTypeData



impl Freeze for InstructionBlockData



impl Freeze for InstructionCloseAndStore



impl Freeze for Int8Data



impl Freeze for Int16Data



impl Freeze for Int32Data



impl Freeze for Int64Data



impl Freeze for Int128Data



impl Freeze for IntegerData



impl Freeze for ListData



impl Freeze for MapData



impl Freeze for PointerAddressConversionError



impl Freeze for RawFullPointerAddress



impl Freeze for RawInternalPointerAddress



impl Freeze for RawLocalPointerAddress



impl Freeze for ShortListData



impl Freeze for ShortMapData



impl Freeze for ShortStatementsData



impl Freeze for ShortTextData



impl Freeze for ShortTextDataRaw



impl Freeze for SlotAddress



impl Freeze for StatementsData



impl Freeze for TextData



impl Freeze for TextDataRaw



impl Freeze for TypeMetadata



impl Freeze for TypeReferenceData



impl Freeze for UInt8Data



impl Freeze for UInt16Data



impl Freeze for UInt32Data



impl Freeze for UInt64Data



impl Freeze for UInt128Data



impl Freeze for UnboundedStatementsData



impl Freeze for datex_core::global::protocol_structures::routing_header::Flags



impl Freeze for Key512



impl Freeze for ReceiverEndpoints



impl Freeze for ReceiverEndpointsWithKeys



impl Freeze for RoutingHeader



impl Freeze for BlockHistoryData



impl Freeze for ScopeContext



impl Freeze for ComHubOptions



impl Freeze for DynamicEndpointProperties



impl Freeze for ResponseOptions



impl Freeze for NetworkTraceHop



impl Freeze for NetworkTraceHopSocket



impl Freeze for NetworkTraceResult



impl Freeze for TraceOptions



impl Freeze for ComInterfaceSockets



impl Freeze for ComInterfaceUUID



impl Freeze for InterfaceProperties



impl Freeze for ComInterfaceSocket



impl Freeze for ComInterfaceSocketUUID



impl Freeze for BaseInterfaceSetupData



impl Freeze for SerialInterfaceSetupData



impl Freeze for TCPClientInterfaceSetupData



impl Freeze for TCPServerInterfaceSetupData



impl Freeze for RTCIceCandidateInitDX



impl Freeze for RTCIceServer



impl Freeze for RTCSessionDescriptionDX



impl Freeze for WebRTCCommon



impl Freeze for WebRTCInterfaceSetupData



impl Freeze for WebSocketClientInterfaceSetupData



impl Freeze for WebSocketServerInterfaceSetupData



impl Freeze for DetailedParserErrorsWithAst



impl Freeze for SpannedParserError



impl Freeze for Loc



impl Freeze for NumericLiteralParts



impl Freeze for SpannedToken



impl Freeze for InvalidDatexParseResult



impl Freeze for ValidDatexParseResult



impl Freeze for Parser



impl Freeze for ParserOptions



impl Freeze for ObserveOptions



impl Freeze for Observer



impl Freeze for IndexOutOfBoundsError



impl Freeze for KeyNotFoundError



impl Freeze for NominalTypeDeclaration



impl Freeze for TypeReference



impl Freeze for ValueReference



impl Freeze for InterruptProvider



impl Freeze for ExecutionLoopState



impl Freeze for RuntimeExecutionSlots



impl Freeze for RuntimeExecutionState



impl Freeze for ExecutionOptions



impl Freeze for MemoryDump



impl Freeze for GlobalContext



impl Freeze for Memory



impl Freeze for AsyncContext



impl Freeze for Runtime



impl Freeze for RuntimeConfig



impl Freeze for RuntimeConfigInterface



impl Freeze for DatexDeserializer



impl Freeze for DatexSerializer



impl Freeze for MapSerializer



impl Freeze for SeqSerializer



impl Freeze for StructSerializer



impl Freeze for StructVariantSerializer



impl Freeze for TupleSerializer



impl Freeze for TupleStructSerializer



impl Freeze for TupleVariantSerializer



impl Freeze for RandomState



impl Freeze for Duration



impl Freeze for Instant



impl Freeze for SystemTime



impl Freeze for SystemTimeError



impl Freeze for TryFromFloatSecsError



impl Freeze for DetailedTypeErrors



impl Freeze for SpannedTypeError



impl Freeze for InferExpressionTypeOptions



impl Freeze for TypeInference



impl Freeze for TypeAlias



impl Freeze for AnsiCodes



impl Freeze for Time



impl Freeze for TimeNative



impl Freeze for UUID



impl Freeze for Boolean



impl Freeze for Callable



impl Freeze for CallableSignature



impl Freeze for Rational



impl Freeze for DecimalTypeVariantIter



impl Freeze for Endpoint



impl Freeze for EndpointParsingError



impl Freeze for Integer



impl Freeze for IntegerTypeVariantIter



impl Freeze for datex_core::values::core_values::list::List



impl Freeze for IntoMapIterator



impl Freeze for Text



impl Freeze for Type



impl Freeze for Value



impl Freeze for AllocError



impl Freeze for Global



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for System



impl Freeze for TypeId



impl Freeze for CpuidResult



impl Freeze for __m128



impl Freeze for __m128bh



impl Freeze for __m128d



impl Freeze for __m128h



impl Freeze for __m128i



impl Freeze for __m256



impl Freeze for __m256bh



impl Freeze for __m256d



impl Freeze for __m256h



impl Freeze for __m256i



impl Freeze for __m512



impl Freeze for __m512bh



impl Freeze for __m512d



impl Freeze for __m512h



impl Freeze for __m512i



impl Freeze for bf16



impl Freeze for TryFromSliceError



impl Freeze for datex_core::stdlib::ascii::EscapeDefault



impl Freeze for BacktraceFrame



impl Freeze for ByteStr



impl Freeze for ByteString



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for CharTryFromError



impl Freeze for DecodeUtf16Error



impl Freeze for datex_core::stdlib::char::EscapeDebug



impl Freeze for datex_core::stdlib::char::EscapeDefault



impl Freeze for datex_core::stdlib::char::EscapeUnicode



impl Freeze for ParseCharError



impl Freeze for ToLowercase



impl Freeze for ToUppercase



impl Freeze for TryFromCharError



impl Freeze for Args



impl Freeze for ArgsOs



impl Freeze for JoinPathsError



impl Freeze for Vars



impl Freeze for VarsOs



impl Freeze for CStr



impl Freeze for CString



impl Freeze for FromBytesUntilNulError



impl Freeze for FromVecWithNulError



impl Freeze for IntoStringError



impl Freeze for NulError



impl Freeze for OsStr



impl Freeze for OsString



impl Freeze for datex_core::stdlib::fmt::Error



impl Freeze for datex_core::stdlib::fmt::FormattingOptions



impl Freeze for DirBuilder



impl Freeze for DirEntry



impl Freeze for File



impl Freeze for FileTimes



impl Freeze for FileType



impl Freeze for Metadata



impl Freeze for OpenOptions



impl Freeze for Permissions



impl Freeze for ReadDir



impl Freeze for DefaultHasher



impl Freeze for SipHasher



impl Freeze for ReturnToArg



impl Freeze for UnwindActionArg



impl Freeze for datex_core::stdlib::io::Empty



impl Freeze for datex_core::stdlib::io::Error



impl Freeze for PipeReader



impl Freeze for PipeWriter



impl Freeze for datex_core::stdlib::io::Repeat



impl Freeze for Sink



impl Freeze for Stderr



impl Freeze for Stdin



impl Freeze for Stdout



impl Freeze for WriterPanicked



impl Freeze for Assume



impl Freeze for AddrParseError



impl Freeze for IntoIncoming



impl Freeze for Ipv4Addr



impl Freeze for Ipv6Addr



impl Freeze for SocketAddrV4



impl Freeze for SocketAddrV6



impl Freeze for TcpListener



impl Freeze for TcpStream



impl Freeze for UdpSocket



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for TryFromIntError



impl Freeze for RangeFull



impl Freeze for OwnedFd



impl Freeze for PidFd



impl Freeze for stat



impl Freeze for datex_core::stdlib::os::unix::net::SocketAddr



impl Freeze for SocketCred



impl Freeze for UCred



impl Freeze for UnixDatagram



impl Freeze for UnixListener



impl Freeze for UnixStream



impl Freeze for NormalizeError



impl Freeze for Path



impl Freeze for PathBuf



impl Freeze for StripPrefixError



impl Freeze for Child



impl Freeze for ChildStderr



impl Freeze for ChildStdin



impl Freeze for ChildStdout



impl Freeze for Command



impl Freeze for ExitCode



impl Freeze for ExitStatus



impl Freeze for ExitStatusError



impl Freeze for Output



impl Freeze for Stdio



impl Freeze for datex_core::stdlib::ptr::Alignment



impl Freeze for DefaultRandomSource



impl Freeze for ParseBoolError



impl Freeze for Utf8Error



impl Freeze for FromUtf8Error



impl Freeze for FromUtf16Error



impl Freeze for IntoChars



impl Freeze for String



impl Freeze for RecvError



impl Freeze for WouldBlock



impl Freeze for BarrierWaitResult



impl Freeze for WaitTimeoutResult



impl Freeze for LocalWaker



impl Freeze for RawWaker



impl Freeze for RawWakerVTable



impl Freeze for Waker



impl Freeze for datex_core::stdlib::thread::AccessError



impl Freeze for Builder



impl Freeze for Thread



impl Freeze for ThreadId



impl Freeze for PhantomPinned



impl<'a> Freeze for Operation<'a>



impl<'a> Freeze for DIFUpdateDataOrMemory<'a>



impl<'a> Freeze for BorrowedMapKey<'a>



impl<'a> Freeze for MapMutIterator<'a>



impl<'a> Freeze for ValueKey<'a>



impl<'a> Freeze for AncillaryData<'a>



impl<'a> Freeze for Component<'a>



impl<'a> Freeze for Prefix<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'a> Freeze for Precompiler<'a>



impl<'a> Freeze for DIFUpdate<'a>



impl<'a> Freeze for datex_core::fmt::Formatter<'a>



impl<'a> Freeze for ParentContext<'a>



impl<'a> Freeze for ExecutionInput<'a>



impl<'a> Freeze for MapIterator<'a>



impl<'a> Freeze for SplitPaths<'a>



impl<'a> Freeze for datex_core::stdlib::ffi::os_str::Display<'a>



impl<'a> Freeze for VaList<'a>



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for datex_core::stdlib::fmt::Formatter<'a>



impl<'a> Freeze for BorrowedCursor<'a>



impl<'a> Freeze for IoSlice<'a>



impl<'a> Freeze for IoSliceMut<'a>



impl<'a> Freeze for StderrLock<'a>



impl<'a> Freeze for StdinLock<'a>



impl<'a> Freeze for StdoutLock<'a>



impl<'a> Freeze for datex_core::stdlib::net::Incoming<'a>



impl<'a> Freeze for datex_core::stdlib::os::unix::net::Incoming<'a>



impl<'a> Freeze for Messages<'a>



impl<'a> Freeze for ScmCredentials<'a>



impl<'a> Freeze for ScmRights<'a>



impl<'a> Freeze for SocketAncillary<'a>



impl<'a> Freeze for Location<'a>



impl<'a> Freeze for PanicHookInfo<'a>



impl<'a> Freeze for Ancestors<'a>



impl<'a> Freeze for Components<'a>



impl<'a> Freeze for datex_core::stdlib::path::Display<'a>



impl<'a> Freeze for datex_core::stdlib::path::Iter<'a>



impl<'a> Freeze for PrefixComponent<'a>



impl<'a> Freeze for CommandArgs<'a>



impl<'a> Freeze for CommandEnvs<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for datex_core::stdlib::str::Bytes<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for datex_core::stdlib::str::EscapeDebug<'a>



impl<'a> Freeze for datex_core::stdlib::str::EscapeDefault<'a>



impl<'a> Freeze for datex_core::stdlib::str::EscapeUnicode<'a>



impl<'a> Freeze for datex_core::stdlib::str::Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for datex_core::stdlib::string::Drain<'a>



impl<'a> Freeze for Context<'a>



impl<'a> Freeze for ContextBuilder<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> Freeze for datex_core::stdlib::option::Iter<'a, A>



impl<'a, A> Freeze for datex_core::stdlib::option::IterMut<'a, A>



impl<'a, B> Freeze for Cow<'a, B>
where <B as ToOwned>::Owned: Freeze, B: ?Sized,



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>
where F: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, I, A> Freeze for datex_core::collections::vec_deque::Splice<'a, I, A>
where I: Freeze,



impl<'a, I, A> Freeze for datex_core::stdlib::vec::Splice<'a, I, A>
where I: Freeze,



impl<'a, K> Freeze for datex_core::collections::btree_set::Cursor<'a, K>



impl<'a, K> Freeze for datex_core::collections::hash_set::Drain<'a, K>



impl<'a, K> Freeze for datex_core::collections::hash_set::Iter<'a, K>



impl<'a, K, A> Freeze for datex_core::collections::btree_set::CursorMut<'a, K, A>



impl<'a, K, A> Freeze for datex_core::collections::btree_set::CursorMutKey<'a, K, A>



impl<'a, K, F> Freeze for datex_core::collections::hash_set::ExtractIf<'a, K, F>
where F: Freeze,



impl<'a, K, V> Freeze for datex_core::collections::hash_map::Entry<'a, K, V>
where K: Freeze,



impl<'a, K, V> Freeze for datex_core::collections::btree_map::Cursor<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::Iter<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::IterMut<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::Keys<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::Range<'a, K, V>



impl<'a, K, V> Freeze for RangeMut<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::Values<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::btree_map::ValuesMut<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::Drain<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::Iter<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::IterMut<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::Keys<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::OccupiedEntry<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::OccupiedError<'a, K, V>
where V: Freeze,



impl<'a, K, V> Freeze for datex_core::collections::hash_map::VacantEntry<'a, K, V>
where K: Freeze,



impl<'a, K, V> Freeze for datex_core::collections::hash_map::Values<'a, K, V>



impl<'a, K, V> Freeze for datex_core::collections::hash_map::ValuesMut<'a, K, V>



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::Entry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::CursorMut<'a, K, V, A>



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::CursorMutKey<'a, K, V, A>



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Freeze,



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::OccupiedError<'a, K, V, A>
where V: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for datex_core::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, F> Freeze for datex_core::collections::hash_map::ExtractIf<'a, K, V, F>
where F: Freeze,



impl<'a, K, V, R, F, A> Freeze for datex_core::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, P> Freeze for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for datex_core::stdlib::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for datex_core::stdlib::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for datex_core::stdlib::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for datex_core::stdlib::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for datex_core::stdlib::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, T> Freeze for datex_core::collections::binary_heap::Iter<'a, T>



impl<'a, T> Freeze for datex_core::collections::btree_set::Iter<'a, T>



impl<'a, T> Freeze for datex_core::collections::btree_set::Range<'a, T>



impl<'a, T> Freeze for datex_core::collections::btree_set::SymmetricDifference<'a, T>



impl<'a, T> Freeze for datex_core::collections::btree_set::Union<'a, T>



impl<'a, T> Freeze for datex_core::collections::linked_list::Iter<'a, T>



impl<'a, T> Freeze for datex_core::collections::linked_list::IterMut<'a, T>



impl<'a, T> Freeze for datex_core::collections::vec_deque::Iter<'a, T>



impl<'a, T> Freeze for datex_core::collections::vec_deque::IterMut<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::result::Iter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::result::IterMut<'a, T>



impl<'a, T> Freeze for Chunks<'a, T>



impl<'a, T> Freeze for ChunksExact<'a, T>



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::slice::Iter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::slice::IterMut<'a, T>



impl<'a, T> Freeze for RChunks<'a, T>



impl<'a, T> Freeze for RChunksExact<'a, T>



impl<'a, T> Freeze for RChunksExactMut<'a, T>



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for Windows<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::sync::mpmc::Iter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::sync::mpmc::TryIter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::sync::mpsc::Iter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::sync::mpsc::TryIter<'a, T>



impl<'a, T> Freeze for datex_core::stdlib::sync::nonpoison::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for datex_core::stdlib::sync::nonpoison::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for datex_core::stdlib::sync::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for datex_core::stdlib::sync::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for ReentrantLockGuard<'a, T>
where T: ?Sized,



impl<'a, T, A> Freeze for datex_core::collections::btree_set::Entry<'a, T, A>
where A: Freeze, T: Freeze,



impl<'a, T, A> Freeze for datex_core::collections::binary_heap::Drain<'a, T, A>



impl<'a, T, A> Freeze for DrainSorted<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::binary_heap::PeekMut<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::btree_set::Difference<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::btree_set::Intersection<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Freeze,



impl<'a, T, A> Freeze for datex_core::collections::btree_set::VacantEntry<'a, T, A>
where T: Freeze, A: Freeze,



impl<'a, T, A> Freeze for datex_core::collections::linked_list::Cursor<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::linked_list::CursorMut<'a, T, A>



impl<'a, T, A> Freeze for datex_core::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> Freeze for datex_core::stdlib::vec::Drain<'a, T, A>



impl<'a, T, A> Freeze for datex_core::stdlib::vec::PeekMut<'a, T, A>



impl<'a, T, F, A> Freeze for datex_core::collections::linked_list::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, F, A> Freeze for datex_core::collections::vec_deque::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, F, A> Freeze for datex_core::stdlib::vec::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for datex_core::stdlib::slice::RSplit<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for datex_core::stdlib::slice::RSplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for datex_core::stdlib::slice::Split<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for datex_core::stdlib::slice::SplitInclusive<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for datex_core::stdlib::slice::SplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, R, F, A> Freeze for datex_core::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, T, S> Freeze for datex_core::collections::hash_set::Entry<'a, T, S>
where T: Freeze,



impl<'a, T, S> Freeze for datex_core::collections::hash_set::Difference<'a, T, S>



impl<'a, T, S> Freeze for datex_core::collections::hash_set::Intersection<'a, T, S>



impl<'a, T, S> Freeze for datex_core::collections::hash_set::OccupiedEntry<'a, T, S>



impl<'a, T, S> Freeze for datex_core::collections::hash_set::SymmetricDifference<'a, T, S>



impl<'a, T, S> Freeze for datex_core::collections::hash_set::Union<'a, T, S>



impl<'a, T, S> Freeze for datex_core::collections::hash_set::VacantEntry<'a, T, S>
where T: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>



impl<'b, T> Freeze for Ref<'b, T>
where T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>
where T: ?Sized,



impl<'data> Freeze for BorrowedBuf<'data>



impl<'fd> Freeze for BorrowedFd<'fd>



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::nonpoison::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::nonpoison::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::nonpoison::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::nonpoison::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for datex_core::stdlib::sync::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'scope, 'env> Freeze for Scope<'scope, 'env>



impl<'scope, T> Freeze for ScopedJoinHandle<'scope, T>



impl<A> Freeze for datex_core::stdlib::iter::Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>
where A: Freeze,



impl<A> Freeze for datex_core::stdlib::option::IntoIter<A>
where A: Freeze,



impl<A> Freeze for OptionFlatten<A>
where A: Freeze,



impl<A> Freeze for RangeFromIter<A>
where A: Freeze,



impl<A> Freeze for RangeInclusiveIter<A>
where A: Freeze,



impl<A> Freeze for RangeIter<A>
where A: Freeze,



impl<A, B> Freeze for datex_core::stdlib::iter::Chain<A, B>
where A: Freeze, B: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<B> Freeze for datex_core::stdlib::io::Lines<B>
where B: Freeze,



impl<B> Freeze for datex_core::stdlib::io::Split<B>
where B: Freeze,



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<Dyn> Freeze for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<E> Freeze for Report<E>
where E: Freeze,



impl<F> Freeze for datex_core::stdlib::fmt::FromFn<F>
where F: Freeze,



impl<F> Freeze for PollFn<F>
where F: Freeze,



impl<F> Freeze for datex_core::stdlib::iter::FromFn<F>
where F: Freeze,



impl<F> Freeze for OnceWith<F>
where F: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>



impl<I> Freeze for FromIter<I>
where I: Freeze,



impl<I> Freeze for DecodeUtf16<I>
where I: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Freeze, I: Freeze,



impl<I> Freeze for Fuse<I>
where I: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for datex_core::stdlib::iter::Take<I>
where I: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for datex_core::stdlib::iter::Map<I, F>
where I: Freeze, F: Freeze,



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, I: Freeze, <I as Iterator>::Item: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, <I as Iterator>::Item: Freeze, I: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Freeze, I: Freeze, F: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<Idx> Freeze for datex_core::stdlib::ops::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::ops::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::ops::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::ops::RangeToInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::range::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::range::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::range::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for datex_core::stdlib::range::RangeToInclusive<Idx>
where Idx: Freeze,



impl<K> Freeze for datex_core::collections::hash_set::IntoIter<K>



impl<K, T> Freeze for FreeHashMap<K, T>
where K: Freeze,



impl<K, V> Freeze for datex_core::collections::hash_map::IntoIter<K, V>



impl<K, V> Freeze for datex_core::collections::hash_map::IntoKeys<K, V>



impl<K, V> Freeze for datex_core::collections::hash_map::IntoValues<K, V>



impl<K, V, A> Freeze for datex_core::collections::btree_map::IntoIter<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for datex_core::collections::btree_map::IntoKeys<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for datex_core::collections::btree_map::IntoValues<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for BTreeMap<K, V, A>
where A: Freeze,



impl<K, V, S> Freeze for HashMap<K, V, S>
where S: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<Ptr> Freeze for Pin<Ptr>
where Ptr: Freeze,



impl<R> Freeze for BufReader<R>
where R: Freeze + ?Sized,



impl<R> Freeze for datex_core::stdlib::io::Bytes<R>
where R: Freeze,



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for MaybeAction<T>
where T: Freeze,



impl<T> Freeze for DeserializeMapOrArray<T>
where T: Freeze,



impl<T> Freeze for VisitAction<T>
where T: Freeze,



impl<T> Freeze for Option<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::sync::TryLockError<T>
where T: Freeze,



impl<T> Freeze for SendTimeoutError<T>
where T: Freeze,



impl<T> Freeze for TrySendError<T>
where T: Freeze,



impl<T> Freeze for Poll<T>
where T: Freeze,



impl<T> Freeze for DataChannels<T>



impl<T> Freeze for MediaTracks<T>



impl<T> Freeze for LiteralWithVariant<T>
where T: Freeze,



impl<T> Freeze for datex_core::task::Receiver<T>



impl<T> Freeze for datex_core::task::Sender<T>



impl<T> Freeze for UnboundedReceiver<T>



impl<T> Freeze for UnboundedSender<T>



impl<T> Freeze for ThinBox<T>
where T: ?Sized,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Pending<T>



impl<T> Freeze for Ready<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::io::Cursor<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::io::Take<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::iter::Empty<T>



impl<T> Freeze for datex_core::stdlib::iter::Once<T>
where T: Freeze,



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for ManuallyDrop<T>
where T: Freeze + ?Sized,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<T> Freeze for AssertUnwindSafe<T>
where T: Freeze,



impl<T> Freeze for NonNull<T>
where T: ?Sized,



impl<T> Freeze for datex_core::stdlib::result::IntoIter<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::sync::mpmc::IntoIter<T>



impl<T> Freeze for datex_core::stdlib::sync::mpmc::Receiver<T>



impl<T> Freeze for SendError<T>
where T: Freeze,



impl<T> Freeze for datex_core::stdlib::sync::mpmc::Sender<T>



impl<T> Freeze for datex_core::stdlib::sync::mpsc::IntoIter<T>



impl<T> Freeze for datex_core::stdlib::sync::mpsc::Receiver<T>



impl<T> Freeze for datex_core::stdlib::sync::mpsc::Sender<T>



impl<T> Freeze for SyncSender<T>



impl<T> Freeze for Exclusive<T>
where T: Freeze + ?Sized,



impl<T> Freeze for PoisonError<T>
where T: Freeze,



impl<T> Freeze for JoinHandle<T>



impl<T> Freeze for LocalKey<T>



impl<T> Freeze for PhantomContravariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where T: ?Sized,



impl<T> Freeze for MaybeUninit<T>
where T: Freeze,



impl<T, A> Freeze for datex_core::collections::binary_heap::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for IntoIterSorted<T, A>
where A: Freeze,



impl<T, A> Freeze for datex_core::collections::btree_set::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for datex_core::collections::linked_list::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for BTreeSet<T, A>
where A: Freeze,



impl<T, A> Freeze for BinaryHeap<T, A>
where A: Freeze,



impl<T, A> Freeze for LinkedList<T, A>
where A: Freeze,



impl<T, A> Freeze for VecDeque<T, A>
where A: Freeze,



impl<T, A> Freeze for datex_core::collections::vec_deque::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for Box<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for Rc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueRc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for datex_core::stdlib::rc::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for Arc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueArc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for datex_core::stdlib::sync::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for datex_core::stdlib::vec::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for Vec<T, A>
where A: Freeze,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F> Freeze for Successors<T, F>
where F: Freeze, T: Freeze,



impl<T, F> Freeze for DropGuard<T, F>
where T: Freeze, F: Freeze,



impl<T, S> Freeze for HashSet<T, S>
where S: Freeze,



impl<T, U> Freeze for datex_core::stdlib::io::Chain<T, U>
where T: Freeze, U: Freeze,



impl<T, const N: usize> Freeze for datex_core::stdlib::array::IntoIter<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for Mask<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for Simd<T, N>
where T: Freeze,



impl<W> Freeze for BufWriter<W>
where W: Freeze + ?Sized,



impl<W> Freeze for IntoInnerError<W>
where W: Freeze,



impl<W> Freeze for LineWriter<W>
where W: Freeze + ?Sized,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,



impl<const N: usize> Freeze for LaneCount<N>