UnwindSafe

Trait UnwindSafe 

1.9.0 · Source
pub auto trait UnwindSafe { }
A marker trait which represents “panic safe” types in Rust.

This trait is implemented by default for many types and behaves similarly in terms of inference of implementation to the Send and Sync traits. The purpose of this trait is to encode what types are safe to cross a catch_unwind boundary with no fear of unwind safety.

What is unwind safety?

In Rust a function can “return” early if it either panics or calls a function which transitively panics. This sort of control flow is not always anticipated, and has the possibility of causing subtle bugs through a combination of two critical components:

  1. A data structure is in a temporarily invalid state when the thread panics.
  2. This broken invariant is then later observed.

Typically in Rust, it is difficult to perform step (2) because catching a panic involves either spawning a thread (which in turn makes it difficult to later witness broken invariants) or using the catch_unwind function in this module. Additionally, even if an invariant is witnessed, it typically isn’t a problem in Rust because there are no uninitialized values (like in C or C++).

It is possible, however, for logical invariants to be broken in Rust, which can end up causing behavioral bugs. Another key aspect of unwind safety in Rust is that, in the absence of unsafe code, a panic cannot lead to memory unsafety.

That was a bit of a whirlwind tour of unwind safety, but for more information about unwind safety and how it applies to Rust, see an associated RFC.

What is UnwindSafe?

Now that we’ve got an idea of what unwind safety is in Rust, it’s also important to understand what this trait represents. As mentioned above, one way to witness broken invariants is through the catch_unwind function in this module as it allows catching a panic and then re-using the environment of the closure.

Simply put, a type T implements UnwindSafe if it cannot easily allow witnessing a broken invariant through the use of catch_unwind (catching a panic). This trait is an auto trait, so it is automatically implemented for many types, and it is also structurally composed (e.g., a struct is unwind safe if all of its components are unwind safe).

Note, however, that this is not an unsafe trait, so there is not a succinct contract that this trait is providing. Instead it is intended as more of a “speed bump” to alert users of catch_unwind that broken invariants may be witnessed and may need to be accounted for.

Who implements UnwindSafe?

Types such as &mut T and &RefCell<T> are examples which are not unwind safe. The general idea is that any mutable state which can be shared across catch_unwind is not unwind safe by default. This is because it is very easy to witness a broken invariant outside of catch_unwind as the data is simply accessed as usual.

Types like &Mutex<T>, however, are unwind safe because they implement poisoning by default. They still allow witnessing a broken invariant, but they already provide their own “speed bumps” to do so.

When should UnwindSafe be used?

It is not intended that most types or functions need to worry about this trait. It is only used as a bound on the catch_unwind function and as mentioned above, the lack of unsafe means it is mostly an advisory. The AssertUnwindSafe wrapper struct can be used to force this trait to be implemented for any closed over variables passed to catch_unwind.

Implementors

1.9.0 · Source

impl<T> !UnwindSafe for &mut T
where T: ?Sized,

1.9.0 · Source

impl UnwindSafe for Stderr

1.9.0 · Source

impl UnwindSafe for StderrLock<'_>

1.9.0 · Source

impl UnwindSafe for Stdout

1.9.0 · Source

impl UnwindSafe for StdoutLock<'_>

1.9.0 · Source

impl UnwindSafe for datex_core::stdlib::sync::Condvar

1.59.0 · Source

impl UnwindSafe for datex_core::stdlib::sync::Once

Source

impl UnwindSafe for CancellationToken

Source

impl UnwindSafe for Handle

Source

impl UnwindSafe for tokio::runtime::runtime::Runtime

Source

impl UnwindSafe for AbortHandle

Source

impl UnwindSafe for Notify

1.64.0 · Source

impl<K, V, A> UnwindSafe for BTreeMap<K, V, A>

1.36.0 · Source

impl<K, V, S> UnwindSafe for HashMap<K, V, S>
where K: UnwindSafe, V: UnwindSafe, S: UnwindSafe,

1.9.0 · Source

impl<T> UnwindSafe for *const T
where T: RefUnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for *mut T
where T: RefUnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for &T
where T: RefUnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for datex_core::std_sync::Mutex<T>
where T: ?Sized,

1.28.0 · Source

impl<T> UnwindSafe for NonZero<T>

1.25.0 · Source

impl<T> UnwindSafe for NonNull<T>
where T: RefUnwindSafe + ?Sized,

Source

impl<T> UnwindSafe for datex_core::stdlib::sync::mpmc::Receiver<T>

Source

impl<T> UnwindSafe for datex_core::stdlib::sync::mpmc::Sender<T>

1.70.0 · Source

impl<T> UnwindSafe for OnceLock<T>
where T: UnwindSafe,

Source

impl<T> UnwindSafe for ReentrantLock<T>
where T: UnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for datex_core::stdlib::sync::RwLock<T>
where T: ?Sized,

Source

impl<T> UnwindSafe for once_cell::unsync::OnceCell<T>
where T: UnwindSafe,

Source

impl<T> UnwindSafe for tokio::runtime::task::join::JoinHandle<T>

1.9.0 · Source

impl<T> UnwindSafe for AssertUnwindSafe<T>

1.9.0 · Source

impl<T, A> UnwindSafe for Rc<T, A>

1.9.0 · Source

impl<T, A> UnwindSafe for Arc<T, A>

1.9.0 · Source

impl<T, A> UnwindSafe for datex_core::stdlib::vec::IntoIter<T, A>

1.80.0 · Source

impl<T, F> UnwindSafe for LazyLock<T, F>
where T: UnwindSafe, F: UnwindSafe,

Auto implementors



impl !UnwindSafe for DatexExpressionData



impl !UnwindSafe for TypeExpressionData



impl !UnwindSafe for StaticValueOrDXB



impl !UnwindSafe for CompilerError



impl !UnwindSafe for SimpleCompilerErrorOrDetailedCompilerErrorWithRichAst



impl !UnwindSafe for SimpleOrDetailedCompilerError



impl !UnwindSafe for DIFApplyError



impl !UnwindSafe for DIFUpdateError



impl !UnwindSafe for IncomingSection



impl !UnwindSafe for Response



impl !UnwindSafe for ParserResult



impl !UnwindSafe for datex_core::references::reference::AccessError



impl !UnwindSafe for AssignmentError



impl !UnwindSafe for Reference



impl !UnwindSafe for datex_core::references::reference::TypeError



impl !UnwindSafe for ExecutionContext



impl !UnwindSafe for ScriptExecutionError



impl !UnwindSafe for ExecutionError



impl !UnwindSafe for ExecutionInterrupt



impl !UnwindSafe for ExternalExecutionInterrupt



impl !UnwindSafe for InterruptResult



impl !UnwindSafe for DeserializationError



impl !UnwindSafe for SerializationError



impl !UnwindSafe for InferOutcome



impl !UnwindSafe for SimpleOrDetailedTypeError



impl !UnwindSafe for datex_core::type_inference::error::TypeError



impl !UnwindSafe for CollectionTypeDefinition



impl !UnwindSafe for TypeDefinition



impl !UnwindSafe for StructuralTypeDefinition



impl !UnwindSafe for CoreValue



impl !UnwindSafe for datex_core::values::core_values::map::Map



impl !UnwindSafe for MapAccessError



impl !UnwindSafe for MapKey



impl !UnwindSafe for OwnedValueKey



impl !UnwindSafe for ValueContainer



impl !UnwindSafe for datex_core::stdlib::fs::TryLockError



impl !UnwindSafe for Apply



impl !UnwindSafe for BinaryOperation



impl !UnwindSafe for CallableDeclaration



impl !UnwindSafe for ComparisonOperation



impl !UnwindSafe for Conditional



impl !UnwindSafe for CreateRef



impl !UnwindSafe for DatexExpression



impl !UnwindSafe for Deref



impl !UnwindSafe for DerefAssignment



impl !UnwindSafe for GenericInstantiation



impl !UnwindSafe for datex_core::ast::expressions::List



impl !UnwindSafe for datex_core::ast::expressions::Map



impl !UnwindSafe for PropertyAccess



impl !UnwindSafe for PropertyAssignment



impl !UnwindSafe for RemoteExecution



impl !UnwindSafe for SlotAssignment



impl !UnwindSafe for Statements



impl !UnwindSafe for TypeDeclaration



impl !UnwindSafe for UnaryOperation



impl !UnwindSafe for VariableAssignment



impl !UnwindSafe for VariableDeclaration



impl !UnwindSafe for CallableTypeExpression



impl !UnwindSafe for FixedSizeList



impl !UnwindSafe for GenericAccess



impl !UnwindSafe for datex_core::ast::type_expressions::Intersection



impl !UnwindSafe for SliceList



impl !UnwindSafe for StructuralList



impl !UnwindSafe for StructuralMap



impl !UnwindSafe for TypeExpression



impl !UnwindSafe for datex_core::ast::type_expressions::Union



impl !UnwindSafe for CompilationContext



impl !UnwindSafe for DetailedCompilerErrors



impl !UnwindSafe for DetailedCompilerErrorsWithMaybeRichAst



impl !UnwindSafe for DetailedCompilerErrorsWithRichAst



impl !UnwindSafe for SpannedCompilerError



impl !UnwindSafe for AstMetadata



impl !UnwindSafe for RichAst



impl !UnwindSafe for VariableMetadata



impl !UnwindSafe for CompilationScope



impl !UnwindSafe for PrecompilerData



impl !UnwindSafe for CompileOptions



impl !UnwindSafe for CompilerWorkspace



impl !UnwindSafe for WorkspaceFile



impl !UnwindSafe for LanguageServerBackend



impl !UnwindSafe for BlockHandler



impl !UnwindSafe for ScopeContext



impl !UnwindSafe for ComHub



impl !UnwindSafe for BaseInterface



impl !UnwindSafe for HTTPServerNativeInterface



impl !UnwindSafe for TCPClientNativeInterface



impl !UnwindSafe for WebRTCCommon



impl !UnwindSafe for WebRTCNativeInterface



impl !UnwindSafe for WebSocketClientNativeInterface



impl !UnwindSafe for DetailedParserErrorsWithAst



impl !UnwindSafe for InvalidDatexParseResult



impl !UnwindSafe for ValidDatexParseResult



impl !UnwindSafe for Observer



impl !UnwindSafe for KeyNotFoundError



impl !UnwindSafe for TypeReference



impl !UnwindSafe for ValueReference



impl !UnwindSafe for LocalExecutionContext



impl !UnwindSafe for RemoteExecutionContext



impl !UnwindSafe for InterruptProvider



impl !UnwindSafe for ExecutionLoopState



impl !UnwindSafe for RuntimeExecutionSlots



impl !UnwindSafe for RuntimeExecutionState



impl !UnwindSafe for MemoryDump



impl !UnwindSafe for GlobalContext



impl !UnwindSafe for Memory



impl !UnwindSafe for datex_core::runtime::Runtime



impl !UnwindSafe for RuntimeConfig



impl !UnwindSafe for RuntimeConfigInterface



impl !UnwindSafe for RuntimeInternal



impl !UnwindSafe for DatexDeserializer



impl !UnwindSafe for MapSerializer



impl !UnwindSafe for SeqSerializer



impl !UnwindSafe for StructSerializer



impl !UnwindSafe for StructVariantSerializer



impl !UnwindSafe for TupleSerializer



impl !UnwindSafe for TupleStructSerializer



impl !UnwindSafe for TupleVariantSerializer



impl !UnwindSafe for DetailedTypeErrors



impl !UnwindSafe for SpannedTypeError



impl !UnwindSafe for TypeInference



impl !UnwindSafe for TypeAlias



impl !UnwindSafe for Callable



impl !UnwindSafe for CallableSignature



impl !UnwindSafe for datex_core::values::core_values::list::List



impl !UnwindSafe for IntoMapIterator



impl !UnwindSafe for Type



impl !UnwindSafe for Value



impl !UnwindSafe for datex_core::stdlib::io::Error



impl !UnwindSafe for Command



impl<'a> !UnwindSafe for DIFUpdateDataOrMemory<'a>



impl<'a> !UnwindSafe for BorrowedMapKey<'a>



impl<'a> !UnwindSafe for MapMutIterator<'a>



impl<'a> !UnwindSafe for ValueKey<'a>



impl<'a> !UnwindSafe for Precompiler<'a>



impl<'a> !UnwindSafe for datex_core::fmt::Formatter<'a>



impl<'a> !UnwindSafe for ExecutionInput<'a>



impl<'a> !UnwindSafe for MapIterator<'a>



impl<'a> !UnwindSafe for Request<'a>



impl<'a> !UnwindSafe for datex_core::stdlib::fmt::Formatter<'a>



impl<'a> !UnwindSafe for BorrowedCursor<'a>



impl<'a> !UnwindSafe for IoSliceMut<'a>



impl<'a> !UnwindSafe for SocketAncillary<'a>



impl<'a> !UnwindSafe for ContextBuilder<'a>



impl<'a> !UnwindSafe for PanicHookInfo<'a>



impl<'a, 'b> !UnwindSafe for DebugList<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugMap<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugSet<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugStruct<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugTuple<'a, 'b>



impl<'a, A> !UnwindSafe for datex_core::stdlib::option::IterMut<'a, A>



impl<'a, I> !UnwindSafe for ByRefSized<'a, I>



impl<'a, K, A = Global> !UnwindSafe for datex_core::collections::btree_set::CursorMut<'a, K, A>



impl<'a, K, A = Global> !UnwindSafe for datex_core::collections::btree_set::CursorMutKey<'a, K, A>



impl<'a, K, F> !UnwindSafe for datex_core::collections::hash_set::ExtractIf<'a, K, F>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::Entry<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::btree_map::IterMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for RangeMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::btree_map::ValuesMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::IterMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::OccupiedEntry<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::OccupiedError<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::VacantEntry<'a, K, V>



impl<'a, K, V> !UnwindSafe for datex_core::collections::hash_map::ValuesMut<'a, K, V>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::Entry<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::CursorMut<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::CursorMutKey<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::OccupiedEntry<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::OccupiedError<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::collections::btree_map::VacantEntry<'a, K, V, A>



impl<'a, K, V, F> !UnwindSafe for datex_core::collections::hash_map::ExtractIf<'a, K, V, F>



impl<'a, K, V, R, F, A = Global> !UnwindSafe for datex_core::collections::btree_map::ExtractIf<'a, K, V, R, F, A>



impl<'a, T> !UnwindSafe for datex_core::collections::linked_list::IterMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::collections::vec_deque::IterMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::stdlib::result::IterMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::stdlib::slice::IterMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::stdlib::sync::nonpoison::MappedMutexGuard<'a, T>



impl<'a, T> !UnwindSafe for datex_core::stdlib::sync::nonpoison::MutexGuard<'a, T>



impl<'a, T> !UnwindSafe for datex_core::stdlib::sync::MappedMutexGuard<'a, T>



impl<'a, T, A = Global> !UnwindSafe for datex_core::collections::btree_set::Entry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for DrainSorted<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::collections::binary_heap::PeekMut<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::collections::btree_set::OccupiedEntry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::collections::btree_set::VacantEntry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::collections::linked_list::CursorMut<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::stdlib::vec::PeekMut<'a, T, A>



impl<'a, T, F, A = Global> !UnwindSafe for datex_core::collections::linked_list::ExtractIf<'a, T, F, A>



impl<'a, T, F, A = Global> !UnwindSafe for datex_core::collections::vec_deque::ExtractIf<'a, T, F, A>



impl<'a, T, F, A = Global> !UnwindSafe for datex_core::stdlib::vec::ExtractIf<'a, T, F, A>



impl<'a, T, P> !UnwindSafe for ChunkByMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitNMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitInclusiveMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitNMut<'a, T, P>



impl<'a, T, R, F, A = Global> !UnwindSafe for datex_core::collections::btree_set::ExtractIf<'a, T, R, F, A>



impl<'a, T, S> !UnwindSafe for datex_core::collections::hash_set::Entry<'a, T, S>



impl<'a, T, S> !UnwindSafe for datex_core::collections::hash_set::OccupiedEntry<'a, T, S>



impl<'a, T, S> !UnwindSafe for datex_core::collections::hash_set::VacantEntry<'a, T, S>



impl<'b, T> !UnwindSafe for Ref<'b, T>



impl<'b, T> !UnwindSafe for RefMut<'b, T>



impl<'data> !UnwindSafe for BorrowedBuf<'data>



impl<'rwlock, T> !UnwindSafe for datex_core::stdlib::sync::nonpoison::MappedRwLockWriteGuard<'rwlock, T>



impl<'rwlock, T> !UnwindSafe for datex_core::stdlib::sync::nonpoison::RwLockWriteGuard<'rwlock, T>



impl<'rwlock, T> !UnwindSafe for datex_core::stdlib::sync::MappedRwLockWriteGuard<'rwlock, T>



impl<'scope, 'env> !UnwindSafe for Scope<'scope, 'env>



impl<'scope, T> !UnwindSafe for ScopedJoinHandle<'scope, T>



impl<Dyn> !UnwindSafe for DynMetadata<Dyn>



impl<T> !UnwindSafe for VisitAction<T>



impl<T> !UnwindSafe for DataChannel<T>



impl<T> !UnwindSafe for DataChannels<T>



impl<T> !UnwindSafe for MediaTrack<T>



impl<T> !UnwindSafe for MediaTracks<T>



impl<T> !UnwindSafe for datex_core::task::Receiver<T>



impl<T> !UnwindSafe for datex_core::task::Sender<T>



impl<T> !UnwindSafe for UnboundedReceiver<T>



impl<T> !UnwindSafe for UnboundedSender<T>



impl<T> !UnwindSafe for datex_core::stdlib::thread::JoinHandle<T>



impl<T, A = Global> !UnwindSafe for UniqueRc<T, A>



impl<T, A = Global> !UnwindSafe for datex_core::stdlib::rc::Weak<T, A>



impl<W> !UnwindSafe for IntoInnerError<W>



impl UnwindSafe for Slot



impl UnwindSafe for TypeDeclarationKind



impl UnwindSafe for VariableKind



impl UnwindSafe for ResolvedVariable



impl UnwindSafe for TryReserveErrorKind



impl UnwindSafe for VariableModel



impl UnwindSafe for VariableRepresentation



impl UnwindSafe for VariableShape



impl UnwindSafe for NewScopeType



impl UnwindSafe for CryptoError



impl UnwindSafe for FormattingMode



impl UnwindSafe for IndentType



impl UnwindSafe for DIFCreatePointerError



impl UnwindSafe for DIFObserveError



impl UnwindSafe for DIFResolveReferenceError



impl UnwindSafe for DIFTypeRepresentation



impl UnwindSafe for DIFValueRepresentation



impl UnwindSafe for DIFTypeDefinition



impl UnwindSafe for DIFTypeDefinitionKind



impl UnwindSafe for DIFKey



impl UnwindSafe for DIFUpdateData



impl UnwindSafe for DIFValueContainer



impl UnwindSafe for Assoc



impl UnwindSafe for BracketStyle



impl UnwindSafe for StatementFormatting



impl UnwindSafe for TypeDeclarationFormatting



impl UnwindSafe for VariantFormatting



impl UnwindSafe for HeaderParsingError



impl UnwindSafe for InstructionCode



impl UnwindSafe for AssignmentOperator



impl UnwindSafe for ArithmeticOperator



impl UnwindSafe for BinaryOperator



impl UnwindSafe for BitwiseOperator



impl UnwindSafe for LogicalOperator



impl UnwindSafe for ComparisonOperator



impl UnwindSafe for ArithmeticUnaryOperator



impl UnwindSafe for BitwiseUnaryOperator



impl UnwindSafe for LogicalUnaryOperator



impl UnwindSafe for ReferenceUnaryOperator



impl UnwindSafe for UnaryOperator



impl UnwindSafe for BlockType



impl UnwindSafe for UserAgent



impl UnwindSafe for Instruction



impl UnwindSafe for RawPointerAddress



impl UnwindSafe for RegularInstruction



impl UnwindSafe for TypeInstruction



impl UnwindSafe for EncryptionType



impl UnwindSafe for ReceiverType



impl UnwindSafe for Receivers



impl UnwindSafe for SignatureType



impl UnwindSafe for InternalSlot



impl UnwindSafe for TypeInstructionCode



impl UnwindSafe for TypeMutabilityCode



impl UnwindSafe for CoreLibPointerId



impl UnwindSafe for ComHubError



impl UnwindSafe for InterfacePriority



impl UnwindSafe for ResponseError



impl UnwindSafe for ResponseResolutionStrategy



impl UnwindSafe for ResponseTimeout



impl UnwindSafe for SocketEndpointRegistrationError



impl UnwindSafe for NetworkTraceHopDirection



impl UnwindSafe for ComInterfaceError



impl UnwindSafe for ComInterfaceState



impl UnwindSafe for InterfaceDirection



impl UnwindSafe for ReconnectionConfig



impl UnwindSafe for SocketState



impl UnwindSafe for BaseInterfaceError



impl UnwindSafe for HTTPError



impl UnwindSafe for SerialError



impl UnwindSafe for TCPError



impl UnwindSafe for MediaKind



impl UnwindSafe for MediaTrackCodec



impl UnwindSafe for RTCSdpTypeDX



impl UnwindSafe for WebRTCError



impl UnwindSafe for URLError



impl UnwindSafe for WebSocketError



impl UnwindSafe for WebSocketServerError



impl UnwindSafe for ParserError



impl UnwindSafe for Token



impl UnwindSafe for IntegerOrDecimal



impl UnwindSafe for IntegerOrTypedInteger



impl UnwindSafe for ObserverError



impl UnwindSafe for ReferenceCreationError



impl UnwindSafe for ReferenceMutability



impl UnwindSafe for ExecutionMode



impl UnwindSafe for InvalidProgramError



impl UnwindSafe for ErrorHandling



impl UnwindSafe for IllegalTypeError



impl UnwindSafe for Color



impl UnwindSafe for CallableBody



impl UnwindSafe for CallableKind



impl UnwindSafe for BigDecimalType



impl UnwindSafe for Decimal



impl UnwindSafe for DecimalTypeVariant



impl UnwindSafe for TypedDecimal



impl UnwindSafe for EndpointInstance



impl UnwindSafe for EndpointType



impl UnwindSafe for InvalidEndpointError



impl UnwindSafe for NumberParseError



impl UnwindSafe for IntegerTypeVariant



impl UnwindSafe for TypedInteger



impl UnwindSafe for PointerAddress



impl UnwindSafe for ValueError



impl UnwindSafe for AsciiChar



impl UnwindSafe for BacktraceStatus



impl UnwindSafe for datex_core::stdlib::cmp::Ordering



impl UnwindSafe for Infallible



impl UnwindSafe for VarError



impl UnwindSafe for FromBytesWithNulError



impl UnwindSafe for c_void



impl UnwindSafe for datex_core::stdlib::fmt::Alignment



impl UnwindSafe for DebugAsHex



impl UnwindSafe for Sign



impl UnwindSafe for Locality



impl UnwindSafe for AtomicOrdering



impl UnwindSafe for BasicBlock



impl UnwindSafe for UnwindTerminateReason



impl UnwindSafe for SimdAlign



impl UnwindSafe for ErrorKind



impl UnwindSafe for SeekFrom



impl UnwindSafe for IpAddr



impl UnwindSafe for Ipv6MulticastScope



impl UnwindSafe for Shutdown



impl UnwindSafe for datex_core::stdlib::net::SocketAddr



impl UnwindSafe for FpCategory



impl UnwindSafe for IntErrorKind



impl UnwindSafe for OneSidedRangeBound



impl UnwindSafe for AncillaryError



impl UnwindSafe for GetDisjointMutError



impl UnwindSafe for SearchStep



impl UnwindSafe for datex_core::stdlib::sync::atomic::Ordering



impl UnwindSafe for RecvTimeoutError



impl UnwindSafe for TryRecvError



impl UnwindSafe for BacktraceStyle



impl UnwindSafe for UnboundedStatement



impl UnwindSafe for VariableAccess



impl UnwindSafe for VariantAccess



impl UnwindSafe for SrcId



impl UnwindSafe for TypeVariantAccess



impl UnwindSafe for UnorderedKeyError



impl UnwindSafe for TryReserveError



impl UnwindSafe for VirtualSlot



impl UnwindSafe for CompileMetadata



impl UnwindSafe for PrecompilerOptions



impl UnwindSafe for PrecompilerScope



impl UnwindSafe for PrecompilerScopeStack



impl UnwindSafe for Variable



impl UnwindSafe for Crypto



impl UnwindSafe for CryptoNative



impl UnwindSafe for DecompileOptions



impl UnwindSafe for datex_core::decompiler::FormattingOptions



impl UnwindSafe for DIFReference



impl UnwindSafe for DIFStructuralTypeDefinition



impl UnwindSafe for DIFType



impl UnwindSafe for DIFReferenceNotFoundError



impl UnwindSafe for DIFValue



impl UnwindSafe for datex_core::fmt::options::FormattingOptions



impl UnwindSafe for BlockId



impl UnwindSafe for DXBBlock



impl UnwindSafe for IncomingEndpointContextId



impl UnwindSafe for IncomingEndpointContextSectionId



impl UnwindSafe for InstructionCodeIter



impl UnwindSafe for BlockHeader



impl UnwindSafe for FlagsAndTimestamp



impl UnwindSafe for EncryptedHeader



impl UnwindSafe for datex_core::global::protocol_structures::encrypted_header::Flags



impl UnwindSafe for ApplyData



impl UnwindSafe for DecimalData



impl UnwindSafe for Float32Data



impl UnwindSafe for Float64Data



impl UnwindSafe for FloatAsInt16Data



impl UnwindSafe for FloatAsInt32Data



impl UnwindSafe for GetOrCreateRefData



impl UnwindSafe for ImplTypeData



impl UnwindSafe for InstructionBlockData



impl UnwindSafe for InstructionCloseAndStore



impl UnwindSafe for Int8Data



impl UnwindSafe for Int16Data



impl UnwindSafe for Int32Data



impl UnwindSafe for Int64Data



impl UnwindSafe for Int128Data



impl UnwindSafe for IntegerData



impl UnwindSafe for ListData



impl UnwindSafe for MapData



impl UnwindSafe for PointerAddressConversionError



impl UnwindSafe for RawFullPointerAddress



impl UnwindSafe for RawInternalPointerAddress



impl UnwindSafe for RawLocalPointerAddress



impl UnwindSafe for ShortListData



impl UnwindSafe for ShortMapData



impl UnwindSafe for ShortStatementsData



impl UnwindSafe for ShortTextData



impl UnwindSafe for ShortTextDataRaw



impl UnwindSafe for SlotAddress



impl UnwindSafe for StatementsData



impl UnwindSafe for TextData



impl UnwindSafe for TextDataRaw



impl UnwindSafe for TypeMetadata



impl UnwindSafe for TypeReferenceData



impl UnwindSafe for UInt8Data



impl UnwindSafe for UInt16Data



impl UnwindSafe for UInt32Data



impl UnwindSafe for UInt64Data



impl UnwindSafe for UInt128Data



impl UnwindSafe for UnboundedStatementsData



impl UnwindSafe for datex_core::global::protocol_structures::routing_header::Flags



impl UnwindSafe for Key512



impl UnwindSafe for ReceiverEndpoints



impl UnwindSafe for ReceiverEndpointsWithKeys



impl UnwindSafe for RoutingHeader



impl UnwindSafe for BlockHistoryData



impl UnwindSafe for ComHubOptions



impl UnwindSafe for DynamicEndpointProperties



impl UnwindSafe for ResponseOptions



impl UnwindSafe for NetworkTraceHop



impl UnwindSafe for NetworkTraceHopSocket



impl UnwindSafe for NetworkTraceResult



impl UnwindSafe for TraceOptions



impl UnwindSafe for ComInterfaceInfo



impl UnwindSafe for ComInterfaceSockets



impl UnwindSafe for ComInterfaceUUID



impl UnwindSafe for InterfaceProperties



impl UnwindSafe for ComInterfaceSocket



impl UnwindSafe for ComInterfaceSocketUUID



impl UnwindSafe for BaseInterfaceSetupData



impl UnwindSafe for LocalLoopbackInterface



impl UnwindSafe for SerialInterfaceSetupData



impl UnwindSafe for SerialNativeInterface



impl UnwindSafe for TCPClientInterfaceSetupData



impl UnwindSafe for TCPServerInterfaceSetupData



impl UnwindSafe for TCPServerNativeInterface



impl UnwindSafe for RTCIceCandidateInitDX



impl UnwindSafe for RTCIceServer



impl UnwindSafe for RTCSessionDescriptionDX



impl UnwindSafe for WebRTCInterfaceSetupData



impl UnwindSafe for WebSocketClientInterfaceSetupData



impl UnwindSafe for WebSocketServerInterfaceSetupData



impl UnwindSafe for WebSocketServerNativeInterface



impl UnwindSafe for SpannedParserError



impl UnwindSafe for Loc



impl UnwindSafe for NumericLiteralParts



impl UnwindSafe for SpannedToken



impl UnwindSafe for Parser



impl UnwindSafe for ParserOptions



impl UnwindSafe for ObserveOptions



impl UnwindSafe for IndexOutOfBoundsError



impl UnwindSafe for NominalTypeDeclaration



impl UnwindSafe for ExecutionOptions



impl UnwindSafe for AsyncContext



impl UnwindSafe for DatexSerializer



impl UnwindSafe for RandomState



impl UnwindSafe for Duration



impl UnwindSafe for Instant



impl UnwindSafe for SystemTime



impl UnwindSafe for SystemTimeError



impl UnwindSafe for TryFromFloatSecsError



impl UnwindSafe for InferExpressionTypeOptions



impl UnwindSafe for AnsiCodes



impl UnwindSafe for Time



impl UnwindSafe for TimeNative



impl UnwindSafe for UUID



impl UnwindSafe for Boolean



impl UnwindSafe for Rational



impl UnwindSafe for DecimalTypeVariantIter



impl UnwindSafe for Endpoint



impl UnwindSafe for EndpointParsingError



impl UnwindSafe for Integer



impl UnwindSafe for IntegerTypeVariantIter



impl UnwindSafe for Text



impl UnwindSafe for AllocError



impl UnwindSafe for Global



impl UnwindSafe for Layout



impl UnwindSafe for LayoutError



impl UnwindSafe for System



impl UnwindSafe for TypeId



impl UnwindSafe for CpuidResult



impl UnwindSafe for __m128



impl UnwindSafe for __m128bh



impl UnwindSafe for __m128d



impl UnwindSafe for __m128h



impl UnwindSafe for __m128i



impl UnwindSafe for __m256



impl UnwindSafe for __m256bh



impl UnwindSafe for __m256d



impl UnwindSafe for __m256h



impl UnwindSafe for __m256i



impl UnwindSafe for __m512



impl UnwindSafe for __m512bh



impl UnwindSafe for __m512d



impl UnwindSafe for __m512h



impl UnwindSafe for __m512i



impl UnwindSafe for bf16



impl UnwindSafe for TryFromSliceError



impl UnwindSafe for datex_core::stdlib::ascii::EscapeDefault



impl UnwindSafe for Backtrace



impl UnwindSafe for BacktraceFrame



impl UnwindSafe for ByteStr



impl UnwindSafe for ByteString



impl UnwindSafe for BorrowError



impl UnwindSafe for BorrowMutError



impl UnwindSafe for CharTryFromError



impl UnwindSafe for DecodeUtf16Error



impl UnwindSafe for datex_core::stdlib::char::EscapeDebug



impl UnwindSafe for datex_core::stdlib::char::EscapeDefault



impl UnwindSafe for datex_core::stdlib::char::EscapeUnicode



impl UnwindSafe for ParseCharError



impl UnwindSafe for ToLowercase



impl UnwindSafe for ToUppercase



impl UnwindSafe for TryFromCharError



impl UnwindSafe for Args



impl UnwindSafe for ArgsOs



impl UnwindSafe for JoinPathsError



impl UnwindSafe for Vars



impl UnwindSafe for VarsOs



impl UnwindSafe for CStr



impl UnwindSafe for CString



impl UnwindSafe for FromBytesUntilNulError



impl UnwindSafe for FromVecWithNulError



impl UnwindSafe for IntoStringError



impl UnwindSafe for NulError



impl UnwindSafe for OsStr



impl UnwindSafe for OsString



impl UnwindSafe for datex_core::stdlib::fmt::Error



impl UnwindSafe for datex_core::stdlib::fmt::FormattingOptions



impl UnwindSafe for DirBuilder



impl UnwindSafe for DirEntry



impl UnwindSafe for File



impl UnwindSafe for FileTimes



impl UnwindSafe for FileType



impl UnwindSafe for Metadata



impl UnwindSafe for OpenOptions



impl UnwindSafe for Permissions



impl UnwindSafe for ReadDir



impl UnwindSafe for DefaultHasher



impl UnwindSafe for SipHasher



impl UnwindSafe for ReturnToArg



impl UnwindSafe for UnwindActionArg



impl UnwindSafe for datex_core::stdlib::io::Empty



impl UnwindSafe for PipeReader



impl UnwindSafe for PipeWriter



impl UnwindSafe for datex_core::stdlib::io::Repeat



impl UnwindSafe for Sink



impl UnwindSafe for Stdin



impl UnwindSafe for WriterPanicked



impl UnwindSafe for PhantomPinned



impl UnwindSafe for Assume



impl UnwindSafe for AddrParseError



impl UnwindSafe for IntoIncoming



impl UnwindSafe for Ipv4Addr



impl UnwindSafe for Ipv6Addr



impl UnwindSafe for SocketAddrV4



impl UnwindSafe for SocketAddrV6



impl UnwindSafe for TcpListener



impl UnwindSafe for TcpStream



impl UnwindSafe for UdpSocket



impl UnwindSafe for ParseFloatError



impl UnwindSafe for ParseIntError



impl UnwindSafe for TryFromIntError



impl UnwindSafe for RangeFull



impl UnwindSafe for OwnedFd



impl UnwindSafe for PidFd



impl UnwindSafe for stat



impl UnwindSafe for datex_core::stdlib::os::unix::net::SocketAddr



impl UnwindSafe for SocketCred



impl UnwindSafe for UCred



impl UnwindSafe for UnixDatagram



impl UnwindSafe for UnixListener



impl UnwindSafe for UnixStream



impl UnwindSafe for NormalizeError



impl UnwindSafe for Path



impl UnwindSafe for PathBuf



impl UnwindSafe for StripPrefixError



impl UnwindSafe for Child



impl UnwindSafe for ChildStderr



impl UnwindSafe for ChildStdin



impl UnwindSafe for ChildStdout



impl UnwindSafe for ExitCode



impl UnwindSafe for ExitStatus



impl UnwindSafe for ExitStatusError



impl UnwindSafe for Output



impl UnwindSafe for Stdio



impl UnwindSafe for datex_core::stdlib::ptr::Alignment



impl UnwindSafe for DefaultRandomSource



impl UnwindSafe for ParseBoolError



impl UnwindSafe for Utf8Error



impl UnwindSafe for FromUtf8Error



impl UnwindSafe for FromUtf16Error



impl UnwindSafe for IntoChars



impl UnwindSafe for String



impl UnwindSafe for AtomicBool



impl UnwindSafe for AtomicI8



impl UnwindSafe for AtomicI16



impl UnwindSafe for AtomicI32



impl UnwindSafe for AtomicI64



impl UnwindSafe for AtomicIsize



impl UnwindSafe for AtomicU8



impl UnwindSafe for AtomicU16



impl UnwindSafe for AtomicU32



impl UnwindSafe for AtomicU64



impl UnwindSafe for AtomicUsize



impl UnwindSafe for RecvError



impl UnwindSafe for datex_core::stdlib::sync::nonpoison::Condvar



impl UnwindSafe for WouldBlock



impl UnwindSafe for Barrier



impl UnwindSafe for BarrierWaitResult



impl UnwindSafe for OnceState



impl UnwindSafe for WaitTimeoutResult



impl UnwindSafe for LocalWaker



impl UnwindSafe for RawWaker



impl UnwindSafe for RawWakerVTable



impl UnwindSafe for Waker



impl UnwindSafe for datex_core::stdlib::thread::AccessError



impl UnwindSafe for Builder



impl UnwindSafe for Thread



impl UnwindSafe for ThreadId



impl<'a> UnwindSafe for Operation<'a>



impl<'a> UnwindSafe for AncillaryData<'a>



impl<'a> UnwindSafe for Component<'a>



impl<'a> UnwindSafe for Prefix<'a>



impl<'a> UnwindSafe for Utf8Pattern<'a>



impl<'a> UnwindSafe for DIFUpdate<'a>



impl<'a> UnwindSafe for ParentContext<'a>



impl<'a> UnwindSafe for SplitPaths<'a>



impl<'a> UnwindSafe for datex_core::stdlib::ffi::os_str::Display<'a>



impl<'a> UnwindSafe for VaList<'a>



impl<'a> UnwindSafe for Arguments<'a>



impl<'a> UnwindSafe for IoSlice<'a>



impl<'a> UnwindSafe for StdinLock<'a>



impl<'a> UnwindSafe for PhantomContravariantLifetime<'a>



impl<'a> UnwindSafe for PhantomCovariantLifetime<'a>



impl<'a> UnwindSafe for PhantomInvariantLifetime<'a>



impl<'a> UnwindSafe for datex_core::stdlib::net::Incoming<'a>



impl<'a> UnwindSafe for datex_core::stdlib::os::unix::net::Incoming<'a>



impl<'a> UnwindSafe for Messages<'a>



impl<'a> UnwindSafe for ScmCredentials<'a>



impl<'a> UnwindSafe for ScmRights<'a>



impl<'a> UnwindSafe for Ancestors<'a>



impl<'a> UnwindSafe for Components<'a>



impl<'a> UnwindSafe for datex_core::stdlib::path::Display<'a>



impl<'a> UnwindSafe for datex_core::stdlib::path::Iter<'a>



impl<'a> UnwindSafe for PrefixComponent<'a>



impl<'a> UnwindSafe for CommandArgs<'a>



impl<'a> UnwindSafe for CommandEnvs<'a>



impl<'a> UnwindSafe for EscapeAscii<'a>



impl<'a> UnwindSafe for CharSearcher<'a>



impl<'a> UnwindSafe for datex_core::stdlib::str::Bytes<'a>



impl<'a> UnwindSafe for CharIndices<'a>



impl<'a> UnwindSafe for Chars<'a>



impl<'a> UnwindSafe for EncodeUtf16<'a>



impl<'a> UnwindSafe for datex_core::stdlib::str::EscapeDebug<'a>



impl<'a> UnwindSafe for datex_core::stdlib::str::EscapeDefault<'a>



impl<'a> UnwindSafe for datex_core::stdlib::str::EscapeUnicode<'a>



impl<'a> UnwindSafe for datex_core::stdlib::str::Lines<'a>



impl<'a> UnwindSafe for LinesAny<'a>



impl<'a> UnwindSafe for SplitAsciiWhitespace<'a>



impl<'a> UnwindSafe for SplitWhitespace<'a>



impl<'a> UnwindSafe for Utf8Chunk<'a>



impl<'a> UnwindSafe for Utf8Chunks<'a>



impl<'a> UnwindSafe for datex_core::stdlib::string::Drain<'a>



impl<'a> UnwindSafe for Context<'a>



impl<'a> UnwindSafe for Location<'a>



impl<'a, 'b> UnwindSafe for CharSliceSearcher<'a, 'b>



impl<'a, 'b> UnwindSafe for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> UnwindSafe for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> UnwindSafe for datex_core::stdlib::option::Iter<'a, A>
where A: RefUnwindSafe,



impl<'a, B> UnwindSafe for Cow<'a, B>
where <B as ToOwned>::Owned: UnwindSafe, B: RefUnwindSafe + ?Sized,



impl<'a, F> UnwindSafe for CharPredicateSearcher<'a, F>
where F: UnwindSafe,



impl<'a, I, A> UnwindSafe for datex_core::collections::vec_deque::Splice<'a, I, A>



impl<'a, I, A> UnwindSafe for datex_core::stdlib::vec::Splice<'a, I, A>



impl<'a, K> UnwindSafe for datex_core::collections::btree_set::Cursor<'a, K>
where K: RefUnwindSafe,



impl<'a, K> UnwindSafe for datex_core::collections::hash_set::Drain<'a, K>
where K: RefUnwindSafe,



impl<'a, K> UnwindSafe for datex_core::collections::hash_set::Iter<'a, K>
where K: RefUnwindSafe,



impl<'a, K, V> UnwindSafe for datex_core::collections::btree_map::Cursor<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::btree_map::Iter<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::btree_map::Keys<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::btree_map::Range<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::btree_map::Values<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::hash_map::Drain<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::hash_map::Iter<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::hash_map::Keys<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::collections::hash_map::Values<'a, K, V>



impl<'a, P> UnwindSafe for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::stdlib::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::stdlib::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::stdlib::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::stdlib::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::stdlib::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::binary_heap::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::btree_set::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::btree_set::Range<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::btree_set::SymmetricDifference<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::btree_set::Union<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::linked_list::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::collections::vec_deque::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::stdlib::result::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Chunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for ChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::stdlib::slice::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Windows<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::stdlib::sync::mpmc::Iter<'a, T>



impl<'a, T> UnwindSafe for datex_core::stdlib::sync::mpmc::TryIter<'a, T>



impl<'a, T> UnwindSafe for datex_core::stdlib::sync::mpsc::Iter<'a, T>



impl<'a, T> UnwindSafe for datex_core::stdlib::sync::mpsc::TryIter<'a, T>



impl<'a, T> UnwindSafe for datex_core::stdlib::sync::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> UnwindSafe for ReentrantLockGuard<'a, T>
where T: RefUnwindSafe + ?Sized,



impl<'a, T, A> UnwindSafe for datex_core::collections::binary_heap::Drain<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::collections::btree_set::Difference<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::collections::btree_set::Intersection<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::collections::linked_list::Cursor<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::stdlib::vec::Drain<'a, T, A>



impl<'a, T, P> UnwindSafe for ChunkBy<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::stdlib::slice::RSplit<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::stdlib::slice::RSplitN<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::stdlib::slice::Split<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::stdlib::slice::SplitInclusive<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::stdlib::slice::SplitN<'a, T, P>



impl<'a, T, S> UnwindSafe for datex_core::collections::hash_set::Difference<'a, T, S>



impl<'a, T, S> UnwindSafe for datex_core::collections::hash_set::Intersection<'a, T, S>



impl<'a, T, S> UnwindSafe for datex_core::collections::hash_set::SymmetricDifference<'a, T, S>



impl<'a, T, S> UnwindSafe for datex_core::collections::hash_set::Union<'a, T, S>



impl<'a, T, const N: usize> UnwindSafe for ArrayWindows<'a, T, N>
where T: RefUnwindSafe,



impl<'a, const N: usize> UnwindSafe for CharArraySearcher<'a, N>



impl<'fd> UnwindSafe for BorrowedFd<'fd>



impl<'rwlock, T> UnwindSafe for datex_core::stdlib::sync::nonpoison::MappedRwLockReadGuard<'rwlock, T>
where T: RefUnwindSafe + ?Sized,



impl<'rwlock, T> UnwindSafe for datex_core::stdlib::sync::nonpoison::RwLockReadGuard<'rwlock, T>
where T: RefUnwindSafe + ?Sized,



impl<'rwlock, T> UnwindSafe for datex_core::stdlib::sync::MappedRwLockReadGuard<'rwlock, T>
where T: RefUnwindSafe + ?Sized,



impl<'rwlock, T> UnwindSafe for datex_core::stdlib::sync::RwLockReadGuard<'rwlock, T>
where T: RefUnwindSafe + ?Sized,



impl<'rwlock, T> UnwindSafe for datex_core::stdlib::sync::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<A> UnwindSafe for datex_core::stdlib::iter::Repeat<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RepeatN<A>
where A: UnwindSafe,



impl<A> UnwindSafe for datex_core::stdlib::option::IntoIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for OptionFlatten<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeFromIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeInclusiveIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeIter<A>
where A: UnwindSafe,



impl<A, B> UnwindSafe for datex_core::stdlib::iter::Chain<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A, B> UnwindSafe for Zip<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<B> UnwindSafe for datex_core::stdlib::io::Lines<B>
where B: UnwindSafe,



impl<B> UnwindSafe for datex_core::stdlib::io::Split<B>
where B: UnwindSafe,



impl<B, C> UnwindSafe for ControlFlow<B, C>
where C: UnwindSafe, B: UnwindSafe,



impl<E> UnwindSafe for Report<E>
where E: UnwindSafe,



impl<F> UnwindSafe for datex_core::stdlib::fmt::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for PollFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for datex_core::stdlib::iter::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for OnceWith<F>
where F: UnwindSafe,



impl<F> UnwindSafe for RepeatWith<F>
where F: UnwindSafe,



impl<G> UnwindSafe for FromCoroutine<G>
where G: UnwindSafe,



impl<H> UnwindSafe for BuildHasherDefault<H>



impl<I> UnwindSafe for FromIter<I>
where I: UnwindSafe,



impl<I> UnwindSafe for DecodeUtf16<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cloned<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Copied<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cycle<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Enumerate<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Flatten<I>



impl<I> UnwindSafe for Fuse<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Intersperse<I>
where <I as Iterator>::Item: Sized + UnwindSafe, I: UnwindSafe,



impl<I> UnwindSafe for Peekable<I>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for Skip<I>
where I: UnwindSafe,



impl<I> UnwindSafe for StepBy<I>
where I: UnwindSafe,



impl<I> UnwindSafe for datex_core::stdlib::iter::Take<I>
where I: UnwindSafe,



impl<I, F> UnwindSafe for FilterMap<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Inspect<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for datex_core::stdlib::iter::Map<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F, const N: usize> UnwindSafe for MapWindows<I, F, N>
where F: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, G> UnwindSafe for IntersperseWith<I, G>
where G: UnwindSafe, <I as Iterator>::Item: UnwindSafe, I: UnwindSafe,



impl<I, P> UnwindSafe for Filter<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for MapWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for SkipWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for TakeWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, St, F> UnwindSafe for Scan<I, St, F>
where I: UnwindSafe, F: UnwindSafe, St: UnwindSafe,



impl<I, U, F> UnwindSafe for FlatMap<I, U, F>



impl<I, const N: usize> UnwindSafe for ArrayChunks<I, N>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::ops::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::ops::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::ops::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for RangeTo<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::ops::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::range::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::range::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::range::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::stdlib::range::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<K> UnwindSafe for datex_core::collections::hash_set::IntoIter<K>



impl<K, T> UnwindSafe for FreeHashMap<K, T>
where K: UnwindSafe, T: UnwindSafe,



impl<K, V> UnwindSafe for datex_core::collections::hash_map::IntoIter<K, V>



impl<K, V> UnwindSafe for datex_core::collections::hash_map::IntoKeys<K, V>



impl<K, V> UnwindSafe for datex_core::collections::hash_map::IntoValues<K, V>



impl<K, V, A> UnwindSafe for datex_core::collections::btree_map::IntoIter<K, V, A>



impl<K, V, A> UnwindSafe for datex_core::collections::btree_map::IntoKeys<K, V, A>



impl<K, V, A> UnwindSafe for datex_core::collections::btree_map::IntoValues<K, V, A>



impl<P> UnwindSafe for MaybeDangling<P>
where P: UnwindSafe + ?Sized,



impl<Ptr> UnwindSafe for Pin<Ptr>
where Ptr: UnwindSafe,



impl<R> UnwindSafe for BufReader<R>
where R: UnwindSafe + ?Sized,



impl<R> UnwindSafe for datex_core::stdlib::io::Bytes<R>
where R: UnwindSafe,



impl<T> UnwindSafe for Bound<T>
where T: UnwindSafe,



impl<T> UnwindSafe for MaybeAction<T>
where T: UnwindSafe,



impl<T> UnwindSafe for DeserializeMapOrArray<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Option<T>
where T: UnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::sync::TryLockError<T>
where T: UnwindSafe,



impl<T> UnwindSafe for SendTimeoutError<T>
where T: UnwindSafe,



impl<T> UnwindSafe for TrySendError<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Poll<T>
where T: UnwindSafe,



impl<T> UnwindSafe for LiteralWithVariant<T>
where T: UnwindSafe,



impl<T> UnwindSafe for ThinBox<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Cell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for datex_core::stdlib::cell::OnceCell<T>
where T: UnwindSafe,



impl<T> UnwindSafe for RefCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for SyncUnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for UnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Reverse<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Pending<T>



impl<T> UnwindSafe for Ready<T>
where T: UnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::io::Cursor<T>
where T: UnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::io::Take<T>
where T: UnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::iter::Empty<T>



impl<T> UnwindSafe for datex_core::stdlib::iter::Once<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Rev<T>
where T: UnwindSafe,



impl<T> UnwindSafe for PhantomContravariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomCovariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomData<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for PhantomInvariant<T>
where T: ?Sized,



impl<T> UnwindSafe for Discriminant<T>



impl<T> UnwindSafe for ManuallyDrop<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Saturating<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Wrapping<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Yeet<T>
where T: UnwindSafe,



impl<T> UnwindSafe for UnsafePinned<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for datex_core::stdlib::result::IntoIter<T>
where T: UnwindSafe,



impl<T> UnwindSafe for AtomicPtr<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::sync::mpmc::IntoIter<T>



impl<T> UnwindSafe for SendError<T>
where T: UnwindSafe,



impl<T> UnwindSafe for datex_core::stdlib::sync::mpsc::IntoIter<T>



impl<T> UnwindSafe for datex_core::stdlib::sync::mpsc::Receiver<T>



impl<T> UnwindSafe for datex_core::stdlib::sync::mpsc::Sender<T>



impl<T> UnwindSafe for SyncSender<T>



impl<T> UnwindSafe for datex_core::stdlib::sync::nonpoison::Mutex<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for datex_core::stdlib::sync::nonpoison::RwLock<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Exclusive<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for PoisonError<T>
where T: UnwindSafe,



impl<T> UnwindSafe for LocalKey<T>



impl<T> UnwindSafe for MaybeUninit<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Storage<T>
where T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::collections::binary_heap::IntoIter<T, A>
where T: UnwindSafe, A: UnwindSafe,



impl<T, A> UnwindSafe for IntoIterSorted<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::collections::btree_set::IntoIter<T, A>



impl<T, A> UnwindSafe for datex_core::collections::linked_list::IntoIter<T, A>



impl<T, A> UnwindSafe for BTreeSet<T, A>



impl<T, A> UnwindSafe for BinaryHeap<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for LinkedList<T, A>



impl<T, A> UnwindSafe for VecDeque<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::collections::vec_deque::IntoIter<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for Box<T, A>
where A: UnwindSafe, T: UnwindSafe + ?Sized,



impl<T, A> UnwindSafe for UniqueArc<T, A>



impl<T, A> UnwindSafe for datex_core::stdlib::sync::Weak<T, A>
where A: UnwindSafe, T: RefUnwindSafe + ?Sized,



impl<T, A> UnwindSafe for Vec<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, D> UnwindSafe for Storage<T, D>
where D: UnwindSafe, T: UnwindSafe,



impl<T, E> UnwindSafe for Result<T, E>
where T: UnwindSafe, E: UnwindSafe,



impl<T, F> UnwindSafe for LazyCell<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for Successors<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for DropGuard<T, F>
where T: UnwindSafe, F: UnwindSafe,



impl<T, S> UnwindSafe for HashSet<T, S>
where S: UnwindSafe, T: UnwindSafe,



impl<T, U> UnwindSafe for datex_core::stdlib::io::Chain<T, U>
where T: UnwindSafe, U: UnwindSafe,



impl<T, const N: usize> UnwindSafe for datex_core::stdlib::array::IntoIter<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Mask<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Simd<T, N>
where T: UnwindSafe,



impl<W> UnwindSafe for BufWriter<W>
where W: UnwindSafe + ?Sized,



impl<W> UnwindSafe for LineWriter<W>
where W: UnwindSafe + ?Sized,



impl<Y, R> UnwindSafe for CoroutineState<Y, R>
where Y: UnwindSafe, R: UnwindSafe,



impl<const N: usize> UnwindSafe for LaneCount<N>