pub struct Rc<T, A = Global>{ /* private fields */ }Expand description
A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference Counted’.
See the module-level documentation for more details.
The inherent methods of Rc are all associated functions, which means
that you have to call them as e.g., Rc::get_mut(&mut value) instead of
value.get_mut(). This avoids conflicts with methods of the inner type T.
Implementations
Sourceimpl<T> Rc<T>
impl<T> Rc<T>
1.60.0 · Sourcepub fn new_cyclic<F>(data_fn: F) -> Rc<T>
pub fn new_cyclic<F>(data_fn: F) -> Rc<T>
Constructs a new Rc<T> while giving you a Weak<T> to the allocation,
to allow you to construct a T which holds a weak pointer to itself.
Generally, a structure circularly referencing itself, either directly or
indirectly, should not hold a strong reference to itself to prevent a memory leak.
Using this function, you get access to the weak pointer during the
initialization of T, before the Rc<T> is created, such that you can
clone and store it inside the T.
new_cyclic first allocates the managed allocation for the Rc<T>,
then calls your closure, giving it a Weak<T> to this allocation,
and only afterwards completes the construction of the Rc<T> by placing
the T returned from your closure into the allocation.
Since the new Rc<T> is not fully-constructed until Rc<T>::new_cyclic
returns, calling upgrade on the weak reference inside your closure will
fail and result in a None value.
Panics
If data_fn panics, the panic is propagated to the caller, and the
temporary Weak<T> is dropped normally.
Examples
use std::rc::{Rc, Weak};
struct Gadget {
me: Weak<Gadget>,
}
impl Gadget {
/// Constructs a reference counted Gadget.
fn new() -> Rc<Self> {
// `me` is a `Weak<Gadget>` pointing at the new allocation of the
// `Rc` we're constructing.
Rc::new_cyclic(|me| {
// Create the actual struct here.
Gadget { me: me.clone() }
})
}
/// Returns a reference counted pointer to Self.
fn me(&self) -> Rc<Self> {
self.me.upgrade().unwrap()
}
}1.82.0 · Sourcepub fn new_uninit() -> Rc<MaybeUninit<T>>
pub fn new_uninit() -> Rc<MaybeUninit<T>>
Constructs a new Rc with uninitialized contents.
Examples
use std::rc::Rc;
let mut five = Rc::<u32>::new_uninit();
// Deferred initialization:
Rc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5)1.92.0 · Sourcepub fn new_zeroed() -> Rc<MaybeUninit<T>>
pub fn new_zeroed() -> Rc<MaybeUninit<T>>
Constructs a new Rc with uninitialized contents, with the memory
being filled with 0 bytes.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
use std::rc::Rc;
let zero = Rc::<u32>::new_zeroed();
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0)Sourcepub fn try_new(value: T) -> Result<Rc<T>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new(value: T) -> Result<Rc<T>, AllocError>
allocator_api)Constructs a new Rc<T>, returning an error if the allocation fails
Examples
#![feature(allocator_api)]
use std::rc::Rc;
let five = Rc::try_new(5);Sourcepub fn try_new_uninit() -> Result<Rc<MaybeUninit<T>>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new_uninit() -> Result<Rc<MaybeUninit<T>>, AllocError>
allocator_api)Constructs a new Rc with uninitialized contents, returning an error if the allocation fails
Examples
#![feature(allocator_api)]
use std::rc::Rc;
let mut five = Rc::<u32>::try_new_uninit()?;
// Deferred initialization:
Rc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5);Sourcepub fn try_new_zeroed() -> Result<Rc<MaybeUninit<T>>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new_zeroed() -> Result<Rc<MaybeUninit<T>>, AllocError>
allocator_api)Constructs a new Rc with uninitialized contents, with the memory
being filled with 0 bytes, returning an error if the allocation fails
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
let zero = Rc::<u32>::try_new_zeroed()?;
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0);1.33.0 · Sourcepub fn pin(value: T) -> Pin<Rc<T>>
pub fn pin(value: T) -> Pin<Rc<T>>
Constructs a new Pin<Rc<T>>. If T does not implement Unpin, then
value will be pinned in memory and unable to be moved.
Sourcepub fn map<U>(this: Rc<T>, f: impl FnOnce(&T) -> U) -> Rc<U>
🔬This is a nightly-only experimental API. (smart_pointer_try_map)
pub fn map<U>(this: Rc<T>, f: impl FnOnce(&T) -> U) -> Rc<U>
smart_pointer_try_map)Maps the value in an Rc, reusing the allocation if possible.
f is called on a reference to the value in the Rc, and the result is returned, also in
an Rc.
Note: this is an associated function, which means that you have
to call it as Rc::map(r, f) instead of r.map(f). This
is so that there is no conflict with a method on the inner type.
Examples
#![feature(smart_pointer_try_map)]
use std::rc::Rc;
let r = Rc::new(7);
let new = Rc::map(r, |i| i + 7);
assert_eq!(*new, 14);Sourcepub fn try_map<R>(
this: Rc<T>,
f: impl FnOnce(&T) -> R,
) -> <<R as Try>::Residual as Residual<Rc<<R as Try>::Output>>>::TryType
🔬This is a nightly-only experimental API. (smart_pointer_try_map)
pub fn try_map<R>( this: Rc<T>, f: impl FnOnce(&T) -> R, ) -> <<R as Try>::Residual as Residual<Rc<<R as Try>::Output>>>::TryType
smart_pointer_try_map)Attempts to map the value in an Rc, reusing the allocation if possible.
f is called on a reference to the value in the Rc, and if the operation succeeds, the
result is returned, also in an Rc.
Note: this is an associated function, which means that you have
to call it as Rc::try_map(r, f) instead of r.try_map(f). This
is so that there is no conflict with a method on the inner type.
Examples
#![feature(smart_pointer_try_map)]
use std::rc::Rc;
let b = Rc::new(7);
let new = Rc::try_map(b, |&i| u32::try_from(i)).unwrap();
assert_eq!(*new, 7);Sourceimpl<T, A> Rc<T, A>where
A: Allocator,
impl<T, A> Rc<T, A>where
A: Allocator,
Sourcepub fn new_in(value: T, alloc: A) -> Rc<T, A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_in(value: T, alloc: A) -> Rc<T, A>
allocator_api)Constructs a new Rc in the provided allocator.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let five = Rc::new_in(5, System);Sourcepub fn new_uninit_in(alloc: A) -> Rc<MaybeUninit<T>, A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_uninit_in(alloc: A) -> Rc<MaybeUninit<T>, A>
allocator_api)Constructs a new Rc with uninitialized contents in the provided allocator.
Examples
#![feature(get_mut_unchecked)]
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let mut five = Rc::<u32, _>::new_uninit_in(System);
let five = unsafe {
// Deferred initialization:
Rc::get_mut_unchecked(&mut five).as_mut_ptr().write(5);
five.assume_init()
};
assert_eq!(*five, 5)Sourcepub fn new_zeroed_in(alloc: A) -> Rc<MaybeUninit<T>, A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_zeroed_in(alloc: A) -> Rc<MaybeUninit<T>, A>
allocator_api)Constructs a new Rc with uninitialized contents, with the memory
being filled with 0 bytes, in the provided allocator.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let zero = Rc::<u32, _>::new_zeroed_in(System);
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0)Sourcepub fn new_cyclic_in<F>(data_fn: F, alloc: A) -> Rc<T, A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_cyclic_in<F>(data_fn: F, alloc: A) -> Rc<T, A>
allocator_api)Constructs a new Rc<T, A> in the given allocator while giving you a Weak<T, A> to the allocation,
to allow you to construct a T which holds a weak pointer to itself.
Generally, a structure circularly referencing itself, either directly or
indirectly, should not hold a strong reference to itself to prevent a memory leak.
Using this function, you get access to the weak pointer during the
initialization of T, before the Rc<T, A> is created, such that you can
clone and store it inside the T.
new_cyclic_in first allocates the managed allocation for the Rc<T, A>,
then calls your closure, giving it a Weak<T, A> to this allocation,
and only afterwards completes the construction of the Rc<T, A> by placing
the T returned from your closure into the allocation.
Since the new Rc<T, A> is not fully-constructed until Rc<T, A>::new_cyclic_in
returns, calling upgrade on the weak reference inside your closure will
fail and result in a None value.
Panics
If data_fn panics, the panic is propagated to the caller, and the
temporary Weak<T, A> is dropped normally.
Examples
See new_cyclic.
Sourcepub fn try_new_in(value: T, alloc: A) -> Result<Rc<T, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new_in(value: T, alloc: A) -> Result<Rc<T, A>, AllocError>
allocator_api)Constructs a new Rc<T> in the provided allocator, returning an error if the allocation
fails
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let five = Rc::try_new_in(5, System);Sourcepub fn try_new_uninit_in(alloc: A) -> Result<Rc<MaybeUninit<T>, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new_uninit_in(alloc: A) -> Result<Rc<MaybeUninit<T>, A>, AllocError>
allocator_api)Constructs a new Rc with uninitialized contents, in the provided allocator, returning an
error if the allocation fails
Examples
#![feature(allocator_api)]
#![feature(get_mut_unchecked)]
use std::rc::Rc;
use std::alloc::System;
let mut five = Rc::<u32, _>::try_new_uninit_in(System)?;
let five = unsafe {
// Deferred initialization:
Rc::get_mut_unchecked(&mut five).as_mut_ptr().write(5);
five.assume_init()
};
assert_eq!(*five, 5);Sourcepub fn try_new_zeroed_in(alloc: A) -> Result<Rc<MaybeUninit<T>, A>, AllocError>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn try_new_zeroed_in(alloc: A) -> Result<Rc<MaybeUninit<T>, A>, AllocError>
allocator_api)Constructs a new Rc with uninitialized contents, with the memory
being filled with 0 bytes, in the provided allocator, returning an error if the allocation
fails
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let zero = Rc::<u32, _>::try_new_zeroed_in(System)?;
let zero = unsafe { zero.assume_init() };
assert_eq!(*zero, 0);Sourcepub fn pin_in(value: T, alloc: A) -> Pin<Rc<T, A>>where
A: 'static,
🔬This is a nightly-only experimental API. (allocator_api)
pub fn pin_in(value: T, alloc: A) -> Pin<Rc<T, A>>where
A: 'static,
allocator_api)Constructs a new Pin<Rc<T>> in the provided allocator. If T does not implement Unpin, then
value will be pinned in memory and unable to be moved.
1.4.0 · Sourcepub fn try_unwrap(this: Rc<T, A>) -> Result<T, Rc<T, A>>
pub fn try_unwrap(this: Rc<T, A>) -> Result<T, Rc<T, A>>
Returns the inner value, if the Rc has exactly one strong reference.
Otherwise, an Err is returned with the same Rc that was
passed in.
This will succeed even if there are outstanding weak references.
Examples
use std::rc::Rc;
let x = Rc::new(3);
assert_eq!(Rc::try_unwrap(x), Ok(3));
let x = Rc::new(4);
let _y = Rc::clone(&x);
assert_eq!(*Rc::try_unwrap(x).unwrap_err(), 4);1.70.0 · Sourcepub fn into_inner(this: Rc<T, A>) -> Option<T>
pub fn into_inner(this: Rc<T, A>) -> Option<T>
Returns the inner value, if the Rc has exactly one strong reference.
Otherwise, None is returned and the Rc is dropped.
This will succeed even if there are outstanding weak references.
If Rc::into_inner is called on every clone of this Rc,
it is guaranteed that exactly one of the calls returns the inner value.
This means in particular that the inner value is not dropped.
Rc::try_unwrap is conceptually similar to Rc::into_inner.
And while they are meant for different use-cases, Rc::into_inner(this)
is in fact equivalent to Rc::try_unwrap(this).ok().
(Note that the same kind of equivalence does not hold true for
Arc, due to race conditions that do not apply to Rc!)
Examples
use std::rc::Rc;
let x = Rc::new(3);
assert_eq!(Rc::into_inner(x), Some(3));
let x = Rc::new(4);
let y = Rc::clone(&x);
assert_eq!(Rc::into_inner(y), None);
assert_eq!(Rc::into_inner(x), Some(4));Sourceimpl<T> Rc<[T]>
impl<T> Rc<[T]>
1.82.0 · Sourcepub fn new_uninit_slice(len: usize) -> Rc<[MaybeUninit<T>]>
pub fn new_uninit_slice(len: usize) -> Rc<[MaybeUninit<T>]>
Constructs a new reference-counted slice with uninitialized contents.
Examples
use std::rc::Rc;
let mut values = Rc::<[u32]>::new_uninit_slice(3);
// Deferred initialization:
let data = Rc::get_mut(&mut values).unwrap();
data[0].write(1);
data[1].write(2);
data[2].write(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [1, 2, 3])1.92.0 · Sourcepub fn new_zeroed_slice(len: usize) -> Rc<[MaybeUninit<T>]>
pub fn new_zeroed_slice(len: usize) -> Rc<[MaybeUninit<T>]>
Constructs a new reference-counted slice with uninitialized contents, with the memory being
filled with 0 bytes.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
use std::rc::Rc;
let values = Rc::<[u32]>::new_zeroed_slice(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [0, 0, 0])Sourcepub fn into_array<const N: usize>(self) -> Option<Rc<[T; N]>>
🔬This is a nightly-only experimental API. (alloc_slice_into_array)
pub fn into_array<const N: usize>(self) -> Option<Rc<[T; N]>>
alloc_slice_into_array)Converts the reference-counted slice into a reference-counted array.
This operation does not reallocate; the underlying array of the slice is simply reinterpreted as an array type.
If N is not exactly equal to the length of self, then this method returns None.
Sourceimpl<T, A> Rc<[T], A>where
A: Allocator,
impl<T, A> Rc<[T], A>where
A: Allocator,
Sourcepub fn new_uninit_slice_in(len: usize, alloc: A) -> Rc<[MaybeUninit<T>], A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_uninit_slice_in(len: usize, alloc: A) -> Rc<[MaybeUninit<T>], A>
allocator_api)Constructs a new reference-counted slice with uninitialized contents.
Examples
#![feature(get_mut_unchecked)]
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let mut values = Rc::<[u32], _>::new_uninit_slice_in(3, System);
let values = unsafe {
// Deferred initialization:
Rc::get_mut_unchecked(&mut values)[0].as_mut_ptr().write(1);
Rc::get_mut_unchecked(&mut values)[1].as_mut_ptr().write(2);
Rc::get_mut_unchecked(&mut values)[2].as_mut_ptr().write(3);
values.assume_init()
};
assert_eq!(*values, [1, 2, 3])Sourcepub fn new_zeroed_slice_in(len: usize, alloc: A) -> Rc<[MaybeUninit<T>], A>
🔬This is a nightly-only experimental API. (allocator_api)
pub fn new_zeroed_slice_in(len: usize, alloc: A) -> Rc<[MaybeUninit<T>], A>
allocator_api)Constructs a new reference-counted slice with uninitialized contents, with the memory being
filled with 0 bytes.
See MaybeUninit::zeroed for examples of correct and
incorrect usage of this method.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let values = Rc::<[u32], _>::new_zeroed_slice_in(3, System);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [0, 0, 0])Sourceimpl<T, A> Rc<MaybeUninit<T>, A>where
A: Allocator,
impl<T, A> Rc<MaybeUninit<T>, A>where
A: Allocator,
1.82.0 · Sourcepub unsafe fn assume_init(self) -> Rc<T, A>
pub unsafe fn assume_init(self) -> Rc<T, A>
Converts to Rc<T>.
Safety
As with MaybeUninit::assume_init,
it is up to the caller to guarantee that the inner value
really is in an initialized state.
Calling this when the content is not yet fully initialized
causes immediate undefined behavior.
Examples
use std::rc::Rc;
let mut five = Rc::<u32>::new_uninit();
// Deferred initialization:
Rc::get_mut(&mut five).unwrap().write(5);
let five = unsafe { five.assume_init() };
assert_eq!(*five, 5)Sourceimpl<T> Rc<T>where
T: CloneToUninit + ?Sized,
impl<T> Rc<T>where
T: CloneToUninit + ?Sized,
Sourcepub fn clone_from_ref(value: &T) -> Rc<T>
🔬This is a nightly-only experimental API. (clone_from_ref)
pub fn clone_from_ref(value: &T) -> Rc<T>
clone_from_ref)Constructs a new Rc<T> with a clone of value.
Examples
#![feature(clone_from_ref)]
use std::rc::Rc;
let hello: Rc<str> = Rc::clone_from_ref("hello");Sourcepub fn try_clone_from_ref(value: &T) -> Result<Rc<T>, AllocError>
🔬This is a nightly-only experimental API. (clone_from_ref)
pub fn try_clone_from_ref(value: &T) -> Result<Rc<T>, AllocError>
clone_from_ref)Constructs a new Rc<T> with a clone of value, returning an error if allocation fails
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::rc::Rc;
let hello: Rc<str> = Rc::try_clone_from_ref("hello")?;Sourceimpl<T, A> Rc<T, A>
impl<T, A> Rc<T, A>
Sourcepub fn clone_from_ref_in(value: &T, alloc: A) -> Rc<T, A>
🔬This is a nightly-only experimental API. (clone_from_ref)
pub fn clone_from_ref_in(value: &T, alloc: A) -> Rc<T, A>
clone_from_ref)Constructs a new Rc<T> with a clone of value in the provided allocator.
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let hello: Rc<str, System> = Rc::clone_from_ref_in("hello", System);Sourcepub fn try_clone_from_ref_in(
value: &T,
alloc: A,
) -> Result<Rc<T, A>, AllocError>
🔬This is a nightly-only experimental API. (clone_from_ref)
pub fn try_clone_from_ref_in( value: &T, alloc: A, ) -> Result<Rc<T, A>, AllocError>
clone_from_ref)Constructs a new Rc<T> with a clone of value in the provided allocator, returning an error if allocation fails
Examples
#![feature(clone_from_ref)]
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let hello: Rc<str, System> = Rc::try_clone_from_ref_in("hello", System)?;Sourceimpl<T, A> Rc<[MaybeUninit<T>], A>where
A: Allocator,
impl<T, A> Rc<[MaybeUninit<T>], A>where
A: Allocator,
1.82.0 · Sourcepub unsafe fn assume_init(self) -> Rc<[T], A>
pub unsafe fn assume_init(self) -> Rc<[T], A>
Converts to Rc<[T]>.
Safety
As with MaybeUninit::assume_init,
it is up to the caller to guarantee that the inner value
really is in an initialized state.
Calling this when the content is not yet fully initialized
causes immediate undefined behavior.
Examples
use std::rc::Rc;
let mut values = Rc::<[u32]>::new_uninit_slice(3);
// Deferred initialization:
let data = Rc::get_mut(&mut values).unwrap();
data[0].write(1);
data[1].write(2);
data[2].write(3);
let values = unsafe { values.assume_init() };
assert_eq!(*values, [1, 2, 3])Sourceimpl<T> Rc<T>where
T: ?Sized,
impl<T> Rc<T>where
T: ?Sized,
1.17.0 · Sourcepub unsafe fn from_raw(ptr: *const T) -> Rc<T>
pub unsafe fn from_raw(ptr: *const T) -> Rc<T>
Constructs an Rc<T> from a raw pointer.
The raw pointer must have been previously returned by a call to
Rc<U>::into_raw with the following requirements:
- If
Uis sized, it must have the same size and alignment asT. This is trivially true ifUisT. - If
Uis unsized, its data pointer must have the same size and alignment asT. This is trivially true ifRc<U>was constructed throughRc<T>and then converted toRc<U>through an unsized coercion.
Note that if U or U’s data pointer is not T but has the same size
and alignment, this is basically like transmuting references of
different types. See mem::transmute for more information
on what restrictions apply in this case.
The raw pointer must point to a block of memory allocated by the global allocator
The user of from_raw has to make sure a specific value of T is only
dropped once.
This function is unsafe because improper use may lead to memory unsafety,
even if the returned Rc<T> is never accessed.
Examples
use std::rc::Rc;
let x = Rc::new("hello".to_owned());
let x_ptr = Rc::into_raw(x);
unsafe {
// Convert back to an `Rc` to prevent leak.
let x = Rc::from_raw(x_ptr);
assert_eq!(&*x, "hello");
// Further calls to `Rc::from_raw(x_ptr)` would be memory-unsafe.
}
// The memory was freed when `x` went out of scope above, so `x_ptr` is now dangling!Convert a slice back into its original array:
use std::rc::Rc;
let x: Rc<[u32]> = Rc::new([1, 2, 3]);
let x_ptr: *const [u32] = Rc::into_raw(x);
unsafe {
let x: Rc<[u32; 3]> = Rc::from_raw(x_ptr.cast::<[u32; 3]>());
assert_eq!(&*x, &[1, 2, 3]);
}1.17.0 · Sourcepub fn into_raw(this: Rc<T>) -> *const T
pub fn into_raw(this: Rc<T>) -> *const T
Consumes the Rc, returning the wrapped pointer.
To avoid a memory leak the pointer must be converted back to an Rc using
Rc::from_raw.
Examples
use std::rc::Rc;
let x = Rc::new("hello".to_owned());
let x_ptr = Rc::into_raw(x);
assert_eq!(unsafe { &*x_ptr }, "hello");1.53.0 · Sourcepub unsafe fn increment_strong_count(ptr: *const T)
pub unsafe fn increment_strong_count(ptr: *const T)
Increments the strong reference count on the Rc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Rc::into_raw and must satisfy the
same layout requirements specified in Rc::from_raw_in.
The associated Rc instance must be valid (i.e. the strong count must be at
least 1) for the duration of this method, and ptr must point to a block of memory
allocated by the global allocator.
Examples
use std::rc::Rc;
let five = Rc::new(5);
unsafe {
let ptr = Rc::into_raw(five);
Rc::increment_strong_count(ptr);
let five = Rc::from_raw(ptr);
assert_eq!(2, Rc::strong_count(&five));
}1.53.0 · Sourcepub unsafe fn decrement_strong_count(ptr: *const T)
pub unsafe fn decrement_strong_count(ptr: *const T)
Decrements the strong reference count on the Rc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Rc::into_rawand must satisfy the
same layout requirements specified in Rc::from_raw_in.
The associated Rc instance must be valid (i.e. the strong count must be at
least 1) when invoking this method, and ptr must point to a block of memory
allocated by the global allocator. This method can be used to release the final Rc and
backing storage, but should not be called after the final Rc has been released.
Examples
use std::rc::Rc;
let five = Rc::new(5);
unsafe {
let ptr = Rc::into_raw(five);
Rc::increment_strong_count(ptr);
let five = Rc::from_raw(ptr);
assert_eq!(2, Rc::strong_count(&five));
Rc::decrement_strong_count(ptr);
assert_eq!(1, Rc::strong_count(&five));
}Sourceimpl<T, A> Rc<T, A>
impl<T, A> Rc<T, A>
Sourcepub fn allocator(this: &Rc<T, A>) -> &A
🔬This is a nightly-only experimental API. (allocator_api)
pub fn allocator(this: &Rc<T, A>) -> &A
allocator_api)Returns a reference to the underlying allocator.
Note: this is an associated function, which means that you have
to call it as Rc::allocator(&r) instead of r.allocator(). This
is so that there is no conflict with a method on the inner type.
Sourcepub fn into_raw_with_allocator(this: Rc<T, A>) -> (*const T, A)
🔬This is a nightly-only experimental API. (allocator_api)
pub fn into_raw_with_allocator(this: Rc<T, A>) -> (*const T, A)
allocator_api)Consumes the Rc, returning the wrapped pointer and allocator.
To avoid a memory leak the pointer must be converted back to an Rc using
Rc::from_raw_in.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let x = Rc::new_in("hello".to_owned(), System);
let (ptr, alloc) = Rc::into_raw_with_allocator(x);
assert_eq!(unsafe { &*ptr }, "hello");
let x = unsafe { Rc::from_raw_in(ptr, alloc) };
assert_eq!(&*x, "hello");1.45.0 · Sourcepub fn as_ptr(this: &Rc<T, A>) -> *const T
pub fn as_ptr(this: &Rc<T, A>) -> *const T
Provides a raw pointer to the data.
The counts are not affected in any way and the Rc is not consumed. The pointer is valid
for as long as there are strong counts in the Rc.
Examples
use std::rc::Rc;
let x = Rc::new(0);
let y = Rc::clone(&x);
let x_ptr = Rc::as_ptr(&x);
assert_eq!(x_ptr, Rc::as_ptr(&y));
assert_eq!(unsafe { *x_ptr }, 0);Sourcepub unsafe fn from_raw_in(ptr: *const T, alloc: A) -> Rc<T, A>
🔬This is a nightly-only experimental API. (allocator_api)
pub unsafe fn from_raw_in(ptr: *const T, alloc: A) -> Rc<T, A>
allocator_api)Constructs an Rc<T, A> from a raw pointer in the provided allocator.
The raw pointer must have been previously returned by a call to Rc<U, A>::into_raw with the following requirements:
- If
Uis sized, it must have the same size and alignment asT. This is trivially true ifUisT. - If
Uis unsized, its data pointer must have the same size and alignment asT. This is trivially true ifRc<U>was constructed throughRc<T>and then converted toRc<U>through an unsized coercion.
Note that if U or U’s data pointer is not T but has the same size
and alignment, this is basically like transmuting references of
different types. See mem::transmute for more information
on what restrictions apply in this case.
The raw pointer must point to a block of memory allocated by alloc
The user of from_raw has to make sure a specific value of T is only
dropped once.
This function is unsafe because improper use may lead to memory unsafety,
even if the returned Rc<T> is never accessed.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let x = Rc::new_in("hello".to_owned(), System);
let (x_ptr, _alloc) = Rc::into_raw_with_allocator(x);
unsafe {
// Convert back to an `Rc` to prevent leak.
let x = Rc::from_raw_in(x_ptr, System);
assert_eq!(&*x, "hello");
// Further calls to `Rc::from_raw(x_ptr)` would be memory-unsafe.
}
// The memory was freed when `x` went out of scope above, so `x_ptr` is now dangling!Convert a slice back into its original array:
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let x: Rc<[u32], _> = Rc::new_in([1, 2, 3], System);
let x_ptr: *const [u32] = Rc::into_raw_with_allocator(x).0;
unsafe {
let x: Rc<[u32; 3], _> = Rc::from_raw_in(x_ptr.cast::<[u32; 3]>(), System);
assert_eq!(&*x, &[1, 2, 3]);
}1.15.0 · Sourcepub fn weak_count(this: &Rc<T, A>) -> usize
pub fn weak_count(this: &Rc<T, A>) -> usize
1.15.0 · Sourcepub fn strong_count(this: &Rc<T, A>) -> usize
pub fn strong_count(this: &Rc<T, A>) -> usize
Gets the number of strong (Rc) pointers to this allocation.
Examples
use std::rc::Rc;
let five = Rc::new(5);
let _also_five = Rc::clone(&five);
assert_eq!(2, Rc::strong_count(&five));Sourcepub unsafe fn increment_strong_count_in(ptr: *const T, alloc: A)where
A: Clone,
🔬This is a nightly-only experimental API. (allocator_api)
pub unsafe fn increment_strong_count_in(ptr: *const T, alloc: A)where
A: Clone,
allocator_api)Increments the strong reference count on the Rc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Rc::into_raw and must satisfy the
same layout requirements specified in Rc::from_raw_in.
The associated Rc instance must be valid (i.e. the strong count must be at
least 1) for the duration of this method, and ptr must point to a block of memory
allocated by alloc.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let five = Rc::new_in(5, System);
unsafe {
let (ptr, _alloc) = Rc::into_raw_with_allocator(five);
Rc::increment_strong_count_in(ptr, System);
let five = Rc::from_raw_in(ptr, System);
assert_eq!(2, Rc::strong_count(&five));
}Sourcepub unsafe fn decrement_strong_count_in(ptr: *const T, alloc: A)
🔬This is a nightly-only experimental API. (allocator_api)
pub unsafe fn decrement_strong_count_in(ptr: *const T, alloc: A)
allocator_api)Decrements the strong reference count on the Rc<T> associated with the
provided pointer by one.
Safety
The pointer must have been obtained through Rc::into_rawand must satisfy the
same layout requirements specified in Rc::from_raw_in.
The associated Rc instance must be valid (i.e. the strong count must be at
least 1) when invoking this method, and ptr must point to a block of memory
allocated by alloc. This method can be used to release the final Rc and
backing storage, but should not be called after the final Rc has been released.
Examples
#![feature(allocator_api)]
use std::rc::Rc;
use std::alloc::System;
let five = Rc::new_in(5, System);
unsafe {
let (ptr, _alloc) = Rc::into_raw_with_allocator(five);
Rc::increment_strong_count_in(ptr, System);
let five = Rc::from_raw_in(ptr, System);
assert_eq!(2, Rc::strong_count(&five));
Rc::decrement_strong_count_in(ptr, System);
assert_eq!(1, Rc::strong_count(&five));
}1.4.0 · Sourcepub fn get_mut(this: &mut Rc<T, A>) -> Option<&mut T>
pub fn get_mut(this: &mut Rc<T, A>) -> Option<&mut T>
Returns a mutable reference into the given Rc, if there are
no other Rc or Weak pointers to the same allocation.
Returns None otherwise, because it is not safe to
mutate a shared value.
See also make_mut, which will clone
the inner value when there are other Rc pointers.
Examples
use std::rc::Rc;
let mut x = Rc::new(3);
*Rc::get_mut(&mut x).unwrap() = 4;
assert_eq!(*x, 4);
let _y = Rc::clone(&x);
assert!(Rc::get_mut(&mut x).is_none());Sourcepub unsafe fn get_mut_unchecked(this: &mut Rc<T, A>) -> &mut T
🔬This is a nightly-only experimental API. (get_mut_unchecked)
pub unsafe fn get_mut_unchecked(this: &mut Rc<T, A>) -> &mut T
get_mut_unchecked)Returns a mutable reference into the given Rc,
without any check.
See also get_mut, which is safe and does appropriate checks.
Safety
If any other Rc or Weak pointers to the same allocation exist, then
they must not be dereferenced or have active borrows for the duration
of the returned borrow, and their inner type must be exactly the same as the
inner type of this Rc (including lifetimes). This is trivially the case if no
such pointers exist, for example immediately after Rc::new.
Examples
#![feature(get_mut_unchecked)]
use std::rc::Rc;
let mut x = Rc::new(String::new());
unsafe {
Rc::get_mut_unchecked(&mut x).push_str("foo")
}
assert_eq!(*x, "foo");Other Rc pointers to the same allocation must be to the same type.
#![feature(get_mut_unchecked)]
use std::rc::Rc;
let x: Rc<str> = Rc::from("Hello, world!");
let mut y: Rc<[u8]> = x.clone().into();
unsafe {
// this is Undefined Behavior, because x's inner type is str, not [u8]
Rc::get_mut_unchecked(&mut y).fill(0xff); // 0xff is invalid in UTF-8
}
println!("{}", &*x); // Invalid UTF-8 in a strOther Rc pointers to the same allocation must be to the exact same type, including lifetimes.
#![feature(get_mut_unchecked)]
use std::rc::Rc;
let x: Rc<&str> = Rc::new("Hello, world!");
{
let s = String::from("Oh, no!");
let mut y: Rc<&str> = x.clone();
unsafe {
// this is Undefined Behavior, because x's inner type
// is &'long str, not &'short str
*Rc::get_mut_unchecked(&mut y) = &s;
}
}
println!("{}", &*x); // Use-after-free1.17.0 · Sourcepub fn ptr_eq(this: &Rc<T, A>, other: &Rc<T, A>) -> bool
pub fn ptr_eq(this: &Rc<T, A>, other: &Rc<T, A>) -> bool
Returns true if the two Rcs point to the same allocation in a vein similar to
ptr::eq. This function ignores the metadata of dyn Trait pointers.
Examples
use std::rc::Rc;
let five = Rc::new(5);
let same_five = Rc::clone(&five);
let other_five = Rc::new(5);
assert!(Rc::ptr_eq(&five, &same_five));
assert!(!Rc::ptr_eq(&five, &other_five));Sourceimpl<T, A> Rc<T, A>
impl<T, A> Rc<T, A>
1.4.0 · Sourcepub fn make_mut(this: &mut Rc<T, A>) -> &mut T
pub fn make_mut(this: &mut Rc<T, A>) -> &mut T
Makes a mutable reference into the given Rc.
If there are other Rc pointers to the same allocation, then make_mut will
clone the inner value to a new allocation to ensure unique ownership. This is also
referred to as clone-on-write.
However, if there are no other Rc pointers to this allocation, but some Weak
pointers, then the Weak pointers will be disassociated and the inner value will not
be cloned.
See also get_mut, which will fail rather than cloning the inner value
or disassociating Weak pointers.
Examples
use std::rc::Rc;
let mut data = Rc::new(5);
*Rc::make_mut(&mut data) += 1; // Won't clone anything
let mut other_data = Rc::clone(&data); // Won't clone inner data
*Rc::make_mut(&mut data) += 1; // Clones inner data
*Rc::make_mut(&mut data) += 1; // Won't clone anything
*Rc::make_mut(&mut other_data) *= 2; // Won't clone anything
// Now `data` and `other_data` point to different allocations.
assert_eq!(*data, 8);
assert_eq!(*other_data, 12);Weak pointers will be disassociated:
use std::rc::Rc;
let mut data = Rc::new(75);
let weak = Rc::downgrade(&data);
assert!(75 == *data);
assert!(75 == *weak.upgrade().unwrap());
*Rc::make_mut(&mut data) += 1;
assert!(76 == *data);
assert!(weak.upgrade().is_none());Sourceimpl<T, A> Rc<T, A>
impl<T, A> Rc<T, A>
1.76.0 · Sourcepub fn unwrap_or_clone(this: Rc<T, A>) -> T
pub fn unwrap_or_clone(this: Rc<T, A>) -> T
If we have the only reference to T then unwrap it. Otherwise, clone T and return the
clone.
Assuming rc_t is of type Rc<T>, this function is functionally equivalent to
(*rc_t).clone(), but will avoid cloning the inner value where possible.
Examples
let inner = String::from("test");
let ptr = inner.as_ptr();
let rc = Rc::new(inner);
let inner = Rc::unwrap_or_clone(rc);
// The inner value was not cloned
assert!(ptr::eq(ptr, inner.as_ptr()));
let rc = Rc::new(inner);
let rc2 = rc.clone();
let inner = Rc::unwrap_or_clone(rc);
// Because there were 2 references, we had to clone the inner value.
assert!(!ptr::eq(ptr, inner.as_ptr()));
// `rc2` is the last reference, so when we unwrap it we get back
// the original `String`.
let inner = Rc::unwrap_or_clone(rc2);
assert!(ptr::eq(ptr, inner.as_ptr()));Sourceimpl<A> Rc<dyn Any, A>where
A: Allocator,
impl<A> Rc<dyn Any, A>where
A: Allocator,
1.29.0 · Sourcepub fn downcast<T>(self) -> Result<Rc<T, A>, Rc<dyn Any, A>>where
T: Any,
pub fn downcast<T>(self) -> Result<Rc<T, A>, Rc<dyn Any, A>>where
T: Any,
Attempts to downcast the Rc<dyn Any> to a concrete type.
Examples
use std::any::Any;
use std::rc::Rc;
fn print_if_string(value: Rc<dyn Any>) {
if let Ok(string) = value.downcast::<String>() {
println!("String ({}): {}", string.len(), string);
}
}
let my_string = "Hello World".to_string();
print_if_string(Rc::new(my_string));
print_if_string(Rc::new(0i8));Sourcepub unsafe fn downcast_unchecked<T>(self) -> Rc<T, A>where
T: Any,
🔬This is a nightly-only experimental API. (downcast_unchecked)
pub unsafe fn downcast_unchecked<T>(self) -> Rc<T, A>where
T: Any,
downcast_unchecked)Downcasts the Rc<dyn Any> to a concrete type.
For a safe alternative see downcast.
Examples
#![feature(downcast_unchecked)]
use std::any::Any;
use std::rc::Rc;
let x: Rc<dyn Any> = Rc::new(1_usize);
unsafe {
assert_eq!(*x.downcast_unchecked::<usize>(), 1);
}Safety
The contained value must be of type T. Calling this method
with the incorrect type is undefined behavior.