pub struct MappedMutexGuard<'a, T>where
T: 'a + ?Sized,{ /* private fields */ }mapped_lock_guards)Expand description
An RAII mutex guard returned by MutexGuard::map, which can point to a
subfield of the protected data. When this structure is dropped (falls out
of scope), the lock will be unlocked.
The main difference between MappedMutexGuard and MutexGuard is that the
former cannot be used with Condvar, since that could introduce soundness issues if the
locked object is modified by another thread while the Mutex is unlocked.
The data protected by the mutex can be accessed through this guard via its
Deref and DerefMut implementations.
This structure is created by the map and filter_map methods on
MutexGuard.
Implementations
Sourceimpl<'a, T> MappedMutexGuard<'a, T>where
T: ?Sized,
impl<'a, T> MappedMutexGuard<'a, T>where
T: ?Sized,
Sourcepub fn map<U, F>(orig: MappedMutexGuard<'a, T>, f: F) -> MappedMutexGuard<'a, U>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn map<U, F>(orig: MappedMutexGuard<'a, T>, f: F) -> MappedMutexGuard<'a, U>
mapped_lock_guards)Makes a MappedMutexGuard for a component of the borrowed data, e.g.
an enum variant.
The Mutex is already locked, so this cannot fail.
This is an associated function that needs to be used as
MappedMutexGuard::map(...). A method would interfere with methods of the
same name on the contents of the MutexGuard used through Deref.
Sourcepub fn filter_map<U, F>(
orig: MappedMutexGuard<'a, T>,
f: F,
) -> Result<MappedMutexGuard<'a, U>, MappedMutexGuard<'a, T>>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn filter_map<U, F>( orig: MappedMutexGuard<'a, T>, f: F, ) -> Result<MappedMutexGuard<'a, U>, MappedMutexGuard<'a, T>>
mapped_lock_guards)Makes a MappedMutexGuard for a component of the borrowed data. The
original guard is returned as an Err(...) if the closure returns
None.
The Mutex is already locked, so this cannot fail.
This is an associated function that needs to be used as
MappedMutexGuard::filter_map(...). A method would interfere with methods of the
same name on the contents of the MutexGuard used through Deref.