RwLockReadGuard

Struct RwLockReadGuard 

pub struct RwLockReadGuard<'rwlock, T>
where T: 'rwlock + ?Sized,
{ /* private fields */ }
🔬This is a nightly-only experimental API. (nonpoison_rwlock)
RAII structure used to release the shared read access of a lock when dropped.

This structure is created by the read and try_read methods on RwLock.

Implementations

Source

impl<'rwlock, T> RwLockReadGuard<'rwlock, T>
where T: ?Sized,

pub fn map<U, F>( orig: RwLockReadGuard<'rwlock, T>, f: F, ) -> MappedRwLockReadGuard<'rwlock, U>
where F: FnOnce(&T) -> &U, U: ?Sized,

🔬This is a nightly-only experimental API. (mapped_lock_guards)

Makes a MappedRwLockReadGuard for a component of the borrowed data, e.g. an enum variant.

The RwLock is already locked for reading, so this cannot fail.

This is an associated function that needs to be used as RwLockReadGuard::map(...). A method would interfere with methods of the same name on the contents of the RwLockReadGuard used through Deref.

Panics

If the closure panics, the guard will be dropped (unlocked).

pub fn filter_map<U, F>( orig: RwLockReadGuard<'rwlock, T>, f: F, ) -> Result<MappedRwLockReadGuard<'rwlock, U>, RwLockReadGuard<'rwlock, T>>
where F: FnOnce(&T) -> Option<&U>, U: ?Sized,

🔬This is a nightly-only experimental API. (mapped_lock_guards)

Makes a MappedRwLockReadGuard for a component of the borrowed data. The original guard is returned as an Err(...) if the closure returns None.

The RwLock is already locked for reading, so this cannot fail.

This is an associated function that needs to be used as RwLockReadGuard::filter_map(...). A method would interfere with methods of the same name on the contents of the RwLockReadGuard used through Deref.

Panics

If the closure panics, the guard will be dropped (unlocked).