pub struct Instant { /* private fields */ }Expand description
A no_std-friendly stand-in for std::time::Instant.
- If the target has 64-bit atomics,
Instant::now()is monotonic-ish (a counter). - Otherwise,
Instant::now()is always the same instant (so elapsed = 0).
This is meant as a compile-time fallback, not a real clock.
Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn elapsed(&self) -> Duration
pub fn elapsed(&self) -> Duration
Returns the amount of time elapsed since this instant was created.
Sourcepub fn duration_since(&self, earlier: Instant) -> Duration
pub fn duration_since(&self, earlier: Instant) -> Duration
Returns the duration between two instants, or panics if earlier is later than self.
Sourcepub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
pub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration>
Returns the duration between two instants, or None if earlier is later than self.
Sourcepub fn saturating_duration_since(&self, earlier: Instant) -> Duration
pub fn saturating_duration_since(&self, earlier: Instant) -> Duration
Returns the duration between two instants, saturating at zero if earlier is later than self.
Sourcepub fn checked_add(&self, duration: Duration) -> Option<Instant>
pub fn checked_add(&self, duration: Duration) -> Option<Instant>
Returns Some(t) where t is the time self + duration if it does not overflow.
Sourcepub fn checked_sub(&self, duration: Duration) -> Option<Instant>
pub fn checked_sub(&self, duration: Duration) -> Option<Instant>
Returns Some(t) where t is the time self - duration if it does not underflow.