StructuralEq

Trait StructuralEq 

pub trait StructuralEq {
    // Required method
    fn structural_eq(&self, other: &Self) -> bool;
}

Required Methods

fn structural_eq(&self, other: &Self) -> bool

Check if two values are equal, ignoring the type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<T: StructuralEq> StructuralEq for Option<T>

Source

fn structural_eq(&self, other: &Self) -> bool

Implementors

Source

impl StructuralEq for SharedContainer

Source

impl StructuralEq for TypeDefinition

Source

impl StructuralEq for StructuralTypeDefinition

Source

impl StructuralEq for CoreValue

Source

impl StructuralEq for Decimal

Source

impl StructuralEq for TypedDecimal

Source

impl StructuralEq for TypedInteger

Source

impl StructuralEq for BorrowedMapKey<'_>

Source

impl StructuralEq for Map

Source

impl StructuralEq for ValueContainer

Structural equality checks the structural equality of the underlying values, collapsing references to their current resolved values.

Source

impl StructuralEq for Boolean

Source

impl StructuralEq for Callable

Source

impl StructuralEq for Endpoint

Source

impl StructuralEq for Integer

Source

impl StructuralEq for List

Source

impl StructuralEq for Text

Source

impl StructuralEq for Type

Source

impl StructuralEq for Value

Two values are structurally equal, if their inner values are structurally equal, regardless of the actual_type of the values