Decimal

Enum Decimal 

pub enum Decimal {
    Finite(Rational),
    Nan,
    Zero,
    NegZero,
    Infinity,
    NegInfinity,
}

Variants



Finite(Rational)



Nan



Zero



NegZero



Infinity



NegInfinity

Implementations

Source

impl Decimal

pub fn into_f32(&self) -> f32

Attempts to convert the Decimal to an f32. If an overflow occurs, returns infinity or -infinity.

pub fn into_f64(&self) -> f64

Attempts to convert the Decimal to an f64. If an overflow occurs, returns infinity or -infinity.

pub fn is_integer(&self) -> bool

pub fn as_integer(&self) -> Option<i64>

pub fn is_finite(&self) -> bool

Returns true if the value is finite (not NaN or Infinity).

pub fn is_infinite(&self) -> bool

Returns true if the value is infinite (positive or negative).

pub fn is_nan(&self) -> bool

Returns true if the value is zero (positive or negative).

pub fn is_zero(&self) -> bool

Returns true if the value is zero (positive or negative).

pub fn is_sign_positive(&self) -> bool

Returns true if the value has a positive sign. Positive values are greater than or equal to zero. So -0.0 is not positive.

pub fn is_sign_negative(&self) -> bool

Returns true if the value has a negative sign. Negative values are less than zero. So +0.0 is not negative.

pub fn from_string(s: &str) -> Result<Self, NumberParseError>

Creates a Decimal from a string representation.