Integer

Struct Integer 

pub struct Integer(pub BigInt);

Tuple Fields

0: BigInt

Implementations

Source

impl Integer

pub fn new<T: Into<BigInt>>(value: T) -> Self

pub fn from_string(s: &str) -> Result<Self, NumberParseError>

Parse an integer from a string in base 10. Returns an error if the string is not a valid integer.

pub fn from_string_radix(s: &str, radix: u32) -> Result<Self, NumberParseError>

Parse an integer from a string in the given radix (base). Returns an error if the string is not a valid integer in the given radix.

pub fn is_zero(&self) -> bool

Returns true if the integer is zero.

pub fn is_negative(&self) -> bool

Returns true if the integer is negative. Note that zero is neither positive nor negative.

pub fn is_positive(&self) -> bool

Returns true if the integer is positive. Note that zero is neither positive nor negative.

pub fn as_i8(&self) -> Option<i8>

Converts the integer to an i8 if it fits, otherwise returns None.

pub fn as_u8(&self) -> Option<u8>

Converts the integer to a u8 if it fits, otherwise returns None.

pub fn as_i16(&self) -> Option<i16>

Converts the integer to an i16 if it fits, otherwise returns None.

pub fn as_u16(&self) -> Option<u16>

Converts the integer to a u16 if it fits, otherwise returns None.

pub fn as_i32(&self) -> Option<i32>

Converts the integer to an i32 if it fits, otherwise returns None.

pub fn as_u32(&self) -> Option<u32>

Converts the integer to a u32 if it fits, otherwise returns None.

pub fn as_i64(&self) -> Option<i64>

Converts the integer to an i64 if it fits, otherwise returns None.

pub fn as_usize(&self) -> Option<usize>

Converts the integer to a usize if it fits, otherwise returns None.

pub fn as_u64(&self) -> Option<u64>

Converts the integer to a u64 if it fits, otherwise returns None.

pub fn as_i128(&self) -> Option<i128>

Converts the integer to an i128 if it fits, otherwise returns None.

pub fn as_u128(&self) -> Option<u128>

Converts the integer to a u128 if it fits, otherwise returns None.

pub fn as_f32(&self) -> f32

pub fn as_f64(&self) -> f64

pub fn as_wrapped_i8(&self) -> i8

Converts the integer to an i8, wrapping on overflow.

pub fn as_wrapped_u8(&self) -> u8

Converts the integer to a u8, wrapping on overflow.

pub fn as_wrapped_i16(&self) -> i16

pub fn as_wrapped_u16(&self) -> u16

pub fn as_wrapped_i32(&self) -> i32

pub fn as_wrapped_u32(&self) -> u32

pub fn as_wrapped_i64(&self) -> i64

pub fn as_wrapped_u64(&self) -> u64

pub fn as_wrapped_i128(&self) -> i128

pub fn as_wrapped_u128(&self) -> u128

pub fn to_smallest_fitting(&self) -> TypedInteger

Converts the integer to the smallest fitting TypedInteger variant. If it doesn’t fit in any smaller type, returns TypedInteger::Big.