Map

Enum Map 

pub enum Map {
    Dynamic(IndexMap<ValueContainer, ValueContainer, RandomState>),
    Structural(Vec<(ValueContainer, ValueContainer)>),
    StructuralWithStringKeys(Vec<(String, ValueContainer)>),
}

Variants

Implementations

Source

impl Map

pub fn new( entries: IndexMap<ValueContainer, ValueContainer, RandomState>, ) -> Self

pub fn is_structural(&self) -> bool

pub fn size(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get<'a>( &self, key: impl Into<ValueKey<'a>>, ) -> Result<&ValueContainer, KeyNotFoundError>

Gets a value in the map by reference. Returns None if the key is not found.

pub fn has<'a>(&self, key: impl Into<ValueKey<'a>>) -> bool

Checks if the map contains the given key.

pub fn delete<'a>( &mut self, key: impl Into<ValueKey<'a>>, ) -> Result<ValueContainer, MapAccessError>

Removes a key from the map, returning the value if it existed.

pub fn clear(&mut self) -> Result<(), MapAccessError>

Clears all entries in the map, returning an error if the map is not dynamic.