pub enum VisitAction<T: Sized> {
VisitChildren,
SkipChildren,
Replace(T),
ReplaceRecurseChildNodes(T),
ReplaceRecurse(T),
SetTypeRecurseChildNodes(Type),
SetTypeSkipChildren(Type),
ToNoop,
}Expand description
Actions that can be taken when visiting an expression
Variants
VisitChildren
Continue visiting child nodes
SkipChildren
Skip visiting child nodes
Replace(T)
Replace the current node with a new one, skipping child nodes
ReplaceRecurseChildNodes(T)
Recurse into child nodes, then replace the current node with a new one
ReplaceRecurse(T)
Replace the current node with a new one, and recurse into it
SetTypeRecurseChildNodes(Type)
Set the type annotation of the current node, and recurse into child nodes
SetTypeSkipChildren(Type)
Set the type annotation of the current node, skipping child nodes
ToNoop
Convert the current node to a no-op