Ref

Struct Ref 

1.0.0 · Source
pub struct Ref<'b, T>
where T: 'b + ?Sized,
{ /* private fields */ }
Wraps a borrowed reference to a value in a RefCell box. A wrapper type for an immutably borrowed value from a RefCell<T>.

See the module-level documentation for more.

Implementations

Source

impl<'b, T> Ref<'b, T>
where T: ?Sized,

1.15.0 (const: unstable) · Source

pub fn clone(orig: &Ref<'b, T>) -> Ref<'b, T>

Copies a Ref.

The RefCell is already immutably borrowed, so this cannot fail.

This is an associated function that needs to be used as Ref::clone(...). A Clone implementation or a method would interfere with the widespread use of r.borrow().clone() to clone the contents of a RefCell.

1.8.0 · Source

pub fn map<U, F>(orig: Ref<'b, T>, f: F) -> Ref<'b, U>
where F: FnOnce(&T) -> &U, U: ?Sized,

Makes a new Ref for a component of the borrowed data.

The RefCell is already immutably borrowed, so this cannot fail.

This is an associated function that needs to be used as Ref::map(...). A method would interfere with methods of the same name on the contents of a RefCell used through Deref.

Examples
use std::cell::{RefCell, Ref};

let c = RefCell::new((5, 'b'));
let b1: Ref<'_, (u32, char)> = c.borrow();
let b2: Ref<'_, u32> = Ref::map(b1, |t| &t.0);
assert_eq!(*b2, 5)
1.63.0 · Source

pub fn filter_map<U, F>( orig: Ref<'b, T>, f: F, ) -> Result<Ref<'b, U>, Ref<'b, T>>
where F: FnOnce(&T) -> Option<&U>, U: ?Sized,

Makes a new Ref for an optional component of the borrowed data. The original guard is returned as an Err(..) if the closure returns None.

The RefCell is already immutably borrowed, so this cannot fail.

This is an associated function that needs to be used as Ref::filter_map(...). A method would interfere with methods of the same name on the contents of a RefCell used through Deref.

Examples
use std::cell::{RefCell, Ref};

let c = RefCell::new(vec![1, 2, 3]);
let b1: Ref<'_, Vec<u32>> = c.borrow();
let b2: Result<Ref<'_, u32>, _> = Ref::filter_map(b1, |v| v.get(1));
assert_eq!(*b2.unwrap(), 2);
pub fn try_map<U, E>( orig: Ref<'b, T>, f: impl FnOnce(&T) -> Result<&U, E>, ) -> Result<Ref<'b, U>, (Ref<'b, T>, E)>
where U: ?Sized,

🔬This is a nightly-only experimental API. (refcell_try_map)

Tries to makes a new Ref for a component of the borrowed data. On failure, the original guard is returned alongside with the error returned by the closure.

The RefCell is already immutably borrowed, so this cannot fail.

This is an associated function that needs to be used as Ref::try_map(...). A method would interfere with methods of the same name on the contents of a RefCell used through Deref.

Examples
#![feature(refcell_try_map)]
use std::cell::{RefCell, Ref};
use std::str::{from_utf8, Utf8Error};

let c = RefCell::new(vec![0xF0, 0x9F, 0xA6 ,0x80]);
let b1: Ref<'_, Vec<u8>> = c.borrow();
let b2: Result<Ref<'_, str>, _> = Ref::try_map(b1, |v| from_utf8(v));
assert_eq!(&*b2.unwrap(), "🦀");

let c = RefCell::new(vec![0xF0, 0x9F, 0xA6]);
let b1: Ref<'_, Vec<u8>> = c.borrow();
let b2: Result<_, (Ref<'_, Vec<u8>>, Utf8Error)> = Ref::try_map(b1, |v| from_utf8(v));
let (b3, e) = b2.unwrap_err();
assert_eq!(*b3, vec![0xF0, 0x9F, 0xA6]);
assert_eq!(e.valid_up_to(), 0);
1.35.0 · Source

pub fn map_split<U, V, F>(orig: Ref<'b, T>, f: F) -> (Ref<'b, U>, Ref<'b, V>)
where F: FnOnce(&T) -> (&U, &V), U: ?Sized, V: ?Sized,

Splits a Ref into multiple Refs for different components of the borrowed data.

The RefCell is already immutably borrowed, so this cannot fail.

This is an associated function that needs to be used as Ref::map_split(...). A method would interfere with methods of the same name on the contents of a RefCell used through Deref.

Examples
use std::cell::{Ref, RefCell};

let cell = RefCell::new([1, 2, 3, 4]);
let borrow = cell.borrow();
let (begin, end) = Ref::map_split(borrow, |slice| slice.split_at(2));
assert_eq!(*begin, [1, 2]);
assert_eq!(*end, [3, 4]);
pub const fn leak(orig: Ref<'b, T>) -> &'b T

🔬This is a nightly-only experimental API. (cell_leak)

Converts into a reference to the underlying data.

The underlying RefCell can never be mutably borrowed from again and will always appear already immutably borrowed. It is not a good idea to leak more than a constant number of references. The RefCell can be immutably borrowed again if only a smaller number of leaks have occurred in total.

This is an associated function that needs to be used as Ref::leak(...). A method would interfere with methods of the same name on the contents of a RefCell used through Deref.

Examples
#![feature(cell_leak)]
use std::cell::{RefCell, Ref};
let cell = RefCell::new(0);

let value = Ref::leak(cell.borrow());
assert_eq!(*value, 0);

assert!(cell.try_borrow().is_ok());
assert!(cell.try_borrow_mut().is_err());