pub trait Ord: Eq + PartialOrd {
// Required method
fn cmp(&self, other: &Self) -> Ordering;
// Provided methods
fn max(self, other: Self) -> Self
where Self: Sized { ... }
fn min(self, other: Self) -> Self
where Self: Sized { ... }
fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized { ... }
}Expand description
Trait for types that form a total order.
Implementations must be consistent with the PartialOrd implementation, and ensure max,
min, and clamp are consistent with cmp:
partial_cmp(a, b) == Some(cmp(a, b)).max(a, b) == max_by(a, b, cmp)(ensured by the default implementation).min(a, b) == min_by(a, b, cmp)(ensured by the default implementation).- For
a.clamp(min, max), see the method docs (ensured by the default implementation).
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Corollaries
From the above and the requirements of PartialOrd, it follows that for all a, b and c:
- exactly one of
a < b,a == bora > bis true; and <is transitive:a < bandb < cimpliesa < c. The same must hold for both==and>.
Mathematically speaking, the < operator defines a strict weak order. In cases where ==
conforms to mathematical equality, it also defines a strict total order.
Derivable
This trait can be used with #[derive].
When derived on structs, it will produce a
lexicographic ordering based on the
top-to-bottom declaration order of the struct’s members.
When derived on enums, variants are ordered primarily by their discriminants. Secondarily,
they are ordered by their fields. By default, the discriminant is smallest for variants at the
top, and largest for variants at the bottom. Here’s an example:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top,
Bottom,
}
assert!(E::Top < E::Bottom);However, manually setting the discriminants can override this default behavior:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top = 2,
Bottom = 1,
}
assert!(E::Bottom < E::Top);Lexicographical comparison
Lexicographical comparison is an operation with the following properties:
- Two sequences are compared element by element.
- The first mismatching element defines which sequence is lexicographically less or greater than the other.
- If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
- If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
- An empty sequence is lexicographically less than any non-empty sequence.
- Two empty sequences are lexicographically equal.
How can I implement Ord?
Ord requires that the type also be PartialOrd, PartialEq, and Eq.
Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and
PartialOrd must agree, you must choose how to implement Ord first. You can choose to
derive it, or implement it manually. If you derive it, you should derive all four traits. If you
implement it manually, you should manually implement all four traits, based on the
implementation of Ord.
Here’s an example where you want to define the Character comparison by health and
experience only, disregarding the field mana:
use std::cmp::Ordering;
struct Character {
health: u32,
experience: u32,
mana: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> Ordering {
self.experience
.cmp(&other.experience)
.then(self.health.cmp(&other.health))
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health && self.experience == other.experience
}
}
impl Eq for Character {}If all you need is to slice::sort a type by a field value, it can be simpler to use
slice::sort_by_key.
Examples of incorrect Ord implementations
use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < other.health {
Ordering::Less
} else if self.health > other.health {
Ordering::Greater
} else {
Ordering::Equal
}
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health
}
}
impl Eq for Character {}
let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };
// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.
// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: u32,
experience: u32,
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < 50 {
self.health.cmp(&other.health)
} else {
self.experience.cmp(&other.experience)
}
}
}
// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.cmp(other) == Ordering::Equal
}
}
impl Eq for Character {}
let a = Character {
health: 3,
experience: 5,
};
let b = Character {
health: 10,
experience: 77,
};
let c = Character {
health: 143,
experience: 2,
};
// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.
// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);The documentation of PartialOrd contains further examples, for example it’s wrong for
PartialOrd and PartialEq to disagree.
Required Methods
1.0.0 · Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
This method returns an Ordering between self and other.
By convention, self.cmp(&other) returns the ordering matching the expression
self <operator> other if true.
Examples
use std::cmp::Ordering;
assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);Provided Methods
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values.
Returns the second argument if the comparison determines them to be equal.
Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").max(Equal("other")).0, "other");1.21.0 · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values.
Returns the first argument if the comparison determines them to be equal.
Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").min(Equal("other")).0, "self");Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Ord for InterfacePriority
impl Ord for AsciiChar
impl Ord for Infallible
impl Ord for IpAddr
impl Ord for SocketAddr
impl Ord for Ordering
impl Ord for ErrorKind
impl Ord for ASN1TimeZone
impl Ord for LineEnding
impl Ord for byteorder::BigEndian
impl Ord for byteorder::LittleEndian
impl Ord for chrono::month::Month
impl Ord for const_oid::error::Error
impl Ord for Class
impl Ord for der::tag::Tag
impl Ord for TagMode
impl Ord for ExtensionType
impl Ord for GeneralCategory
impl Ord for IpAddrRange
impl Ord for IpNet
impl Ord for IpSubnets
impl Ord for log::Level
impl Ord for log::LevelFilter
impl Ord for InsertError
impl Ord for PosixFadviseAdvice
impl Ord for AioFsyncMode
impl Ord for LioMode
impl Ord for MmapAdvise
impl Ord for Event
impl Ord for Request
impl Ord for QuotaFmt
impl Ord for QuotaType
impl Ord for RebootMode
impl Ord for Resource
impl Ord for UsageWho
impl Ord for SigmaskHow
impl Ord for Signal
impl Ord for BaudRate
impl Ord for FlowArg
impl Ord for FlushArg
impl Ord for SetArg
impl Ord for SpecialCharacterIndices
impl Ord for nix::sys::timerfd::ClockId
impl Ord for Id
impl Ord for Sign
impl Ord for Utf8Sequence
impl Ord for time::month::Month
impl Ord for Yaml
impl Ord for yansi::attr_quirk::Attribute
impl Ord for Quirk
impl Ord for Color
impl Ord for PCBit
impl Ord for TagClass
impl Ord for BERMode
impl Ord for zerocopy::byteorder::BigEndian
impl Ord for zerocopy::byteorder::LittleEndian
impl Ord for bool
impl Ord for char
impl Ord for i8
impl Ord for i16
impl Ord for i32
impl Ord for i64
impl Ord for i128
impl Ord for isize
impl Ord for !
impl Ord for str
Implements ordering of strings.
Strings are ordered lexicographically by their byte values. This orders Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Sorting strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl Ord for u8
impl Ord for u16
impl Ord for u32
impl Ord for u64
impl Ord for u128
impl Ord for ()
impl Ord for usize
impl Ord for TypeId
impl Ord for CpuidResult
impl Ord for CStr
impl Ord for CString
impl Ord for datex_core::without_std::fmt::Error
impl Ord for PhantomPinned
impl Ord for Ipv4Addr
impl Ord for Ipv6Addr
impl Ord for SocketAddrV4
impl Ord for SocketAddrV6
impl Ord for Location<'_>
impl Ord for String
impl Ord for Alignment
impl Ord for datex_core::without_std::time::Duration
impl Ord for ByteString
impl Ord for ByteStr
impl Ord for OsStr
impl Ord for OsString
impl Ord for Components<'_>
impl Ord for Path
impl Ord for PathBuf
impl Ord for PrefixComponent<'_>
impl Ord for std::time::Instant
impl Ord for SystemTime
impl Ord for aead::Error
impl Ord for aho_corasick::util::primitives::PatternID
impl Ord for aho_corasick::util::primitives::StateID
impl Ord for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
impl Ord for asn1_rs::asn1_types::utctime::UtcTime
impl Ord for ASN1DateTime
impl Ord for Base64Bcrypt
impl Ord for Base64Crypt
impl Ord for Base64ShaCrypt
impl Ord for Base64
impl Ord for Base64Unpadded
impl Ord for Base64Url
impl Ord for Base64UrlUnpadded
impl Ord for BigDecimal
impl Ord for BigDecimalRef<'_>
impl Ord for bigint::uint::U128
impl Ord for U256
impl Ord for U512
impl Ord for Bytes
impl Ord for BytesMut
impl Ord for Months
impl Ord for NaiveDate
impl Ord for NaiveDateDaysIterator
impl Ord for NaiveDateWeeksIterator
impl Ord for NaiveDateTime
impl Ord for IsoWeek
impl Ord for Days
impl Ord for NaiveTime
impl Ord for TimeDelta
impl Ord for WeekdaySet
impl Ord for EmptyErr
impl Ord for const_oid::ObjectIdentifier
impl Ord for Limb
impl Ord for Any
impl Ord for BitString
impl Ord for BmpString
impl Ord for der::asn1::generalized_time::GeneralizedTime
impl Ord for Ia5String
impl Ord for Int
impl Ord for der::asn1::integer::uint::allocating::Uint
impl Ord for Null
impl Ord for OctetString
impl Ord for PrintableString
impl Ord for TeletexString
impl Ord for der::asn1::utc_time::UtcTime
impl Ord for der::datetime::DateTime
impl Ord for IndefiniteLength
impl Ord for Length
impl Ord for TagNumber
impl Ord for RecoveryId
impl Ord for HeaderValue
impl Ord for StatusCode
impl Ord for Version
impl Ord for HttpDate
impl Ord for ReasonPhrase
impl Ord for Other
impl Ord for icu_locale_core::extensions::private::other::Subtag
impl Ord for Private
impl Ord for Fields
impl Ord for icu_locale_core::extensions::transform::key::Key
impl Ord for icu_locale_core::extensions::transform::value::Value
impl Ord for icu_locale_core::extensions::unicode::attribute::Attribute
impl Ord for Attributes
impl Ord for icu_locale_core::extensions::unicode::key::Key
impl Ord for Keywords
impl Ord for SubdivisionId
impl Ord for SubdivisionSuffix
impl Ord for icu_locale_core::extensions::unicode::value::Value
impl Ord for Language
impl Ord for Region
impl Ord for icu_locale_core::subtags::script::Script
impl Ord for icu_locale_core::subtags::Subtag
impl Ord for Variant
impl Ord for Variants
impl Ord for GeneralCategoryULE
impl Ord for BidiClass
impl Ord for CanonicalCombiningClass
impl Ord for EastAsianWidth
impl Ord for GeneralCategoryOutOfBoundsError
impl Ord for GraphemeClusterBreak
impl Ord for HangulSyllableType
impl Ord for IndicSyllabicCategory
impl Ord for JoiningType
impl Ord for LineBreak
impl Ord for icu_properties::props::Script
impl Ord for SentenceBreak
impl Ord for VerticalOrientation
impl Ord for WordBreak
impl Ord for DataMarkerId
impl Ord for DataMarkerIdHash
impl Ord for DataMarkerInfo
impl Ord for DataMarkerAttributes
impl Ord for DataRequestMetadata
impl Ord for Ipv4AddrRange
impl Ord for Ipv6AddrRange
impl Ord for Ipv4Net
impl Ord for Ipv4Subnets
impl Ord for Ipv6Net
impl Ord for Ipv6Subnets
impl Ord for Mime
impl Ord for Interest
impl Ord for Token
impl Ord for AtFlags
impl Ord for FallocateFlags
impl Ord for FdFlag
impl Ord for OFlag
impl Ord for RenameFlags
impl Ord for SealFlag
impl Ord for SpliceFFlags
impl Ord for DeleteModuleFlags
impl Ord for ModuleInitFlags
impl Ord for MntFlags
impl Ord for nix::mount::linux::MsFlags
impl Ord for MQ_OFlag
impl Ord for InterfaceFlags
impl Ord for PollFlags
impl Ord for CloneFlags
impl Ord for EpollCreateFlags
impl Ord for EpollFlags
impl Ord for EfdFlags
impl Ord for AddWatchFlags
impl Ord for InitFlags
impl Ord for WatchDescriptor
impl Ord for MemFdCreateFlag
impl Ord for MRemapFlags
impl Ord for MapFlags
impl Ord for MlockAllFlags
impl Ord for nix::sys::mman::MsFlags
impl Ord for ProtFlags
impl Ord for Persona
impl Ord for Options
impl Ord for QuotaValidFlags
impl Ord for SaFlags
impl Ord for SfdFlags
impl Ord for MsgFlags
impl Ord for SockFlag
impl Ord for TimestampingFlag
impl Ord for Mode
impl Ord for SFlag
impl Ord for FsFlags
impl Ord for ControlFlags
impl Ord for InputFlags
impl Ord for LocalFlags
impl Ord for OutputFlags
impl Ord for TimeSpec
impl Ord for TimeVal
impl Ord for TimerSetTimeFlags
impl Ord for TimerFlags
impl Ord for WaitPidFlag
impl Ord for nix::time::ClockId
impl Ord for AccessFlags
impl Ord for Pid
impl Ord for BigInt
impl Ord for BigUint
impl Ord for Asn1Integer
impl Ord for Asn1IntegerRef
impl Ord for BigNum
impl Ord for BigNumRef
impl Ord for CMSOptions
impl Ord for OcspFlag
impl Ord for Pkcs7Flags
impl Ord for ExtensionContext
impl Ord for ShutdownState
impl Ord for SslMode
impl Ord for SslOptions
impl Ord for SslSessionCacheMode
impl Ord for SslVerifyMode
impl Ord for X509
impl Ord for X509Ref
impl Ord for X509CheckFlags
impl Ord for X509VerifyFlags
impl Ord for p256::arithmetic::scalar::Scalar
impl Ord for NistP256
impl Ord for p384::arithmetic::scalar::Scalar
impl Ord for NistP384
impl Ord for Integer
impl Ord for PotentialCodePoint
impl Ord for PotentialUtf8
impl Ord for PotentialUtf16
impl Ord for LazyStateID
impl Ord for Unit
impl Ord for NonMaxUsize
impl Ord for regex_automata::util::primitives::PatternID
impl Ord for SmallIndex
impl Ord for regex_automata::util::primitives::StateID
impl Ord for Position
impl Ord for Span
impl Ord for Literal
impl Ord for ClassBytesRange
impl Ord for ClassUnicodeRange
impl Ord for Utf8Range
impl Ord for UnixTime
impl Ord for SigId
impl Ord for SmolStr
impl Ord for FontStyle
impl Ord for MatchPower
impl Ord for Scope
impl Ord for time::date::Date
impl Ord for time::duration::Duration
impl Ord for OffsetDateTime
impl Ord for PrimitiveDateTime
impl Ord for Time
impl Ord for UtcDateTime
impl Ord for UtcOffset
impl Ord for Ready
impl Ord for tokio::time::instant::Instant
impl Ord for tracing_core::metadata::Level
impl Ord for tracing_core::metadata::LevelFilter
impl Ord for ATerm
impl Ord for B0
impl Ord for B1
impl Ord for Z0
impl Ord for Equal
impl Ord for Greater
impl Ord for Less
impl Ord for UTerm
impl Ord for Url
URLs compare like their serialization.
impl Ord for Braced
impl Ord for Hyphenated
impl Ord for uuid::fmt::Simple
impl Ord for Urn
impl Ord for Uuid
impl Ord for ASN1Time
impl Ord for Condition
impl Ord for Style
impl Ord for TaggedDerValue
impl Ord for yasna::models::oid::ObjectIdentifier
impl Ord for yasna::models::time::GeneralizedTime
impl Ord for UTCTime
impl Ord for yasna::Tag
impl Ord for CharULE
impl Ord for Index8
impl Ord for Index16
impl Ord for Index32
impl<'a> Ord for Component<'a>
impl<'a> Ord for std::path::Prefix<'a>
impl<'a> Ord for PrefixDeclaration<'a>
impl<'a> Ord for PhantomContravariantLifetime<'a>
impl<'a> Ord for PhantomCovariantLifetime<'a>
impl<'a> Ord for PhantomInvariantLifetime<'a>
impl<'a> Ord for AnyRef<'a>
impl<'a> Ord for BitStringRef<'a>
impl<'a> Ord for Ia5StringRef<'a>
impl<'a> Ord for IntRef<'a>
impl<'a> Ord for UintRef<'a>
impl<'a> Ord for OctetStringRef<'a>
impl<'a> Ord for PrintableStringRef<'a>
impl<'a> Ord for TeletexStringRef<'a>
impl<'a> Ord for Utf8StringRef<'a>
impl<'a> Ord for VideotexStringRef<'a>
impl<'a> Ord for Metadata<'a>
impl<'a> Ord for MetadataBuilder<'a>
impl<'a> Ord for Name<'a>
impl<'a> Ord for LocalName<'a>
impl<'a> Ord for Namespace<'a>
impl<'a> Ord for quick_xml::name::Prefix<'a>
impl<'a> Ord for QName<'a>
impl<'a, T> Ord for RichPattern<'a, T>where
T: Ord,
impl<'a, T> Ord for RichReason<'a, T>where
T: Ord,
impl<'a, T> Ord for ContextSpecificRef<'a, T>where
T: Ord,
impl<'a, T> Ord for ZeroVec<'a, T>
impl<'a, T, F> Ord for VarZeroVec<'a, T, F>
impl<'a, T, S> Ord for chumsky::error::Simple<'a, T, S>
impl<'a, V> Ord for VarZeroCow<'a, V>
impl<'k, 'v> Ord for Params<'k, 'v>
impl<'src, I> Ord for Cursor<'src, '_, I>where
I: Input<'src>,
impl<A> Ord for &A
impl<A> Ord for &mut A
impl<A> Ord for SmallVec<A>
impl<A, B> Ord for Tuple2ULE<A, B>
impl<A, B> Ord for VarTuple<A, B>
impl<A, B, C> Ord for Tuple3ULE<A, B, C>
impl<A, B, C, D> Ord for Tuple4ULE<A, B, C, D>
impl<A, B, C, D, E> Ord for Tuple5ULE<A, B, C, D, E>
impl<A, B, C, D, E, F> Ord for Tuple6ULE<A, B, C, D, E, F>
impl<A, B, C, D, E, F, Format> Ord for Tuple6VarULE<A, B, C, D, E, F, Format>
impl<A, B, C, D, E, Format> Ord for Tuple5VarULE<A, B, C, D, E, Format>
impl<A, B, C, D, Format> Ord for Tuple4VarULE<A, B, C, D, Format>
impl<A, B, C, Format> Ord for Tuple3VarULE<A, B, C, Format>
impl<A, B, Format> Ord for Tuple2VarULE<A, B, Format>
impl<A, V> Ord for VarTupleULE<A, V>
impl<B> Ord for Cow<'_, B>
impl<B> Ord for BitSet<B>where
B: BitBlock,
impl<B> Ord for BitVec<B>where
B: BitBlock,
impl<C> Ord for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> Ord for PublicKey<C>where
C: CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> Ord for ScalarPrimitive<C>where
C: Curve,
impl<Dyn> Ord for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> Ord for Fwhere
F: FnPtr,
impl<K, V> Ord for indexmap::map::slice::Slice<K, V>
impl<K, V> Ord for ringmap::map::slice::Slice<K, V>
impl<K, V, A> Ord for BTreeMap<K, V, A>
impl<K, V, S> Ord for LinkedHashMap<K, V, S>
impl<K, V, S> Ord for LiteMap<K, V, S>
impl<K, V, S> Ord for RingMap<K, V, S>
impl<L, R> Ord for Either<L, R>
impl<O> Ord for I16<O>where
O: ByteOrder,
impl<O> Ord for I32<O>where
O: ByteOrder,
impl<O> Ord for I64<O>where
O: ByteOrder,
impl<O> Ord for I128<O>where
O: ByteOrder,
impl<O> Ord for Isize<O>where
O: ByteOrder,
impl<O> Ord for U16<O>where
O: ByteOrder,
impl<O> Ord for U32<O>where
O: ByteOrder,
impl<O> Ord for U64<O>where
O: ByteOrder,
impl<O> Ord for zerocopy::byteorder::U128<O>where
O: ByteOrder,
impl<O> Ord for Usize<O>where
O: ByteOrder,
impl<Params> Ord for AlgorithmIdentifier<Params>where
Params: Ord,
impl<Ptr> Ord for Pin<Ptr>
impl<S> Ord for Host<S>where
S: Ord,
impl<S> Ord for Cheap<S>where
S: Ord,
impl<Size> Ord for EncodedPoint<Size>where
Size: ModulusSize,
impl<T> Ord for Option<T>where
T: Ord,
impl<T> Ord for Poll<T>where
T: Ord,
impl<T> Ord for Attr<T>where
T: Ord,
impl<T> Ord for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> Ord for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> Ord for [T]where
T: Ord,
Implements comparison of slices lexicographically.
impl<T> Ord for (T₁, T₂, …, Tₙ)where
T: Ord,
This trait is implemented for tuples up to twelve items long.
impl<T> Ord for Cell<T>
impl<T> Ord for RefCell<T>
impl<T> Ord for PhantomContravariant<T>where
T: ?Sized,
impl<T> Ord for PhantomCovariant<T>where
T: ?Sized,
impl<T> Ord for PhantomData<T>where
T: ?Sized,
impl<T> Ord for PhantomInvariant<T>where
T: ?Sized,
impl<T> Ord for ManuallyDrop<T>
impl<T> Ord for datex_core::without_std::num::NonZero<T>where
T: ZeroablePrimitive + Ord,
impl<T> Ord for Saturating<T>where
T: Ord,
impl<T> Ord for datex_core::without_std::num::Wrapping<T>where
T: Ord,
impl<T> Ord for NonNull<T>where
T: ?Sized,
impl<T> Ord for Exclusive<T>
impl<T> Ord for Constant<T>where
T: Ord,
impl<T> Ord for crypto_bigint::non_zero::NonZero<T>
impl<T> Ord for crypto_bigint::wrapping::Wrapping<T>where
T: Ord,
impl<T> Ord for ContextSpecific<T>where
T: Ord,
impl<T> Ord for SetOfVec<T>
impl<T> Ord for AllowStdIo<T>where
T: Ord,
impl<T> Ord for indexmap::set::slice::Slice<T>where
T: Ord,
impl<T> Ord for Intern<T>
impl<T> Ord for Ratio<T>
impl<T> Ord for NotNan<T>where
T: FloatCore,
impl<T> Ord for OrderedFloat<T>where
T: FloatCore,
impl<T> Ord for ringmap::set::slice::Slice<T>where
T: Ord,
impl<T> Ord for TryWriteableInfallibleAsWriteable<T>where
T: Ord,
impl<T> Ord for WriteableAsTryWriteableInfallible<T>where
T: Ord,
impl<T> Ord for Unalign<T>
impl<T> Ord for ZeroSlice<T>
impl<T> Ord for Reverse<T>where
T: Ord,
impl<T, A> Ord for BTreeSet<T, A>
impl<T, A> Ord for LinkedList<T, A>
impl<T, A> Ord for VecDeque<T, A>
impl<T, A> Ord for datex_core::without_std::prelude::Box<T, A>
impl<T, A> Ord for datex_core::without_std::prelude::Vec<T, A>
Implements ordering of vectors, lexicographically.
impl<T, A> Ord for Rc<T, A>
impl<T, A> Ord for UniqueRc<T, A>
impl<T, A> Ord for Arc<T, A>
impl<T, A> Ord for UniqueArc<T, A>
impl<T, A> Ord for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Ord for allocator_api2::stable::vec::Vec<T, A>
Implements ordering of vectors, lexicographically.
impl<T, B> Ord for Ref<B, T>
impl<T, E> Ord for Result<T, E>
impl<T, E> Ord for ParseResult<T, E>
impl<T, F> Ord for VarZeroSlice<T, F>
impl<T, N> Ord for GenericArray<T, N>where
T: Ord,
N: ArrayLength<T>,
impl<T, R> Ord for Maybe<T, R>
impl<T, S> Ord for RingSet<T, S>where
T: Ord,
impl<T, const N: usize> Ord for [T; N]where
T: Ord,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> Ord for Simd<T, N>
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.