TryFrom

Trait TryFrom 

1.34.0 (const: unstable) · Source
pub trait TryFrom<T>: Sized {
    type Error;

    // Required method
    fn try_from(value: T) -> Result<Self, Self::Error>;
}
Simple and safe type conversions that may fail in a controlled way under some circumstances. It is the reciprocal of TryInto.

This is useful when you are doing a type conversion that may trivially succeed but may also need special handling. For example, there is no way to convert an i64 into an i32 using the From trait, because an i64 may contain a value that an i32 cannot represent and so the conversion would lose data. This might be handled by truncating the i64 to an i32 or by simply returning i32::MAX, or by some other method. The From trait is intended for perfect conversions, so the TryFrom trait informs the programmer when a type conversion could go bad and lets them decide how to handle it.

Generic Implementations

  • TryFrom<T> for U implies TryInto<U> for T
  • try_from is reflexive, which means that TryFrom<T> for T is implemented and cannot fail – the associated Error type for calling T::try_from() on a value of type T is Infallible. When the ! type is stabilized Infallible and ! will be equivalent.

Prefer using TryInto over TryFrom when specifying trait bounds on a generic function to ensure that types that only implement TryInto can be used as well.

TryFrom<T> can be implemented as follows:

struct GreaterThanZero(i32);

impl TryFrom<i32> for GreaterThanZero {
    type Error = &'static str;

    fn try_from(value: i32) -> Result<Self, Self::Error> {
        if value <= 0 {
            Err("GreaterThanZero only accepts values greater than zero!")
        } else {
            Ok(GreaterThanZero(value))
        }
    }
}

Examples

As described, i32 implements TryFrom<i64>:

let big_number = 1_000_000_000_000i64;
// Silently truncates `big_number`, requires detecting
// and handling the truncation after the fact.
let smaller_number = big_number as i32;
assert_eq!(smaller_number, -727379968);

// Returns an error because `big_number` is too big to
// fit in an `i32`.
let try_smaller_number = i32::try_from(big_number);
assert!(try_smaller_number.is_err());

// Returns `Ok(3)`.
let try_successful_smaller_number = i32::try_from(3);
assert!(try_successful_smaller_number.is_ok());

Required Associated Types

1.34.0 · Source

type Error

The type returned in the event of a conversion error.

Required Methods

1.34.0 · Source

fn try_from(value: T) -> Result<Self, Self::Error>

Performs the conversion.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl TryFrom<&DatexExpression> for StructuralTypeDefinition

Source

impl TryFrom<&DatexExpression> for ValueContainer

Source

impl TryFrom<&DatexExpression> for Type

Source

impl TryFrom<&PointerAddress> for CoreLibPointerId

Source

impl TryFrom<&PrivateKeyDer<'_>> for KeyPair

Source

impl TryFrom<&str> for InterfaceDirection

Source

impl TryFrom<&str> for DecimalTypeVariant

Source

impl TryFrom<&str> for IntegerTypeVariant

Source

impl TryFrom<&str> for PointerAddress

Source

type Error = &'static str

Source

impl TryFrom<&str> for IpAddr

Source

impl TryFrom<&str> for Endpoint

Source

impl TryFrom<&str> for Alphabet

Source

impl TryFrom<&str> for fancy_regex::Regex

Source

impl TryFrom<&str> for LogSpecification

Source

impl TryFrom<&str> for rcgen::string_types::BmpString

Source

impl TryFrom<&str> for rcgen::string_types::Ia5String

Source

impl TryFrom<&str> for rcgen::string_types::PrintableString

Source

impl TryFrom<&str> for rcgen::string_types::TeletexString

Source

impl TryFrom<&str> for rcgen::string_types::UniversalString

Source

impl TryFrom<&str> for regex::regex::bytes::Regex

Source

impl TryFrom<&str> for regex::regex::string::Regex

Source

impl TryFrom<&str> for Ipv4Addr

Source

impl TryFrom<&str> for Ipv6Addr

Source

impl TryFrom<&str> for Uuid

Source

impl TryFrom<&String> for LogSpecification

Source

impl TryFrom<&String> for PathAndQuery

Source

impl TryFrom<&SystemTime> for der::asn1::generalized_time::GeneralizedTime

Source

impl TryFrom<&SystemTime> for DateTime

Source

impl TryFrom<&DateTime> for der::asn1::utc_time::UtcTime

Source

impl TryFrom<&BigInt> for i8

Source

impl TryFrom<&BigInt> for i16

Source

impl TryFrom<&BigInt> for i32

Source

impl TryFrom<&BigInt> for i64

Source

impl TryFrom<&BigInt> for i128

Source

impl TryFrom<&BigInt> for isize

Source

impl TryFrom<&BigInt> for u8

Source

impl TryFrom<&BigInt> for u16

Source

impl TryFrom<&BigInt> for u32

Source

impl TryFrom<&BigInt> for u64

Source

impl TryFrom<&BigInt> for u128

Source

impl TryFrom<&BigInt> for usize

Source

impl TryFrom<&BigInt> for BigUint

Source

impl TryFrom<&BigUint> for i8

Source

impl TryFrom<&BigUint> for i16

Source

impl TryFrom<&BigUint> for i32

Source

impl TryFrom<&BigUint> for i64

Source

impl TryFrom<&BigUint> for i128

Source

impl TryFrom<&BigUint> for isize

Source

impl TryFrom<&BigUint> for u8

Source

impl TryFrom<&BigUint> for u16

Source

impl TryFrom<&BigUint> for u32

Source

impl TryFrom<&BigUint> for u64

Source

impl TryFrom<&BigUint> for u128

Source

impl TryFrom<&BigUint> for usize

Source

impl TryFrom<&PrivateKeyInfo<'_>> for SecretDocument

Source

impl TryFrom<&KeyPair> for CryptoPrivateKey

Source

impl TryFrom<&PrivatePkcs8KeyDer<'_>> for KeyPair

Source

impl TryFrom<&EcPrivateKey<'_>> for SecretDocument

Source

impl TryFrom<&[u8]> for SectionKind

Source

impl TryFrom<&[u8]> for ObjectIdentifier

Source

impl TryFrom<&[u8]> for CompressedEdwardsY

Source

impl TryFrom<&[u8]> for CompressedRistretto

Source

impl TryFrom<&[u8]> for Document

Source

impl TryFrom<&[u8]> for SecretDocument

Source

impl TryFrom<&[u8]> for ReasonPhrase

Source

type Error = InvalidReasonPhrase

Source

impl TryFrom<&[u8]> for Pem

Source

impl TryFrom<&[u8]> for KeyPair

Source

impl TryFrom<&[u8]> for ring::aead::Tag

Source

impl TryFrom<InstructionCode> for AssignmentOperator

Source

impl TryFrom<CoreValue> for Map

Source

impl TryFrom<CoreValue> for Endpoint

Source

impl TryFrom<CoreValue> for List

Source

impl TryFrom<BigDecimalType> for Decimal

Source

impl TryFrom<Error> for Format

Source

impl TryFrom<Error> for InvalidFormatDescription

Source

impl TryFrom<Error> for Parse

Source

impl TryFrom<Error> for ParseFromDescription

Source

impl TryFrom<Error> for TryFromParsed

Source

impl TryFrom<Error> for ComponentRange

Source

impl TryFrom<Error> for ConversionRange

Source

impl TryFrom<Error> for DifferentVariant

Source

impl TryFrom<Error> for InvalidVariant

Source

impl TryFrom<Format> for Error

Source

impl TryFrom<Format> for ComponentRange

Source

impl TryFrom<Parse> for ParseFromDescription

Source

impl TryFrom<Parse> for TryFromParsed

Source

impl TryFrom<TryFromParsed> for ComponentRange

Source

impl TryFrom<BorrowedFormatItem<'_>> for Component

Source

impl TryFrom<OwnedFormatItem> for Component

Source

impl TryFrom<OwnedFormatItem> for Vec<OwnedFormatItem>

Source

impl TryFrom<Message> for String

1.59.0 (const: unstable) · Source

impl TryFrom<char> for u8

Maps a char with code point in U+0000..=U+00FF to a byte in 0x00..=0xFF with same value, failing if the code point is greater than U+00FF.

See impl From<u8> for char for details on the encoding.

1.74.0 (const: unstable) · Source

impl TryFrom<char> for u16

Maps a char with code point in U+0000..=U+FFFF to a u16 in 0x0000..=0xFFFF with same value, failing if the code point is greater than U+FFFF.

This corresponds to the UCS-2 encoding, as specified in ISO/IEC 10646:2003.

Source

impl TryFrom<f32> for BigDecimal

Source

impl TryFrom<f32> for NotNan<f32>

Source

impl TryFrom<f64> for BigDecimal

Source

impl TryFrom<f64> for NotNan<f64>

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<i8> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<i8> for NonZero<i8>

Source

impl TryFrom<i8> for BigUint

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<i16> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<i16> for NonZero<i16>

Source

impl TryFrom<i16> for BigUint

Source

impl TryFrom<i32> for AioFsyncMode

Source

impl TryFrom<i32> for Signal

Source

impl TryFrom<i32> for SockType

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<i32> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<i32> for NonZero<i32>

Source

impl TryFrom<i32> for BigUint

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<i64> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<i64> for NonZero<i64>

Source

impl TryFrom<i64> for BigUint

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for i64

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<i128> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<i128> for NonZero<i128>

Source

impl TryFrom<i128> for BigUint

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for i64

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for i128

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for u128

1.34.0 (const: unstable) · Source

impl TryFrom<isize> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<isize> for NonZero<isize>

Source

impl TryFrom<isize> for BigUint

Source

impl TryFrom<u8> for InstructionCode

Source

impl TryFrom<u8> for TypeSpaceInstructionCode

Source

impl TryFrom<u8> for ReferenceMutability

Source

impl TryFrom<u8> for BigDecimalType

Source

impl TryFrom<u8> for DecimalTypeVariant

Source

impl TryFrom<u8> for IntegerTypeVariant

Source

impl TryFrom<u8> for Class

Source

impl TryFrom<u8> for chrono::month::Month

Source

impl TryFrom<u8> for Weekday

Any weekday can be represented as an integer from 0 to 6, which equals to Weekday::num_days_from_monday in this implementation. Do not heavily depend on this though; use explicit methods whenever possible.

Source

impl TryFrom<u8> for der::tag::Tag

Source

impl TryFrom<u8> for TrieType

Source

impl TryFrom<u8> for GeneralCategory

Source

impl TryFrom<u8> for Version

Source

impl TryFrom<u8> for CameraDirection

Source

impl TryFrom<u8> for VideoRotation

Source

impl TryFrom<u8> for RevocationReason

Source

impl TryFrom<u8> for sec1::point::Tag

Source

impl TryFrom<u8> for DataBits

Source

impl TryFrom<u8> for StopBits

Source

impl TryFrom<u8> for time::month::Month

1.34.0 (const: unstable) · Source

impl TryFrom<u8> for i8

1.46.0 (const: unstable) · Source

impl TryFrom<u8> for NonZero<u8>

Source

impl TryFrom<u8> for TagNumber

Source

impl TryFrom<u8> for RecoveryId

1.34.0 (const: unstable) · Source

impl TryFrom<u16> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<u16> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<u16> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<u16> for u8

1.46.0 (const: unstable) · Source

impl TryFrom<u16> for NonZero<u16>

Source

impl TryFrom<u16> for aho_corasick::util::primitives::PatternID

Source

impl TryFrom<u16> for aho_corasick::util::primitives::StateID

Source

impl TryFrom<u16> for StatusCode

Source

impl TryFrom<u16> for regex_automata::util::primitives::PatternID

Source

impl TryFrom<u16> for SmallIndex

Source

impl TryFrom<u16> for regex_automata::util::primitives::StateID

Source

impl TryFrom<u32> for InternalSlot

Source

impl TryFrom<u32> for BaudRate

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for char

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<u32> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<u32> for NonZero<u32>

Source

impl TryFrom<u32> for aho_corasick::util::primitives::PatternID

Source

impl TryFrom<u32> for aho_corasick::util::primitives::StateID

Source

impl TryFrom<u32> for Length

Source

impl TryFrom<u32> for PotentialCodePoint

Source

impl TryFrom<u32> for regex_automata::util::primitives::PatternID

Source

impl TryFrom<u32> for SmallIndex

Source

impl TryFrom<u32> for regex_automata::util::primitives::StateID

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for i64

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<u64> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<u64> for NonZero<u64>

Source

impl TryFrom<u64> for aho_corasick::util::primitives::PatternID

Source

impl TryFrom<u64> for aho_corasick::util::primitives::StateID

Source

impl TryFrom<u64> for regex_automata::util::primitives::PatternID

Source

impl TryFrom<u64> for SmallIndex

Source

impl TryFrom<u64> for regex_automata::util::primitives::StateID

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for i64

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for i128

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<u128> for usize

1.46.0 (const: unstable) · Source

impl TryFrom<u128> for NonZero<u128>

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for i8

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for i16

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for i32

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for i64

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for i128

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for isize

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for u8

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for u16

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for u32

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for u64

1.34.0 (const: unstable) · Source

impl TryFrom<usize> for u128

1.46.0 (const: unstable) · Source

impl TryFrom<usize> for NonZero<usize>

Source

impl TryFrom<usize> for Alignment

Source

impl TryFrom<usize> for aho_corasick::util::primitives::PatternID

Source

impl TryFrom<usize> for aho_corasick::util::primitives::StateID

Source

impl TryFrom<usize> for Length

Source

impl TryFrom<usize> for regex_automata::util::primitives::PatternID

Source

impl TryFrom<usize> for SmallIndex

Source

impl TryFrom<usize> for regex_automata::util::primitives::StateID

1.85.0 · Source

impl TryFrom<CString> for String

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i8>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i16>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i32>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i64>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<i64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<i128>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<i64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<i128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<u128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<isize>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u8>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u16>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u16>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u16>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u16>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u32>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<i64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u64>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<i64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<i128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<u128>> for NonZero<usize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<i8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<i16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<i32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<i64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<i128>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<isize>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<u8>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<u16>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<u32>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<u64>

1.49.0 (const: unstable) · Source

impl TryFrom<NonZero<usize>> for NonZero<u128>

Source

impl TryFrom<NonZero<usize>> for Alignment

Source

impl TryFrom<String> for PointerAddress

Source

type Error = &'static str

Source

impl TryFrom<String> for ServerName<'static>

Source

impl TryFrom<String> for Endpoint

Source

impl TryFrom<String> for der::asn1::ia5_string::allocation::Ia5String

Source

impl TryFrom<String> for der::asn1::printable_string::allocation::PrintableString

Source

impl TryFrom<String> for der::asn1::teletex_string::allocation::TeletexString

Source

impl TryFrom<String> for fancy_regex::Regex

Source

impl TryFrom<String> for HeaderName

Source

impl TryFrom<String> for HeaderValue

Source

impl TryFrom<String> for Authority

Source

impl TryFrom<String> for PathAndQuery

Source

impl TryFrom<String> for Uri

Source

impl TryFrom<String> for ReasonPhrase

Source

type Error = InvalidReasonPhrase

Source

impl TryFrom<String> for rcgen::string_types::BmpString

Source

impl TryFrom<String> for rcgen::string_types::Ia5String

Source

impl TryFrom<String> for rcgen::string_types::PrintableString

Source

impl TryFrom<String> for rcgen::string_types::TeletexString

Source

impl TryFrom<String> for rcgen::string_types::UniversalString

Source

impl TryFrom<String> for regex::regex::bytes::Regex

Source

impl TryFrom<String> for regex::regex::string::Regex

Source

impl TryFrom<String> for DnsName<'static>

Source

impl TryFrom<String> for SessionDescription

Source

impl TryFrom<String> for Uuid

Source

impl TryFrom<Vec<u8>> for PrivateKeyDer<'_>

Source

type Error = &'static str

1.87.0 · Source

impl TryFrom<Vec<u8>> for String

Source

impl TryFrom<Vec<u8>> for Document

Source

impl TryFrom<Vec<u8>> for SecretDocument

Source

impl TryFrom<Vec<u8>> for HeaderName

Source

impl TryFrom<Vec<u8>> for HeaderValue

Source

impl TryFrom<Vec<u8>> for Authority

Source

impl TryFrom<Vec<u8>> for PathAndQuery

Source

impl TryFrom<Vec<u8>> for Uri

Source

impl TryFrom<Vec<u8>> for ReasonPhrase

Source

type Error = InvalidReasonPhrase

Source

impl TryFrom<Vec<u8>> for KeyPair

Source

impl TryFrom<Vec<u8>> for Uuid

Source

impl TryFrom<Duration> for time::duration::Duration

Source

impl TryFrom<ByteString> for String

Source

impl TryFrom<Error> for Errno

Source

impl TryFrom<TcpListener> for TcpListener

Source

impl TryFrom<TcpStream> for TcpStream

Source

impl TryFrom<UdpSocket> for UdpSocket

Source

impl TryFrom<UnixDatagram> for UnixDatagram

Source

impl TryFrom<UnixListener> for UnixListener

Source

impl TryFrom<UnixStream> for UnixStream

Source

impl TryFrom<SystemTime> for der::asn1::generalized_time::GeneralizedTime

Source

impl TryFrom<SystemTime> for DateTime

Source

impl TryFrom<SystemTime> for Timestamp

Source

impl TryFrom<Integer<'_>> for i8

Source

impl TryFrom<Integer<'_>> for i16

Source

impl TryFrom<Integer<'_>> for i32

Source

impl TryFrom<Integer<'_>> for i64

Source

impl TryFrom<Integer<'_>> for i128

Source

impl TryFrom<Integer<'_>> for u8

Source

impl TryFrom<Integer<'_>> for u16

Source

impl TryFrom<Integer<'_>> for u32

Source

impl TryFrom<Integer<'_>> for u64

Source

impl TryFrom<Integer<'_>> for u128

Source

impl TryFrom<NullString> for String

Source

impl TryFrom<NullWideString> for String

Source

impl TryFrom<Bytes> for ReasonPhrase

Source

type Error = InvalidReasonPhrase

Source

impl TryFrom<Uint<crypto_bigint::::uint::U384::{constant#0}>> for Scalar

Source

impl TryFrom<AnyRef<'_>> for bool

Source

impl TryFrom<AnyRef<'_>> for i8

Source

impl TryFrom<AnyRef<'_>> for i16

Source

impl TryFrom<AnyRef<'_>> for i32

Source

impl TryFrom<AnyRef<'_>> for i64

Source

impl TryFrom<AnyRef<'_>> for i128

Source

impl TryFrom<AnyRef<'_>> for u8

Source

impl TryFrom<AnyRef<'_>> for u16

Source

impl TryFrom<AnyRef<'_>> for u32

Source

impl TryFrom<AnyRef<'_>> for u64

Source

impl TryFrom<AnyRef<'_>> for u128

Source

impl TryFrom<AnyRef<'_>> for ()

Source

impl TryFrom<AnyRef<'_>> for ObjectIdentifier

Source

impl TryFrom<DateTime> for der::asn1::utc_time::UtcTime

Source

impl TryFrom<IndefiniteLength> for Length

Source

impl TryFrom<Length> for usize

Source

impl TryFrom<Method> for MethodFilter

Source

type Error = NoMatchingMethodFilter

Source

impl TryFrom<Parts> for Uri

Source

impl TryFrom<Value> for CurrencyType

Source

impl TryFrom<Value> for NumberingSystem

Source

impl TryFrom<Value> for RegionOverride

Source

impl TryFrom<Value> for RegionalSubdivision

Source

impl TryFrom<Value> for TimeZoneShortId

Source

impl TryFrom<BigInt> for i8

Source

impl TryFrom<BigInt> for i16

Source

impl TryFrom<BigInt> for i32

Source

impl TryFrom<BigInt> for i64

Source

impl TryFrom<BigInt> for i128

Source

impl TryFrom<BigInt> for isize

Source

impl TryFrom<BigInt> for u8

Source

impl TryFrom<BigInt> for u16

Source

impl TryFrom<BigInt> for u32

Source

impl TryFrom<BigInt> for u64

Source

impl TryFrom<BigInt> for u128

Source

impl TryFrom<BigInt> for usize

Source

impl TryFrom<BigInt> for BigUint

Source

impl TryFrom<BigUint> for i8

Source

impl TryFrom<BigUint> for i16

Source

impl TryFrom<BigUint> for i32

Source

impl TryFrom<BigUint> for i64

Source

impl TryFrom<BigUint> for i128

Source

impl TryFrom<BigUint> for isize

Source

impl TryFrom<BigUint> for u8

Source

impl TryFrom<BigUint> for u16

Source

impl TryFrom<BigUint> for u32

Source

impl TryFrom<BigUint> for u64

Source

impl TryFrom<BigUint> for u128

Source

impl TryFrom<BigUint> for usize

Source

impl TryFrom<PrivateKeyInfo<'_>> for SecretDocument

Source

impl TryFrom<PotentialCodePoint> for char

Source

impl TryFrom<EcPrivateKey<'_>> for SecretDocument

Source

impl TryFrom<Duration> for datex_core::without_std::time::Duration

Source

impl TryFrom<Parsed> for Date

Source

impl TryFrom<Parsed> for OffsetDateTime

Source

impl TryFrom<Parsed> for PrimitiveDateTime

Source

impl TryFrom<Parsed> for Time

Source

impl TryFrom<Parsed> for UtcDateTime

Source

impl TryFrom<Parsed> for UtcOffset

Source

impl TryFrom<Uuid> for NonNilUuid

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::bit_string::allocating::BitString

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::generalized_time::GeneralizedTime

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::ia5_string::allocation::Ia5String

Source

impl<'__der> TryFrom<&'__der Any> for Int

Source

impl<'__der> TryFrom<&'__der Any> for Uint

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::null::Null

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::octet_string::allocating::OctetString

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::printable_string::allocation::PrintableString

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::teletex_string::allocation::TeletexString

Source

impl<'__der> TryFrom<&'__der Any> for der::asn1::utc_time::UtcTime

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::bit_string::allocating::BitString

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::generalized_time::GeneralizedTime

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::ia5_string::allocation::Ia5String

Source

impl<'__der> TryFrom<AnyRef<'__der>> for Int

Source

impl<'__der> TryFrom<AnyRef<'__der>> for Uint

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::null::Null

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::octet_string::allocating::OctetString

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::printable_string::allocation::PrintableString

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::teletex_string::allocation::TeletexString

Source

impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::utc_time::UtcTime

Source

impl<'__der, 'a> TryFrom<&'__der Any> for BitStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for Ia5StringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for IntRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for UintRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for OctetStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for PrintableStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for TeletexStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for Utf8StringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<&'__der Any> for VideotexStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for BitStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Ia5StringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for IntRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for UintRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for OctetStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for PrintableStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for TeletexStringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Utf8StringRef<'a>
where '__der: 'a,

Source

impl<'__der, 'a> TryFrom<AnyRef<'__der>> for VideotexStringRef<'a>
where '__der: 'a,

Source

impl<'a> TryFrom<&&'a [u8]> for BitStringRef<'a>

Hack for simplifying the custom derive use case.

Source

impl<'a> TryFrom<&'a str> for ServerName<'a>

Attempt to make a ServerName from a string by parsing as a DNS name or IP address.

Source

impl<'a> TryFrom<&'a str> for HeaderName

Source

impl<'a> TryFrom<&'a str> for HeaderValue

Source

impl<'a> TryFrom<&'a str> for Method

Source

impl<'a> TryFrom<&'a str> for StatusCode

Source

impl<'a> TryFrom<&'a str> for Authority

Source

impl<'a> TryFrom<&'a str> for PathAndQuery

Source

impl<'a> TryFrom<&'a str> for Scheme

Source

impl<'a> TryFrom<&'a str> for Uri

Source

impl<'a> TryFrom<&'a str> for DnsName<'a>

Source

impl<'a> TryFrom<&'a str> for Url

Source

impl<'a> TryFrom<&'a String> for HeaderName

Source

impl<'a> TryFrom<&'a String> for HeaderValue

Source

impl<'a> TryFrom<&'a String> for Uri

Source

impl<'a> TryFrom<&'a ByteString> for &'a str

Source

impl<'a> TryFrom<&'a ByteStr> for &'a str

Source

impl<'a> TryFrom<&'a ByteStr> for String

1.72.0 · Source

impl<'a> TryFrom<&'a OsStr> for &'a str

Source

impl<'a> TryFrom<&'a Uri> for Uri

Source

impl<'a> TryFrom<&'a CertificateDer<'a>> for EndEntityCert<'a>

Source

impl<'a> TryFrom<&'a CertificateDer<'a>> for ParsedCertificate<'a>

Source

impl<'a> TryFrom<&'a SubjectPublicKeyInfoDer<'a>> for RawPublicKeyEntity<'a>

Source

impl<'a> TryFrom<&'a [u8]> for PrivateKeyDer<'a>

Source

type Error = &'static str

Source

impl<'a> TryFrom<&'a [u8]> for ServerName<'a>

Source

impl<'a> TryFrom<&'a [u8]> for AnyRef<'a>

Source

impl<'a> TryFrom<&'a [u8]> for BitStringRef<'a>

Source

impl<'a> TryFrom<&'a [u8]> for HeaderName

Source

impl<'a> TryFrom<&'a [u8]> for HeaderValue

Source

impl<'a> TryFrom<&'a [u8]> for Method

Source

impl<'a> TryFrom<&'a [u8]> for StatusCode

Source

impl<'a> TryFrom<&'a [u8]> for Authority

Source

impl<'a> TryFrom<&'a [u8]> for PathAndQuery

Source

impl<'a> TryFrom<&'a [u8]> for Scheme

Source

impl<'a> TryFrom<&'a [u8]> for Uri

Source

impl<'a> TryFrom<&'a [u8]> for PrivateKeyInfo<'a>

Source

impl<'a> TryFrom<&'a [u8]> for DnsName<'a>

Source

impl<'a> TryFrom<&'a [u8]> for EcPrivateKey<'a>

Source

impl<'a> TryFrom<&'a mut ByteStr> for &'a mut str

Source

impl<'a> TryFrom<BorrowedFormatItem<'a>> for &[BorrowedFormatItem<'a>]

Source

impl<'a> TryFrom<Any<'a>> for &'a str

Source

impl<'a> TryFrom<Any<'a>> for &'a [u8]

Source

impl<'a> TryFrom<Any<'a>> for Real

Source

impl<'a> TryFrom<Any<'a>> for GeneralName<'a>

Source

impl<'a> TryFrom<Any<'a>> for bool

Source

impl<'a> TryFrom<Any<'a>> for f32

Source

impl<'a> TryFrom<Any<'a>> for f64

Source

impl<'a> TryFrom<Any<'a>> for i8

Source

impl<'a> TryFrom<Any<'a>> for i16

Source

impl<'a> TryFrom<Any<'a>> for i32

Source

impl<'a> TryFrom<Any<'a>> for i64

Source

impl<'a> TryFrom<Any<'a>> for i128

Source

impl<'a> TryFrom<Any<'a>> for u8

Source

impl<'a> TryFrom<Any<'a>> for u16

Source

impl<'a> TryFrom<Any<'a>> for u32

Source

impl<'a> TryFrom<Any<'a>> for u64

Source

impl<'a> TryFrom<Any<'a>> for u128

Source

impl<'a> TryFrom<Any<'a>> for ()

Source

impl<'a> TryFrom<Any<'a>> for String

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::bitstring::BitString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::boolean::Boolean

Source

impl<'a> TryFrom<Any<'a>> for EmbeddedPdv<'a>

Source

impl<'a> TryFrom<Any<'a>> for EndOfContent

Source

impl<'a> TryFrom<Any<'a>> for Enumerated

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime

Source

impl<'a> TryFrom<Any<'a>> for Integer<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::null::Null

Source

impl<'a> TryFrom<Any<'a>> for ObjectDescriptor<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>

Source

impl<'a> TryFrom<Any<'a>> for Oid<'a>

Source

impl<'a> TryFrom<Any<'a>> for Sequence<'a>

Source

impl<'a> TryFrom<Any<'a>> for Set<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::bmpstring::BmpString<'a>

Source

impl<'a> TryFrom<Any<'a>> for GeneralString<'a>

Source

impl<'a> TryFrom<Any<'a>> for GraphicString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::ia5string::Ia5String<'a>

Source

impl<'a> TryFrom<Any<'a>> for NumericString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>

Source

impl<'a> TryFrom<Any<'a>> for Utf8String<'a>

Source

impl<'a> TryFrom<Any<'a>> for VideotexString<'a>

Source

impl<'a> TryFrom<Any<'a>> for VisibleString<'a>

Source

impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::utctime::UtcTime

Source

impl<'a> TryFrom<Any<'a>> for BerObject<'a>

Source

impl<'a> TryFrom<Any<'a>> for RsaAesOaepParams<'a>

Source

impl<'a> TryFrom<Any<'a>> for RsaSsaPssParams<'a>

Source

impl<'a> TryFrom<AnyRef<'a>> for &'a str

Source

impl<'a> TryFrom<AnyRef<'a>> for String

Source

impl<'a> TryFrom<AnyRef<'a>> for SystemTime

Source

impl<'a> TryFrom<BitStringRef<'a>> for &'a [u8]

Source

impl<'a> TryFrom<Item<'a>> for BorrowedFormatItem<'a>

Source

type Error = Error

Source

impl<'a, 'b> TryFrom<&'a AttributeTypeAndValue<'b>> for &'a str

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for &'a str

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Real

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for bool

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for i8

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for i16

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for i32

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for i64

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for i128

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for u8

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for u16

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for u32

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for u64

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for u128

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for String

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::bitstring::BitString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::boolean::Boolean

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for EmbeddedPdv<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for EndOfContent

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Enumerated

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Integer<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::null::Null

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for ObjectDescriptor<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Oid<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Sequence<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Set<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for GeneralString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for GraphicString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::ia5string::Ia5String<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for NumericString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for Utf8String<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for VideotexString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for VisibleString<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::utctime::UtcTime

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for BerObject<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for RsaAesOaepParams<'a>

Source

impl<'a, 'b> TryFrom<&'b Any<'a>> for RsaSsaPssParams<'a>

Source

impl<'a, 'b> TryFrom<&'b AlgorithmIdentifier<'a>> for SignatureAlgorithm<'a>

Source

impl<'a, 'b, E, T, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
where T: TryFrom<Any<'a>, Error = E> + Tagged, E: From<Error>,

Source

type Error = E

Source

impl<'a, 'b, T, E, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
where T: FromBer<'a, E>, E: From<Error>,

Source

type Error = E

Source

impl<'a, 'k, Params, Key> TryFrom<&SubjectPublicKeyInfo<Params, Key>> for Document
where 'a: 'k, Key: 'k + Decode<'a> + Encode + FixedTag, Params: Choice<'a> + Encode, BitStringRef<'a>: From<&'k Key>,

Source

impl<'a, 'k, Params, Key> TryFrom<SubjectPublicKeyInfo<Params, Key>> for Document
where 'a: 'k, Key: 'k + Decode<'a> + Encode + FixedTag, Params: Choice<'a> + Encode, BitStringRef<'a>: From<&'k Key>,

Source

impl<'a, 'r> TryFrom<&'r Any<'a>> for asn1_rs::asn1_types::strings::bmpstring::BmpString<'a>

Source

impl<'a, K, V, S, T> TryFrom<&'a HashMap<K, V, S>> for HeaderMap<T>

Try to convert a HashMap into a HeaderMap.

Examples

use std::collections::HashMap;
use std::convert::TryInto;
use http::HeaderMap;

let mut map = HashMap::new();
map.insert("X-Custom-Header".to_string(), "my value".to_string());

let headers: HeaderMap = (&map).try_into().expect("valid headers");
assert_eq!(headers["X-Custom-Header"], "my value");
Source

impl<'a, Params> TryFrom<&'a [u8]> for spki::algorithm::AlgorithmIdentifier<Params>
where Params: Choice<'a> + Encode,

Source

impl<'a, Params, Key> TryFrom<&'a [u8]> for SubjectPublicKeyInfo<Params, Key>
where Params: Choice<'a> + Encode, Key: Decode<'a> + Encode + FixedTag,

Source

impl<'a, T> TryFrom<Any<'a>> for BTreeSet<T>
where T: FromBer<'a> + Ord,

Source

impl<'a, T> TryFrom<Any<'a>> for Vec<T>
where T: FromBer<'a>,

Source

impl<'a, T> TryFrom<Any<'a>> for HashSet<T>
where T: FromBer<'a> + Hash + Eq,

Source

impl<'a, T> TryFrom<Any<'a>> for SequenceOf<T>
where T: FromBer<'a>,

Source

impl<'a, T> TryFrom<Any<'a>> for asn1_rs::asn1_types::set::set_of::SetOf<T>
where T: FromBer<'a>,

Source

impl<'a, T> TryFrom<AnyRef<'a>> for ContextSpecific<T>
where T: Decode<'a>,

Source

impl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
where T: FromBer<'a, E>, E: From<Error>,

Source

type Error = E

Source

impl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
where T: TryFrom<Any<'a>, Error = E> + Tagged, E: From<Error>,

Source

type Error = E

1.34.0 (const: unstable) · Source

impl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]

Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if slice.len() == N.

let bytes: [u8; 3] = [1, 0, 2];

let bytes_head: &[u8; 2] = <&[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));

let bytes_tail: &[u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));
1.34.0 (const: unstable) · Source

impl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]

Tries to create a mutable array ref &mut [T; N] from a mutable slice ref &mut [T]. Succeeds if slice.len() == N.

let mut bytes: [u8; 3] = [1, 0, 2];

let bytes_head: &mut [u8; 2] = <&mut [u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));

let bytes_tail: &mut [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));
Source

impl<'ber, 'a> TryFrom<Any<'ber>> for PolicyMapping<'a>
where 'ber: 'a,

Source

impl<'ber, 'a> TryFrom<Any<'ber>> for EcdsaSigValue<'a>
where 'ber: 'a,

Source

impl<'ber, 'a> TryFrom<Any<'ber>> for x509_parser::x509::AlgorithmIdentifier<'a>
where 'ber: 'a,

Source

impl<'ns> TryFrom<ResolveResult<'ns>> for Option<Namespace<'ns>>

Source

impl<C> TryFrom<&GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>

Source

impl<C> TryFrom<&AffinePoint<C>> for PublicKey<C>

Source

impl<C> TryFrom<&ProjectivePoint<C>> for PublicKey<C>

Source

impl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>

Source

impl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>

Source

impl<C> TryFrom<&SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>

Source

impl<C> TryFrom<&[u8]> for ecdsa::der::Signature<C>

Source

impl<C> TryFrom<&[u8]> for SigningKey<C>

Source

impl<C> TryFrom<&[u8]> for ecdsa::Signature<C>

Source

impl<C> TryFrom<&[u8]> for SignatureWithOid<C>

NOTE: this implementation assumes the default digest for the given elliptic curve as defined by hazmat::DigestPrimitive.

When working with alternative digests, you will need to use e.g. SignatureWithOid::new_with_digest.

Source

impl<C> TryFrom<&[u8]> for VerifyingKey<C>

Source

impl<C> TryFrom<&[u8]> for NonZeroScalar<C>
where C: CurveArithmetic,

Source

impl<C> TryFrom<Signature<C>> for ecdsa::Signature<C>

Source

impl<C> TryFrom<GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>

Source

impl<C> TryFrom<PrivateKeyInfo<'_>> for SigningKey<C>

Source

impl<C> TryFrom<PrivateKeyInfo<'_>> for SecretKey<C>

Source

impl<C> TryFrom<AffinePoint<C>> for PublicKey<C>

Source

impl<C> TryFrom<ProjectivePoint<C>> for PublicKey<C>

Source

impl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>

Source

impl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>

Source

impl<C> TryFrom<EcPrivateKey<'_>> for SecretKey<C>

Source

impl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for VerifyingKey<C>

Source

impl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>

Source

impl<O> TryFrom<i32> for I16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<i64> for I16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<i64> for I32<O>
where O: ByteOrder,

Source

impl<O> TryFrom<i128> for I16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<i128> for I32<O>
where O: ByteOrder,

Source

impl<O> TryFrom<i128> for I64<O>
where O: ByteOrder,

Source

impl<O> TryFrom<isize> for I16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u32> for U16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u64> for U16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u64> for U32<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u128> for U16<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u128> for U32<O>
where O: ByteOrder,

Source

impl<O> TryFrom<u128> for U64<O>
where O: ByteOrder,

Source

impl<O> TryFrom<usize> for U16<O>
where O: ByteOrder,

Source

impl<O, P> TryFrom<I32<P>> for I16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<I64<P>> for I16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<I64<P>> for I32<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<I128<P>> for I16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<I128<P>> for I32<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<I128<P>> for I64<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<Isize<P>> for I16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U32<P>> for U16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U64<P>> for U16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U64<P>> for U32<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U128<P>> for U16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U128<P>> for U32<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<U128<P>> for U64<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<O, P> TryFrom<Usize<P>> for U16<O>
where O: ByteOrder, P: ByteOrder,

Source

impl<Size> TryFrom<&[u8]> for EncodedPoint<Size>
where Size: ModulusSize,

Source

impl<T> TryFrom<Vec<T>> for SetOfVec<T>
where T: DerOrd,

Source

impl<T> TryFrom<Dh<T>> for PKey<T>

Source

impl<T> TryFrom<Dsa<T>> for PKey<T>

Source

impl<T> TryFrom<EcKey<T>> for PKey<T>

Source

impl<T> TryFrom<PKey<T>> for Dh<T>

Source

impl<T> TryFrom<PKey<T>> for Dsa<T>

Source

impl<T> TryFrom<PKey<T>> for EcKey<T>

Source

impl<T> TryFrom<PKey<T>> for Rsa<T>

Source

impl<T> TryFrom<Rsa<T>> for PKey<T>

1.48.0 · Source

impl<T, A, const N: usize> TryFrom<Vec<T, A>> for [T; N]
where A: Allocator,

Source

type Error = Vec<T, A>

1.43.0 · Source

impl<T, A, const N: usize> TryFrom<Rc<[T], A>> for Rc<[T; N], A>
where A: Allocator,

Source

type Error = Rc<[T], A>

1.43.0 · Source

impl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>
where A: Allocator,

Source

type Error = Arc<[T], A>

Source

impl<T, A, const N: usize> TryFrom<Box<[T], A>> for allocator_api2::stable::boxed::Box<[T; N], A>
where A: Allocator,

Source

type Error = Box<[T], A>

Source

impl<T, A, const N: usize> TryFrom<Vec<T, A>> for [T; N]
where A: Allocator,

Source

type Error = Vec<T, A>

1.34.0 (const: unstable) · Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

1.34.0 (const: unstable) · Source

impl<T, const N: usize> TryFrom<&[T]> for [T; N]
where T: Copy,

Tries to create an array [T; N] by copying from a slice &[T]. Succeeds if slice.len() == N.

let bytes: [u8; 3] = [1, 0, 2];

let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));

let bytes_tail: [u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));
Source

impl<T, const N: usize> TryFrom<&[T]> for Simd<T, N>

1.59.0 (const: unstable) · Source

impl<T, const N: usize> TryFrom<&mut [T]> for [T; N]
where T: Copy,

Tries to create an array [T; N] by copying from a mutable slice &mut [T]. Succeeds if slice.len() == N.

let mut bytes: [u8; 3] = [1, 0, 2];

let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));

let bytes_tail: [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));
Source

impl<T, const N: usize> TryFrom<&mut [T]> for Simd<T, N>

Source

impl<T, const N: usize> TryFrom<[T; N]> for der::asn1::set_of::SetOf<T, N>
where T: DerOrd,

Source

impl<T, const N: usize> TryFrom<[T; N]> for SetOfVec<T>
where T: DerOrd,

1.43.0 · Source

impl<T, const N: usize> TryFrom<Box<[T]>> for datex_core::without_std::prelude::Box<[T; N]>

1.66.0 · Source

impl<T, const N: usize> TryFrom<Vec<T>> for datex_core::without_std::prelude::Box<[T; N]>

Source

type Error = Vec<T>

Source

impl<T: Into<ValueContainer>> TryFrom<Option<T>> for TypedInteger

Source

impl<T: Into<ValueContainer>> TryFrom<Option<T>> for datex_core::values::core_values::boolean::Boolean

Source

impl<T: Into<ValueContainer>> TryFrom<Option<T>> for Endpoint

Source

impl<const MIN: i8, const MAX: i8> TryFrom<i8> for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> TryFrom<i16> for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> TryFrom<i32> for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> TryFrom<i64> for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> TryFrom<i128> for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> TryFrom<isize> for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> TryFrom<u8> for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> TryFrom<u16> for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> TryFrom<u32> for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> TryFrom<u64> for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> TryFrom<u128> for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> TryFrom<usize> for RangedUsize<MIN, MAX>

Source

impl<const N: usize> TryFrom<TinyAsciiStr<N>> for Subtag