Module ffi
Source - c_str
- va_listExperimental
- C’s “variable arguments”
- CStr
- Representation of a borrowed C string.
- CString
- A type representing an owned, C-compatible, nul-terminated string with no nul bytes in the
middle.
- FromBytesUntilNulError
- An error indicating that no nul byte was present.
- FromVecWithNulError
- An error indicating that a nul byte was not in the expected position.
- IntoStringError
- An error indicating invalid UTF-8 when converting a
CString into a String. - NulError
- An error indicating that an interior nul byte was found.
- VaListExperimental
- A wrapper for a
va_list - VaListImplExperimental
- x86_64 ABI implementation of a
va_list.
- FromBytesWithNulError
- An error indicating that a nul byte was not in the expected position.
- c_void
- Equivalent to C’s
void type when used as a pointer.
- VaArgSafeExperimental
- Types that are valid to read using
VaListImpl::arg.
- c_char
- Equivalent to C’s
char type. - c_double
- Equivalent to C’s
double type. - c_float
- Equivalent to C’s
float type. - c_int
- Equivalent to C’s
signed int (int) type. - c_long
- Equivalent to C’s
signed long (long) type. - c_longlong
- Equivalent to C’s
signed long long (long long) type. - c_schar
- Equivalent to C’s
signed char type. - c_short
- Equivalent to C’s
signed short (short) type. - c_uchar
- Equivalent to C’s
unsigned char type. - c_uint
- Equivalent to C’s
unsigned int type. - c_ulong
- Equivalent to C’s
unsigned long type. - c_ulonglong
- Equivalent to C’s
unsigned long long type. - c_ushort
- Equivalent to C’s
unsigned short type. - c_ptrdiff_tExperimental
- Equivalent to C’s
ptrdiff_t type, from stddef.h (or cstddef for C++). - c_size_tExperimental
- Equivalent to C’s
size_t type, from stddef.h (or cstddef for C++). - c_ssize_tExperimental
- Equivalent to C’s
ssize_t (on POSIX) or SSIZE_T (on Windows) type.