pub struct VaList<'a, 'f>where
'f: 'a,{ /* private fields */ }c_variadic)Expand description
A wrapper for a va_list
Methods from Deref<Target = VaListImpl<'f>>
Sourcepub fn as_va_list<'a>(&'a mut self) -> VaList<'a, 'f>
🔬This is a nightly-only experimental API. (c_variadic)
pub fn as_va_list<'a>(&'a mut self) -> VaList<'a, 'f>
c_variadic)Converts a VaListImpl into a VaList that is binary-compatible with C’s va_list.
Sourcepub unsafe fn arg<T>(&mut self) -> Twhere
T: VaArgSafe,
🔬This is a nightly-only experimental API. (c_variadic)
pub unsafe fn arg<T>(&mut self) -> Twhere
T: VaArgSafe,
c_variadic)Advance to and read the next variable argument.
Safety
This function is only sound to call when the next variable argument:
- has a type that is ABI-compatible with the type
T - has a value that is a properly initialized value of type
T
Calling this function with an incompatible type, an invalid value, or when there are no more variable arguments, is unsound.