BorrowedCursor

Struct BorrowedCursor 

pub struct BorrowedCursor<'a> { /* private fields */ }
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
A writeable view of the unfilled portion of a BorrowedBuf.

The unfilled portion consists of an initialized and an uninitialized part; see BorrowedBuf for details.

Data can be written directly to the cursor by using append or indirectly by getting a slice of part or all of the cursor and writing into the slice. In the indirect case, the caller must call advance after writing to inform the cursor how many bytes have been written.

Once data is written to the cursor, it becomes part of the filled portion of the underlying BorrowedBuf and can no longer be accessed or re-written by the cursor. I.e., the cursor tracks the unfilled part of the underlying BorrowedBuf.

The lifetime 'a is a bound on the lifetime of the underlying buffer (which means it is a bound on the data in that buffer by transitivity).

Implementations

Source

impl<'a> BorrowedCursor<'a>

pub fn reborrow<'this>(&'this mut self) -> BorrowedCursor<'this>

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Reborrows this cursor by cloning it with a smaller lifetime.

Since a cursor maintains unique access to its underlying buffer, the borrowed cursor is not accessible while the new cursor exists.

pub fn capacity(&self) -> usize

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Returns the available space in the cursor.

pub fn written(&self) -> usize

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Returns the number of bytes written to the BorrowedBuf this cursor was created from.

In particular, the count returned is shared by all reborrows of the cursor.

pub fn init_mut(&mut self) -> &mut [u8]

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Returns a mutable reference to the initialized portion of the cursor.

pub unsafe fn as_mut(&mut self) -> &mut [MaybeUninit<u8>]

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Returns a mutable reference to the whole cursor.

Safety

The caller must not uninitialize any bytes in the initialized portion of the cursor.

pub fn advance(&mut self, n: usize) -> &mut BorrowedCursor<'a>

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Advances the cursor by asserting that n bytes have been filled.

After advancing, the n bytes are no longer accessible via the cursor and can only be accessed via the underlying buffer. I.e., the buffer’s filled portion grows by n elements and its unfilled portion (and the capacity of this cursor) shrinks by n elements.

If less than n bytes initialized (by the cursor’s point of view), set_init should be called first.

Panics

Panics if there are less than n bytes initialized.

pub unsafe fn advance_unchecked(&mut self, n: usize) -> &mut BorrowedCursor<'a>

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Advances the cursor by asserting that n bytes have been filled.

After advancing, the n bytes are no longer accessible via the cursor and can only be accessed via the underlying buffer. I.e., the buffer’s filled portion grows by n elements and its unfilled portion (and the capacity of this cursor) shrinks by n elements.

Safety

The caller must ensure that the first n bytes of the cursor have been properly initialised.

pub fn ensure_init(&mut self) -> &mut BorrowedCursor<'a>

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Initializes all bytes in the cursor.

pub unsafe fn set_init(&mut self, n: usize) -> &mut BorrowedCursor<'a>

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Asserts that the first n unfilled bytes of the cursor are initialized.

BorrowedBuf assumes that bytes are never de-initialized, so this method does nothing when called with fewer bytes than are already known to be initialized.

Safety

The caller must ensure that the first n bytes of the buffer have already been initialized.

pub fn append(&mut self, buf: &[u8])

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Appends data to the cursor, advancing position within its buffer.

Panics

Panics if self.capacity() is less than buf.len().

pub fn with_unfilled_buf<T>( &mut self, f: impl FnOnce(&mut BorrowedBuf<'_>) -> T, ) -> T

🔬This is a nightly-only experimental API. (core_io_borrowed_buf)

Runs the given closure with a BorrowedBuf containing the unfilled part of the cursor.

This enables inspecting what was written to the cursor.

Panics

Panics if the BorrowedBuf given to the closure is replaced by another one.