Extend

Trait Extend 

1.0.0 · Source
pub trait Extend<A> {
    // Required method
    fn extend<T>(&mut self, iter: T)
       where T: IntoIterator<Item = A>;

    // Provided methods
    fn extend_one(&mut self, item: A) { ... }
    fn extend_reserve(&mut self, additional: usize) { ... }
}
Extend a collection with the contents of an iterator.

Iterators produce a series of values, and collections can also be thought of as a series of values. The Extend trait bridges this gap, allowing you to extend a collection by including the contents of that iterator. When extending a collection with an already existing key, that entry is updated or, in the case of collections that permit multiple entries with equal keys, that entry is inserted.

Examples

Basic usage:

// You can extend a String with some chars:
let mut message = String::from("The first three letters are: ");

message.extend(&['a', 'b', 'c']);

assert_eq!("abc", &message[29..32]);

Implementing Extend:

// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);

// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
    fn new() -> MyCollection {
        MyCollection(Vec::new())
    }

    fn add(&mut self, elem: i32) {
        self.0.push(elem);
    }
}

// since MyCollection has a list of i32s, we implement Extend for i32
impl Extend<i32> for MyCollection {

    // This is a bit simpler with the concrete type signature: we can call
    // extend on anything which can be turned into an Iterator which gives
    // us i32s. Because we need i32s to put into MyCollection.
    fn extend<T: IntoIterator<Item=i32>>(&mut self, iter: T) {

        // The implementation is very straightforward: loop through the
        // iterator, and add() each element to ourselves.
        for elem in iter {
            self.add(elem);
        }
    }
}

let mut c = MyCollection::new();

c.add(5);
c.add(6);
c.add(7);

// let's extend our collection with three more numbers
c.extend(vec![1, 2, 3]);

// we've added these elements onto the end
assert_eq!("MyCollection([5, 6, 7, 1, 2, 3])", format!("{c:?}"));

Required Methods

1.0.0 · Source

fn extend<T>(&mut self, iter: T)
where T: IntoIterator<Item = A>,

Extends a collection with the contents of an iterator.

As this is the only required method for this trait, the trait-level docs contain more details.

Examples
// You can extend a String with some chars:
let mut message = String::from("abc");

message.extend(['d', 'e', 'f'].iter());

assert_eq!("abcdef", &message);

Provided Methods

fn extend_one(&mut self, item: A)

🔬This is a nightly-only experimental API. (extend_one)

Extends a collection with exactly one element.

fn extend_reserve(&mut self, additional: usize)

🔬This is a nightly-only experimental API. (extend_one)

Reserves capacity in a collection for the given number of additional elements.

The default implementation does nothing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Extend<(String, Value)> for Dictionary

Source

impl Extend<(String, Value)> for Map<String, Value>

Source

impl Extend<AsciiChar> for String

Source

impl Extend<Signal> for SigSet

1.0.0 · Source

impl Extend<char> for String

Source

impl Extend<u8> for BytesMut

1.28.0 · Source

impl Extend<()> for ()

1.4.0 · Source

impl Extend<String> for String

1.52.0 · Source

impl Extend<OsString> for OsString

Source

impl Extend<Bytes> for BytesMut

Source

impl Extend<AtFlags> for AtFlags

Source

impl Extend<FallocateFlags> for FallocateFlags

Source

impl Extend<FdFlag> for FdFlag

Source

impl Extend<OFlag> for OFlag

Source

impl Extend<RenameFlags> for RenameFlags

Source

impl Extend<SealFlag> for SealFlag

Source

impl Extend<SpliceFFlags> for SpliceFFlags

Source

impl Extend<DeleteModuleFlags> for DeleteModuleFlags

Source

impl Extend<ModuleInitFlags> for ModuleInitFlags

Source

impl Extend<MntFlags> for MntFlags

Source

impl Extend<MsFlags> for nix::mount::linux::MsFlags

Source

impl Extend<MQ_OFlag> for MQ_OFlag

Source

impl Extend<InterfaceFlags> for InterfaceFlags

Source

impl Extend<PollFlags> for PollFlags

Source

impl Extend<CloneFlags> for CloneFlags

Source

impl Extend<EpollCreateFlags> for EpollCreateFlags

Source

impl Extend<EpollFlags> for EpollFlags

Source

impl Extend<EfdFlags> for EfdFlags

Source

impl Extend<AddWatchFlags> for AddWatchFlags

Source

impl Extend<InitFlags> for InitFlags

Source

impl Extend<MemFdCreateFlag> for MemFdCreateFlag

Source

impl Extend<MRemapFlags> for MRemapFlags

Source

impl Extend<MapFlags> for MapFlags

Source

impl Extend<MlockAllFlags> for MlockAllFlags

Source

impl Extend<MsFlags> for nix::sys::mman::MsFlags

Source

impl Extend<ProtFlags> for ProtFlags

Source

impl Extend<Persona> for Persona

Source

impl Extend<Options> for Options

Source

impl Extend<QuotaValidFlags> for QuotaValidFlags

Source

impl Extend<SaFlags> for SaFlags

Source

impl Extend<SfdFlags> for SfdFlags

Source

impl Extend<MsgFlags> for MsgFlags

Source

impl Extend<SockFlag> for SockFlag

Source

impl Extend<TimestampingFlag> for TimestampingFlag

Source

impl Extend<Mode> for Mode

Source

impl Extend<SFlag> for SFlag

Source

impl Extend<FsFlags> for FsFlags

Source

impl Extend<ControlFlags> for ControlFlags

Source

impl Extend<InputFlags> for InputFlags

Source

impl Extend<LocalFlags> for LocalFlags

Source

impl Extend<OutputFlags> for OutputFlags

Source

impl Extend<TimerSetTimeFlags> for TimerSetTimeFlags

Source

impl Extend<TimerFlags> for TimerFlags

Source

impl Extend<WaitPidFlag> for WaitPidFlag

Source

impl Extend<AccessFlags> for AccessFlags

Source

impl Extend<CipherCtxFlags> for CipherCtxFlags

Source

impl Extend<CMSOptions> for CMSOptions

Source

impl Extend<OcspFlag> for OcspFlag

Source

impl Extend<Pkcs7Flags> for Pkcs7Flags

Source

impl Extend<ExtensionContext> for ExtensionContext

Source

impl Extend<ShutdownState> for ShutdownState

Source

impl Extend<SslMode> for SslMode

Source

impl Extend<SslOptions> for SslOptions

Source

impl Extend<SslSessionCacheMode> for SslSessionCacheMode

Source

impl Extend<SslVerifyMode> for SslVerifyMode

Source

impl Extend<X509CheckFlags> for X509CheckFlags

Source

impl Extend<X509VerifyFlags> for X509VerifyFlags

Source

impl Extend<TrustAnchor<'static>> for RootCertStore

Source

impl Extend<FontStyle> for FontStyle

Source

impl<'a> Extend<&'a AsciiChar> for String

1.2.0 · Source

impl<'a> Extend<&'a char> for String

1.0.0 · Source

impl<'a> Extend<&'a str> for String

Source

impl<'a> Extend<&'a u8> for BytesMut

Source

impl<'a> Extend<&'a u8> for PrefixedPayload

1.52.0 · Source

impl<'a> Extend<&'a OsStr> for OsString

1.19.0 · Source

impl<'a> Extend<Cow<'a, str>> for String

1.52.0 · Source

impl<'a> Extend<Cow<'a, OsStr>> for OsString

1.2.0 · Source

impl<'a, K, V, A> Extend<(&'a K, &'a V)> for BTreeMap<K, V, A>
where K: Ord + Copy, V: Copy, A: Allocator + Clone,

1.4.0 · Source

impl<'a, K, V, S> Extend<(&'a K, &'a V)> for std::collections::hash::map::HashMap<K, V, S>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a K, &'a V)> for IndexMap<K, V, S>
where K: Hash + Eq + Copy, V: Copy, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a K, &'a V)> for LinkedHashMap<K, V, S>
where K: 'a + Hash + Eq + Copy, V: 'a + Copy, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a K, &'a V)> for RingMap<K, V, S>
where K: Hash + Eq + Copy, V: Copy, S: BuildHasher,

Source

impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for BTreeSet<T, A>
where T: 'a + Ord + Copy, A: Allocator + Clone,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for BinaryHeap<T, A>
where T: 'a + Ord + Copy, A: Allocator,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for LinkedList<T, A>
where T: 'a + Copy, A: Allocator,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for VecDeque<T, A>
where T: 'a + Copy, A: Allocator,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for datex_core::without_std::prelude::Vec<T, A>
where T: Copy + 'a, A: Allocator,

Extend implementation that copies elements out of references before pushing them onto the Vec.

This implementation is specialized for slice iterators, where it uses copy_from_slice to append the entire slice at once.

Source

impl<'a, T, A> Extend<&'a T> for allocator_api2::stable::vec::Vec<T, A>
where T: Copy + 'a, A: Allocator + 'a,

Extend implementation that copies elements out of references before pushing them onto the Vec.

This implementation is specialized for slice iterators, where it uses copy_from_slice to append the entire slice at once.

1.4.0 · Source

impl<'a, T, S> Extend<&'a T> for std::collections::hash::set::HashSet<T, S>
where T: 'a + Eq + Hash + Copy, S: BuildHasher,

Source

impl<'a, T, S> Extend<&'a T> for IndexSet<T, S>
where T: Hash + Eq + Copy + 'a, S: BuildHasher,

Source

impl<'a, T, S> Extend<&'a T> for RingSet<T, S>
where T: Hash + Eq + Copy + 'a, S: BuildHasher,

Source

impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
where T: 'a + Eq + Hash + Copy, S: BuildHasher, A: Allocator,

Source

impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
where T: 'a + Eq + Hash + Copy, S: BuildHasher, A: Allocator,

Source

impl<A> Extend<<A as Array>::Item> for SmallVec<A>
where A: Array,

1.45.0 · Source

impl<A> Extend<Box<str, A>> for String
where A: Allocator,

Source

impl<A> Extend<Box<str, A>> for String
where A: Allocator,

Source

impl<B> Extend<bool> for BitVec<B>
where B: BitBlock,

Source

impl<B> Extend<usize> for BitSet<B>
where B: BitBlock,

Source

impl<Fut> Extend<Fut> for FuturesOrdered<Fut>
where Fut: Future,

Source

impl<Fut> Extend<Fut> for FuturesUnordered<Fut>

Source

impl<K, V> Extend<(K, V)> for StreamMap<K, V>

1.0.0 · Source

impl<K, V, A> Extend<(K, V)> for BTreeMap<K, V, A>
where K: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<K, V, S> Extend<(K, V)> for std::collections::hash::map::HashMap<K, V, S>
where K: Eq + Hash, S: BuildHasher,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<K, V, S> Extend<(K, V)> for IndexMap<K, V, S>
where K: Hash + Eq, S: BuildHasher,

Source

impl<K, V, S> Extend<(K, V)> for LinkedHashMap<K, V, S>
where K: Hash + Eq, S: BuildHasher,

Source

impl<K, V, S> Extend<(K, V)> for LiteMap<K, V, S>
where K: Ord, S: StoreBulkMut<K, V>,

Source

impl<K, V, S> Extend<(K, V)> for RingMap<K, V, S>
where K: Hash + Eq, S: BuildHasher,

Source

impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<L, R, A> Extend<A> for Either<L, R>
where L: Extend<A>, R: Extend<A>,

1.0.0 · Source

impl<P> Extend<P> for PathBuf
where P: AsRef<Path>,

Source

impl<St> Extend<St> for SelectAll<St>
where St: Stream + Unpin,

Source

impl<T> Extend<(Option<HeaderName>, T)> for HeaderMap<T>

Source

impl<T> Extend<(HeaderName, T)> for HeaderMap<T>

1.0.0 · Source

impl<T, A> Extend<T> for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Extend<T> for BinaryHeap<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Extend<T> for LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> Extend<T> for VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> Extend<T> for datex_core::without_std::prelude::Vec<T, A>
where A: Allocator,

Source

impl<T, A> Extend<T> for allocator_api2::stable::vec::Vec<T, A>
where A: Allocator,

1.56.0 · Source

impl<T, ExtendT> Extend<(T₁, T₂, …, Tₙ)> for (ExtendT₁, ExtendT₂, …, ExtendTₙ)
where ExtendT: Extend<T>,

This trait is implemented for tuples up to twelve items long. The impls for 1- and 3- through 12-ary tuples were stabilized after 2-tuples, in 1.85.0.

1.0.0 · Source

impl<T, S> Extend<T> for std::collections::hash::set::HashSet<T, S>
where T: Eq + Hash, S: BuildHasher,

Source

impl<T, S> Extend<T> for IndexSet<T, S>
where T: Hash + Eq, S: BuildHasher,

Source

impl<T, S> Extend<T> for RingSet<T, S>
where T: Hash + Eq, S: BuildHasher,

Source

impl<T, S, A> Extend<T> for hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> Extend<T> for hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,