Send

Trait Send 

1.0.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

1.26.0 · Source

impl !Send for Args

1.26.0 · Source

impl !Send for ArgsOs

1.0.0 · Source

impl Send for TypeId

Source

impl Send for datex_core::without_std::ffi::c_str::Bytes<'_>

1.10.0 · Source

impl Send for Location<'_>

1.6.0 · Source

impl Send for datex_core::without_std::string::Drain<'_>

1.36.0 · Source

impl Send for Waker

Source

impl Send for atomic_waker::AtomicWaker

Source

impl Send for bytes::bytes::Bytes

Source

impl Send for BytesMut

Source

impl Send for futures_core::task::__internal::atomic_waker::AtomicWaker

Source

impl Send for Dir

Source

impl Send for Asn1BitString

Source

impl Send for Asn1BitStringRef

Source

impl Send for Asn1Enumerated

Source

impl Send for Asn1EnumeratedRef

Source

impl Send for Asn1GeneralizedTime

Source

impl Send for Asn1GeneralizedTimeRef

Source

impl Send for Asn1Integer

Source

impl Send for Asn1IntegerRef

Source

impl Send for Asn1Object

Source

impl Send for Asn1ObjectRef

Source

impl Send for Asn1OctetString

Source

impl Send for Asn1OctetStringRef

Source

impl Send for Asn1String

Source

impl Send for Asn1StringRef

Source

impl Send for Asn1Time

Source

impl Send for Asn1TimeRef

Source

impl Send for BigNum

Source

impl Send for BigNumContext

Source

impl Send for BigNumContextRef

Source

impl Send for BigNumRef

Source

impl Send for openssl::cipher::Cipher

Source

impl Send for CipherRef

Source

impl Send for CipherCtx

Source

impl Send for CipherCtxRef

Source

impl Send for CmsContentInfo

Source

impl Send for CmsContentInfoRef

Source

impl Send for Conf

Source

impl Send for ConfRef

Source

impl Send for Deriver<'_>

Source

impl Send for DsaSig

Source

impl Send for DsaSigRef

Source

impl Send for EcGroup

Source

impl Send for EcGroupRef

Source

impl Send for EcPoint

Source

impl Send for EcPointRef

Source

impl Send for EcdsaSig

Source

impl Send for EcdsaSigRef

Source

impl Send for Decrypter<'_>

Source

impl Send for Encrypter<'_>

Source

impl Send for openssl::error::Error

Source

impl Send for Hasher

Source

impl Send for MessageDigest

Source

impl Send for LibCtx

Source

impl Send for LibCtxRef

Source

impl Send for Md

Source

impl Send for MdRef

Source

impl Send for MdCtx

Source

impl Send for MdCtxRef

Source

impl Send for OcspBasicResponse

Source

impl Send for OcspBasicResponseRef

Source

impl Send for OcspCertId

Source

impl Send for OcspCertIdRef

Source

impl Send for OcspOneReq

Source

impl Send for OcspOneReqRef

Source

impl Send for OcspRequest

Source

impl Send for OcspRequestRef

Source

impl Send for OcspResponse

Source

impl Send for OcspResponseRef

Source

impl Send for Pkcs7

Source

impl Send for Pkcs7Ref

Source

impl Send for Pkcs7Signed

Source

impl Send for Pkcs7SignedRef

Source

impl Send for Pkcs7SignerInfo

Source

impl Send for Pkcs7SignerInfoRef

Source

impl Send for Pkcs12

Source

impl Send for Pkcs12Ref

Source

impl Send for Provider

Source

impl Send for ProviderRef

Source

impl Send for Signer<'_>

Source

impl Send for Verifier<'_>

Source

impl Send for SrtpProtectionProfile

Source

impl Send for SrtpProtectionProfileRef

Source

impl Send for Ssl

Source

impl Send for SslContext

Source

impl Send for SslContextRef

Source

impl Send for SslMethod

Source

impl Send for SslRef

Source

impl Send for SslSession

Source

impl Send for SslSessionRef

Source

impl Send for OpensslString

Source

impl Send for OpensslStringRef

Source

impl Send for openssl::symm::Cipher

Source

impl Send for X509Store

Source

impl Send for X509StoreBuilder

Source

impl Send for X509StoreBuilderRef

Source

impl Send for X509StoreRef

Source

impl Send for AccessDescription

Source

impl Send for AccessDescriptionRef

Source

impl Send for DistPoint

Source

impl Send for DistPointName

Source

impl Send for DistPointNameRef

Source

impl Send for DistPointRef

Source

impl Send for GeneralName

Source

impl Send for GeneralNameRef

Source

impl Send for X509

Source

impl Send for X509Algorithm

Source

impl Send for X509AlgorithmRef

Source

impl Send for X509Crl

Source

impl Send for X509CrlRef

Source

impl Send for X509Extension

Source

impl Send for X509ExtensionRef

Source

impl Send for X509Name

Source

impl Send for X509NameEntry

Source

impl Send for X509NameEntryRef

Source

impl Send for X509NameRef

Source

impl Send for X509Object

Source

impl Send for X509ObjectRef

Source

impl Send for X509Ref

Source

impl Send for X509Req

Source

impl Send for X509ReqRef

Source

impl Send for X509Revoked

Source

impl Send for X509RevokedRef

Source

impl Send for X509StoreContext

Source

impl Send for X509StoreContextRef

Source

impl Send for X509VerifyParam

Source

impl Send for X509VerifyParamRef

Source

impl Send for AbortHandle

1.44.0 · Source

impl<'a> Send for IoSlice<'a>

1.44.0 · Source

impl<'a> Send for IoSliceMut<'a>

Source

impl<'a> Send for Notified<'a>

Source

impl<'a, K, V> Send for linked_hash_map::Drain<'a, K, V>
where K: Send, V: Send,

Source

impl<'a, K, V> Send for linked_hash_map::Iter<'a, K, V>
where K: Send, V: Send,

Source

impl<'a, K, V> Send for linked_hash_map::IterMut<'a, K, V>
where K: Send, V: Send,

Source

impl<'a, K, V, S> Send for Entries<'a, K, V, S>
where K: Send, V: Send, S: Send,

Source

impl<'a, R, T> Send for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Send + 'a + ?Sized, <R as RawMutex>::GuardMarker: Send,

Source

impl<'a, R, T> Send for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Sync + 'a + ?Sized, <R as RawRwLock>::GuardMarker: Send,

Source

impl<'a, R, T> Send for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Send + 'a + ?Sized, <R as RawRwLock>::GuardMarker: Send,

Source

impl<'a, T> Send for http::header::map::Drain<'a, T>
where T: Send,

Source

impl<'a, T> Send for http::header::map::Iter<'a, T>
where T: Sync,

Source

impl<'a, T> Send for http::header::map::IterMut<'a, T>
where T: Send,

Source

impl<'a, T> Send for ValueDrain<'a, T>
where T: Send,

Source

impl<'a, T> Send for ValueIterMut<'a, T>
where T: Send,

Source

impl<'a, T> Send for smallvec::Drain<'a, T>
where T: Send + Array,

Source

impl<'a, T> Send for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: Send + 'a + ?Sized,

Source

impl<'a, T> Send for ZeroVec<'a, T>
where T: AsULE, <T as AsULE>::ULE: Send + Sync,

Source

impl<A> Send for SmallVec<A>
where A: Array, <A as Array>::Item: Send,

Source

impl<C> Send for CartableOptionPointer<C>

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<Fut> Send for futures_util::stream::futures_unordered::iter::IntoIter<Fut>
where Fut: Send + Unpin,

Source

impl<Fut> Send for IterPinMut<'_, Fut>
where Fut: Send,

Source

impl<Fut> Send for IterPinRef<'_, Fut>
where Fut: Send,

Source

impl<Fut> Send for FuturesUnordered<Fut>
where Fut: Send,

Source

impl<K, V> Send for hashbrown::map::IterMut<'_, K, V>
where K: Send, V: Send,

Source

impl<K, V> Send for hashbrown::map::IterMut<'_, K, V>
where K: Send, V: Send,

Source

impl<K, V> Send for linked_hash_map::IntoIter<K, V>
where K: Send, V: Send,

Source

impl<K, V, S> Send for LinkedHashMap<K, V, S>
where K: Send, V: Send, S: Send,

Source

impl<K, V, S, A> Send for hashbrown::map::OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

Source

impl<K, V, S, A> Send for hashbrown::map::OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

Source

impl<K, V, S, A> Send for RawOccupiedEntryMut<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

Source

impl<R, G> Send for RawReentrantMutex<R, G>
where R: RawMutex + Send, G: GetThreadId + Send,

Source

impl<R, G, T> Send for ReentrantMutex<R, G, T>
where R: RawMutex + Send, G: GetThreadId + Send, T: Send + ?Sized,

Source

impl<R, T> Send for lock_api::mutex::Mutex<R, T>
where R: RawMutex + Send, T: Send + ?Sized,

Source

impl<R, T> Send for lock_api::rwlock::RwLock<R, T>
where R: RawRwLock + Send, T: Send + ?Sized,

Source

impl<S> Send for AllowStd<S>
where S: Send,

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

Source

impl<T> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for ReentrantLockGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for datex_core::without_std::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for datex_core::without_std::collections::linked_list::IterMut<'_, T>
where T: Send,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for datex_core::without_std::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for datex_core::without_std::slice::IterMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for AtomicPtr<T>

Source

impl<T> Send for std::sync::mpmc::Receiver<T>
where T: Send,

Source

impl<T> Send for std::sync::mpmc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Receiver<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for SyncSender<T>
where T: Send,

Source

impl<T> Send for std::sync::nonpoison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

Source

impl<T> Send for std::sync::nonpoison::rwlock::RwLock<T>
where T: Send + ?Sized,

1.70.0 · Source

impl<T> Send for OnceLock<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::poison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.0.0 · Source

impl<T> Send for std::sync::poison::rwlock::RwLock<T>
where T: Send + ?Sized,

Source

impl<T> Send for ReentrantLock<T>
where T: Send + ?Sized,

1.29.0 · Source

impl<T> Send for std::thread::JoinHandle<T>

Source

impl<T> Send for FutureObj<'_, T>

Source

impl<T> Send for futures_util::lock::mutex::Mutex<T>
where T: Send + ?Sized,

Source

impl<T> Send for futures_util::lock::mutex::MutexGuard<'_, T>
where T: Send + ?Sized,

Source

impl<T> Send for MutexLockFuture<'_, T>
where T: Send + ?Sized,

Source

impl<T> Send for OwnedMutexGuard<T>
where T: Send + ?Sized,

Source

impl<T> Send for OwnedMutexLockFuture<T>
where T: Send + ?Sized,

Source

impl<T> Send for IoVec<T>
where T: Send,

Source

impl<T> Send for Dh<T>

Source

impl<T> Send for DhRef<T>

Source

impl<T> Send for Dsa<T>

Source

impl<T> Send for DsaRef<T>

Source

impl<T> Send for EcKey<T>

Source

impl<T> Send for EcKeyRef<T>

Source

impl<T> Send for PKey<T>

Source

impl<T> Send for PKeyRef<T>

Source

impl<T> Send for PkeyCtx<T>

Source

impl<T> Send for PkeyCtxRef<T>

Source

impl<T> Send for Rsa<T>

Source

impl<T> Send for RsaRef<T>

Source

impl<T> Send for Stack<T>
where T: Stackable + Send,

Source

impl<T> Send for StackRef<T>
where T: Stackable + Send,

Source

impl<T> Send for X509Lookup<T>

Source

impl<T> Send for X509LookupMethod<T>

Source

impl<T> Send for X509LookupMethodRef<T>

Source

impl<T> Send for X509LookupRef<T>

Source

impl<T> Send for tokio_stream::empty::Empty<T>

Source

impl<T> Send for tokio_stream::pending::Pending<T>

Source

impl<T> Send for ReadHalf<T>
where T: Send,

Source

impl<T> Send for WriteHalf<T>
where T: Send,

Source

impl<T> Send for tokio::runtime::task::join::JoinHandle<T>
where T: Send,

Source

impl<T> Send for tokio::sync::mutex::Mutex<T>
where T: Send + ?Sized,

Source

impl<T> Send for tokio::sync::once_cell::OnceCell<T>
where T: Send,

Source

impl<T> Send for OwnedRwLockWriteGuard<T>
where T: Send + Sync + ?Sized,

Source

impl<T> Send for tokio::sync::rwlock::read_guard::RwLockReadGuard<'_, T>
where T: Sync + ?Sized,

Source

impl<T> Send for tokio::sync::rwlock::RwLock<T>
where T: Send + ?Sized,

Source

impl<T> Send for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'_, T>
where T: Send + Sync + ?Sized,

Source

impl<T> Send for RwLockMappedWriteGuard<'_, T>
where T: Send + Sync + ?Sized,

Source

impl<T> Send for SetOnce<T>
where T: Send,

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for datex_core::without_std::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Send for datex_core::without_std::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for datex_core::without_std::collections::linked_list::CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for datex_core::without_std::collections::vec_deque::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for datex_core::without_std::prelude::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for datex_core::without_std::prelude::vec::IntoIter<T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.4.0 · Source

impl<T, A> Send for datex_core::without_std::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

Source

impl<T, A> Send for allocator_api2::stable::boxed::Box<T, A>
where A: Allocator + Send, T: Send + ?Sized,

Source

impl<T, A> Send for allocator_api2::stable::vec::drain::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, A> Send for allocator_api2::stable::vec::into_iter::IntoIter<T, A>
where T: Send, A: Allocator + Send,

Source

impl<T, A> Send for hashbrown::table::OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, A> Send for hashbrown::table::OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,

Source

impl<T, N> Send for GenericArray<T, N>
where T: Send, N: ArrayLength<T>,

Source

impl<T, U> Send for futures_util::lock::mutex::MappedMutexGuard<'_, T, U>
where T: Send + ?Sized, U: Send + ?Sized,

Source

impl<T, U> Send for OwnedMappedMutexGuard<T, U>
where T: Send + ?Sized, U: Send + ?Sized,

Source

impl<T, U> Send for OwnedRwLockReadGuard<T, U>
where T: Send + Sync + ?Sized, U: Sync + ?Sized,

Source

impl<T, U> Send for OwnedRwLockMappedWriteGuard<T, U>
where T: Send + Sync + ?Sized, U: Send + Sync + ?Sized,

Source

impl<Tz> Send for Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Send,

Auto implementors



impl !Send for ApplyOperation



impl !Send for DatexExpression



impl !Send for StaticValueOrDXB



impl !Send for CompilerError



impl !Send for DIFApplyError



impl !Send for DIFUpdateError



impl !Send for AssignmentError



impl !Send for Reference



impl !Send for TypeError



impl !Send for ExecutionError



impl !Send for ExecutionStep



impl !Send for InterruptProvider



impl !Send for ExecutionContext



impl !Send for ScriptExecutionError



impl !Send for DeserializationError



impl !Send for SerializationError



impl !Send for CollectionTypeDefinition



impl !Send for TypeDefinition



impl !Send for StructuralTypeDefinition



impl !Send for TypeContainer



impl !Send for CoreValue



impl !Send for datex_core::values::core_values::map::Map



impl !Send for OwnedMapKey



impl !Send for ValueContainer



impl !Send for DatexParseResult



impl !Send for Statement



impl !Send for CompilationScope



impl !Send for PrecompilerData



impl !Send for BlockHandler



impl !Send for ComHub



impl !Send for BaseInterface



impl !Send for HTTPServerNativeInterface



impl !Send for TCPClientNativeInterface



impl !Send for WebRTCCommon



impl !Send for WebRTCNativeInterface



impl !Send for Observer



impl !Send for TypeReference



impl !Send for ValueReference



impl !Send for MemoryDump



impl !Send for RuntimeExecutionContext



impl !Send for LocalExecutionContext



impl !Send for RemoteExecutionContext



impl !Send for Memory



impl !Send for Runtime



impl !Send for RuntimeConfig



impl !Send for RuntimeConfigInterface



impl !Send for RuntimeInternal



impl !Send for DatexDeserializer



impl !Send for MapSerializer



impl !Send for SeqSerializer



impl !Send for StructSerializer



impl !Send for StructVariantSerializer



impl !Send for TupleSerializer



impl !Send for TupleStructSerializer



impl !Send for TupleVariantSerializer



impl !Send for List



impl !Send for IntoMapIterator



impl !Send for Type



impl !Send for Value



impl !Send for RawWaker



impl Send for AssignmentOperator



impl Send for ArithmeticOperator



impl Send for BinaryOperator



impl Send for BitwiseOperator



impl Send for LogicalOperator



impl Send for ComparisonOperator



impl Send for Slot



impl Send for TypeExpression



impl Send for VariableKind



impl Send for ErrorKind



impl Send for SpanOrToken



impl Send for Pattern



impl Send for Token



impl Send for ArithmeticUnaryOperator



impl Send for BitwiseUnaryOperator



impl Send for LogicalUnaryOperator



impl Send for ReferenceUnaryOperator



impl Send for UnaryOperator



impl Send for VariableModel



impl Send for VariableRepresentation



impl Send for CryptoError



impl Send for Formatting



impl Send for ScopeType



impl Send for DIFCreatePointerError



impl Send for DIFObserveError



impl Send for DIFResolveReferenceError



impl Send for DIFTypeRepresentation



impl Send for DIFValueRepresentation



impl Send for DIFTypeContainer



impl Send for DIFTypeDefinition



impl Send for DIFProperty



impl Send for DIFUpdateData



impl Send for DIFValueContainer



impl Send for HeaderParsingError



impl Send for IncomingSection



impl Send for InstructionCode



impl Send for BlockType



impl Send for UserAgent



impl Send for Instruction



impl Send for TypeInstruction



impl Send for EncryptionType



impl Send for ReceiverType



impl Send for Receivers



impl Send for SignatureType



impl Send for InternalSlot



impl Send for TypeSpaceInstructionCode



impl Send for CoreLibPointerId



impl Send for ComHubError



impl Send for InterfacePriority



impl Send for Response



impl Send for ResponseError



impl Send for ResponseResolutionStrategy



impl Send for ResponseTimeout



impl Send for SocketEndpointRegistrationError



impl Send for NetworkTraceHopDirection



impl Send for ComInterfaceError



impl Send for ComInterfaceState



impl Send for InterfaceDirection



impl Send for ReconnectionConfig



impl Send for SocketState



impl Send for BaseInterfaceError



impl Send for HTTPError



impl Send for SerialError



impl Send for TCPError



impl Send for MediaKind



impl Send for MediaTrackCodec



impl Send for RTCSdpTypeDX



impl Send for WebRTCError



impl Send for URLError



impl Send for WebSocketError



impl Send for WebSocketServerError



impl Send for ObserverError



impl Send for AccessError



impl Send for ReferenceCreationError



impl Send for ReferenceMutability



impl Send for InvalidProgramError



impl Send for IllegalTypeError



impl Send for Color



impl Send for BigDecimalType



impl Send for datex_core::values::core_values::decimal::Decimal



impl Send for DecimalTypeVariant



impl Send for TypedDecimal



impl Send for EndpointInstance



impl Send for EndpointType



impl Send for InvalidEndpointError



impl Send for NumberParseError



impl Send for IntegerTypeVariant



impl Send for TypedInteger



impl Send for MapAccessError



impl Send for datex_core::values::pointer::PointerAddress



impl Send for ValueError



impl Send for AsciiChar



impl Send for datex_core::without_std::cmp::Ordering



impl Send for TryReserveErrorKind



impl Send for Infallible



impl Send for FromBytesWithNulError



impl Send for c_void



impl Send for datex_core::without_std::fmt::Alignment



impl Send for DebugAsHex



impl Send for datex_core::without_std::fmt::Sign



impl Send for AtomicOrdering



impl Send for BasicBlock



impl Send for UnwindTerminateReason



impl Send for IpAddr



impl Send for Ipv6MulticastScope



impl Send for SocketAddr



impl Send for FpCategory



impl Send for IntErrorKind



impl Send for OneSidedRangeBound



impl Send for GetDisjointMutError



impl Send for SearchStep



impl Send for datex_core::without_std::sync::atomic::Ordering



impl Send for ParseError



impl Send for SrcId



impl Send for Loc



impl Send for VirtualSlot



impl Send for CompileMetadata



impl Send for Variable



impl Send for Crypto



impl Send for CryptoNative



impl Send for DecompileOptions



impl Send for DIFReference



impl Send for DIFStructuralTypeDefinition



impl Send for DIFType



impl Send for DIFUpdate



impl Send for DIFReferenceNotFoundError



impl Send for DIFValue



impl Send for BlockId



impl Send for DXBBlock



impl Send for IncomingEndpointContextId



impl Send for IncomingEndpointContextSectionId



impl Send for BlockHeader



impl Send for FlagsAndTimestamp



impl Send for EncryptedHeader



impl Send for datex_core::global::protocol_structures::encrypted_header::Flags



impl Send for ApplyData



impl Send for DecimalData



impl Send for ExecutionBlockData



impl Send for Float32Data



impl Send for Float64Data



impl Send for FloatAsInt16Data



impl Send for FloatAsInt32Data



impl Send for GetOrCreateRefData



impl Send for InstructionCloseAndStore



impl Send for Int8Data



impl Send for Int16Data



impl Send for Int32Data



impl Send for Int64Data



impl Send for Int128Data



impl Send for IntegerData



impl Send for RawFullPointerAddress



impl Send for RawInternalPointerAddress



impl Send for RawLocalPointerAddress



impl Send for ShortTextData



impl Send for ShortTextDataRaw



impl Send for SlotAddress



impl Send for TextData



impl Send for TextDataRaw



impl Send for UInt8Data



impl Send for UInt16Data



impl Send for UInt32Data



impl Send for UInt64Data



impl Send for UInt128Data



impl Send for datex_core::global::protocol_structures::routing_header::Flags



impl Send for Key512



impl Send for datex_core::global::protocol_structures::routing_header::PointerAddress



impl Send for ReceiverEndpoints



impl Send for ReceiverEndpointsWithKeys



impl Send for RoutingHeader



impl Send for BlockHistoryData



impl Send for ScopeContext



impl Send for ComHubOptions



impl Send for DynamicEndpointProperties



impl Send for ResponseOptions



impl Send for NetworkTraceHop



impl Send for NetworkTraceHopSocket



impl Send for NetworkTraceResult



impl Send for TraceOptions



impl Send for ComInterfaceInfo



impl Send for ComInterfaceSockets



impl Send for ComInterfaceUUID



impl Send for InterfaceProperties



impl Send for ComInterfaceSocket



impl Send for ComInterfaceSocketUUID



impl Send for BaseInterfaceSetupData



impl Send for LocalLoopbackInterface



impl Send for SerialInterfaceSetupData



impl Send for SerialNativeInterface



impl Send for TCPClientInterfaceSetupData



impl Send for TCPServerInterfaceSetupData



impl Send for TCPServerNativeInterface



impl Send for RTCIceCandidateInitDX



impl Send for RTCIceServer



impl Send for RTCSessionDescriptionDX



impl Send for WebRTCInterfaceSetupData



impl Send for WebSocketClientNativeInterface



impl Send for WebSocketClientInterfaceSetupData



impl Send for WebSocketServerInterfaceSetupData



impl Send for WebSocketServerNativeInterface



impl Send for ObserveOptions



impl Send for NominalTypeDeclaration



impl Send for ExecutionOptions



impl Send for GlobalContext



impl Send for DatexSerializer



impl Send for AnsiCodes



impl Send for Time



impl Send for TimeNative



impl Send for UUID



impl Send for Boolean



impl Send for Rational



impl Send for DecimalTypeVariantIter



impl Send for Endpoint



impl Send for EndpointParsingError



impl Send for Integer



impl Send for IntegerTypeVariantIter



impl Send for Text



impl Send for AllocError



impl Send for Global



impl Send for Layout



impl Send for LayoutError



impl Send for CpuidResult



impl Send for __m128



impl Send for __m128bh



impl Send for __m128d



impl Send for __m128h



impl Send for __m128i



impl Send for __m256



impl Send for __m256bh



impl Send for __m256d



impl Send for __m256h



impl Send for __m256i



impl Send for __m512



impl Send for __m512bh



impl Send for __m512d



impl Send for __m512h



impl Send for __m512i



impl Send for bf16



impl Send for TryFromSliceError



impl Send for datex_core::without_std::ascii::EscapeDefault



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for CharTryFromError



impl Send for DecodeUtf16Error



impl Send for datex_core::without_std::char::EscapeDebug



impl Send for datex_core::without_std::char::EscapeDefault



impl Send for datex_core::without_std::char::EscapeUnicode



impl Send for ParseCharError



impl Send for ToLowercase



impl Send for ToUppercase



impl Send for TryFromCharError



impl Send for UnorderedKeyError



impl Send for TryReserveError



impl Send for CStr



impl Send for CString



impl Send for FromBytesUntilNulError



impl Send for FromVecWithNulError



impl Send for IntoStringError



impl Send for NulError



impl Send for datex_core::without_std::fmt::Error



impl Send for FormattingOptions



impl Send for SipHasher



impl Send for ReturnToArg



impl Send for UnwindActionArg



impl Send for Assume



impl Send for AddrParseError



impl Send for Ipv4Addr



impl Send for Ipv6Addr



impl Send for SocketAddrV4



impl Send for SocketAddrV6



impl Send for ParseFloatError



impl Send for ParseIntError



impl Send for TryFromIntError



impl Send for RangeFull



impl Send for String



impl Send for datex_core::without_std::ptr::Alignment



impl Send for ParseBoolError



impl Send for Utf8Error



impl Send for FromUtf8Error



impl Send for FromUtf16Error



impl Send for IntoChars



impl Send for AtomicBool



impl Send for AtomicI8



impl Send for AtomicI16



impl Send for AtomicI32



impl Send for AtomicI64



impl Send for AtomicIsize



impl Send for AtomicU8



impl Send for AtomicU16



impl Send for AtomicU32



impl Send for AtomicU64



impl Send for AtomicUsize



impl Send for RawWakerVTable



impl Send for Duration



impl Send for TryFromFloatSecsError



impl Send for PhantomPinned



impl Send for Big8x3



impl Send for Big32x40



impl Send for CodePointInner



impl Send for Decimal



impl Send for DecimalSeq



impl Send for Decoded



impl Send for FullDecoded



impl Send for I32NotAllOnes



impl Send for I64NotAllOnes



impl Send for Nanoseconds



impl Send for NonZeroCharInner



impl Send for NonZeroI8Inner



impl Send for NonZeroI16Inner



impl Send for NonZeroI32Inner



impl Send for NonZeroI64Inner



impl Send for NonZeroI128Inner



impl Send for NonZeroIsizeInner



impl Send for NonZeroU8Inner



impl Send for NonZeroU16Inner



impl Send for NonZeroU32Inner



impl Send for NonZeroU64Inner



impl Send for NonZeroU128Inner



impl Send for NonZeroUsizeInner



impl Send for Sign



impl Send for U32NotAllOnes



impl Send for U64NotAllOnes



impl Send for UsizeNoHighBit



impl<'a> !Send for MapKey<'a>



impl<'a> !Send for MapMutIterator<'a>



impl<'a> !Send for CompilationContext<'a>



impl<'a> !Send for CompileOptions<'a>



impl<'a> !Send for ExecutionInput<'a>



impl<'a> !Send for MapIterator<'a>



impl<'a> !Send for Request<'a>



impl<'a> !Send for Source<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for PanicInfo<'a>



impl<'a> !Send for PanicMessage<'a>



impl<'a> !Send for Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'a> Send for BorrowedCursor<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for datex_core::without_std::str::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for datex_core::without_std::str::EscapeDebug<'a>



impl<'a> Send for datex_core::without_std::str::EscapeDefault<'a>



impl<'a> Send for datex_core::without_std::str::EscapeUnicode<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a> Send for Formatted<'a>



impl<'a> Send for Part<'a>



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'f> !Send for VaList<'a, 'f>



impl<'a, A> Send for datex_core::without_std::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Send for datex_core::without_std::option::IterMut<'a, A>
where A: Send,



impl<'a, B> Send for Cow<'a, B>
where <B as ToOwned>::Owned: Send, B: Sync + ?Sized,



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where F: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where I: Send,



impl<'a, I, A> Send for Splice<'a, I, A>
where I: Send, <I as Iterator>::Item: Send, A: Send,



impl<'a, K> Send for datex_core::without_std::collections::btree_set::Cursor<'a, K>
where K: Sync,



impl<'a, K, A> Send for datex_core::without_std::collections::btree_set::CursorMut<'a, K, A>
where A: Send, K: Send,



impl<'a, K, A> Send for datex_core::without_std::collections::btree_set::CursorMutKey<'a, K, A>
where A: Send, K: Send,



impl<'a, K, V> Send for datex_core::without_std::collections::btree_map::Cursor<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for datex_core::without_std::collections::btree_map::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for datex_core::without_std::collections::btree_map::IterMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for Keys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for datex_core::without_std::collections::btree_map::Range<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for RangeMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for Values<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for ValuesMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V, A> Send for datex_core::without_std::collections::btree_map::Entry<'a, K, V, A>
where K: Send, A: Send, V: Send,



impl<'a, K, V, A> Send for datex_core::without_std::collections::btree_map::CursorMut<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for datex_core::without_std::collections::btree_map::CursorMutKey<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for datex_core::without_std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for OccupiedError<'a, K, V, A>
where V: Send, A: Send, K: Send,



impl<'a, K, V, A> Send for datex_core::without_std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Send, A: Send, V: Send,



impl<'a, K, V, R, F, A> Send for datex_core::without_std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Send, A: Send, R: Send, K: Send, V: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for datex_core::without_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for datex_core::without_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for datex_core::without_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for datex_core::without_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for datex_core::without_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, T> Send for datex_core::without_std::collections::binary_heap::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for datex_core::without_std::collections::btree_set::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for datex_core::without_std::collections::btree_set::Range<'a, T>
where T: Sync,



impl<'a, T> Send for SymmetricDifference<'a, T>
where T: Sync,



impl<'a, T> Send for Union<'a, T>
where T: Sync,



impl<'a, T> Send for datex_core::without_std::collections::vec_deque::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for datex_core::without_std::collections::vec_deque::IterMut<'a, T>
where T: Send,



impl<'a, T> Send for datex_core::without_std::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for datex_core::without_std::result::IterMut<'a, T>
where T: Send,



impl<'a, T> Send for Chunks<'a, T>
where T: Sync,



impl<'a, T> Send for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for RChunks<'a, T>
where T: Sync,



impl<'a, T> Send for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for Windows<'a, T>
where T: Sync,



impl<'a, T, A> Send for datex_core::without_std::collections::btree_set::Entry<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for datex_core::without_std::collections::binary_heap::Drain<'a, T, A>
where T: Send, A: Send,



impl<'a, T, A> Send for DrainSorted<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for datex_core::without_std::collections::binary_heap::PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for Difference<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Send for Intersection<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Send for datex_core::without_std::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for datex_core::without_std::collections::btree_set::VacantEntry<'a, T, A>
where T: Send, A: Send,



impl<'a, T, A> Send for datex_core::without_std::prelude::vec::PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, F, A = Global> !Send for datex_core::without_std::collections::linked_list::ExtractIf<'a, T, F, A>



impl<'a, T, F, A> Send for datex_core::without_std::prelude::vec::ExtractIf<'a, T, F, A>
where F: Send, A: Send, T: Send,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for datex_core::without_std::slice::RSplit<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for datex_core::without_std::slice::RSplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for datex_core::without_std::slice::Split<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for datex_core::without_std::slice::SplitInclusive<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for datex_core::without_std::slice::SplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, R, F, A> Send for datex_core::without_std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Send, A: Send, R: Send, T: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>



impl<'b, T> !Send for Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<'data> Send for BorrowedBuf<'data>



impl<'f> !Send for VaListImpl<'f>



impl<A> Send for Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>
where A: Send,



impl<A> Send for datex_core::without_std::option::IntoIter<A>
where A: Send,



impl<A> Send for IterRange<A>
where A: Send,



impl<A> Send for IterRangeFrom<A>
where A: Send,



impl<A> Send for IterRangeInclusive<A>
where A: Send,



impl<A, B> Send for Chain<A, B>
where A: Send, B: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<F> Send for datex_core::without_std::fmt::FromFn<F>
where F: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for datex_core::without_std::iter::FromFn<F>
where F: Send,



impl<F> Send for OnceWith<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>



impl<I> Send for FromIter<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Send, I: Send,



impl<I> Send for Fuse<I>
where I: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, <I as Iterator>::Item: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for Take<I>
where I: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for datex_core::without_std::iter::Map<I, F>
where I: Send, F: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, I: Send, <I as Iterator>::Item: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, <I as Iterator>::Item: Send, I: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Send, I: Send, F: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, <I as Iterator>::Item: Send,



impl<Idx> Send for datex_core::without_std::ops::Range<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::ops::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::ops::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::ops::RangeToInclusive<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for datex_core::without_std::range::RangeToInclusive<Idx>
where Idx: Send,



impl<K, T> Send for FreeHashMap<K, T>
where K: Send, T: Send,



impl<K, V, A> Send for datex_core::without_std::collections::btree_map::IntoIter<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for IntoKeys<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for IntoValues<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for BTreeMap<K, V, A>
where A: Send, K: Send, V: Send,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<T> !Send for DataChannel<T>



impl<T> !Send for DataChannels<T>



impl<T> !Send for MediaTrack<T>



impl<T> !Send for MediaTracks<T>



impl<T> Send for DeserializeMapOrArray<T>
where T: Send,



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for TypedLiteral<T>
where T: Send,



impl<T> Send for datex_core::without_std::cell::OnceCell<T>
where T: Send,



impl<T> Send for SyncUnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for NumBuffer<T>
where T: Send,



impl<T> Send for datex_core::without_std::future::Pending<T>



impl<T> Send for Ready<T>
where T: Send,



impl<T> Send for datex_core::without_std::iter::Empty<T>



impl<T> Send for Once<T>
where T: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for Discriminant<T>



impl<T> Send for ManuallyDrop<T>
where T: Send + ?Sized,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for UnsafePinned<T>
where T: Send + ?Sized,



impl<T> Send for datex_core::without_std::result::IntoIter<T>
where T: Send,



impl<T> Send for Exclusive<T>
where T: Send + ?Sized,



impl<T> Send for PhantomContravariant<T>
where T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where T: ?Sized,



impl<T> Send for PhantomData<T>
where T: Send + ?Sized,



impl<T> Send for PhantomInvariant<T>
where T: ?Sized,



impl<T> Send for MaybeUninit<T>
where T: Send,



impl<T, A> Send for datex_core::without_std::collections::binary_heap::IntoIter<T, A>
where T: Send, A: Send,



impl<T, A> Send for IntoIterSorted<T, A>
where A: Send, T: Send,



impl<T, A> Send for datex_core::without_std::collections::btree_set::IntoIter<T, A>
where A: Send, T: Send,



impl<T, A> Send for datex_core::without_std::collections::linked_list::IntoIter<T, A>
where T: Send, A: Send,



impl<T, A> Send for BTreeSet<T, A>
where A: Send, T: Send,



impl<T, A> Send for BinaryHeap<T, A>
where A: Send, T: Send,



impl<T, A> Send for VecDeque<T, A>
where A: Send, T: Send,



impl<T, A> Send for datex_core::without_std::collections::vec_deque::IntoIter<T, A>
where A: Send, T: Send,



impl<T, A> Send for datex_core::without_std::prelude::Box<T, A>
where A: Send, T: Send + ?Sized,



impl<T, A> Send for Vec<T, A>
where A: Send, T: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for LazyCell<T, F>
where F: Send, T: Send,



impl<T, F> Send for Successors<T, F>
where F: Send, T: Send,



impl<T, F> Send for DropGuard<T, F>
where T: Send, F: Send,



impl<T, const N: usize> Send for datex_core::without_std::array::IntoIter<T, N>
where T: Send,



impl<T, const N: usize> Send for Mask<T, N>
where T: Send,



impl<T, const N: usize> Send for Simd<T, N>
where T: Send,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,



impl<const N: usize> Send for LaneCount<N>