IpAddr

Enum IpAddr 

1.77.0 · Source
pub enum IpAddr {
    V4(Ipv4Addr),
    V6(Ipv6Addr),
}
An IP address, either IPv4 or IPv6.

This enum can contain either an Ipv4Addr or an Ipv6Addr, see their respective documentation for more details.

Examples

use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

let localhost_v4 = IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1));
let localhost_v6 = IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1));

assert_eq!("127.0.0.1".parse(), Ok(localhost_v4));
assert_eq!("::1".parse(), Ok(localhost_v6));

assert_eq!(localhost_v4.is_ipv6(), false);
assert_eq!(localhost_v4.is_ipv4(), true);

Variants

1.77.0

V4(Ipv4Addr)

An IPv4 address.

1.77.0

V6(Ipv6Addr)

An IPv6 address.

Implementations

Source

impl IpAddr

1.12.0 (const: 1.50.0) · Source

pub const fn is_unspecified(&self) -> bool

Returns true for the special ‘unspecified’ address.

See the documentation for Ipv4Addr::is_unspecified() and Ipv6Addr::is_unspecified() for more details.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)).is_unspecified(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 0)).is_unspecified(), true);
1.12.0 (const: 1.50.0) · Source

pub const fn is_loopback(&self) -> bool

Returns true if this is a loopback address.

See the documentation for Ipv4Addr::is_loopback() and Ipv6Addr::is_loopback() for more details.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)).is_loopback(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 0x1)).is_loopback(), true);
pub const fn is_global(&self) -> bool

🔬This is a nightly-only experimental API. (ip)

Returns true if the address appears to be globally routable.

See the documentation for Ipv4Addr::is_global() and Ipv6Addr::is_global() for more details.

Examples
#![feature(ip)]

use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(80, 9, 12, 3)).is_global(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0, 0, 0x1c9, 0, 0, 0xafc8, 0, 0x1)).is_global(), true);
1.12.0 (const: 1.50.0) · Source

pub const fn is_multicast(&self) -> bool

Returns true if this is a multicast address.

See the documentation for Ipv4Addr::is_multicast() and Ipv6Addr::is_multicast() for more details.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(224, 254, 0, 0)).is_multicast(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0xff00, 0, 0, 0, 0, 0, 0, 0)).is_multicast(), true);
pub const fn is_documentation(&self) -> bool

🔬This is a nightly-only experimental API. (ip)

Returns true if this address is in a range designated for documentation.

See the documentation for Ipv4Addr::is_documentation() and Ipv6Addr::is_documentation() for more details.

Examples
#![feature(ip)]

use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(203, 0, 113, 6)).is_documentation(), true);
assert_eq!(
    IpAddr::V6(Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 0)).is_documentation(),
    true
);
pub const fn is_benchmarking(&self) -> bool

🔬This is a nightly-only experimental API. (ip)

Returns true if this address is in a range designated for benchmarking.

See the documentation for Ipv4Addr::is_benchmarking() and Ipv6Addr::is_benchmarking() for more details.

Examples
#![feature(ip)]

use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(198, 19, 255, 255)).is_benchmarking(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0x2001, 0x2, 0, 0, 0, 0, 0, 0)).is_benchmarking(), true);
1.16.0 (const: 1.50.0) · Source

pub const fn is_ipv4(&self) -> bool

Returns true if this address is an IPv4 address, and false otherwise.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(203, 0, 113, 6)).is_ipv4(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 0)).is_ipv4(), false);
1.16.0 (const: 1.50.0) · Source

pub const fn is_ipv6(&self) -> bool

Returns true if this address is an IPv6 address, and false otherwise.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

assert_eq!(IpAddr::V4(Ipv4Addr::new(203, 0, 113, 6)).is_ipv6(), false);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 0)).is_ipv6(), true);
1.75.0 (const: 1.75.0) · Source

pub const fn to_canonical(&self) -> IpAddr

Converts this address to an IpAddr::V4 if it is an IPv4-mapped IPv6 address, otherwise returns self as-is.

Examples
use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

let localhost_v4 = Ipv4Addr::new(127, 0, 0, 1);

assert_eq!(IpAddr::V4(localhost_v4).to_canonical(), localhost_v4);
assert_eq!(IpAddr::V6(localhost_v4.to_ipv6_mapped()).to_canonical(), localhost_v4);
assert_eq!(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)).to_canonical().is_loopback(), true);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0xffff, 0x7f00, 0x1)).is_loopback(), false);
assert_eq!(IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0xffff, 0x7f00, 0x1)).to_canonical().is_loopback(), true);
pub const fn as_octets(&self) -> &[u8]

🔬This is a nightly-only experimental API. (ip_as_octets)

Returns the eight-bit integers this address consists of as a slice.

Examples
#![feature(ip_as_octets)]

use std::net::{Ipv4Addr, Ipv6Addr, IpAddr};

assert_eq!(IpAddr::V4(Ipv4Addr::LOCALHOST).as_octets(), &[127, 0, 0, 1]);
assert_eq!(IpAddr::V6(Ipv6Addr::LOCALHOST).as_octets(),
           &[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1])
Source

impl IpAddr

pub fn parse_ascii(b: &[u8]) -> Result<IpAddr, AddrParseError>

🔬This is a nightly-only experimental API. (addr_parse_ascii)

Parse an IP address from a slice of bytes.

#![feature(addr_parse_ascii)]

use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

let localhost_v4 = IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1));
let localhost_v6 = IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 1));

assert_eq!(IpAddr::parse_ascii(b"127.0.0.1"), Ok(localhost_v4));
assert_eq!(IpAddr::parse_ascii(b"::1"), Ok(localhost_v6));