pub struct AddrParseError(/* private fields */);Expand description
An error which can be returned when parsing an IP address or a socket address.
This error is used as the error type for the FromStr implementation for
IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr, SocketAddrV4, and
SocketAddrV6.
Potential causes
AddrParseError may be thrown because the provided string does not parse as the given type,
often because it includes information only handled by a different address type.
use std::net::IpAddr;
let _foo: IpAddr = "127.0.0.1:8080".parse().expect("Cannot handle the socket port");IpAddr doesn’t handle the port. Use SocketAddr instead.
use std::net::SocketAddr;
// No problem, the `panic!` message has disappeared.
let _foo: SocketAddr = "127.0.0.1:8080".parse().expect("unreachable panic");Trait Implementations
1.0.0 · Sourceimpl Clone for AddrParseError
impl Clone for AddrParseError
Sourcefn clone(&self) -> AddrParseError
fn clone(&self) -> AddrParseError
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more1.0.0 · Sourceimpl Debug for AddrParseError
impl Debug for AddrParseError
1.4.0 · Sourceimpl Display for AddrParseError
impl Display for AddrParseError
1.4.0 · Sourceimpl Error for AddrParseError
impl Error for AddrParseError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
Sourceimpl From<AddrParseError> for Error
impl From<AddrParseError> for Error
Sourcefn from(source: AddrParseError) -> Error
fn from(source: AddrParseError) -> Error
Sourceimpl From<AddrParseError> for Error
impl From<AddrParseError> for Error
Sourcefn from(source: AddrParseError) -> Error
fn from(source: AddrParseError) -> Error
Sourceimpl From<AddrParseError> for Error
impl From<AddrParseError> for Error
Sourcefn from(source: AddrParseError) -> Error
fn from(source: AddrParseError) -> Error
Sourceimpl From<AddrParseError> for Error
impl From<AddrParseError> for Error
Sourcefn from(source: AddrParseError) -> Error
fn from(source: AddrParseError) -> Error
1.0.0 · Sourceimpl PartialEq for AddrParseError
impl PartialEq for AddrParseError
impl Eq for AddrParseError
impl StructuralPartialEq for AddrParseError