PeekMut

Struct PeekMut 

pub struct PeekMut<'a, T, A = Global>
where A: Allocator,
{ /* private fields */ }
๐Ÿ”ฌThis is a nightly-only experimental API. (vec_peek_mut)
Structure wrapping a mutable reference to the last item in a Vec.

This struct is created by the peek_mut method on Vec. See its documentation for more.

Implementations

Source

impl<'a, T, A> PeekMut<'a, T, A>
where A: Allocator,

pub fn pop(this: PeekMut<'a, T, A>) -> T

๐Ÿ”ฌThis is a nightly-only experimental API. (vec_peek_mut)

Removes the peeked value from the vector and returns it.