pub struct Range<Idx> {
pub start: Idx,
pub end: Idx,
}new_range_api)Expand description
A (half-open) range bounded inclusively below and exclusively above
(start..end in a future edition).
The range start..end contains all values with start <= x < end.
It is empty if start >= end.
Examples
#![feature(new_range_api)]
use core::range::Range;
assert_eq!(Range::from(3..5), Range { start: 3, end: 5 });
assert_eq!(3 + 4 + 5, Range::from(3..6).into_iter().sum());Fields
start: Idxnew_range_api)The lower bound of the range (inclusive).
end: Idxnew_range_api)The upper bound of the range (exclusive).
Implementations
Sourceimpl<Idx> Range<Idx>where
Idx: Step,
impl<Idx> Range<Idx>where
Idx: Step,
Sourcepub fn iter(&self) -> IterRange<Idx> โ
๐ฌThis is a nightly-only experimental API. (new_range_api)
pub fn iter(&self) -> IterRange<Idx> โ
new_range_api)Creates an iterator over the elements within this range.
Shorthand for .clone().into_iter()
Examples
#![feature(new_range_api)]
use core::range::Range;
let mut i = Range::from(3..9).iter().map(|n| n*n);
assert_eq!(i.next(), Some(9));
assert_eq!(i.next(), Some(16));
assert_eq!(i.next(), Some(25));Sourceimpl<Idx> Range<Idx>where
Idx: PartialOrd,
impl<Idx> Range<Idx>where
Idx: PartialOrd,
Sourcepub fn contains<U>(&self, item: &U) -> bool
๐ฌThis is a nightly-only experimental API. (new_range_api)
pub fn contains<U>(&self, item: &U) -> bool
new_range_api)Returns true if item is contained in the range.
Examples
#![feature(new_range_api)]
use core::range::Range;
assert!(!Range::from(3..5).contains(&2));
assert!( Range::from(3..5).contains(&3));
assert!( Range::from(3..5).contains(&4));
assert!(!Range::from(3..5).contains(&5));
assert!(!Range::from(3..3).contains(&3));
assert!(!Range::from(3..2).contains(&3));
assert!( Range::from(0.0..1.0).contains(&0.5));
assert!(!Range::from(0.0..1.0).contains(&f32::NAN));
assert!(!Range::from(0.0..f32::NAN).contains(&0.5));
assert!(!Range::from(f32::NAN..1.0).contains(&0.5));Sourcepub fn is_empty(&self) -> bool
๐ฌThis is a nightly-only experimental API. (new_range_api)
pub fn is_empty(&self) -> bool
new_range_api)Returns true if the range contains no items.
Examples
#![feature(new_range_api)]
use core::range::Range;
assert!(!Range::from(3..5).is_empty());
assert!( Range::from(3..3).is_empty());
assert!( Range::from(3..2).is_empty());The range is empty if either side is incomparable:
#![feature(new_range_api)]
use core::range::Range;
assert!(!Range::from(3.0..5.0).is_empty());
assert!( Range::from(3.0..f32::NAN).is_empty());
assert!( Range::from(f32::NAN..5.0).is_empty());Trait Implementations
Sourceimpl GetDisjointMutIndex for Range<usize>
impl GetDisjointMutIndex for Range<usize>
Sourcefn is_in_bounds(&self, len: usize) -> bool
fn is_in_bounds(&self, len: usize) -> bool
get_disjoint_mut_helpers)true if self is in bounds for len slice elements.Sourceimpl<T> IntoBounds<T> for Range<T>
impl<T> IntoBounds<T> for Range<T>
Sourceimpl<A> IntoIterator for Range<A>where
A: Step,
impl<A> IntoIterator for Range<A>where
A: Step,
Sourceimpl<T> RangeBounds<T> for Range<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start..end with (Bound::Included(start), Bound::Excluded(end)).
impl<T> RangeBounds<T> for Range<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start..end with (Bound::Included(start), Bound::Excluded(end)).
Sourceimpl<T> RangeBounds<T> for Range<T>
impl<T> RangeBounds<T> for Range<T>
Sourceimpl<T> SliceIndex<[T]> for Range<usize>
impl<T> SliceIndex<[T]> for Range<usize>
Sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)Sourceimpl SliceIndex<ByteStr> for Range<usize>
impl SliceIndex<ByteStr> for Range<usize>
Sourcefn get(
self,
slice: &ByteStr,
) -> Option<&<Range<usize> as SliceIndex<ByteStr>>::Output>
fn get( self, slice: &ByteStr, ) -> Option<&<Range<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut ByteStr,
) -> Option<&mut <Range<usize> as SliceIndex<ByteStr>>::Output>
fn get_mut( self, slice: &mut ByteStr, ) -> Option<&mut <Range<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const ByteStr,
) -> *const <Range<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked( self, slice: *const ByteStr, ) -> *const <Range<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut ByteStr,
) -> *mut <Range<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut ByteStr, ) -> *mut <Range<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceimpl SliceIndex<str> for Range<usize>
impl SliceIndex<str> for Range<usize>
Sourcefn get(self, slice: &str) -> Option<&<Range<usize> as SliceIndex<str>>::Output>
fn get(self, slice: &str) -> Option<&<Range<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <Range<usize> as SliceIndex<str>>::Output>
fn get_mut( self, slice: &mut str, ) -> Option<&mut <Range<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <Range<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <Range<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <Range<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <Range<usize> as SliceIndex<str>>::Output
slice_index_methods)impl<T> CloneFromCell for Range<T>where
T: CloneFromCell,
impl<Idx> Copy for Range<Idx>where
Idx: Copy,
impl<Idx> Eq for Range<Idx>where
Idx: Eq,
impl<Idx> StructuralPartialEq for Range<Idx>