pub struct RangeInclusive<Idx> {
pub start: Idx,
pub last: Idx,
}new_range_api)Expand description
A range bounded inclusively below and above (start..=last).
The RangeInclusive start..=last contains all values with x >= start
and x <= last. It is empty unless start <= last.
Examples
The start..=last syntax is a RangeInclusive:
#![feature(new_range_api)]
use core::range::RangeInclusive;
assert_eq!(RangeInclusive::from(3..=5), RangeInclusive { start: 3, last: 5 });
assert_eq!(3 + 4 + 5, RangeInclusive::from(3..=5).into_iter().sum());Fields
start: Idxnew_range_api)The lower bound of the range (inclusive).
last: Idxnew_range_api)The upper bound of the range (inclusive).
Implementations
Sourceimpl<Idx> RangeInclusive<Idx>where
Idx: PartialOrd,
impl<Idx> RangeInclusive<Idx>where
Idx: PartialOrd,
Sourcepub fn contains<U>(&self, item: &U) -> bool
🔬This is a nightly-only experimental API. (new_range_api)
pub fn contains<U>(&self, item: &U) -> bool
new_range_api)Returns true if item is contained in the range.
Examples
#![feature(new_range_api)]
use core::range::RangeInclusive;
assert!(!RangeInclusive::from(3..=5).contains(&2));
assert!( RangeInclusive::from(3..=5).contains(&3));
assert!( RangeInclusive::from(3..=5).contains(&4));
assert!( RangeInclusive::from(3..=5).contains(&5));
assert!(!RangeInclusive::from(3..=5).contains(&6));
assert!( RangeInclusive::from(3..=3).contains(&3));
assert!(!RangeInclusive::from(3..=2).contains(&3));
assert!( RangeInclusive::from(0.0..=1.0).contains(&1.0));
assert!(!RangeInclusive::from(0.0..=1.0).contains(&f32::NAN));
assert!(!RangeInclusive::from(0.0..=f32::NAN).contains(&0.0));
assert!(!RangeInclusive::from(f32::NAN..=1.0).contains(&1.0));Sourcepub fn is_empty(&self) -> bool
🔬This is a nightly-only experimental API. (new_range_api)
pub fn is_empty(&self) -> bool
new_range_api)Returns true if the range contains no items.
Examples
#![feature(new_range_api)]
use core::range::RangeInclusive;
assert!(!RangeInclusive::from(3..=5).is_empty());
assert!(!RangeInclusive::from(3..=3).is_empty());
assert!( RangeInclusive::from(3..=2).is_empty());The range is empty if either side is incomparable:
#![feature(new_range_api)]
use core::range::RangeInclusive;
assert!(!RangeInclusive::from(3.0..=5.0).is_empty());
assert!( RangeInclusive::from(3.0..=f32::NAN).is_empty());
assert!( RangeInclusive::from(f32::NAN..=5.0).is_empty());Sourceimpl<Idx> RangeInclusive<Idx>where
Idx: Step,
impl<Idx> RangeInclusive<Idx>where
Idx: Step,
Sourcepub fn iter(&self) -> IterRangeInclusive<Idx> ⓘ
🔬This is a nightly-only experimental API. (new_range_api)
pub fn iter(&self) -> IterRangeInclusive<Idx> ⓘ
new_range_api)Creates an iterator over the elements within this range.
Shorthand for .clone().into_iter()
Examples
#![feature(new_range_api)]
use core::range::RangeInclusive;
let mut i = RangeInclusive::from(3..=8).iter().map(|n| n*n);
assert_eq!(i.next(), Some(9));
assert_eq!(i.next(), Some(16));
assert_eq!(i.next(), Some(25));Trait Implementations
Sourceimpl<Idx> Clone for RangeInclusive<Idx>where
Idx: Clone,
impl<Idx> Clone for RangeInclusive<Idx>where
Idx: Clone,
Sourcefn clone(&self) -> RangeInclusive<Idx>
fn clone(&self) -> RangeInclusive<Idx>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<Idx> Debug for RangeInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for RangeInclusive<Idx>where
Idx: Debug,
Sourceimpl<T> From<RangeInclusive<T>> for RangeInclusive<T>
impl<T> From<RangeInclusive<T>> for RangeInclusive<T>
Sourcefn from(value: RangeInclusive<T>) -> RangeInclusive<T> ⓘ
fn from(value: RangeInclusive<T>) -> RangeInclusive<T> ⓘ
Sourceimpl<T> From<RangeInclusive<T>> for RangeInclusive<T>
impl<T> From<RangeInclusive<T>> for RangeInclusive<T>
Sourcefn from(value: RangeInclusive<T>) -> RangeInclusive<T>
fn from(value: RangeInclusive<T>) -> RangeInclusive<T>
Sourceimpl GetDisjointMutIndex for RangeInclusive<usize>
impl GetDisjointMutIndex for RangeInclusive<usize>
Sourcefn is_in_bounds(&self, len: usize) -> bool
fn is_in_bounds(&self, len: usize) -> bool
get_disjoint_mut_helpers)true if self is in bounds for len slice elements.Sourcefn is_overlapping(&self, other: &RangeInclusive<usize>) -> bool
fn is_overlapping(&self, other: &RangeInclusive<usize>) -> bool
get_disjoint_mut_helpers)Sourceimpl<Idx> Hash for RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeInclusive<Idx>where
Idx: Hash,
Sourceimpl<T> IntoBounds<T> for RangeInclusive<T>
impl<T> IntoBounds<T> for RangeInclusive<T>
Sourceimpl<A> IntoIterator for RangeInclusive<A>where
A: Step,
impl<A> IntoIterator for RangeInclusive<A>where
A: Step,
Sourcetype IntoIter = IterRangeInclusive<A>
type IntoIter = IterRangeInclusive<A>
Sourcefn into_iter(self) -> <RangeInclusive<A> as IntoIterator>::IntoIter
fn into_iter(self) -> <RangeInclusive<A> as IntoIterator>::IntoIter
Sourceimpl<Idx> PartialEq for RangeInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for RangeInclusive<Idx>where
Idx: PartialEq,
Sourceimpl<T> RangeBounds<T> for RangeInclusive<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start..=end with (Bound::Included(start), Bound::Included(end)).
impl<T> RangeBounds<T> for RangeInclusive<&T>
If you need to use this implementation where T is unsized,
consider using the RangeBounds impl for a 2-tuple of Bound<&T>,
i.e. replace start..=end with (Bound::Included(start), Bound::Included(end)).
Sourceimpl<T> RangeBounds<T> for RangeInclusive<T>
impl<T> RangeBounds<T> for RangeInclusive<T>
Sourceimpl<T> SliceIndex<[T]> for RangeInclusive<usize>
impl<T> SliceIndex<[T]> for RangeInclusive<usize>
Sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)Sourceimpl SliceIndex<ByteStr> for RangeInclusive<usize>
impl SliceIndex<ByteStr> for RangeInclusive<usize>
Sourcefn get(
self,
slice: &ByteStr,
) -> Option<&<RangeInclusive<usize> as SliceIndex<ByteStr>>::Output>
fn get( self, slice: &ByteStr, ) -> Option<&<RangeInclusive<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut ByteStr,
) -> Option<&mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output>
fn get_mut( self, slice: &mut ByteStr, ) -> Option<&mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const ByteStr,
) -> *const <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked( self, slice: *const ByteStr, ) -> *const <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut ByteStr,
) -> *mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut ByteStr, ) -> *mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourcefn index(
self,
slice: &ByteStr,
) -> &<RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
fn index( self, slice: &ByteStr, ) -> &<RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourcefn index_mut(
self,
slice: &mut ByteStr,
) -> &mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
fn index_mut( self, slice: &mut ByteStr, ) -> &mut <RangeInclusive<usize> as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceimpl SliceIndex<str> for RangeInclusive<usize>
impl SliceIndex<str> for RangeInclusive<usize>
Sourcefn get(
self,
slice: &str,
) -> Option<&<RangeInclusive<usize> as SliceIndex<str>>::Output>
fn get( self, slice: &str, ) -> Option<&<RangeInclusive<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <RangeInclusive<usize> as SliceIndex<str>>::Output>
fn get_mut( self, slice: &mut str, ) -> Option<&mut <RangeInclusive<usize> as SliceIndex<str>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <RangeInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <RangeInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <RangeInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <RangeInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourcefn index(
self,
slice: &str,
) -> &<RangeInclusive<usize> as SliceIndex<str>>::Output
fn index( self, slice: &str, ) -> &<RangeInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Sourcefn index_mut(
self,
slice: &mut str,
) -> &mut <RangeInclusive<usize> as SliceIndex<str>>::Output
fn index_mut( self, slice: &mut str, ) -> &mut <RangeInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)impl<Idx> Copy for RangeInclusive<Idx>where
Idx: Copy,
impl<Idx> Eq for RangeInclusive<Idx>where
Idx: Eq,
impl<Idx> StructuralPartialEq for RangeInclusive<Idx>