FromStr

Trait FromStr 

1.0.0 (const: unstable) · Source
pub trait FromStr: Sized {
    type Err;

    // Required method
    fn from_str(s: &str) -> Result<Self, Self::Err>;
}
Parse a value from a string

FromStr’s from_str method is often used implicitly, through str’s parse method. See parse’s documentation for examples.

FromStr does not have a lifetime parameter, and so you can only parse types that do not contain a lifetime parameter themselves. In other words, you can parse an i32 with FromStr, but not a &i32. You can parse a struct that contains an i32, but not one that contains an &i32.

Input format and round-tripping

The input format expected by a type’s FromStr implementation depends on the type. Check the type’s documentation for the input formats it knows how to parse. Note that the input format of a type’s FromStr implementation might not necessarily accept the output format of its Display implementation, and even if it does, the Display implementation may not be lossless so the round-trip may lose information.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Examples

Basic implementation of FromStr on an example Point type:

use std::str::FromStr;

#[derive(Debug, PartialEq)]
struct Point {
    x: i32,
    y: i32
}

#[derive(Debug, PartialEq, Eq)]
struct ParsePointError;

impl FromStr for Point {
    type Err = ParsePointError;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        let (x, y) = s
            .strip_prefix('(')
            .and_then(|s| s.strip_suffix(')'))
            .and_then(|s| s.split_once(','))
            .ok_or(ParsePointError)?;

        let x_fromstr = x.parse::<i32>().map_err(|_| ParsePointError)?;
        let y_fromstr = y.parse::<i32>().map_err(|_| ParsePointError)?;

        Ok(Point { x: x_fromstr, y: y_fromstr })
    }
}

let expected = Ok(Point { x: 1, y: 2 });
// Explicit call
assert_eq!(Point::from_str("(1,2)"), expected);
// Implicit calls, through parse
assert_eq!("(1,2)".parse(), expected);
assert_eq!("(1,2)".parse::<Point>(), expected);
// Invalid input string
assert!(Point::from_str("(1 2)").is_err());

Required Associated Types

1.0.0 · Source

type Err

The associated error which can be returned from parsing.

Required Methods

1.0.0 · Source

fn from_str(s: &str) -> Result<Self, Self::Err>

Parses a string s to return a value of this type.

If parsing succeeds, return the value inside Ok, otherwise when the string is ill-formatted return an error specific to the inside Err. The error type is specific to the implementation of the trait.

Examples

Basic usage with i32, a type that implements FromStr:

use std::str::FromStr;

let s = "5";
let x = i32::from_str(s).unwrap();

assert_eq!(5, x);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl FromStr for CoreLibPointerId

Source

impl FromStr for InterfaceDirection

Source

impl FromStr for DecimalTypeVariant

Source

impl FromStr for IntegerTypeVariant

1.7.0 · Source

impl FromStr for IpAddr

1.0.0 · Source

impl FromStr for SocketAddr

Source

impl FromStr for chrono::month::Month

Parsing a str into a Month uses the format %B.

Example

use chrono::Month;

assert_eq!("January".parse::<Month>(), Ok(Month::January));
assert!("any day".parse::<Month>().is_err());

The parsing is case-insensitive.

assert_eq!("fEbruARy".parse::<Month>(), Ok(Month::February));

Only the shortest form (e.g. jan) and the longest form (e.g. january) is accepted.

assert!("septem".parse::<Month>().is_err());
assert!("Augustin".parse::<Month>().is_err());
Source

impl FromStr for chrono::weekday::Weekday

Parsing a str into a Weekday uses the format %A.

Example

use chrono::Weekday;

assert_eq!("Sunday".parse::<Weekday>(), Ok(Weekday::Sun));
assert!("any day".parse::<Weekday>().is_err());

The parsing is case-insensitive.

assert_eq!("mON".parse::<Weekday>(), Ok(Weekday::Mon));

Only the shortest form (e.g. sun) and the longest form (e.g. sunday) is accepted.

assert!("thurs".parse::<Weekday>().is_err());
Source

impl FromStr for TagMode

Source

impl FromStr for IpNet

Source

impl FromStr for log::Level

Source

impl FromStr for log::LevelFilter

Source

impl FromStr for Signal

Source

impl FromStr for CidrSubnet

Obtains the CidrSubnet from the well-known addr/prefix notation.

// The "192.0.2.0/24" example from
// https://tools.ietf.org/html/rfc5280#page-42
let subnet = CidrSubnet::from_str("192.0.2.0/24").unwrap();
assert_eq!(subnet, CidrSubnet::V4([0xC0, 0x00, 0x02, 0x00], [0xFF, 0xFF, 0xFF, 0x00]));
Source

impl FromStr for Value

Source

impl FromStr for FlowControl

Source

impl FromStr for UnderlineOption

Source

impl FromStr for time::month::Month

Source

impl FromStr for time::weekday::Weekday

1.0.0 · Source

impl FromStr for bool

1.20.0 · Source

impl FromStr for char

1.0.0 · Source

impl FromStr for f16

1.0.0 · Source

impl FromStr for f32

1.0.0 · Source

impl FromStr for f64

1.0.0 (const: unstable) · Source

impl FromStr for i8

1.0.0 (const: unstable) · Source

impl FromStr for i16

1.0.0 (const: unstable) · Source

impl FromStr for i32

1.0.0 (const: unstable) · Source

impl FromStr for i64

1.0.0 (const: unstable) · Source

impl FromStr for i128

1.0.0 (const: unstable) · Source

impl FromStr for isize

1.0.0 (const: unstable) · Source

impl FromStr for u8

1.0.0 (const: unstable) · Source

impl FromStr for u16

1.0.0 (const: unstable) · Source

impl FromStr for u32

1.0.0 (const: unstable) · Source

impl FromStr for u64

1.0.0 (const: unstable) · Source

impl FromStr for u128

1.0.0 (const: unstable) · Source

impl FromStr for usize

Source

impl FromStr for Endpoint

1.85.0 · Source

impl FromStr for CString

1.0.0 · Source

impl FromStr for Ipv4Addr

1.0.0 · Source

impl FromStr for Ipv6Addr

1.5.0 · Source

impl FromStr for SocketAddrV4

1.5.0 · Source

impl FromStr for SocketAddrV6

1.35.0 · Source

impl FromStr for NonZero<i8>

1.35.0 · Source

impl FromStr for NonZero<i16>

1.35.0 · Source

impl FromStr for NonZero<i32>

1.35.0 · Source

impl FromStr for NonZero<i64>

1.35.0 · Source

impl FromStr for NonZero<i128>

1.35.0 · Source

impl FromStr for NonZero<isize>

1.35.0 · Source

impl FromStr for NonZero<u8>

1.35.0 · Source

impl FromStr for NonZero<u16>

1.35.0 · Source

impl FromStr for NonZero<u32>

1.35.0 · Source

impl FromStr for NonZero<u64>

1.35.0 · Source

impl FromStr for NonZero<u128>

1.35.0 · Source

impl FromStr for NonZero<usize>

1.0.0 · Source

impl FromStr for String

Source

impl FromStr for ByteString

1.45.0 · Source

impl FromStr for OsString

1.32.0 · Source

impl FromStr for PathBuf

Source

impl FromStr for BigDecimal

Source

impl FromStr for chrono::datetime::DateTime<FixedOffset>

Accepts a relaxed form of RFC3339. A space or a ‘T’ are accepted as the separator between the date and time parts. Additional spaces are allowed between each component.

All of these examples are equivalent:

"2012-12-12T12:12:12Z".parse::<DateTime<FixedOffset>>()?;
"2012-12-12 12:12:12Z".parse::<DateTime<FixedOffset>>()?;
"2012-  12-12T12:  12:12Z".parse::<DateTime<FixedOffset>>()?;
Source

impl FromStr for chrono::datetime::DateTime<Local>

Accepts a relaxed form of RFC3339. A space or a ‘T’ are accepted as the separator between the date and time parts.

All of these examples are equivalent:

"2012-12-12T12:12:12Z".parse::<DateTime<Local>>()?;
"2012-12-12 12:12:12Z".parse::<DateTime<Local>>()?;
"2012-12-12 12:12:12+0000".parse::<DateTime<Local>>()?;
"2012-12-12 12:12:12+00:00".parse::<DateTime<Local>>()?;
Source

impl FromStr for chrono::datetime::DateTime<Utc>

Accepts a relaxed form of RFC3339. A space or a ‘T’ are accepted as the separator between the date and time parts.

All of these examples are equivalent:

"2012-12-12T12:12:12Z".parse::<DateTime<Utc>>()?;
"2012-12-12 12:12:12Z".parse::<DateTime<Utc>>()?;
"2012-12-12 12:12:12+0000".parse::<DateTime<Utc>>()?;
"2012-12-12 12:12:12+00:00".parse::<DateTime<Utc>>()?;
Source

impl FromStr for NaiveDate

Parsing a str into a NaiveDate uses the same format, %Y-%m-%d, as in Debug and Display.

Example

use chrono::NaiveDate;

let d = NaiveDate::from_ymd_opt(2015, 9, 18).unwrap();
assert_eq!("2015-09-18".parse::<NaiveDate>(), Ok(d));

let d = NaiveDate::from_ymd_opt(12345, 6, 7).unwrap();
assert_eq!("+12345-6-7".parse::<NaiveDate>(), Ok(d));

assert!("foo".parse::<NaiveDate>().is_err());
Source

impl FromStr for NaiveDateTime

Parsing a str into a NaiveDateTime uses the same format, %Y-%m-%dT%H:%M:%S%.f, as in Debug.

Example

use chrono::{NaiveDateTime, NaiveDate};

let dt = NaiveDate::from_ymd_opt(2015, 9, 18).unwrap().and_hms_opt(23, 56, 4).unwrap();
assert_eq!("2015-09-18T23:56:04".parse::<NaiveDateTime>(), Ok(dt));

let dt = NaiveDate::from_ymd_opt(12345, 6, 7).unwrap().and_hms_milli_opt(7, 59, 59, 1_500).unwrap(); // leap second
assert_eq!("+12345-6-7T7:59:60.5".parse::<NaiveDateTime>(), Ok(dt));

assert!("foo".parse::<NaiveDateTime>().is_err());
Source

impl FromStr for NaiveTime

Parsing a str into a NaiveTime uses the same format, %H:%M:%S%.f, as in Debug and Display.

Example

use chrono::NaiveTime;

let t = NaiveTime::from_hms_opt(23, 56, 4).unwrap();
assert_eq!("23:56:04".parse::<NaiveTime>(), Ok(t));

let t = NaiveTime::from_hms_nano_opt(23, 56, 4, 12_345_678).unwrap();
assert_eq!("23:56:4.012345678".parse::<NaiveTime>(), Ok(t));

let t = NaiveTime::from_hms_nano_opt(23, 59, 59, 1_234_567_890).unwrap(); // leap second
assert_eq!("23:59:60.23456789".parse::<NaiveTime>(), Ok(t));

// Seconds are optional
let t = NaiveTime::from_hms_opt(23, 56, 0).unwrap();
assert_eq!("23:56".parse::<NaiveTime>(), Ok(t));

assert!("foo".parse::<NaiveTime>().is_err());
Source

impl FromStr for FixedOffset

Parsing a str into a FixedOffset uses the format %z.

Source

impl FromStr for const_oid::ObjectIdentifier

Source

impl FromStr for der::asn1::bmp_string::BmpString

Source

impl FromStr for der::datetime::DateTime

Source

impl FromStr for fancy_regex::Regex

Source

impl FromStr for HeaderName

Source

impl FromStr for HeaderValue

Source

impl FromStr for Method

Source

impl FromStr for StatusCode

Source

impl FromStr for Authority

Source

impl FromStr for PathAndQuery

Source

impl FromStr for Scheme

Source

impl FromStr for Uri

Source

impl FromStr for HttpDate

Source

impl FromStr for icu_locale_core::extensions::private::other::Subtag

Source

impl FromStr for icu_locale_core::extensions::transform::key::Key

Source

impl FromStr for Attribute

Source

impl FromStr for icu_locale_core::extensions::unicode::key::Key

Source

impl FromStr for SubdivisionId

Source

impl FromStr for SubdivisionSuffix

Source

impl FromStr for Language

Source

impl FromStr for Region

Source

impl FromStr for Script

Source

impl FromStr for icu_locale_core::subtags::Subtag

Source

impl FromStr for Variant

Source

impl FromStr for Ipv4Net

Source

impl FromStr for Ipv6Net

Source

impl FromStr for Mime

Source

impl FromStr for SockaddrIn6

Source

impl FromStr for SockaddrIn

Source

impl FromStr for BigInt

Source

impl FromStr for BigUint

Source

impl FromStr for Pem

Source

impl FromStr for rcgen::string_types::BmpString

Source

impl FromStr for Ia5String

Source

impl FromStr for PrintableString

Source

impl FromStr for TeletexString

Source

impl FromStr for regex::regex::bytes::Regex

Source

impl FromStr for regex::regex::string::Regex

Source

impl FromStr for Map<String, Value>

Source

impl FromStr for Number

Source

impl FromStr for SmolStr

Source

impl FromStr for ScopeSelector

Source

impl FromStr for ScopeSelectors

Source

impl FromStr for Color

Source

impl FromStr for FontStyle

Source

impl FromStr for Scope

Source

impl FromStr for ScopeStack

Source

impl FromStr for tracing_core::metadata::Level

Source

impl FromStr for tracing_core::metadata::LevelFilter

Source

impl FromStr for Url

Parse a string as an URL, without a base URL or encoding override.

Source

impl FromStr for Braced

Source

impl FromStr for Hyphenated

Source

impl FromStr for Simple

Source

impl FromStr for Urn

Source

impl FromStr for Uuid

Source

impl FromStr for yasna::models::oid::ObjectIdentifier

Source

impl<'a> FromStr for Oid<'a>

Source

impl<C> FromStr for SigningKey<C>

Source

impl<C> FromStr for Signature<C>

Source

impl<C> FromStr for VerifyingKey<C>

Source

impl<C> FromStr for PublicKey<C>

Source

impl<C> FromStr for NonZeroScalar<C>
where C: CurveArithmetic,

Source

impl<C> FromStr for ScalarPrimitive<C>
where C: Curve,

Source

impl<C> FromStr for SecretKey<C>

Source

impl<Size> FromStr for EncodedPoint<Size>
where Size: ModulusSize,

Decode a SEC1-encoded point from hexadecimal.

Upper and lower case hexadecimal are both accepted, however mixed case is rejected.

Source

impl<T> FromStr for Complex<T>
where T: FromStr + Num + Clone,

Source

impl<T> FromStr for Ratio<T>
where T: FromStr + Clone + Integer,

Source

impl<T> FromStr for NotNan<T>
where T: FloatCore + FromStr,

Source

impl<T> FromStr for OrderedFloat<T>
where T: FromStr,

Source

type Err = <T as FromStr>::Err

Source

impl<const MIN: i8, const MAX: i8> FromStr for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> FromStr for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> FromStr for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> FromStr for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> FromStr for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> FromStr for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> FromStr for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> FromStr for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> FromStr for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> FromStr for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> FromStr for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> FromStr for RangedUsize<MIN, MAX>

Source

impl<const N: usize> FromStr for TinyAsciiStr<N>