Module sync

Modules

atomic
Atomic types

Structs

Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
Weak
Weak is a version of Arc that holds a non-owning reference to the managed allocation.
ExclusiveExperimental
Exclusive provides only mutable access, also referred to as exclusive access to the underlying value. It provides no immutable, or shared access to the underlying value.
UniqueArcExperimental
A uniquely owned Arc.