pub struct ContextBuilder<'a> { /* private fields */ }local_waker)Expand description
A Builder used to construct a Context instance
with support for LocalWaker.
Examples
#![feature(local_waker)]
use std::task::{ContextBuilder, LocalWaker, Waker, Poll};
use std::future::Future;
let local_waker = LocalWaker::noop();
let waker = Waker::noop();
let mut cx = ContextBuilder::from_waker(&waker)
.local_waker(&local_waker)
.build();
let mut future = std::pin::pin!(async { 20 });
let poll = future.as_mut().poll(&mut cx);
assert_eq!(poll, Poll::Ready(20));
Implementations
Sourceimpl<'a> ContextBuilder<'a>
impl<'a> ContextBuilder<'a>
Sourcepub const fn from_waker(waker: &'a Waker) -> ContextBuilder<'a>
🔬This is a nightly-only experimental API. (local_waker)
pub const fn from_waker(waker: &'a Waker) -> ContextBuilder<'a>
local_waker)Creates a ContextBuilder from a Waker.
Sourcepub const fn from(cx: &'a mut Context<'_>) -> ContextBuilder<'a>
🔬This is a nightly-only experimental API. (context_ext)
pub const fn from(cx: &'a mut Context<'_>) -> ContextBuilder<'a>
context_ext)Creates a ContextBuilder from an existing Context.
Sourcepub const fn waker(self, waker: &'a Waker) -> ContextBuilder<'a>
🔬This is a nightly-only experimental API. (context_ext)
pub const fn waker(self, waker: &'a Waker) -> ContextBuilder<'a>
context_ext)Sets the value for the waker on Context.
Sourcepub const fn local_waker(
self,
local_waker: &'a LocalWaker,
) -> ContextBuilder<'a>
🔬This is a nightly-only experimental API. (local_waker)
pub const fn local_waker( self, local_waker: &'a LocalWaker, ) -> ContextBuilder<'a>
local_waker)Sets the value for the local waker on Context.
Sourcepub const fn ext(self, data: &'a mut (dyn Any + 'static)) -> ContextBuilder<'a>
🔬This is a nightly-only experimental API. (context_ext)
pub const fn ext(self, data: &'a mut (dyn Any + 'static)) -> ContextBuilder<'a>
context_ext)Sets the value for the extension data on Context.