Modules
Structs
- Compile
Options - Variable
- Represents a variable in the DATEX script.
Enums
Functions
- compile_
block - Compiles a DATEX script text into a single DXB block including routing and block headers. This function is used to create a block that can be sent over the network.
- compile_
rich_ ast - compile_
script - Compiles a DATEX script text into a DXB body
- compile_
script_ or_ return_ static_ value - Converts a DATEX script template text with inserted values into an AST with metadata If the script does not contain any dynamic values or operations, the static result value is directly returned instead of the AST.
- compile_
template - Compiles a DATEX script template text with inserted values into a DXB body
- extract_
static_ value_ from_ script - Directly extracts a static value from a DATEX script as a
ValueContainer. This only works if the script does not contain any dynamic values or operations. All JSON-files can be compiled to static values, but not all DATEX scripts. - parse_
datex_ script_ to_ rich_ ast_ detailed_ errors - Parses and precompiles a DATEX script template text with inserted values into an AST with metadata Returns all occurring errors and the AST if one or more errors occur.
- parse_
datex_ script_ to_ rich_ ast_ simple_ error - Parses and precompiles a DATEX script template text with inserted values into an AST with metadata Only returns the first occurring error