Module compiler

Module compiler 

Modules

context
error
metadata
scope

Structs

CompileOptions
Variable
Represents a variable in the DATEX script.

Enums

StaticValueOrDXB
VariableModel
VariableRepresentation

Functions

compile_ast
compile_ast_with_metadata
compile_block
Compiles a DATEX script text into a single DXB block including routing and block headers. This function is used to create a block that can be sent over the network.
compile_script
Compiles a DATEX script text into a DXB body
compile_script_or_return_static_value
Compiles a DATEX script template text with inserted values into a DXB body If the script does not contain any dynamic values or operations, the static result value is directly returned instead of the DXB body.
compile_template
Compiles a DATEX script template text with inserted values into a DXB body
compile_template_or_return_static_value_with_refs
Compiles a DATEX script template text with inserted values into a DXB body
compile_template_with_refs
Compiles a DATEX script template text with inserted values into a DXB body The value containers are passed by reference
compile_value
extract_static_value_from_script
Directly extracts a static value from a DATEX script as a ValueContainer. This only works if the script does not contain any dynamic values or operations. All JSON-files can be compiled to static values, but not all DATEX scripts.