Modules
Structs
- Compile
Options - Variable
- Represents a variable in the DATEX script.
Enums
Functions
- compile_
ast - compile_
ast_ with_ metadata - compile_
block - Compiles a DATEX script text into a single DXB block including routing and block headers. This function is used to create a block that can be sent over the network.
- compile_
script - Compiles a DATEX script text into a DXB body
- compile_
script_ or_ return_ static_ value - Compiles a DATEX script template text with inserted values into a DXB body If the script does not contain any dynamic values or operations, the static result value is directly returned instead of the DXB body.
- compile_
template - Compiles a DATEX script template text with inserted values into a DXB body
- compile_
template_ or_ return_ static_ value_ with_ refs - Compiles a DATEX script template text with inserted values into a DXB body
- compile_
template_ with_ refs - Compiles a DATEX script template text with inserted values into a DXB body The value containers are passed by reference
- compile_
value - extract_
static_ value_ from_ script - Directly extracts a static value from a DATEX script as a
ValueContainer. This only works if the script does not contain any dynamic values or operations. All JSON-files can be compiled to static values, but not all DATEX scripts.