Structs
- Detailed
Compiler Errors - Detailed
Compiler Errors With Maybe Rich Ast - Detailed
Compiler Errors With Rich Ast - Spanned
Compiler Error - A compiler error that can be linked to a specific span in the source code
Enums
- Compiler
Error - Maybe
Action - Describes an optional action that is only executed if an Ok result was returned (used in collect_or_pass_error);
- Simple
Compiler Error OrDetailed Compiler Error With Rich Ast - Extended SimpleOrDetailedCompilerError type that includes RichAst for the Detailed variant
- Simple
OrDetailed Compiler Error
Traits
Functions
- collect_
or_ pass_ error - Handles a generic Result with an SpannedCompilerError error. If the result is Ok(), an Ok(MaybeAction::Do) with the result is returned If result is Error() and collected_errors is Some, the error is appended to the collected_errors and an Ok(MaybeAction::Skip) is returned If result is Error() and collected_errors is None, the error is directly returned