pub fn extract_static_value_from_script(
datex_script: &str,
) -> Result<Option<ValueContainer>, CompilerError>Expand description
Directly extracts a static value from a DATEX script as a ValueContainer.
This only works if the script does not contain any dynamic values or operations.
All JSON-files can be compiled to static values, but not all DATEX scripts.