pub enum DIFValueRepresentation {
Null,
Boolean(bool),
String(String),
Number(f64),
Array(Vec<DIFValueContainer>),
Map(Vec<(DIFValueContainer, DIFValueContainer)>),
Object(Vec<(String, DIFValueContainer)>),
}Variants
Null
Boolean(bool)
Represents a boolean value in DIF.
String(String)
Represents a string value in DIF.
Number(f64)
Represents a number in DIF.
Array(Vec<DIFValueContainer>)
Represents a array of DIF values.
Map(Vec<(DIFValueContainer, DIFValueContainer)>)
Represents a map of DIF values.
Object(Vec<(String, DIFValueContainer)>)
Represents a struct value in DIF.
Implementations
Sourceimpl DIFValueRepresentation
impl DIFValueRepresentation
Sourcepub fn to_default_value(
self,
memory: &RefCell<Memory>,
) -> Result<Value, DIFReferenceNotFoundError>
pub fn to_default_value( self, memory: &RefCell<Memory>, ) -> Result<Value, DIFReferenceNotFoundError>
Converts a DIFRepresentationValue into a default Value, without considering additional type information. Returns an error if a reference cannot be resolved.
Sourcepub fn to_value_with_type(
self,
type_container: &DIFTypeContainer,
memory: &RefCell<Memory>,
) -> Result<Value, DIFReferenceNotFoundError>
pub fn to_value_with_type( self, type_container: &DIFTypeContainer, memory: &RefCell<Memory>, ) -> Result<Value, DIFReferenceNotFoundError>
Converts a DIFRepresentationValue into a Value, using the provided type information to guide the conversion. Returns an error if a reference cannot be resolved.