pub enum DIFUpdateData {
Replace {
value: DIFValueContainer,
},
Set {
key: DIFProperty,
value: DIFValueContainer,
},
Remove {
key: DIFProperty,
},
Clear,
Push {
value: DIFValueContainer,
},
}Expand description
Represents an update operation for a DIF value.
Variants
Replace
Represents a replacement operation for a DIF value.
Fields
value: DIFValueContainerSet
Represents an update to a specific property of a DIF value.
The key specifies which property to update, and value is the new value for that property.
Remove
Represents the removal of a specific property from a DIF value.
Fields
key: DIFPropertyClear
Represents clearing all elements from a collection-type DIF value (like an array or map).
Push
Represents adding a new element to a collection-type DIF value (like an array or map).
Fields
value: DIFValueContainerImplementations
Sourceimpl DIFUpdateData
impl DIFUpdateData
Sourcepub fn replace(value: impl Into<DIFValueContainer>) -> Self
pub fn replace(value: impl Into<DIFValueContainer>) -> Self
Creates a new DIFUpdateData::Replace variant with the given value.
Sourcepub fn set(
key: impl Into<DIFProperty>,
value: impl Into<DIFValueContainer>,
) -> Self
pub fn set( key: impl Into<DIFProperty>, value: impl Into<DIFValueContainer>, ) -> Self
Creates a new DIFUpdateData::Set variant with the given key and value.
Sourcepub fn remove(key: impl Into<DIFProperty>) -> Self
pub fn remove(key: impl Into<DIFProperty>) -> Self
Creates a new DIFUpdateData::Remove variant with the given key.
Sourcepub fn push(value: impl Into<DIFValueContainer>) -> Self
pub fn push(value: impl Into<DIFValueContainer>) -> Self
Creates a new DIFUpdateData::Push variant with the given value.
pub fn with_source(self, source_id: TransceiverId) -> DIFUpdate