pub struct BlockHeader {
pub context_id: u32,
pub section_index: u16,
pub block_number: u16,
pub flags_and_timestamp: FlagsAndTimestamp,
pub lifetime: Option<u32>,
pub represented_by: Option<Endpoint>,
pub iv: Option<[u8; 16]>,
}Fields
context_id: u32A unique id that defines the context in which this block lives A context has a persistent state that can e.g. contain DATEX variables
section_index: u16A section is a collection of multiple sequential blocks inside the same context (each with an incrementing block number) When a new section starts, the block number is not reset but continues to increment
block_number: u16A unique number that identifies a block inside a block context The context_id combined with the block_number define a unique block from a specific endpoint the block id (endpoint, context_id, block_number) defines a globally unique block Note: blocks ids are not completely unique, when the block_number or section_index overflows, it starts from 0 again, leading to duplicate block ids after a while
flags_and_timestamp: FlagsAndTimestamplifetime: Option<u32>represented_by: Option<Endpoint>iv: Option<[u8; 16]>Trait Implementations
Sourceimpl BinRead for BlockHeader
impl BinRead for BlockHeader
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for BlockHeader
impl BinWrite for BlockHeader
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write<W>(&self, writer: &mut W) -> Result<(), Error>
fn write<W>(&self, writer: &mut W) -> Result<(), Error>
Self to the writer using default arguments. Read moreSourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Self to the writer assuming native-endian byte order. Read moreSourcefn write_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Self to the writer using the given arguments. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for BlockHeader
impl Clone for BlockHeader
Sourcefn clone(&self) -> BlockHeader
fn clone(&self) -> BlockHeader
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BlockHeader
impl Debug for BlockHeader
Sourceimpl Default for BlockHeader
impl Default for BlockHeader
Sourcefn default() -> BlockHeader
fn default() -> BlockHeader
Sourceimpl PartialEq for BlockHeader
impl PartialEq for BlockHeader
Sourceimpl ReadEndian for BlockHeader
impl ReadEndian for BlockHeader
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
Sourceimpl Serializable for BlockHeader
impl Serializable for BlockHeader
Sourceimpl WriteEndian for BlockHeader
impl WriteEndian for BlockHeader
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
impl StructuralPartialEq for BlockHeader