Flags

pub struct Flags { /* private fields */ }

Implementations

Source

impl Flags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl Flags

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl Flags

pub fn user_agent(&self) -> <UserAgent as Specifier>::InOut

Returns the value of user_agent.

pub fn user_agent_or_err( &self, ) -> Result<<UserAgent as Specifier>::InOut, InvalidBitPattern<<UserAgent as Specifier>::Bytes>>

Returns the value of user_agent.

Errors

If the returned value contains an invalid bit pattern for user_agent.

pub fn with_user_agent(self, new_val: <UserAgent as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of user_agent set to the given value.

Panics

If the given value is out of bounds for user_agent.

pub fn with_user_agent_checked( self, new_val: <UserAgent as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of user_agent set to the given value.

Errors

If the given value is out of bounds for user_agent.

pub fn set_user_agent(&mut self, new_val: <UserAgent as Specifier>::InOut)

Sets the value of user_agent to the given value.

Panics

If the given value is out of bounds for user_agent.

pub fn set_user_agent_checked( &mut self, new_val: <UserAgent as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of user_agent to the given value.

Errors

If the given value is out of bounds for user_agent.

pub fn has_on_behalf_of(&self) -> <bool as Specifier>::InOut

Returns the value of has_on_behalf_of.

pub fn has_on_behalf_of_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of has_on_behalf_of.

Errors

If the returned value contains an invalid bit pattern for has_on_behalf_of.

pub fn with_has_on_behalf_of(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of has_on_behalf_of set to the given value.

Panics

If the given value is out of bounds for has_on_behalf_of.

pub fn with_has_on_behalf_of_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of has_on_behalf_of set to the given value.

Errors

If the given value is out of bounds for has_on_behalf_of.

pub fn set_has_on_behalf_of(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of has_on_behalf_of to the given value.

Panics

If the given value is out of bounds for has_on_behalf_of.

pub fn set_has_on_behalf_of_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of has_on_behalf_of to the given value.

Errors

If the given value is out of bounds for has_on_behalf_of.