pub struct Flags { /* private fields */ }Implementations
Sourceimpl Flags
impl Flags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl Flags
impl Flags
Sourcepub fn device_type(&self) -> <DeviceType as Specifier>::InOut
pub fn device_type(&self) -> <DeviceType as Specifier>::InOut
Returns the value of device_type.
Sourcepub fn device_type_or_err(
&self,
) -> Result<<DeviceType as Specifier>::InOut, InvalidBitPattern<<DeviceType as Specifier>::Bytes>>
pub fn device_type_or_err( &self, ) -> Result<<DeviceType as Specifier>::InOut, InvalidBitPattern<<DeviceType as Specifier>::Bytes>>
Returns the value of device_type.
Errors
If the returned value contains an invalid bit pattern for device_type.
Sourcepub fn with_device_type(self, new_val: <DeviceType as Specifier>::InOut) -> Self
pub fn with_device_type(self, new_val: <DeviceType as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of device_type set to the given value.
Panics
If the given value is out of bounds for device_type.
Sourcepub fn with_device_type_checked(
self,
new_val: <DeviceType as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_device_type_checked( self, new_val: <DeviceType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of device_type set to the given value.
Errors
If the given value is out of bounds for device_type.
Sourcepub fn set_device_type(&mut self, new_val: <DeviceType as Specifier>::InOut)
pub fn set_device_type(&mut self, new_val: <DeviceType as Specifier>::InOut)
Sets the value of device_type to the given value.
Panics
If the given value is out of bounds for device_type.
Sourcepub fn set_device_type_checked(
&mut self,
new_val: <DeviceType as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_device_type_checked( &mut self, new_val: <DeviceType as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of device_type to the given value.
Errors
If the given value is out of bounds for device_type.
Sourcepub fn has_on_behalf_of(&self) -> <bool as Specifier>::InOut
pub fn has_on_behalf_of(&self) -> <bool as Specifier>::InOut
Returns the value of has_on_behalf_of.
Sourcepub fn has_on_behalf_of_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn has_on_behalf_of_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of has_on_behalf_of.
Errors
If the returned value contains an invalid bit pattern for has_on_behalf_of.
Sourcepub fn with_has_on_behalf_of(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_has_on_behalf_of(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of has_on_behalf_of set to the given value.
Panics
If the given value is out of bounds for has_on_behalf_of.
Sourcepub fn with_has_on_behalf_of_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_has_on_behalf_of_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of has_on_behalf_of set to the given value.
Errors
If the given value is out of bounds for has_on_behalf_of.
Sourcepub fn set_has_on_behalf_of(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_has_on_behalf_of(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of has_on_behalf_of to the given value.
Panics
If the given value is out of bounds for has_on_behalf_of.
Sourcepub fn set_has_on_behalf_of_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_has_on_behalf_of_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of has_on_behalf_of to the given value.
Errors
If the given value is out of bounds for has_on_behalf_of.