pub struct Flags { /* private fields */ }Implementations
Sourceimpl Flags
impl Flags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl Flags
impl Flags
Sourcepub fn signature_type(&self) -> <SignatureType as Specifier>::InOut
pub fn signature_type(&self) -> <SignatureType as Specifier>::InOut
Returns the value of signature_type.
Sourcepub fn signature_type_or_err(
&self,
) -> Result<<SignatureType as Specifier>::InOut, InvalidBitPattern<<SignatureType as Specifier>::Bytes>>
pub fn signature_type_or_err( &self, ) -> Result<<SignatureType as Specifier>::InOut, InvalidBitPattern<<SignatureType as Specifier>::Bytes>>
Returns the value of signature_type.
Errors
If the returned value contains an invalid bit pattern for signature_type.
Sourcepub fn with_signature_type(
self,
new_val: <SignatureType as Specifier>::InOut,
) -> Self
pub fn with_signature_type( self, new_val: <SignatureType as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of signature_type set to the given value.
Panics
If the given value is out of bounds for signature_type.
Sourcepub fn with_signature_type_checked(
self,
new_val: <SignatureType as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_signature_type_checked( self, new_val: <SignatureType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of signature_type set to the given value.
Errors
If the given value is out of bounds for signature_type.
Sourcepub fn set_signature_type(
&mut self,
new_val: <SignatureType as Specifier>::InOut,
)
pub fn set_signature_type( &mut self, new_val: <SignatureType as Specifier>::InOut, )
Sets the value of signature_type to the given value.
Panics
If the given value is out of bounds for signature_type.
Sourcepub fn set_signature_type_checked(
&mut self,
new_val: <SignatureType as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_signature_type_checked( &mut self, new_val: <SignatureType as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of signature_type to the given value.
Errors
If the given value is out of bounds for signature_type.
Sourcepub fn encryption_type(&self) -> <EncryptionType as Specifier>::InOut
pub fn encryption_type(&self) -> <EncryptionType as Specifier>::InOut
Returns the value of encryption_type.
Sourcepub fn encryption_type_or_err(
&self,
) -> Result<<EncryptionType as Specifier>::InOut, InvalidBitPattern<<EncryptionType as Specifier>::Bytes>>
pub fn encryption_type_or_err( &self, ) -> Result<<EncryptionType as Specifier>::InOut, InvalidBitPattern<<EncryptionType as Specifier>::Bytes>>
Returns the value of encryption_type.
Errors
If the returned value contains an invalid bit pattern for encryption_type.
Sourcepub fn with_encryption_type(
self,
new_val: <EncryptionType as Specifier>::InOut,
) -> Self
pub fn with_encryption_type( self, new_val: <EncryptionType as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of encryption_type set to the given value.
Panics
If the given value is out of bounds for encryption_type.
Sourcepub fn with_encryption_type_checked(
self,
new_val: <EncryptionType as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_encryption_type_checked( self, new_val: <EncryptionType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of encryption_type set to the given value.
Errors
If the given value is out of bounds for encryption_type.
Sourcepub fn set_encryption_type(
&mut self,
new_val: <EncryptionType as Specifier>::InOut,
)
pub fn set_encryption_type( &mut self, new_val: <EncryptionType as Specifier>::InOut, )
Sets the value of encryption_type to the given value.
Panics
If the given value is out of bounds for encryption_type.
Sourcepub fn set_encryption_type_checked(
&mut self,
new_val: <EncryptionType as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_encryption_type_checked( &mut self, new_val: <EncryptionType as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of encryption_type to the given value.
Errors
If the given value is out of bounds for encryption_type.
Sourcepub fn receiver_type(&self) -> <ReceiverType as Specifier>::InOut
pub fn receiver_type(&self) -> <ReceiverType as Specifier>::InOut
Returns the value of receiver_type.
Sourcepub fn receiver_type_or_err(
&self,
) -> Result<<ReceiverType as Specifier>::InOut, InvalidBitPattern<<ReceiverType as Specifier>::Bytes>>
pub fn receiver_type_or_err( &self, ) -> Result<<ReceiverType as Specifier>::InOut, InvalidBitPattern<<ReceiverType as Specifier>::Bytes>>
Returns the value of receiver_type.
Errors
If the returned value contains an invalid bit pattern for receiver_type.
Sourcepub fn with_receiver_type(
self,
new_val: <ReceiverType as Specifier>::InOut,
) -> Self
pub fn with_receiver_type( self, new_val: <ReceiverType as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of receiver_type set to the given value.
Panics
If the given value is out of bounds for receiver_type.
Sourcepub fn with_receiver_type_checked(
self,
new_val: <ReceiverType as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_receiver_type_checked( self, new_val: <ReceiverType as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of receiver_type set to the given value.
Errors
If the given value is out of bounds for receiver_type.
Sourcepub fn set_receiver_type(&mut self, new_val: <ReceiverType as Specifier>::InOut)
pub fn set_receiver_type(&mut self, new_val: <ReceiverType as Specifier>::InOut)
Sets the value of receiver_type to the given value.
Panics
If the given value is out of bounds for receiver_type.
Sourcepub fn set_receiver_type_checked(
&mut self,
new_val: <ReceiverType as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_receiver_type_checked( &mut self, new_val: <ReceiverType as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of receiver_type to the given value.
Errors
If the given value is out of bounds for receiver_type.
Sourcepub fn is_bounce_back(&self) -> <bool as Specifier>::InOut
pub fn is_bounce_back(&self) -> <bool as Specifier>::InOut
Returns the value of is_bounce_back.
Sourcepub fn is_bounce_back_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn is_bounce_back_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of is_bounce_back.
Errors
If the returned value contains an invalid bit pattern for is_bounce_back.
Sourcepub fn with_is_bounce_back(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_is_bounce_back(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of is_bounce_back set to the given value.
Panics
If the given value is out of bounds for is_bounce_back.
Sourcepub fn with_is_bounce_back_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_is_bounce_back_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of is_bounce_back set to the given value.
Errors
If the given value is out of bounds for is_bounce_back.
Sourcepub fn set_is_bounce_back(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_is_bounce_back(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of is_bounce_back to the given value.
Panics
If the given value is out of bounds for is_bounce_back.
Sourcepub fn set_is_bounce_back_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_is_bounce_back_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of is_bounce_back to the given value.
Errors
If the given value is out of bounds for is_bounce_back.
Sourcepub fn has_checksum(&self) -> <bool as Specifier>::InOut
pub fn has_checksum(&self) -> <bool as Specifier>::InOut
Returns the value of has_checksum.
Sourcepub fn has_checksum_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn has_checksum_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of has_checksum.
Errors
If the returned value contains an invalid bit pattern for has_checksum.
Sourcepub fn with_has_checksum(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_has_checksum(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of has_checksum set to the given value.
Panics
If the given value is out of bounds for has_checksum.
Sourcepub fn with_has_checksum_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_has_checksum_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of has_checksum set to the given value.
Errors
If the given value is out of bounds for has_checksum.
Sourcepub fn set_has_checksum(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_has_checksum(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of has_checksum to the given value.
Panics
If the given value is out of bounds for has_checksum.
Sourcepub fn set_has_checksum_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_has_checksum_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of has_checksum to the given value.
Errors
If the given value is out of bounds for has_checksum.