pub struct ReceiverFlags { /* private fields */ }Implementations
Sourceimpl ReceiverFlags
impl ReceiverFlags
Sourceimpl ReceiverFlags
impl ReceiverFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl ReceiverFlags
impl ReceiverFlags
Sourcepub fn has_pointer_id(&self) -> <bool as Specifier>::InOut
pub fn has_pointer_id(&self) -> <bool as Specifier>::InOut
Returns the value of has_pointer_id.
Sourcepub fn has_pointer_id_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn has_pointer_id_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of has_pointer_id.
Errors
If the returned value contains an invalid bit pattern for has_pointer_id.
Sourcepub fn with_has_pointer_id(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_has_pointer_id(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of has_pointer_id set to the given value.
Panics
If the given value is out of bounds for has_pointer_id.
Sourcepub fn with_has_pointer_id_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_has_pointer_id_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of has_pointer_id set to the given value.
Errors
If the given value is out of bounds for has_pointer_id.
Sourcepub fn set_has_pointer_id(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_has_pointer_id(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of has_pointer_id to the given value.
Panics
If the given value is out of bounds for has_pointer_id.
Sourcepub fn set_has_pointer_id_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_has_pointer_id_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of has_pointer_id to the given value.
Errors
If the given value is out of bounds for has_pointer_id.
Sourcepub fn has_endpoints(&self) -> <bool as Specifier>::InOut
pub fn has_endpoints(&self) -> <bool as Specifier>::InOut
Returns the value of has_endpoints.
Sourcepub fn has_endpoints_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn has_endpoints_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of has_endpoints.
Errors
If the returned value contains an invalid bit pattern for has_endpoints.
Sourcepub fn with_has_endpoints(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_has_endpoints(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of has_endpoints set to the given value.
Panics
If the given value is out of bounds for has_endpoints.
Sourcepub fn with_has_endpoints_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_has_endpoints_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of has_endpoints set to the given value.
Errors
If the given value is out of bounds for has_endpoints.
Sourcepub fn set_has_endpoints(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_has_endpoints(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of has_endpoints to the given value.
Panics
If the given value is out of bounds for has_endpoints.
Sourcepub fn set_has_endpoints_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_has_endpoints_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of has_endpoints to the given value.
Errors
If the given value is out of bounds for has_endpoints.
Sourcepub fn has_endpoint_keys(&self) -> <bool as Specifier>::InOut
pub fn has_endpoint_keys(&self) -> <bool as Specifier>::InOut
Returns the value of has_endpoint_keys.
Sourcepub fn has_endpoint_keys_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn has_endpoint_keys_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of has_endpoint_keys.
Errors
If the returned value contains an invalid bit pattern for has_endpoint_keys.
Sourcepub fn with_has_endpoint_keys(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_has_endpoint_keys(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of has_endpoint_keys set to the given value.
Panics
If the given value is out of bounds for has_endpoint_keys.
Sourcepub fn with_has_endpoint_keys_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_has_endpoint_keys_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of has_endpoint_keys set to the given value.
Errors
If the given value is out of bounds for has_endpoint_keys.
Sourcepub fn set_has_endpoint_keys(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_has_endpoint_keys(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of has_endpoint_keys to the given value.
Panics
If the given value is out of bounds for has_endpoint_keys.
Sourcepub fn set_has_endpoint_keys_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_has_endpoint_keys_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of has_endpoint_keys to the given value.
Errors
If the given value is out of bounds for has_endpoint_keys.