Enums
Statics
Functions
- boolean
- callable
- create_
core_ lib_ types - Creates a new instance of the core library as a ValueContainer including all core types as properties.
- create_
core_ lib_ vals - decimal
- decimal_
variant - endpoint
- get_
core_ lib_ type - get_
core_ lib_ type_ definition - get_
core_ lib_ type_ reference - get_
core_ lib_ value - Retrieves either a core library type or value by its CoreLibPointerId.
- integer
- integer_
variant - list
- load_
core_ lib - Loads the core library into the provided memory instance.
- map
- never
- null
- range
- text
- ty
- unit
- unknown