Module core

Module core 

Enums

CoreLibPointerId

Constants

CORE_LIB_TYPES

Functions

boolean
create_core_lib
Creates a new instance of the core library as a ValueContainer including all core types as properties.
decimal
decimal_variant
endpoint
get_core_lib_type
get_core_lib_type_reference
integer
integer_variant
list
load_core_lib
Loads the core library into the provided memory instance.
map
null
text
type
unit