Enums
Constants
Functions
- boolean
- create_
core_ lib - Creates a new instance of the core library as a ValueContainer including all core types as properties.
- decimal
- decimal_
variant - endpoint
- get_
core_ lib_ type - get_
core_ lib_ type_ reference - integer
- integer_
variant - list
- load_
core_ lib - Loads the core library into the provided memory instance.
- map
- null
- text
- type
- unit