pub struct BlockHandler {
pub current_context_id: RefCell<OutgoingContextId>,
pub block_cache: RefCell<HashMap<IncomingEndpointContextId, ScopeContext>>,
pub incoming_sections_queue: RefCell<VecDeque<IncomingSection>>,
pub section_observers: RefCell<HashMap<(IncomingContextId, IncomingSectionIndex), Box<dyn FnMut(IncomingSection)>>>,
pub incoming_blocks_history: RefCell<RingMap<BlockId, BlockHistoryData>>,
}Fields
current_context_id: RefCell<OutgoingContextId>block_cache: RefCell<HashMap<IncomingEndpointContextId, ScopeContext>>a map of active request scopes for incoming blocks
incoming_sections_queue: RefCell<VecDeque<IncomingSection>>a queue of incoming request scopes the scopes can be retrieved from the request_scopes map
section_observers: RefCell<HashMap<(IncomingContextId, IncomingSectionIndex), Box<dyn FnMut(IncomingSection)>>>a map of observers for incoming response blocks (by context_id + block_index) contains an observer callback and an optional queue of blocks if the response block is a multi-block stream
incoming_blocks_history: RefCell<RingMap<BlockId, BlockHistoryData>>history of all incoming blocks
Implementations
Sourceimpl BlockHandler
impl BlockHandler
pub fn new() -> BlockHandler
Sourcepub fn add_block_to_history(
&self,
block: &DXBBlock,
original_socket_uuid: Option<ComInterfaceSocketUUID>,
)
pub fn add_block_to_history( &self, block: &DXBBlock, original_socket_uuid: Option<ComInterfaceSocketUUID>, )
Adds a block to the history of incoming blocks if the block is not already in the history returns true if the block was added and not already in the history
Sourcepub fn is_block_in_history(&self, block: &DXBBlock) -> bool
pub fn is_block_in_history(&self, block: &DXBBlock) -> bool
Checks if a block is already in the history
pub fn get_block_data_from_history( &self, block: &DXBBlock, ) -> Option<BlockHistoryData>
pub fn handle_incoming_block(&self, block: DXBBlock)
pub fn get_new_context_id(&self) -> OutgoingContextId
Sourcepub fn register_incoming_block_observer(
&self,
context_id: OutgoingContextId,
section_index: OutgoingSectionIndex,
) -> UnboundedReceiver<IncomingSection>
pub fn register_incoming_block_observer( &self, context_id: OutgoingContextId, section_index: OutgoingSectionIndex, ) -> UnboundedReceiver<IncomingSection>
Adds a new observer for incoming blocks with a specific scope id and block index Returns a receiver that can be awaited to get the incoming sections
Sourcepub async fn wait_for_incoming_response_block(
&self,
context_id: OutgoingContextId,
section_index: OutgoingSectionIndex,
) -> Option<IncomingSection>
pub async fn wait_for_incoming_response_block( &self, context_id: OutgoingContextId, section_index: OutgoingSectionIndex, ) -> Option<IncomingSection>
Waits for incoming response block with a specific scope id and block index