Reference

Enum Reference 

pub enum Reference {
    ValueReference(Rc<RefCell<ValueReference>>),
    TypeReference(Rc<RefCell<TypeReference>>),
}

Variants



ValueReference(Rc<RefCell<ValueReference>>)



TypeReference(Rc<RefCell<TypeReference>>)

Implementations

Source

impl Reference

pub fn try_set_property( &self, source_id: TransceiverId, key: ValueContainer, val: ValueContainer, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

Sets a property on the value if applicable (e.g. for maps)

pub fn try_set_text_property( &self, source_id: TransceiverId, key: &str, val: ValueContainer, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

Sets a text property on the value if applicable (e.g. for structs)

pub fn try_set_numeric_property( &self, source_id: TransceiverId, index: u32, val: ValueContainer, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

pub fn try_set_value<T: Into<ValueContainer>>( &self, source_id: TransceiverId, value: T, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

Sets a value on the reference if it is mutable and the type is compatible.

pub fn try_push_value<T: Into<ValueContainer>>( &self, source_id: TransceiverId, value: T, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

Pushes a value to the reference if it is a list.

pub fn try_delete_property( &self, source_id: TransceiverId, key: ValueContainer, memory: &RefCell<Memory>, ) -> Result<(), AccessError>

Tries to delete a property from the reference if it is a map. Notifies observers if successful.

pub fn try_clear(&self, source_id: TransceiverId) -> Result<(), AccessError>

Source

impl Reference

pub fn observe(&self, observer: Observer) -> Result<u32, ObserverError>

Adds an observer to this reference that will be notified on value changes. Returns an error if the reference is immutable or a type reference. The returned u32 is an observer ID that can be used to remove the observer later.

pub fn unobserve(&self, observer_id: u32) -> Result<(), ObserverError>

Removes an observer by its ID. Returns an error if the observer ID is not found or the reference is immutable.

pub fn update_observer_options( &self, observer_id: u32, options: ObserveOptions, ) -> Result<(), ObserverError>

Updates the options for an existing observer by its ID. Returns an error if the observer ID is not found or the reference is immutable.

pub fn observers_ids(&self) -> Vec<u32>

Returns a list of all observer IDs currently registered to this reference. A type reference or immutable reference will always return an empty list.

pub fn unobserve_all(&self) -> Result<(), ObserverError>

Removes all observers from this reference. Returns an error if the reference is immutable.

pub fn notify_observers(&self, dif: &DIFUpdate)

Notifies all observers of a change represented by the given DIFUpdate.

pub fn has_observers(&self) -> bool

Check if there are any observers registered

Source

impl Reference

pub fn supports_clear(&self) -> bool

Checks if the reference supports clear operation

pub fn supports_property_access(&self) -> bool

Checks if the reference has property access. This is true for maps, lists and text. For other types, this returns false. Note that this does not check if a specific property exists, only if property access is generally possible.

pub fn supports_text_property_access(&self) -> bool

Checks if the reference has text property access. This is true for maps.

pub fn supports_numeric_property_access(&self) -> bool

Checks if the reference has numeric property access. This is true for maps, lists and text.

pub fn supports_push(&self) -> bool

Checks if the reference supports push operation

Source

impl Reference

pub fn pointer_address(&self) -> Option<PointerAddress>

pub fn set_pointer_address(&self, pointer_address: PointerAddress)

Sets the pointer address of the reference. Panics if the reference already has a pointer address.

pub fn is_mutable(&self) -> bool

Checks if the reference is mutable. A reference is mutable if it is a mutable ValueReference and all references in the chain are mutable. TypeReferences are always immutable. FIXME #284: Do we really need this? Probably we already collapse the ref and then change it’s value and perform the mutability check on the most inner ref.

pub fn try_new_from_value_container( value_container: ValueContainer, allowed_type: Option<TypeContainer>, maybe_pointer_id: Option<PointerAddress>, mutability: ReferenceMutability, ) -> Result<Self, ReferenceCreationError>

Creates a new reference from a value container

pub fn new_from_type( type_value: Type, maybe_pointer_address: Option<PointerAddress>, maybe_nominal_type_declaration: Option<NominalTypeDeclaration>, ) -> Self

pub fn try_mut_from( value_container: ValueContainer, ) -> Result<Self, ReferenceCreationError>

pub fn try_final_from( value_container: ValueContainer, ) -> Result<Self, ReferenceCreationError>

Creates a final reference from a value container. If the value container is a reference, it must be a final reference, otherwise an error is returned. If the value container is a value, a final reference to that value is created.

pub fn collapse_reference_chain(&self) -> Reference

Collapses the reference chain to most inner reference to which this reference points.

pub fn collapse_to_value(&self) -> Rc<RefCell<Value>>

Converts a reference to its current value, collapsing any reference chains and converting type references to type values.

pub fn value_container(&self) -> ValueContainer

pub fn upgrade_inner_combined_values_to_references(&self)

upgrades all inner combined values (e.g. map properties) to references

pub fn bind_child(&self, child: ValueContainer) -> ValueContainer

Binds a child value to this reference, ensuring the child is a reference if it is a combined value

pub fn allowed_type(&self) -> TypeContainer

pub fn actual_type(&self) -> TypeContainer

pub fn is_type(&self) -> bool

pub fn non_final_reference(&self) -> Option<Rc<RefCell<ValueReference>>>

Returns a non-final reference to the ValueReference if this is a non-final ValueReference.

pub fn set_value_container( &self, new_value_container: ValueContainer, ) -> Result<(), AssignmentError>

Sets the value container of the reference if it is mutable. If the reference is immutable, an error is returned.

Source

impl Reference

Getter for references

pub fn try_get_property<T: Into<ValueContainer>>( &self, key: T, ) -> Result<ValueContainer, AccessError>

Gets a property on the value if applicable (e.g. for map and structs)

pub fn try_get_text_property( &self, key: &str, ) -> Result<ValueContainer, AccessError>

Gets a text property from the value if applicable (e.g. for structs)

pub fn get_numeric_property( &self, index: u32, ) -> Result<ValueContainer, AccessError>

Gets a numeric property from the value if applicable (e.g. for lists and text)

Source

impl Reference

pub fn ensure_pointer_address(&self, memory: &RefCell<Memory>) -> PointerAddress

Returns the PointerAddress of this reference, if it has one. Otherwise, it registers the reference in the given memory and returns the newly assigned PointerAddress.