pub struct ValueReference {
pub value_container: ValueContainer,
pub pointer_address: Option<PointerAddress>,
pub allowed_type: TypeContainer,
pub observers: FreeHashMap<u32, Observer>,
pub mutability: ReferenceMutability,
}Fields
value_container: ValueContainerthe value that this reference points to
pointer_address: Option<PointerAddress>pointer id, can be initialized as None for local pointers
allowed_type: TypeContainercustom type for the pointer that the Datex value is allowed to reference
observers: FreeHashMap<u32, Observer>list of observer callbacks
mutability: ReferenceMutabilityImplementations
Sourceimpl ValueReference
impl ValueReference
pub fn new( value_container: ValueContainer, pointer_address: Option<PointerAddress>, allowed_type: TypeContainer, mutability: ReferenceMutability, ) -> Self
Sourceimpl ValueReference
impl ValueReference
pub fn pointer_address(&self) -> &Option<PointerAddress>
pub fn current_value_container(&self) -> &ValueContainer
pub fn resolve_current_value(&self) -> Rc<RefCell<Value>>
pub fn is_mutable(&self) -> bool
pub fn is_final(&self) -> bool