pub enum ExecutionContext {
Local(LocalExecutionContext),
Remote(RemoteExecutionContext),
}Expand description
An execution context holds the persistent state for executing multiple scripts sequentially within the same context. This can be either a local context, which is used for executing scripts in the same process, or a remote context, which is used for executing scripts on a remote endpoint.
Variants
Local(LocalExecutionContext)
Remote(RemoteExecutionContext)
Implementations
Sourceimpl ExecutionContext
impl ExecutionContext
pub fn local( execution_mode: ExecutionMode, runtime: Rc<RuntimeInternal>, ) -> Self
Sourcepub fn local_static(runtime: Rc<RuntimeInternal>) -> Self
pub fn local_static(runtime: Rc<RuntimeInternal>) -> Self
Creates a new local static execution context (can only be used once).
Sourcepub fn local_unbounded(runtime: Rc<RuntimeInternal>) -> Self
pub fn local_unbounded(runtime: Rc<RuntimeInternal>) -> Self
Creates a new local execution context (can be used multiple times).
Sourcepub fn local_debug(
execution_mode: ExecutionMode,
runtime: Rc<RuntimeInternal>,
) -> Self
pub fn local_debug( execution_mode: ExecutionMode, runtime: Rc<RuntimeInternal>, ) -> Self
Creates a new local execution context with verbose mode enabled, providing more log outputs for debugging purposes.
Sourceimpl ExecutionContext
impl ExecutionContext
Sourcepub fn execute_dxb_sync(
&mut self,
dxb: &[u8],
) -> Result<Option<ValueContainer>, ExecutionError>
pub fn execute_dxb_sync( &mut self, dxb: &[u8], ) -> Result<Option<ValueContainer>, ExecutionError>
Executes DXB in a local execution context.
pub async fn execute_dxb( &mut self, dxb: &[u8], ) -> Result<Option<ValueContainer>, ExecutionError>
Sourcepub fn memory_dump(&self) -> Option<MemoryDump>
pub fn memory_dump(&self) -> Option<MemoryDump>
Returns a memory dump of the current state of the execution context if available.