pub fn execution_loop(
state: RuntimeExecutionState,
dxb_body: Rc<RefCell<Vec<u8>>>,
interrupt_provider: InterruptProvider,
) -> impl Iterator<Item = Result<ExternalExecutionInterrupt, ExecutionError>>Expand description
Main execution loop that drives the execution of the DXB body The interrupt_provider is used to provide results for synchronous or asynchronous I/O operations