pub struct Memory { /* private fields */ }Implementations
Sourceimpl Memory
impl Memory
Sourcepub fn new(endpoint: Endpoint) -> Memory
pub fn new(endpoint: Endpoint) -> Memory
Creates a new, Memory instance with the core library loaded.
Sourcepub fn register_reference(&mut self, reference: &Reference) -> PointerAddress
pub fn register_reference(&mut self, reference: &Reference) -> PointerAddress
Registers a new reference in memory. If the reference has no PointerAddress, a new local one is generated. If the reference is already registered (has a PointerAddress), the existing address is returned and no new registration is done. Returns the PointerAddress of the registered reference.
Sourcepub fn get_reference(
&self,
pointer_address: &PointerAddress,
) -> Option<&Reference>
pub fn get_reference( &self, pointer_address: &PointerAddress, ) -> Option<&Reference>
Returns a reference stored at the given PointerAddress, if it exists.
pub fn get_value_reference( &self, pointer_address: &PointerAddress, ) -> Option<&Rc<RefCell<ValueReference>>>
pub fn get_type_reference( &self, pointer_address: &PointerAddress, ) -> Option<&Rc<RefCell<TypeReference>>>
Sourcepub fn get_core_reference(&self, pointer_id: CoreLibPointerId) -> &Reference
pub fn get_core_reference(&self, pointer_id: CoreLibPointerId) -> &Reference
Helper function to get a core value directly from memory
Sourcepub fn get_core_type_reference(
&self,
pointer_id: CoreLibPointerId,
) -> Result<Rc<RefCell<TypeReference>>, IllegalTypeError>
pub fn get_core_type_reference( &self, pointer_id: CoreLibPointerId, ) -> Result<Rc<RefCell<TypeReference>>, IllegalTypeError>
Helper function to get a core type directly from memory if it can be used as a type
Sourcepub fn get_core_type_reference_unchecked(
&self,
pointer_id: CoreLibPointerId,
) -> Rc<RefCell<TypeReference>>
pub fn get_core_type_reference_unchecked( &self, pointer_id: CoreLibPointerId, ) -> Rc<RefCell<TypeReference>>
Helper function to get a core type directly from memory, asserting that is can be used as a type Panics if the core type is not found or cannot be used as a type.
Sourcepub fn get_pointer_address_from_raw_full_address(
&self,
raw_address: RawFullPointerAddress,
) -> PointerAddress
pub fn get_pointer_address_from_raw_full_address( &self, raw_address: RawFullPointerAddress, ) -> PointerAddress
Takes a RawFullPointerAddress and converts it to a PointerAddress::Local or PointerAddress::Remote, depending on whether the pointer origin id matches the local endpoint.
Sourcepub fn get_new_local_address(&mut self) -> PointerAddress
pub fn get_new_local_address(&mut self) -> PointerAddress
Creates a new unique local PointerAddress.