Reexport of Mutex that works in both std and no_std environments.
Type Aliases
- Mutex
- A primitive that synchronizes the execution of multiple threads. See
mutex::Mutexfor documentation.
Reexport of Mutex that works in both std and no_std environments.
mutex::Mutex for documentation.