pub trait PartialOrd<Rhs = Self>: PartialEq<Rhs>where
Rhs: ?Sized,{
// Required method
fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>;
// Provided methods
fn lt(&self, other: &Rhs) -> bool { ... }
fn le(&self, other: &Rhs) -> bool { ... }
fn gt(&self, other: &Rhs) -> bool { ... }
fn ge(&self, other: &Rhs) -> bool { ... }
}Expand description
Trait for types that form a partial order.
The lt, le, gt, and ge methods of this trait can be called using the <, <=, >, and
>= operators, respectively.
This trait should only contain the comparison logic for a type if one plans on only
implementing PartialOrd but not Ord. Otherwise the comparison logic should be in Ord
and this trait implemented with Some(self.cmp(other)).
The methods of this trait must be consistent with each other and with those of PartialEq.
The following conditions must hold:
a == bif and only ifpartial_cmp(a, b) == Some(Equal).a < bif and only ifpartial_cmp(a, b) == Some(Less)a > bif and only ifpartial_cmp(a, b) == Some(Greater)a <= bif and only ifa < b || a == ba >= bif and only ifa > b || a == ba != bif and only if!(a == b).
Conditions 2–5 above are ensured by the default implementation. Condition 6 is already ensured
by PartialEq.
If Ord is also implemented for Self and Rhs, it must also be consistent with
partial_cmp (see the documentation of that trait for the exact requirements). It’s easy to
accidentally make them disagree by deriving some of the traits and manually implementing others.
The comparison relations must satisfy the following conditions (for all a, b, c of type
A, B, C):
- Transitivity: if
A: PartialOrd<B>andB: PartialOrd<C>andA: PartialOrd<C>, thena < bandb < cimpliesa < c. The same must hold for both==and>. This must also work for longer chains, such as whenA: PartialOrd<B>,B: PartialOrd<C>,C: PartialOrd<D>, andA: PartialOrd<D>all exist. - Duality: if
A: PartialOrd<B>andB: PartialOrd<A>, thena < bif and only ifb > a.
Note that the B: PartialOrd<A> (dual) and A: PartialOrd<C> (transitive) impls are not forced
to exist, but these requirements apply whenever they do exist.
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Cross-crate considerations
Upholding the requirements stated above can become tricky when one crate implements PartialOrd
for a type of another crate (i.e., to allow comparing one of its own types with a type from the
standard library). The recommendation is to never implement this trait for a foreign type. In
other words, such a crate should do impl PartialOrd<ForeignType> for LocalType, but it should
not do impl PartialOrd<LocalType> for ForeignType.
This avoids the problem of transitive chains that criss-cross crate boundaries: for all local
types T, you may assume that no other crate will add impls that allow comparing T < U. In
other words, if other crates add impls that allow building longer transitive chains U1 < ... < T < V1 < ..., then all the types that appear to the right of T must be types that the crate
defining T already knows about. This rules out transitive chains where downstream crates can
add new impls that “stitch together” comparisons of foreign types in ways that violate
transitivity.
Not having such foreign impls also avoids forward compatibility issues where one crate adding
more PartialOrd implementations can cause build failures in downstream crates.
Corollaries
The following corollaries follow from the above requirements:
- irreflexivity of
<and>:!(a < a),!(a > a) - transitivity of
>: ifa > bandb > cthena > c - duality of
partial_cmp:partial_cmp(a, b) == partial_cmp(b, a).map(Ordering::reverse)
Strict and non-strict partial orders
The < and > operators behave according to a strict partial order. However, <= and >=
do not behave according to a non-strict partial order. That is because mathematically, a
non-strict partial order would require reflexivity, i.e. a <= a would need to be true for
every a. This isn’t always the case for types that implement PartialOrd, for example:
let a = f64::sqrt(-1.0);
assert_eq!(a <= a, false);Derivable
This trait can be used with #[derive].
When derived on structs, it will produce a
lexicographic ordering based on the
top-to-bottom declaration order of the struct’s members.
When derived on enums, variants are primarily ordered by their discriminants. Secondarily,
they are ordered by their fields. By default, the discriminant is smallest for variants at the
top, and largest for variants at the bottom. Here’s an example:
#[derive(PartialEq, PartialOrd)]
enum E {
Top,
Bottom,
}
assert!(E::Top < E::Bottom);However, manually setting the discriminants can override this default behavior:
#[derive(PartialEq, PartialOrd)]
enum E {
Top = 2,
Bottom = 1,
}
assert!(E::Bottom < E::Top);How can I implement PartialOrd?
PartialOrd only requires implementation of the partial_cmp method, with the others
generated from default implementations.
However it remains possible to implement the others separately for types which do not have a
total order. For example, for floating point numbers, NaN < 0 == false and NaN >= 0 == false
(cf. IEEE 754-2008 section 5.11).
PartialOrd requires your type to be PartialEq.
If your type is Ord, you can implement partial_cmp by using cmp:
use std::cmp::Ordering;
struct Person {
id: u32,
name: String,
height: u32,
}
impl PartialOrd for Person {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl Ord for Person {
fn cmp(&self, other: &Self) -> Ordering {
self.height.cmp(&other.height)
}
}
impl PartialEq for Person {
fn eq(&self, other: &Self) -> bool {
self.height == other.height
}
}
impl Eq for Person {}You may also find it useful to use partial_cmp on your type’s fields. Here is an example of
Person types who have a floating-point height field that is the only field to be used for
sorting:
use std::cmp::Ordering;
struct Person {
id: u32,
name: String,
height: f64,
}
impl PartialOrd for Person {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
self.height.partial_cmp(&other.height)
}
}
impl PartialEq for Person {
fn eq(&self, other: &Self) -> bool {
self.height == other.height
}
}Examples of incorrect PartialOrd implementations
use std::cmp::Ordering;
#[derive(PartialEq, Debug)]
struct Character {
health: u32,
experience: u32,
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.health.cmp(&other.health))
}
}
let a = Character {
health: 10,
experience: 5,
};
let b = Character {
health: 10,
experience: 77,
};
// Mistake: `PartialEq` and `PartialOrd` disagree with each other.
assert_eq!(a.partial_cmp(&b).unwrap(), Ordering::Equal); // a == b according to `PartialOrd`.
assert_ne!(a, b); // a != b according to `PartialEq`.Examples
let x: u32 = 0;
let y: u32 = 1;
assert_eq!(x < y, true);
assert_eq!(x.lt(&y), true);Required Methods
1.0.0 · Sourcefn partial_cmp(&self, other: &Rhs) -> Option<Ordering>
fn partial_cmp(&self, other: &Rhs) -> Option<Ordering>
This method returns an ordering between self and other values if one exists.
Examples
use std::cmp::Ordering;
let result = 1.0.partial_cmp(&2.0);
assert_eq!(result, Some(Ordering::Less));
let result = 1.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Equal));
let result = 2.0.partial_cmp(&1.0);
assert_eq!(result, Some(Ordering::Greater));When comparison is impossible:
let result = f64::NAN.partial_cmp(&1.0);
assert_eq!(result, None);Provided Methods
1.0.0 · Sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
Tests less than (for self and other) and is used by the < operator.
Examples
assert_eq!(1.0 < 1.0, false);
assert_eq!(1.0 < 2.0, true);
assert_eq!(2.0 < 1.0, false);1.0.0 · Sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
Tests less than or equal to (for self and other) and is used by the
<= operator.
Examples
assert_eq!(1.0 <= 1.0, true);
assert_eq!(1.0 <= 2.0, true);
assert_eq!(2.0 <= 1.0, false);Implementors
impl PartialOrd for InterfacePriority
impl PartialOrd for AsciiChar
impl PartialOrd for Infallible
impl PartialOrd for ErrorKind
impl PartialOrd for IpAddr
impl PartialOrd for SocketAddr
impl PartialOrd for Ordering
impl PartialOrd for ASN1TimeZone
impl PartialOrd for LineEnding
impl PartialOrd for byteorder::BigEndian
impl PartialOrd for byteorder::LittleEndian
impl PartialOrd for chrono::month::Month
impl PartialOrd for const_oid::error::Error
impl PartialOrd for Class
impl PartialOrd for der::tag::Tag
impl PartialOrd for TagMode
impl PartialOrd for ExtensionType
impl PartialOrd for GeneralCategory
impl PartialOrd for IpAddrRange
impl PartialOrd for IpNet
impl PartialOrd for IpSubnets
impl PartialOrd for log::Level
impl PartialOrd for log::LevelFilter
impl PartialOrd for GlobPattern
impl PartialOrd for InsertError
impl PartialOrd for PosixFadviseAdvice
impl PartialOrd for AioFsyncMode
impl PartialOrd for LioMode
impl PartialOrd for MmapAdvise
impl PartialOrd for Event
impl PartialOrd for Request
impl PartialOrd for QuotaFmt
impl PartialOrd for QuotaType
impl PartialOrd for RebootMode
impl PartialOrd for Resource
impl PartialOrd for UsageWho
impl PartialOrd for SigmaskHow
impl PartialOrd for Signal
impl PartialOrd for BaudRate
impl PartialOrd for FlowArg
impl PartialOrd for FlushArg
impl PartialOrd for SetArg
impl PartialOrd for SpecialCharacterIndices
impl PartialOrd for nix::sys::timerfd::ClockId
impl PartialOrd for nix::sys::wait::Id
impl PartialOrd for Sign
impl PartialOrd for Utf8Sequence
impl PartialOrd for Contract
impl PartialOrd for time::month::Month
impl PartialOrd for Section
impl PartialOrd for Yaml
impl PartialOrd for PCBit
impl PartialOrd for TagClass
impl PartialOrd for BERMode
impl PartialOrd for zerocopy::byteorder::BigEndian
impl PartialOrd for zerocopy::byteorder::LittleEndian
impl PartialOrd for bool
impl PartialOrd for char
impl PartialOrd for f16
impl PartialOrd for f32
impl PartialOrd for f64
impl PartialOrd for f128
impl PartialOrd for i8
impl PartialOrd for i16
impl PartialOrd for i32
impl PartialOrd for i64
impl PartialOrd for i128
impl PartialOrd for isize
impl PartialOrd for !
impl PartialOrd for str
Implements comparison operations on strings.
Strings are compared lexicographically by their byte values. This compares Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Comparing strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl PartialOrd for u8
impl PartialOrd for u16
impl PartialOrd for u32
impl PartialOrd for u64
impl PartialOrd for u128
impl PartialOrd for ()
impl PartialOrd for usize
impl PartialOrd for datex_core::time::Duration
impl PartialOrd for datex_core::time::Instant
impl PartialOrd for SystemTime
impl PartialOrd for TypeId
impl PartialOrd for CpuidResult
impl PartialOrd for ByteStr
impl PartialOrd for ByteString
impl PartialOrd for CStr
impl PartialOrd for CString
impl PartialOrd for OsStr
impl PartialOrd for OsString
impl PartialOrd for datex_core::stdlib::fmt::Error
impl PartialOrd for PhantomPinned
impl PartialOrd for Ipv4Addr
impl PartialOrd for Ipv6Addr
impl PartialOrd for SocketAddrV4
impl PartialOrd for SocketAddrV6
impl PartialOrd for Location<'_>
impl PartialOrd for Path
impl PartialOrd for PathBuf
impl PartialOrd for Alignment
impl PartialOrd for String
impl PartialOrd for aead::Error
impl PartialOrd for aho_corasick::util::primitives::PatternID
impl PartialOrd for aho_corasick::util::primitives::StateID
impl PartialOrd for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
impl PartialOrd for asn1_rs::asn1_types::utctime::UtcTime
impl PartialOrd for ASN1DateTime
impl PartialOrd for Base64Bcrypt
impl PartialOrd for Base64Crypt
impl PartialOrd for Base64ShaCrypt
impl PartialOrd for Base64
impl PartialOrd for Base64Unpadded
impl PartialOrd for Base64Url
impl PartialOrd for Base64UrlUnpadded
impl PartialOrd for BigDecimal
impl PartialOrd for BigDecimalRef<'_>
impl PartialOrd for Bytes
impl PartialOrd for BytesMut
impl PartialOrd for Months
impl PartialOrd for NaiveDate
impl PartialOrd for NaiveDateDaysIterator
impl PartialOrd for NaiveDateWeeksIterator
impl PartialOrd for NaiveDateTime
impl PartialOrd for IsoWeek
impl PartialOrd for Days
impl PartialOrd for NaiveTime
impl PartialOrd for TimeDelta
impl PartialOrd for WeekdaySet
impl PartialOrd for const_oid::ObjectIdentifier
impl PartialOrd for Limb
impl PartialOrd for Any
impl PartialOrd for BitString
impl PartialOrd for BmpString
impl PartialOrd for der::asn1::generalized_time::GeneralizedTime
impl PartialOrd for Ia5String
impl PartialOrd for Int
impl PartialOrd for der::asn1::integer::uint::allocating::Uint
impl PartialOrd for Null
impl PartialOrd for OctetString
impl PartialOrd for PrintableString
impl PartialOrd for TeletexString
impl PartialOrd for der::asn1::utc_time::UtcTime
impl PartialOrd for der::datetime::DateTime
impl PartialOrd for IndefiniteLength
impl PartialOrd for Length
impl PartialOrd for TagNumber
impl PartialOrd for RecoveryId
impl PartialOrd for Errno
impl PartialOrd for HeaderValue
impl PartialOrd for StatusCode
impl PartialOrd for Authority
Case-insensitive ordering
Examples
let authority: Authority = "DEF.com".parse().unwrap();
assert!(authority < "ghi.com");
assert!(authority > "abc.com");impl PartialOrd for PathAndQuery
impl PartialOrd for Version
impl PartialOrd for HttpDate
impl PartialOrd for ReasonPhrase
impl PartialOrd for Other
impl PartialOrd for icu_locale_core::extensions::private::other::Subtag
impl PartialOrd for Private
impl PartialOrd for Fields
impl PartialOrd for icu_locale_core::extensions::transform::key::Key
impl PartialOrd for icu_locale_core::extensions::transform::value::Value
impl PartialOrd for Attribute
impl PartialOrd for Attributes
impl PartialOrd for icu_locale_core::extensions::unicode::key::Key
impl PartialOrd for Keywords
impl PartialOrd for SubdivisionId
impl PartialOrd for SubdivisionSuffix
impl PartialOrd for icu_locale_core::extensions::unicode::value::Value
impl PartialOrd for Language
impl PartialOrd for Region
impl PartialOrd for icu_locale_core::subtags::script::Script
impl PartialOrd for icu_locale_core::subtags::Subtag
impl PartialOrd for Variant
impl PartialOrd for Variants
impl PartialOrd for GeneralCategoryULE
impl PartialOrd for BidiClass
impl PartialOrd for CanonicalCombiningClass
impl PartialOrd for EastAsianWidth
impl PartialOrd for GeneralCategoryOutOfBoundsError
impl PartialOrd for GraphemeClusterBreak
impl PartialOrd for HangulSyllableType
impl PartialOrd for IndicConjunctBreak
impl PartialOrd for IndicSyllabicCategory
impl PartialOrd for JoiningType
impl PartialOrd for LineBreak
impl PartialOrd for icu_properties::props::Script
impl PartialOrd for SentenceBreak
impl PartialOrd for VerticalOrientation
impl PartialOrd for WordBreak
impl PartialOrd for DataMarkerId
impl PartialOrd for DataMarkerIdHash
impl PartialOrd for DataMarkerInfo
impl PartialOrd for DataMarkerAttributes
impl PartialOrd for DataRequestMetadata
impl PartialOrd for Ipv4AddrRange
impl PartialOrd for Ipv6AddrRange
impl PartialOrd for Ipv4Net
impl PartialOrd for Ipv4Subnets
impl PartialOrd for Ipv6Net
impl PartialOrd for Ipv6Subnets
impl PartialOrd for CodeActionKind
impl PartialOrd for SemanticTokenModifier
impl PartialOrd for SemanticTokenType
impl PartialOrd for TokenFormat
impl PartialOrd for DiagnosticSeverity
impl PartialOrd for DidChangeWatchedFilesRegistrationOptions
impl PartialOrd for FileSystemWatcher
impl PartialOrd for lsp_types::Position
impl PartialOrd for PositionEncodingKind
impl PartialOrd for RelativePattern
impl PartialOrd for WatchKind
impl PartialOrd for WorkspaceFolder
impl PartialOrd for Mime
impl PartialOrd for Interest
impl PartialOrd for Token
impl PartialOrd for AtFlags
impl PartialOrd for FallocateFlags
impl PartialOrd for FdFlag
impl PartialOrd for OFlag
impl PartialOrd for RenameFlags
impl PartialOrd for SealFlag
impl PartialOrd for SpliceFFlags
impl PartialOrd for DeleteModuleFlags
impl PartialOrd for ModuleInitFlags
impl PartialOrd for MntFlags
impl PartialOrd for nix::mount::linux::MsFlags
impl PartialOrd for MQ_OFlag
impl PartialOrd for InterfaceFlags
impl PartialOrd for PollFlags
impl PartialOrd for CloneFlags
impl PartialOrd for EpollCreateFlags
impl PartialOrd for EpollFlags
impl PartialOrd for EfdFlags
impl PartialOrd for AddWatchFlags
impl PartialOrd for InitFlags
impl PartialOrd for WatchDescriptor
impl PartialOrd for MemFdCreateFlag
impl PartialOrd for MRemapFlags
impl PartialOrd for MapFlags
impl PartialOrd for MlockAllFlags
impl PartialOrd for nix::sys::mman::MsFlags
impl PartialOrd for ProtFlags
impl PartialOrd for Persona
impl PartialOrd for Options
impl PartialOrd for QuotaValidFlags
impl PartialOrd for SaFlags
impl PartialOrd for SfdFlags
impl PartialOrd for MsgFlags
impl PartialOrd for SockFlag
impl PartialOrd for TimestampingFlag
impl PartialOrd for Mode
impl PartialOrd for SFlag
impl PartialOrd for FsFlags
impl PartialOrd for ControlFlags
impl PartialOrd for InputFlags
impl PartialOrd for LocalFlags
impl PartialOrd for OutputFlags
impl PartialOrd for TimeSpec
impl PartialOrd for TimeVal
impl PartialOrd for TimerSetTimeFlags
impl PartialOrd for TimerFlags
impl PartialOrd for WaitPidFlag
impl PartialOrd for nix::time::ClockId
impl PartialOrd for AccessFlags
impl PartialOrd for Pid
impl PartialOrd for BigInt
impl PartialOrd for BigUint
impl PartialOrd for Asn1Integer
impl PartialOrd for Asn1IntegerRef
impl PartialOrd for Asn1Time
impl PartialOrd for Asn1TimeRef
impl PartialOrd for BigNum
impl PartialOrd for BigNumRef
impl PartialOrd for CMSOptions
impl PartialOrd for OcspFlag
impl PartialOrd for Pkcs7Flags
impl PartialOrd for ExtensionContext
impl PartialOrd for ShutdownState
impl PartialOrd for SslMode
impl PartialOrd for SslOptions
impl PartialOrd for SslSessionCacheMode
impl PartialOrd for SslVerifyMode
impl PartialOrd for X509
impl PartialOrd for X509Ref
impl PartialOrd for X509CheckFlags
impl PartialOrd for X509VerifyFlags
impl PartialOrd for p256::arithmetic::scalar::Scalar
impl PartialOrd for NistP256
impl PartialOrd for p384::arithmetic::scalar::Scalar
impl PartialOrd for NistP384
impl PartialOrd for Integer
impl PartialOrd for PotentialCodePoint
impl PartialOrd for PotentialUtf8
impl PartialOrd for PotentialUtf16
impl PartialOrd for LazyStateID
impl PartialOrd for Unit
impl PartialOrd for NonMaxUsize
impl PartialOrd for regex_automata::util::primitives::PatternID
impl PartialOrd for SmallIndex
impl PartialOrd for regex_automata::util::primitives::StateID
impl PartialOrd for regex_syntax::ast::Position
impl PartialOrd for Span
impl PartialOrd for Literal
impl PartialOrd for ClassBytesRange
impl PartialOrd for ClassUnicodeRange
impl PartialOrd for Utf8Range
impl PartialOrd for UnixTime
impl PartialOrd for SigId
impl PartialOrd for SmolStr
impl PartialOrd for FontStyle
impl PartialOrd for MatchPower
impl PartialOrd for Scope
impl PartialOrd for time::date::Date
impl PartialOrd for time::duration::Duration
impl PartialOrd for OffsetDateTime
impl PartialOrd for PrimitiveDateTime
impl PartialOrd for Time
impl PartialOrd for UtcDateTime
impl PartialOrd for UtcOffset
impl PartialOrd for AnyDelimiterCodec
impl PartialOrd for BytesCodec
impl PartialOrd for LinesCodec
impl PartialOrd for Ready
impl PartialOrd for tokio::runtime::task::id::Id
impl PartialOrd for tokio::time::instant::Instant
impl PartialOrd for tracing_core::metadata::Level
impl PartialOrd for tracing_core::metadata::LevelFilter
impl PartialOrd for ATerm
impl PartialOrd for B0
impl PartialOrd for B1
impl PartialOrd for Z0
impl PartialOrd for Equal
impl PartialOrd for Greater
impl PartialOrd for Less
impl PartialOrd for UTerm
impl PartialOrd for Url
URLs compare like their serialization.
impl PartialOrd for Braced
impl PartialOrd for Hyphenated
impl PartialOrd for Simple
impl PartialOrd for Urn
impl PartialOrd for Uuid
impl PartialOrd for ASN1Time
impl PartialOrd for TaggedDerValue
impl PartialOrd for yasna::models::oid::ObjectIdentifier
impl PartialOrd for yasna::models::time::GeneralizedTime
impl PartialOrd for UTCTime
impl PartialOrd for yasna::Tag
impl PartialOrd for CharULE
impl PartialOrd for Index8
impl PartialOrd for Index16
impl PartialOrd for Index32
impl PartialOrd<IpAddr> for Ipv4Addr
impl PartialOrd<IpAddr> for Ipv6Addr
impl PartialOrd<Level> for log::LevelFilter
impl PartialOrd<LevelFilter> for log::Level
impl PartialOrd<char> for PotentialCodePoint
impl PartialOrd<i8> for &BigDecimal
impl PartialOrd<i8> for BigDecimal
impl PartialOrd<i8> for BigDecimalRef<'_>
impl PartialOrd<i16> for &BigDecimal
impl PartialOrd<i16> for BigDecimal
impl PartialOrd<i16> for BigDecimalRef<'_>
impl PartialOrd<i32> for &BigDecimal
impl PartialOrd<i32> for BigDecimal
impl PartialOrd<i32> for BigDecimalRef<'_>
impl PartialOrd<i64> for &BigDecimal
impl PartialOrd<i64> for BigDecimal
impl PartialOrd<i64> for BigDecimalRef<'_>
impl PartialOrd<i128> for &BigDecimal
impl PartialOrd<i128> for BigDecimal
impl PartialOrd<i128> for BigDecimalRef<'_>
impl PartialOrd<str> for OsStr
impl PartialOrd<str> for OsString
impl PartialOrd<str> for Bytes
impl PartialOrd<str> for BytesMut
impl PartialOrd<str> for HeaderValue
impl PartialOrd<str> for Authority
impl PartialOrd<str> for PathAndQuery
impl PartialOrd<str> for PotentialUtf8
impl PartialOrd<u8> for &BigDecimal
impl PartialOrd<u8> for BigDecimal
impl PartialOrd<u8> for BigDecimalRef<'_>
impl PartialOrd<u16> for &BigDecimal
impl PartialOrd<u16> for BigDecimal
impl PartialOrd<u16> for BigDecimalRef<'_>
impl PartialOrd<u32> for &BigDecimal
impl PartialOrd<u32> for BigDecimal
impl PartialOrd<u32> for BigDecimalRef<'_>
impl PartialOrd<u64> for &BigDecimal
impl PartialOrd<u64> for BigDecimal
impl PartialOrd<u64> for BigDecimalRef<'_>
impl PartialOrd<u128> for &BigDecimal
impl PartialOrd<u128> for BigDecimal
impl PartialOrd<u128> for BigDecimalRef<'_>
impl PartialOrd<Duration> for time::duration::Duration
impl PartialOrd<SystemTime> for OffsetDateTime
impl PartialOrd<SystemTime> for UtcDateTime
impl PartialOrd<OsStr> for Path
impl PartialOrd<OsStr> for PathBuf
impl PartialOrd<OsString> for Path
impl PartialOrd<OsString> for PathBuf
impl PartialOrd<Ipv4Addr> for IpAddr
impl PartialOrd<Ipv6Addr> for IpAddr
impl PartialOrd<Path> for OsStr
impl PartialOrd<Path> for OsString
impl PartialOrd<Path> for PathBuf
impl PartialOrd<PathBuf> for OsStr
impl PartialOrd<PathBuf> for OsString
impl PartialOrd<PathBuf> for Path
impl PartialOrd<String> for Bytes
impl PartialOrd<String> for BytesMut
impl PartialOrd<String> for HeaderValue
impl PartialOrd<String> for Authority
impl PartialOrd<String> for PathAndQuery
impl PartialOrd<Vec<u8>> for Bytes
impl PartialOrd<Vec<u8>> for BytesMut
impl PartialOrd<Bytes> for &str
impl PartialOrd<Bytes> for &[u8]
impl PartialOrd<Bytes> for str
impl PartialOrd<Bytes> for String
impl PartialOrd<Bytes> for datex_core::stdlib::vec::Vec<u8>
impl PartialOrd<Bytes> for [u8]
impl PartialOrd<BytesMut> for &str
impl PartialOrd<BytesMut> for &[u8]
impl PartialOrd<BytesMut> for str
impl PartialOrd<BytesMut> for String
impl PartialOrd<BytesMut> for datex_core::stdlib::vec::Vec<u8>
impl PartialOrd<BytesMut> for [u8]
impl PartialOrd<HeaderValue> for str
impl PartialOrd<HeaderValue> for String
impl PartialOrd<HeaderValue> for [u8]
impl PartialOrd<Authority> for str
impl PartialOrd<Authority> for String
impl PartialOrd<PathAndQuery> for str
impl PartialOrd<PathAndQuery> for String
impl PartialOrd<Asn1Time> for &Asn1TimeRef
impl PartialOrd<Asn1Time> for Asn1TimeRef
impl PartialOrd<Asn1TimeRef> for Asn1Time
impl PartialOrd<BigNum> for BigNumRef
impl PartialOrd<BigNumRef> for BigNum
impl PartialOrd<X509> for X509Ref
impl PartialOrd<X509Ref> for X509
impl PartialOrd<PotentialCodePoint> for char
impl PartialOrd<PotentialUtf8> for str
impl PartialOrd<Duration> for datex_core::time::Duration
impl PartialOrd<OffsetDateTime> for SystemTime
impl PartialOrd<OffsetDateTime> for UtcDateTime
impl PartialOrd<UtcDateTime> for SystemTime
impl PartialOrd<UtcDateTime> for OffsetDateTime
impl PartialOrd<Level> for tracing_core::metadata::LevelFilter
impl PartialOrd<LevelFilter> for tracing_core::metadata::Level
impl PartialOrd<[u8]> for Bytes
impl PartialOrd<[u8]> for BytesMut
impl PartialOrd<[u8]> for HeaderValue
impl<'a> PartialOrd for Component<'a>
impl<'a> PartialOrd for datex_core::stdlib::path::Prefix<'a>
impl<'a> PartialOrd for PrefixDeclaration<'a>
impl<'a> PartialOrd for PhantomContravariantLifetime<'a>
impl<'a> PartialOrd for PhantomCovariantLifetime<'a>
impl<'a> PartialOrd for PhantomInvariantLifetime<'a>
impl<'a> PartialOrd for Components<'a>
impl<'a> PartialOrd for PrefixComponent<'a>
impl<'a> PartialOrd for AnyRef<'a>
impl<'a> PartialOrd for BitStringRef<'a>
impl<'a> PartialOrd for Ia5StringRef<'a>
impl<'a> PartialOrd for IntRef<'a>
impl<'a> PartialOrd for UintRef<'a>
impl<'a> PartialOrd for OctetStringRef<'a>
impl<'a> PartialOrd for PrintableStringRef<'a>
impl<'a> PartialOrd for TeletexStringRef<'a>
impl<'a> PartialOrd for Utf8StringRef<'a>
impl<'a> PartialOrd for VideotexStringRef<'a>
impl<'a> PartialOrd for Metadata<'a>
impl<'a> PartialOrd for MetadataBuilder<'a>
impl<'a> PartialOrd for Name<'a>
impl<'a> PartialOrd for LocalName<'a>
impl<'a> PartialOrd for Namespace<'a>
impl<'a> PartialOrd for quick_xml::name::Prefix<'a>
impl<'a> PartialOrd for QName<'a>
impl<'a> PartialOrd<&'a str> for Authority
impl<'a> PartialOrd<&'a str> for PathAndQuery
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, str>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, ByteStr>
impl<'a> PartialOrd<&'a ByteStr> for Cow<'a, [u8]>
impl<'a> PartialOrd<&'a OsStr> for Path
impl<'a> PartialOrd<&'a OsStr> for PathBuf
impl<'a> PartialOrd<&'a Path> for OsStr
impl<'a> PartialOrd<&'a Path> for OsString
impl<'a> PartialOrd<&'a Path> for PathBuf
impl<'a> PartialOrd<&'a Asn1TimeRef> for Asn1Time
impl<'a> PartialOrd<&ByteStr> for ByteString
impl<'a> PartialOrd<Cow<'_, str>> for ByteString
impl<'a> PartialOrd<Cow<'_, ByteStr>> for ByteString
impl<'a> PartialOrd<Cow<'_, [u8]>> for ByteString
impl<'a> PartialOrd<Cow<'a, str>> for &'a ByteStr
impl<'a> PartialOrd<Cow<'a, ByteStr>> for &'a ByteStr
impl<'a> PartialOrd<Cow<'a, OsStr>> for Path
impl<'a> PartialOrd<Cow<'a, OsStr>> for PathBuf
impl<'a> PartialOrd<Cow<'a, Path>> for OsStr
impl<'a> PartialOrd<Cow<'a, Path>> for OsString
impl<'a> PartialOrd<Cow<'a, Path>> for Path
impl<'a> PartialOrd<Cow<'a, Path>> for PathBuf
impl<'a> PartialOrd<Cow<'a, [u8]>> for &'a ByteStr
impl<'a> PartialOrd<ByteStr> for ByteString
impl<'a> PartialOrd<ByteString> for &ByteStr
impl<'a> PartialOrd<ByteString> for Cow<'_, str>
impl<'a> PartialOrd<ByteString> for Cow<'_, ByteStr>
impl<'a> PartialOrd<ByteString> for Cow<'_, [u8]>
impl<'a> PartialOrd<ByteString> for ByteStr
impl<'a> PartialOrd<OsStr> for &'a Path
impl<'a> PartialOrd<OsStr> for Cow<'a, Path>
impl<'a> PartialOrd<OsString> for &'a Path
impl<'a> PartialOrd<OsString> for Cow<'a, Path>
impl<'a> PartialOrd<Path> for &'a OsStr
impl<'a> PartialOrd<Path> for Cow<'a, OsStr>
impl<'a> PartialOrd<Path> for Cow<'a, Path>
impl<'a> PartialOrd<PathBuf> for &'a OsStr
impl<'a> PartialOrd<PathBuf> for &'a Path
impl<'a> PartialOrd<PathBuf> for Cow<'a, OsStr>
impl<'a> PartialOrd<PathBuf> for Cow<'a, Path>
impl<'a> PartialOrd<HeaderValue> for &'a str
impl<'a> PartialOrd<HeaderValue> for &'a HeaderValue
impl<'a> PartialOrd<Authority> for &'a str
impl<'a> PartialOrd<PathAndQuery> for &'a str
impl<'a, 'b> PartialOrd<&'a OsStr> for OsString
impl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<&'b OsStr> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsStr
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for OsString
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b OsStr
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path
impl<'a, 'b> PartialOrd<OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsStr> for OsString
impl<'a, 'b> PartialOrd<OsString> for &'a OsStr
impl<'a, 'b> PartialOrd<OsString> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<OsString> for OsStr
impl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, T> PartialOrd for ContextSpecificRef<'a, T>where
T: PartialOrd,
impl<'a, T> PartialOrd for ZeroVec<'a, T>where
T: AsULE + PartialOrd,
impl<'a, T> PartialOrd<&'a T> for Bytes
impl<'a, T> PartialOrd<&'a T> for BytesMut
impl<'a, T> PartialOrd<&'a T> for HeaderValue
impl<'a, T, F> PartialOrd for VarZeroVec<'a, T, F>
impl<'a, V> PartialOrd for VarZeroCow<'a, V>
impl<'k, 'v> PartialOrd for Params<'k, 'v>
impl<A> PartialOrd for ArrayString<A>
impl<A> PartialOrd for ArrayVec<A>
impl<A> PartialOrd for SmallVec<A>
impl<A> PartialOrd<str> for ArrayString<A>
impl<A> PartialOrd<ArrayString<A>> for str
impl<A, B> PartialOrd for OneOf<A, B>where
A: PartialOrd,
B: PartialOrd,
impl<A, B> PartialOrd for Tuple2ULE<A, B>
impl<A, B> PartialOrd for VarTuple<A, B>where
A: PartialOrd,
B: PartialOrd,
impl<A, B> PartialOrd<&B> for &A
impl<A, B> PartialOrd<&mut B> for &mut A
impl<A, B, C> PartialOrd for Tuple3ULE<A, B, C>
impl<A, B, C, D> PartialOrd for Tuple4ULE<A, B, C, D>
impl<A, B, C, D, E> PartialOrd for Tuple5ULE<A, B, C, D, E>where
A: PartialOrd + ULE,
B: PartialOrd + ULE,
C: PartialOrd + ULE,
D: PartialOrd + ULE,
E: PartialOrd + ULE,
impl<A, B, C, D, E, F> PartialOrd for Tuple6ULE<A, B, C, D, E, F>where
A: PartialOrd + ULE,
B: PartialOrd + ULE,
C: PartialOrd + ULE,
D: PartialOrd + ULE,
E: PartialOrd + ULE,
F: PartialOrd + ULE,
impl<A, B, C, D, E, F, Format> PartialOrd for Tuple6VarULE<A, B, C, D, E, F, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
E: PartialOrd + VarULE + ?Sized,
F: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, D, E, Format> PartialOrd for Tuple5VarULE<A, B, C, D, E, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
E: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, D, Format> PartialOrd for Tuple4VarULE<A, B, C, D, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
D: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, C, Format> PartialOrd for Tuple3VarULE<A, B, C, Format>where
A: PartialOrd + VarULE + ?Sized,
B: PartialOrd + VarULE + ?Sized,
C: PartialOrd + VarULE + ?Sized,
Format: VarZeroVecFormat,
impl<A, B, Format> PartialOrd for Tuple2VarULE<A, B, Format>
impl<A, V> PartialOrd for VarTupleULE<A, V>
impl<B> PartialOrd for BitSet<B>where
B: BitBlock,
impl<B> PartialOrd for BitVec<B>where
B: BitBlock,
impl<C> PartialOrd for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> PartialOrd for PublicKey<C>where
C: CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
sec1 only.impl<C> PartialOrd for ScalarPrimitive<C>where
C: Curve,
impl<Dyn> PartialOrd for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> PartialOrd for Fwhere
F: FnPtr,
impl<K, V> PartialOrd for indexmap::map::slice::Slice<K, V>where
K: PartialOrd,
V: PartialOrd,
impl<K, V> PartialOrd for ringmap::map::slice::Slice<K, V>where
K: PartialOrd,
V: PartialOrd,
impl<K, V, A> PartialOrd for BTreeMap<K, V, A>
impl<K, V, S1, S2> PartialOrd<RingMap<K, V, S2>> for RingMap<K, V, S1>where
K: PartialOrd,
V: PartialOrd,
impl<K, V, S> PartialOrd for LinkedHashMap<K, V, S>
impl<K, V, S> PartialOrd for LiteMap<K, V, S>
impl<L, R> PartialOrd for Either<L, R>where
L: PartialOrd,
R: PartialOrd,
impl<O> PartialOrd for F32<O>where
O: ByteOrder,
impl<O> PartialOrd for F64<O>where
O: ByteOrder,
impl<O> PartialOrd for I16<O>where
O: ByteOrder,
impl<O> PartialOrd for I32<O>where
O: ByteOrder,
impl<O> PartialOrd for I64<O>where
O: ByteOrder,
impl<O> PartialOrd for I128<O>where
O: ByteOrder,
impl<O> PartialOrd for Isize<O>where
O: ByteOrder,
impl<O> PartialOrd for U16<O>where
O: ByteOrder,
impl<O> PartialOrd for U32<O>where
O: ByteOrder,
impl<O> PartialOrd for U64<O>where
O: ByteOrder,
impl<O> PartialOrd for U128<O>where
O: ByteOrder,
impl<O> PartialOrd for Usize<O>where
O: ByteOrder,
impl<O> PartialOrd<i16> for I16<O>where
O: ByteOrder,
impl<O> PartialOrd<i32> for I32<O>where
O: ByteOrder,
impl<O> PartialOrd<i64> for I64<O>where
O: ByteOrder,
impl<O> PartialOrd<i128> for I128<O>where
O: ByteOrder,
impl<O> PartialOrd<isize> for Isize<O>where
O: ByteOrder,
impl<O> PartialOrd<u16> for U16<O>where
O: ByteOrder,
impl<O> PartialOrd<u32> for U32<O>where
O: ByteOrder,
impl<O> PartialOrd<u64> for U64<O>where
O: ByteOrder,
impl<O> PartialOrd<u128> for U128<O>where
O: ByteOrder,
impl<O> PartialOrd<usize> for Usize<O>where
O: ByteOrder,
impl<Params> PartialOrd for AlgorithmIdentifier<Params>where
Params: PartialOrd,
impl<Ptr, Q> PartialOrd<Pin<Q>> for Pin<Ptr>
impl<S> PartialOrd for Host<S>where
S: PartialOrd,
impl<Size> PartialOrd for EncodedPoint<Size>where
Size: ModulusSize,
impl<T> PartialOrd for Option<T>where
T: PartialOrd,
impl<T> PartialOrd for Poll<T>where
T: PartialOrd,
impl<T> PartialOrd for Attr<T>where
T: PartialOrd,
impl<T> PartialOrd for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> PartialOrd for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> PartialOrd for [T]where
T: PartialOrd,
Implements comparison of slices lexicographically.
impl<T> PartialOrd for (T₁, T₂, …, Tₙ)where
T: PartialOrd,
This trait is implemented for tuples up to twelve items long.
impl<T> PartialOrd for Cell<T>where
T: PartialOrd + Copy,
impl<T> PartialOrd for RefCell<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for PhantomContravariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomCovariant<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomData<T>where
T: ?Sized,
impl<T> PartialOrd for PhantomInvariant<T>where
T: ?Sized,
impl<T> PartialOrd for ManuallyDrop<T>where
T: PartialOrd + ?Sized,
impl<T> PartialOrd for datex_core::stdlib::num::NonZero<T>where
T: ZeroablePrimitive + PartialOrd,
impl<T> PartialOrd for Saturating<T>where
T: PartialOrd,
impl<T> PartialOrd for datex_core::stdlib::num::Wrapping<T>where
T: PartialOrd,
impl<T> PartialOrd for NonNull<T>where
T: ?Sized,
impl<T> PartialOrd for Constant<T>where
T: PartialOrd,
impl<T> PartialOrd for CapacityError<T>where
T: PartialOrd,
impl<T> PartialOrd for crypto_bigint::non_zero::NonZero<T>where
T: PartialOrd + Zero,
impl<T> PartialOrd for crypto_bigint::wrapping::Wrapping<T>where
T: PartialOrd,
impl<T> PartialOrd for ContextSpecific<T>where
T: PartialOrd,
impl<T> PartialOrd for SetOfVec<T>where
T: PartialOrd + DerOrd,
impl<T> PartialOrd for AllowStdIo<T>where
T: PartialOrd,
impl<T> PartialOrd for indexmap::set::slice::Slice<T>where
T: PartialOrd,
impl<T> PartialOrd for Intern<T>
impl<T> PartialOrd for Ratio<T>
impl<T> PartialOrd for NotNan<T>where
T: PartialOrd,
impl<T> PartialOrd for OrderedFloat<T>where
T: FloatCore,
impl<T> PartialOrd for ringmap::set::slice::Slice<T>where
T: PartialOrd,
impl<T> PartialOrd for TryWriteableInfallibleAsWriteable<T>where
T: PartialOrd,
impl<T> PartialOrd for WriteableAsTryWriteableInfallible<T>where
T: PartialOrd,
impl<T> PartialOrd for Unalign<T>where
T: Unaligned + PartialOrd,
impl<T> PartialOrd for ZeroSlice<T>where
T: AsULE + PartialOrd,
impl<T> PartialOrd for Reverse<T>where
T: PartialOrd,
impl<T, A1, A2> PartialOrd<Vec<T, A2>> for datex_core::stdlib::vec::Vec<T, A1>
Implements comparison of vectors, lexicographically.
impl<T, A> PartialOrd for BTreeSet<T, A>
impl<T, A> PartialOrd for LinkedList<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for VecDeque<T, A>where
T: PartialOrd,
A: Allocator,
impl<T, A> PartialOrd for datex_core::stdlib::boxed::Box<T, A>
impl<T, A> PartialOrd for Rc<T, A>
impl<T, A> PartialOrd for UniqueRc<T, A>
impl<T, A> PartialOrd for Arc<T, A>
impl<T, A> PartialOrd for UniqueArc<T, A>
impl<T, A> PartialOrd for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> PartialOrd for allocator_api2::stable::vec::Vec<T, A>where
T: PartialOrd,
A: Allocator,
Implements comparison of vectors, lexicographically.
impl<T, B> PartialOrd for Ref<B, T>
impl<T, E> PartialOrd for Result<T, E>where
T: PartialOrd,
E: PartialOrd,
impl<T, F> PartialOrd for VarZeroSlice<T, F>
impl<T, N> PartialOrd for GenericArray<T, N>where
T: PartialOrd,
N: ArrayLength<T>,
impl<T, S1, S2> PartialOrd<RingSet<T, S2>> for RingSet<T, S1>where
T: PartialOrd,
impl<T, U> PartialOrd<Exclusive<U>> for Exclusive<T>
impl<T, const N: usize> PartialOrd for [T; N]where
T: PartialOrd,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> PartialOrd for Mask<T, N>
impl<T, const N: usize> PartialOrd for Simd<T, N>
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.