pub trait Error: Debug + Display {
// Provided methods
fn source(&self) -> Option<&(dyn Error + 'static)> { ... }
fn description(&self) -> &str { ... }
fn cause(&self) -> Option<&dyn Error> { ... }
fn provide<'a>(&'a self, request: &mut Request<'a>) { ... }
}Expand description
Error is a trait representing the basic expectations for error values,
i.e., values of type E in Result<T, E>.
Errors must describe themselves through the Display and Debug
traits. Error messages are typically concise lowercase sentences without
trailing punctuation:
let err = "NaN".parse::<u32>().unwrap_err();
assert_eq!(err.to_string(), "invalid digit found in string");Error source
Errors may provide cause information. Error::source() is generally
used when errors cross “abstraction boundaries”. If one module must report
an error that is caused by an error from a lower-level module, it can allow
accessing that error via Error::source(). This makes it possible for the
high-level module to provide its own errors while also revealing some of the
implementation for debugging.
In error types that wrap an underlying error, the underlying error
should be either returned by the outer error’s Error::source(), or rendered
by the outer error’s Display implementation, but not both.
Example
Implementing the Error trait only requires that Debug and Display are implemented too.
use std::error::Error;
use std::fmt;
use std::path::PathBuf;
#[derive(Debug)]
struct ReadConfigError {
path: PathBuf
}
impl fmt::Display for ReadConfigError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
let path = self.path.display();
write!(f, "unable to read configuration at {path}")
}
}
impl Error for ReadConfigError {}Provided Methods
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct SuperError {
source: SuperErrorSideKick,
}
impl fmt::Display for SuperError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "SuperError is here!")
}
}
impl Error for SuperError {
fn source(&self) -> Option<&(dyn Error + 'static)> {
Some(&self.source)
}
}
#[derive(Debug)]
struct SuperErrorSideKick;
impl fmt::Display for SuperErrorSideKick {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "SuperErrorSideKick is here!")
}
}
impl Error for SuperErrorSideKick {}
fn get_super_error() -> Result<(), SuperError> {
Err(SuperError { source: SuperErrorSideKick })
}
fn main() {
match get_super_error() {
Err(e) => {
println!("Error: {e}");
println!("Caused by: {}", e.source().unwrap());
}
_ => println!("No error"),
}
}1.0.0 · Sourcefn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
fn description(&self) -> &str
if let Err(e) = "xc".parse::<u32>() {
// Print `e` itself, no need for description().
eprintln!("Error: {e}");
}fn cause(&self) -> Option<&dyn Error>
Sourcefn provide<'a>(&'a self, request: &mut Request<'a>)
🔬This is a nightly-only experimental API. (error_generic_member_access)
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access)Provides type-based access to context intended for error reports.
Used in conjunction with Request::provide_value and Request::provide_ref to extract
references to member variables from dyn Error trait objects.
Example
#![feature(error_generic_member_access)]
use core::fmt;
use core::error::{request_ref, Request};
#[derive(Debug)]
enum MyLittleTeaPot {
Empty,
}
#[derive(Debug)]
struct MyBacktrace {
// ...
}
impl MyBacktrace {
fn new() -> MyBacktrace {
// ...
}
}
#[derive(Debug)]
struct Error {
backtrace: MyBacktrace,
}
impl fmt::Display for Error {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "Example Error")
}
}
impl std::error::Error for Error {
fn provide<'a>(&'a self, request: &mut Request<'a>) {
request
.provide_ref::<MyBacktrace>(&self.backtrace);
}
}
fn main() {
let backtrace = MyBacktrace::new();
let error = Error { backtrace };
let dyn_error = &error as &dyn std::error::Error;
let backtrace_ref = request_ref::<MyBacktrace>(dyn_error).unwrap();
assert!(core::ptr::eq(&error.backtrace, backtrace_ref));
assert!(request_ref::<MyLittleTeaPot>(dyn_error).is_none());
}Implementations
Sourceimpl dyn Error
impl dyn Error
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Returns true if the inner type is the same as T.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Returns some reference to the inner value if it is of type T, or
None if it isn’t.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Returns some mutable reference to the inner value if it is of type T, or
None if it isn’t.
Sourceimpl dyn Error + Send
impl dyn Error + Send
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
Sourceimpl dyn Error + Sync + Send
impl dyn Error + Sync + Send
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
Sourceimpl dyn Error
impl dyn Error
Sourcepub fn sources(&self) -> Source<'_> ⓘ
🔬This is a nightly-only experimental API. (error_iter)
pub fn sources(&self) -> Source<'_> ⓘ
error_iter)Returns an iterator starting with the current error and continuing with
recursively calling Error::source.
If you want to omit the current error and only use its sources,
use skip(1).
Examples
#![feature(error_iter)]
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct A;
#[derive(Debug)]
struct B(Option<Box<dyn Error + 'static>>);
impl fmt::Display for A {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "A")
}
}
impl fmt::Display for B {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "B")
}
}
impl Error for A {}
impl Error for B {
fn source(&self) -> Option<&(dyn Error + 'static)> {
self.0.as_ref().map(|e| e.as_ref())
}
}
let b = B(Some(Box::new(A)));
// let err : Box<Error> = b.into(); // or
let err = &b as &dyn Error;
let mut iter = err.sources();
assert_eq!("B".to_string(), iter.next().unwrap().to_string());
assert_eq!("A".to_string(), iter.next().unwrap().to_string());
assert!(iter.next().is_none());
assert!(iter.next().is_none());Trait Implementations
1.6.0 · Sourceimpl<'a> From<&str> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<&str> for Box<dyn Error + 'a>
no_global_oom_handling only.1.0.0 · Sourceimpl<'a> From<&str> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<&str> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
no_global_oom_handling only.1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Sourcefn from(err: Cow<'b, str>) -> Box<dyn Error + Sync + Send + 'a>
fn from(err: Cow<'b, str>) -> Box<dyn Error + Sync + Send + 'a>
Converts a Cow into a box of dyn Error + Send + Sync.
Examples
use std::error::Error;
use std::borrow::Cow;
let a_cow_str_error = Cow::from("a str error");
let a_boxed_error = Box::<dyn Error + Send + Sync>::from(a_cow_str_error);
assert!(
size_of::<Box<dyn Error + Send + Sync>>() == size_of_val(&a_boxed_error))1.0.0 · Sourceimpl<'a, E> From<E> for Box<dyn Error + 'a>where
E: Error + 'a,
Available on non-no_global_oom_handling only.
impl<'a, E> From<E> for Box<dyn Error + 'a>where
E: Error + 'a,
no_global_oom_handling only.Sourcefn from(err: E) -> Box<dyn Error + 'a>
fn from(err: E) -> Box<dyn Error + 'a>
Converts a type of Error into a box of dyn Error.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct AnError;
impl fmt::Display for AnError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "An error")
}
}
impl Error for AnError {}
let an_error = AnError;
assert!(0 == size_of_val(&an_error));
let a_boxed_error = Box::<dyn Error>::from(an_error);
assert!(size_of::<Box<dyn Error>>() == size_of_val(&a_boxed_error))1.0.0 · Sourceimpl<'a, E> From<E> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a, E> From<E> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Sourcefn from(err: E) -> Box<dyn Error + Sync + Send + 'a>
fn from(err: E) -> Box<dyn Error + Sync + Send + 'a>
Converts a type of Error + Send + Sync into a box of
dyn Error + Send + Sync.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct AnError;
impl fmt::Display for AnError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "An error")
}
}
impl Error for AnError {}
unsafe impl Send for AnError {}
unsafe impl Sync for AnError {}
let an_error = AnError;
assert!(0 == size_of_val(&an_error));
let a_boxed_error = Box::<dyn Error + Send + Sync>::from(an_error);
assert!(
size_of::<Box<dyn Error + Send + Sync>>() == size_of_val(&a_boxed_error))1.6.0 · Sourceimpl<'a> From<String> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<String> for Box<dyn Error + 'a>
no_global_oom_handling only.1.0.0 · Sourceimpl<'a> From<String> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<String> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Implementors
impl !Error for &str
impl Error for HeaderParsingError
impl Error for BaseInterfaceError
impl Error for HTTPError
impl Error for SerialError
impl Error for TCPError
impl Error for WebRTCError
impl Error for WebSocketError
impl Error for WebSocketServerError
impl Error for DeserializationError
impl Error for SerializationError
impl Error for Infallible
impl Error for VarError
impl Error for FromBytesWithNulError
impl Error for datex_core::stdlib::fs::TryLockError
impl Error for datex_core::stdlib::slice::GetDisjointMutError
impl Error for RecvTimeoutError
impl Error for datex_core::stdlib::sync::mpmc::TryRecvError
impl Error for DerConstraint
std only.impl Error for asn1_rs::error::Error
std only.impl Error for asn1_rs::error::SerializeError
impl Error for BytesRejection
impl Error for FailedToBufferBody
impl Error for StringRejection
impl Error for ExtensionRejection
impl Error for FormRejection
impl Error for JsonRejection
impl Error for MatchedPathRejection
impl Error for PathRejection
impl Error for QueryRejection
impl Error for RawFormRejection
impl Error for RawPathParamsRejection
impl Error for ParseAlphabetError
std only.impl Error for base64::decode::DecodeError
std only.impl Error for DecodeSliceError
std only.impl Error for EncodeSliceError
std only.impl Error for base64ct::errors::Error
impl Error for ParseBigDecimalError
std only.impl Error for ErrorKind
impl Error for binrw::error::Error
std only.impl Error for RoundingError
std only.impl Error for fancy_regex::error::Error
std only.impl Error for FlexiLoggerError
impl Error for FromHexError
std only.impl Error for httparse::Error
std only.impl Error for GetTimezoneError
impl Error for icu_collections::codepointtrie::error::Error
impl Error for icu_locale_core::parser::errors::ParseError
impl Error for PreferencesParseError
impl Error for indexmap::GetDisjointMutError
impl Error for interceptor::error::Error
impl Error for InsertError
impl Error for matchit::error::MatchError
impl Error for nix::errno::consts::Errno
impl Error for PemError
std only.impl Error for pkcs8::error::Error
std only.impl Error for EncodingError
impl Error for quick_xml::errors::Error
impl Error for IllFormedError
impl Error for SyntaxError
impl Error for EscapeError
impl Error for ParseCharRefError
impl Error for AttrError
impl Error for NamespaceError
impl Error for BernoulliError
std only.impl Error for WeightedError
std only.impl Error for rcgen::error::Error
impl Error for regex_automata::dfa::automaton::StartError
std only.impl Error for regex_automata::hybrid::error::StartError
std only.impl Error for regex_syntax::error::Error
std only.impl Error for regex::error::Error
std only.impl Error for ringmap::GetDisjointMutError
std only.impl Error for rtcp::error::Error
impl Error for rtp::error::Error
impl Error for rustls_pki_types::pem::Error
std only.impl Error for webpki::error::Error
std only.impl Error for EarlyDataError
std only.impl Error for EncodeError
std only.impl Error for EncryptError
std only.impl Error for rustls::error::Error
std only.impl Error for VerifierBuilderError
std only.impl Error for sdp::error::Error
impl Error for sec1::error::Error
std only.impl Error for serde_urlencoded::ser::Error
impl Error for slab::GetDisjointMutError
std only.impl Error for spki::error::Error
std only.impl Error for strum::ParseError
std only.impl Error for stun::error::Error
impl Error for syntect::Error
impl Error for LoadingError
impl Error for SettingsError
impl Error for ParseThemeError
impl Error for ParsingError
impl Error for ParseScopeError
impl Error for ScopeError
impl Error for ParseSyntaxError
impl Error for time::error::Error
impl Error for Format
impl Error for InvalidFormatDescription
impl Error for Parse
impl Error for ParseFromDescription
impl Error for TryFromParsed
impl Error for tinystr::error::ParseError
impl Error for BroadcastStreamRecvError
impl Error for AnyDelimiterCodecError
impl Error for LinesCodecError
impl Error for TryAcquireError
impl Error for tokio::sync::broadcast::error::RecvError
impl Error for tokio::sync::broadcast::error::TryRecvError
impl Error for tokio::sync::mpsc::error::TryRecvError
impl Error for tokio::sync::oneshot::error::TryRecvError
impl Error for tungstenite::error::CapacityError
impl Error for tungstenite::error::Error
impl Error for ProtocolError
impl Error for TlsError
impl Error for UrlError
impl Error for turn::error::Error
impl Error for unescaper::Error
impl Error for url::parser::ParseError
std only.impl Error for webrtc_data::error::Error
impl Error for webrtc_dtls::error::Error
impl Error for webrtc_ice::error::Error
impl Error for webrtc_mdns::error::Error
impl Error for webrtc_media::audio::buffer::Error
impl Error for webrtc_media::error::Error
impl Error for webrtc_sctp::error::Error
impl Error for webrtc_srtp::error::Error
impl Error for KeyingMaterialExporterError
impl Error for webrtc_util::error::Error
impl Error for webrtc::error::Error
impl Error for PEMError
impl Error for X509Error
impl Error for EmitError
impl Error for ZeroTrieBuildError
impl Error for UleError
impl Error for !
impl Error for UnorderedKeyError
impl Error for datex_core::collections::TryReserveError
impl Error for SystemTimeError
impl Error for TryFromFloatSecsError
impl Error for AllocError
impl Error for LayoutError
impl Error for TryFromSliceError
impl Error for BorrowError
impl Error for BorrowMutError
impl Error for CharTryFromError
impl Error for DecodeUtf16Error
impl Error for ParseCharError
impl Error for TryFromCharError
impl Error for JoinPathsError
impl Error for FromBytesUntilNulError
impl Error for FromVecWithNulError
impl Error for IntoStringError
impl Error for NulError
impl Error for datex_core::stdlib::fmt::Error
impl Error for datex_core::stdlib::io::Error
impl Error for WriterPanicked
impl Error for datex_core::stdlib::net::AddrParseError
impl Error for ParseFloatError
impl Error for datex_core::stdlib::num::ParseIntError
impl Error for datex_core::stdlib::num::TryFromIntError
impl Error for NormalizeError
impl Error for StripPrefixError
impl Error for ExitStatusError
impl Error for ParseBoolError
impl Error for Utf8Error
impl Error for FromUtf8Error
impl Error for FromUtf16Error
impl Error for datex_core::stdlib::sync::mpmc::RecvError
impl Error for AccessError
impl Error for aead::Error
std only.impl Error for aho_corasick::util::error::BuildError
std only.impl Error for aho_corasick::util::error::MatchError
std only.impl Error for aho_corasick::util::primitives::PatternIDError
std only.impl Error for aho_corasick::util::primitives::StateIDError
std only.impl Error for axum_core::error::Error
impl Error for InvalidUtf8
impl Error for axum_core::extract::rejection::LengthLimitError
impl Error for UnknownBodyError
impl Error for FailedToDeserializePathParams
impl Error for InvalidUtf8InPathParam
impl Error for FailedToDeserializeForm
impl Error for FailedToDeserializeFormBody
impl Error for FailedToDeserializeQueryString
impl Error for InvalidFormContentType
impl Error for JsonDataError
impl Error for JsonSyntaxError
impl Error for MatchedPathMissing
impl Error for MissingExtension
impl Error for MissingJsonContentType
impl Error for MissingPathParams
impl Error for NestedPathRejection
impl Error for InvalidEncodingError
impl Error for InvalidLengthError
impl Error for TryGetError
std only.impl Error for chrono::format::ParseError
core-error or std only.impl Error for ParseMonthError
std only.impl Error for OutOfRange
std only.impl Error for OutOfRangeError
std or core-error only.impl Error for ParseWeekdayError
std only.impl Error for InvalidLength
std only.impl Error for data_encoding::DecodeError
std only.impl Error for SpecificationError
std only.impl Error for der::error::Error
std only.impl Error for deranged::ParseIntError
impl Error for deranged::TryFromIntError
impl Error for MacError
std only.impl Error for InvalidBufferSize
std only.impl Error for InvalidOutputSize
std only.impl Error for elliptic_curve::error::Error
std only.impl Error for errno::Errno
std only.impl Error for CompressError
impl Error for DecompressError
impl Error for futures_channel::mpsc::SendError
impl Error for futures_channel::mpsc::TryRecvError
impl Error for Canceled
std only.impl Error for EnterError
impl Error for SpawnError
std only.impl Error for Aborted
std only.impl Error for getrandom::error::Error
impl Error for http_body_util::limited::LengthLimitError
impl Error for http::error::Error
impl Error for MaxSizeReached
impl Error for InvalidHeaderName
impl Error for InvalidHeaderValue
impl Error for ToStrError
impl Error for InvalidMethod
impl Error for InvalidStatusCode
impl Error for InvalidUri
impl Error for InvalidUriParts
impl Error for httpdate::Error
impl Error for hyper::error::Error
impl Error for DataError
impl Error for Errors
std only.impl Error for indexmap::TryReserveError
impl Error for PrefixLenError
impl Error for ipnet::parser::AddrParseError
impl Error for libudev::error::Error
impl Error for log::ParseLevelError
std only.impl Error for SetLoggerError
std only.impl Error for FromStrError
impl Error for native_tls::Error
impl Error for ClearEnvError
impl Error for ParseBigIntError
std only.impl Error for ParseRatioError
std only.impl Error for openssl::error::Error
impl Error for ErrorStack
impl Error for openssl::ssl::error::Error
impl Error for X509VerifyResult
impl Error for FloatIsNan
std only.impl Error for InvalidXmlDate
impl Error for plist::error::Error
impl Error for ReadError
impl Error for rand_core::error::Error
std only.impl Error for realhydroper_lsp::jsonrpc::error::Error
impl Error for ExitedError
impl Error for regex_automata::dfa::dense::BuildError
std and dfa-build only.impl Error for regex_automata::dfa::onepass::BuildError
std only.impl Error for regex_automata::hybrid::error::BuildError
std only.impl Error for CacheError
std only.impl Error for regex_automata::meta::error::BuildError
std only.impl Error for regex_automata::nfa::thompson::error::BuildError
std only.impl Error for GroupInfoError
std only.impl Error for UnicodeWordBoundaryError
std only.impl Error for regex_automata::util::primitives::PatternIDError
std only.impl Error for SmallIndexError
std only.impl Error for regex_automata::util::primitives::StateIDError
std only.impl Error for regex_automata::util::search::MatchError
std only.impl Error for PatternSetInsertError
std only.impl Error for DeserializeError
std only.impl Error for regex_automata::util::wire::SerializeError
std only.impl Error for regex_syntax::ast::Error
std only.impl Error for regex_syntax::hir::Error
std only.impl Error for CaseFoldError
std only.impl Error for UnicodeWordError
std only.impl Error for ringmap::TryReserveError
std only.impl Error for rustls_pki_types::server_name::AddrParseError
std only.impl Error for InvalidDnsNameError
std only.impl Error for UnsupportedOperationError
std only.impl Error for OtherError
std only.impl Error for serde_core::de::value::Error
std only.impl Error for serde_json::error::Error
impl Error for serialport::Error
impl Error for signature::error::Error
std only.impl Error for ComponentRange
impl Error for ConversionRange
impl Error for DifferentVariant
impl Error for InvalidVariant
impl Error for tokio_stream::stream_ext::timeout::Elapsed
impl Error for LengthDelimitedCodecError
impl Error for tokio::net::tcp::split_owned::ReuniteError
impl Error for tokio::net::unix::split_owned::ReuniteError
impl Error for TryCurrentError
impl Error for JoinError
impl Error for AcquireError
impl Error for tokio::sync::mutex::TryLockError
impl Error for tokio::sync::oneshot::error::RecvError
impl Error for tokio::sync::watch::error::RecvError
impl Error for tokio::time::error::Elapsed
impl Error for tokio::time::error::Error
impl Error for tower::util::optional::error::None
impl Error for tower::util::optional::error::None
impl Error for SetGlobalDefaultError
std only.impl Error for tracing_core::metadata::ParseLevelError
std only.impl Error for ParseLevelFilterError
std only.impl Error for uuid::error::Error
impl Error for walkdir::error::Error
impl Error for ScanError
impl Error for ParseOidError
std only.impl Error for ASN1Error
std only.impl<'a> Error for utf8::DecodeError<'a>
impl<'a> Error for BufReadDecoderError<'a>
impl<'a, K, V> Error for datex_core::collections::btree_map::OccupiedError<'a, K, V>
impl<'a, K, V> Error for datex_core::collections::hash_map::OccupiedError<'a, K, V>
impl<'a, T> Error for &'a T
impl<A, S, V> Error for ConvertError<A, S, V>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<E> Error for Err<E>where
E: Debug,
std only.impl<E> Error for ParseNotNanError<E>
std only.impl<E> Error for Box<E>where
E: Error,
impl<E> Error for ParseComplexError<E>where
E: Error,
std only.impl<E> Error for serde_path_to_error::Error<E>where
E: Error,
impl<Enum> Error for TryFromPrimitiveError<Enum>where
Enum: TryFromPrimitive,
impl<I> Error for nom::error::Error<I>
std only.impl<I> Error for VerboseError<I>
std only.impl<K, V> Error for TryIntoHeaderError<K, V>
impl<Role> Error for tungstenite::handshake::HandshakeError<Role>where
Role: HandshakeRole,
impl<S> Error for native_tls::HandshakeError<S>
impl<S> Error for openssl::ssl::error::HandshakeError<S>where
S: Debug,
impl<Src, Dst> Error for AlignmentError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<Src, Dst> Error for SizeError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<Src, Dst> Error for ValidityError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<T> Error for datex_core::stdlib::sync::TryLockError<T>
impl<T> Error for datex_core::stdlib::sync::mpmc::SendTimeoutError<T>
impl<T> Error for datex_core::stdlib::sync::mpmc::TrySendError<T>
impl<T> Error for tokio::sync::mpsc::error::SendTimeoutError<T>
time only.impl<T> Error for tokio::sync::mpsc::error::TrySendError<T>
impl<T> Error for SetError<T>where
T: Debug,
impl<T> Error for ThinBox<T>
impl<T> Error for datex_core::stdlib::sync::mpmc::SendError<T>
impl<T> Error for Arc<T>
impl<T> Error for PoisonError<T>
impl<T> Error for arrayvec::errors::CapacityError<T>where
T: Any,
std only.Requires features="std".
impl<T> Error for futures_channel::mpsc::TrySendError<T>where
T: Any,
impl<T> Error for futures_util::io::split::ReuniteError<T>where
T: Any,
std only.impl<T> Error for TryFromBigIntError<T>where
T: Debug,
std only.impl<T> Error for PollSendError<T>where
T: Debug,
impl<T> Error for AsyncFdTryNewError<T>
impl<T> Error for tokio::sync::broadcast::error::SendError<T>where
T: Debug,
impl<T> Error for tokio::sync::mpsc::error::SendError<T>
impl<T> Error for SetOnceError<T>where
T: Debug,
impl<T> Error for tokio::sync::watch::error::SendError<T>
impl<T, E> Error for TryChunksError<T, E>
std only.impl<T, E> Error for TryReadyChunksError<T, E>
std only.impl<T, Item> Error for futures_util::stream::stream::split::ReuniteError<T, Item>where
T: Any,
std only.