pub trait Hash {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Hash for VariableKind
impl Hash for ResolvedVariable
impl Hash for VariableShape
impl Hash for ArithmeticOperator
impl Hash for CoreLibPointerId
impl Hash for Reference
impl Hash for ReferenceCreationError
impl Hash for ReferenceMutability
impl Hash for TypeError
impl Hash for CollectionTypeDefinition
impl Hash for TypeDefinition
impl Hash for StructuralTypeDefinition
impl Hash for CoreValue
impl Hash for CallableBody
impl Hash for CallableKind
impl Hash for Decimal
impl Hash for DecimalTypeVariant
impl Hash for TypedDecimal
impl Hash for EndpointInstance
impl Hash for EndpointType
impl Hash for IntegerTypeVariant
impl Hash for TypedInteger
impl Hash for BorrowedMapKey<'_>
impl Hash for datex_core::values::core_values::map::Map
impl Hash for PointerAddress
impl Hash for ValueContainer
impl Hash for AsciiChar
impl Hash for datex_core::stdlib::cmp::Ordering
impl Hash for Infallible
impl Hash for Locality
impl Hash for datex_core::stdlib::io::ErrorKind
impl Hash for datex_core::stdlib::net::IpAddr
impl Hash for Ipv6MulticastScope
impl Hash for SocketAddr
impl Hash for IntErrorKind
impl Hash for datex_core::stdlib::sync::atomic::Ordering
impl Hash for RoundingMode
impl Hash for CheckedCastError
impl Hash for PodCastError
impl Hash for byteorder::BigEndian
impl Hash for byteorder::LittleEndian
impl Hash for Colons
impl Hash for Fixed
impl Hash for Numeric
impl Hash for OffsetPrecision
impl Hash for Pad
impl Hash for ParseErrorKind
impl Hash for SecondsFormat
impl Hash for chrono::month::Month
impl Hash for chrono::weekday::Weekday
impl Hash for PollNext
impl Hash for ExtensionType
impl Hash for CalendarAlgorithm
impl Hash for HijriCalendarAlgorithm
impl Hash for CollationCaseFirst
impl Hash for CollationNumericOrdering
impl Hash for CollationType
impl Hash for CurrencyFormatStyle
impl Hash for EmojiPresentationStyle
impl Hash for FirstDay
impl Hash for HourCycle
impl Hash for LineBreakStyle
impl Hash for LineBreakWordHandling
impl Hash for MeasurementSystem
impl Hash for MeasurementUnitOverride
impl Hash for SentenceBreakSupressions
impl Hash for CommonVariantType
impl Hash for GeneralCategory
impl Hash for BufferFormat
impl Hash for IpAddrRange
impl Hash for IpNet
impl Hash for IpSubnets
impl Hash for tpacket_versions
impl Hash for log::Level
impl Hash for log::LevelFilter
impl Hash for NumberOrString
impl Hash for InsertError
impl Hash for CompressionStrategy
impl Hash for TDEFLFlush
impl Hash for TDEFLStatus
impl Hash for CompressionLevel
impl Hash for DataFormat
impl Hash for MZError
impl Hash for MZFlush
impl Hash for MZStatus
impl Hash for TINFLStatus
impl Hash for nix::dir::Type
impl Hash for FlockArg
impl Hash for PosixFadviseAdvice
impl Hash for AioCancelStat
impl Hash for AioFsyncMode
impl Hash for LioMode
impl Hash for EpollOp
impl Hash for MmapAdvise
impl Hash for Event
impl Hash for Request
impl Hash for QuotaFmt
impl Hash for QuotaType
impl Hash for RebootMode
impl Hash for Resource
impl Hash for UsageWho
impl Hash for SigHandler
impl Hash for SigevNotify
impl Hash for SigmaskHow
impl Hash for Signal
impl Hash for AddressFamily
impl Hash for InetAddr
impl Hash for nix::sys::socket::addr::IpAddr
impl Hash for nix::sys::socket::addr::SockAddr
impl Hash for Shutdown
impl Hash for SockProtocol
impl Hash for BaudRate
impl Hash for FlowArg
impl Hash for FlushArg
impl Hash for SetArg
impl Hash for SpecialCharacterIndices
impl Hash for nix::sys::timerfd::ClockId
impl Hash for nix::sys::wait::Id
impl Hash for WaitStatus
impl Hash for PathconfVar
impl Hash for SysconfVar
impl Hash for nom::error::ErrorKind
impl Hash for Sign
impl Hash for BasicConstraints
impl Hash for CidrSubnet
impl Hash for DnType
impl Hash for ExtendedKeyUsagePurpose
impl Hash for IsCa
impl Hash for DnValue
impl Hash for KeyIdMethod
impl Hash for KeyUsagePurpose
impl Hash for OtherNameValue
impl Hash for SanType
impl Hash for realhydroper_lsp::jsonrpc::Id
impl Hash for UnitType
impl Hash for rustls_pki_types::server_name::IpAddr
impl Hash for serde_json::value::Value
impl Hash for strum::ParseError
impl Hash for time::month::Month
impl Hash for time::weekday::Weekday
impl Hash for Origin
impl Hash for HandshakeType
impl Hash for NetworkType
impl Hash for Yaml
impl Hash for PCBit
impl Hash for TagClass
impl Hash for BERMode
impl Hash for zerocopy::byteorder::BigEndian
impl Hash for zerocopy::byteorder::LittleEndian
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for SrcId
impl Hash for VirtualSlot
impl Hash for BlockId
impl Hash for IncomingEndpointContextId
impl Hash for IncomingEndpointContextSectionId
impl Hash for ComInterfaceUUID
impl Hash for ComInterfaceSocketUUID
impl Hash for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common::structures::RTCIceServer
impl Hash for Loc
impl Hash for NominalTypeDeclaration
impl Hash for TypeReference
impl Hash for datex_core::time::Duration
impl Hash for datex_core::time::Instant
impl Hash for SystemTime
impl Hash for UUID
impl Hash for Boolean
impl Hash for Callable
impl Hash for CallableSignature
impl Hash for Rational
impl Hash for Endpoint
impl Hash for datex_core::values::core_values::integer::Integer
impl Hash for List
impl Hash for Text
impl Hash for datex_core::values::core_values::type::Type
impl Hash for datex_core::values::value::Value
impl Hash for Layout
impl Hash for TypeId
impl Hash for ByteStr
impl Hash for ByteString
impl Hash for CStr
impl Hash for CString
impl Hash for OsStr
impl Hash for OsString
impl Hash for datex_core::stdlib::fmt::Error
impl Hash for FileType
impl Hash for PhantomPinned
impl Hash for datex_core::stdlib::net::Ipv4Addr
impl Hash for datex_core::stdlib::net::Ipv6Addr
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for RangeFull
impl Hash for datex_core::stdlib::os::unix::net::UCred
impl Hash for Location<'_>
impl Hash for Path
impl Hash for PathBuf
impl Hash for PrefixComponent<'_>
impl Hash for Alignment
impl Hash for String
impl Hash for ThreadId
impl Hash for aead::Error
impl Hash for aho_corasick::util::primitives::PatternID
impl Hash for aho_corasick::util::primitives::StateID
impl Hash for aho_corasick::util::search::Match
impl Hash for aho_corasick::util::search::Span
impl Hash for Base64Bcrypt
impl Hash for Base64Crypt
impl Hash for Base64ShaCrypt
impl Hash for Base64
impl Hash for Base64Unpadded
impl Hash for Base64Url
impl Hash for Base64UrlUnpadded
impl Hash for BigDecimal
impl Hash for Bytes
impl Hash for BytesMut
impl Hash for Parsed
impl Hash for InternalFixed
impl Hash for InternalNumeric
impl Hash for OffsetFormat
impl Hash for chrono::format::ParseError
impl Hash for Months
impl Hash for NaiveDate
impl Hash for NaiveDateDaysIterator
impl Hash for NaiveDateWeeksIterator
impl Hash for NaiveDateTime
impl Hash for IsoWeek
impl Hash for Days
impl Hash for NaiveWeek
impl Hash for NaiveTime
impl Hash for FixedOffset
impl Hash for Utc
impl Hash for OutOfRange
impl Hash for TimeDelta
impl Hash for WeekdaySet
impl Hash for const_oid::ObjectIdentifier
impl Hash for Limb
impl Hash for CompressedEdwardsY
impl Hash for MontgomeryPoint
impl Hash for CompressedRistretto
impl Hash for Scalar
impl Hash for Errno
impl Hash for HeaderName
impl Hash for HeaderValue
impl Hash for Method
impl Hash for StatusCode
impl Hash for Authority
Case-insensitive hashing
Examples
let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();
let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();
let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();
assert_eq!(a, b);impl Hash for PathAndQuery
impl Hash for Scheme
Case-insensitive hashing
impl Hash for Uri
impl Hash for Version
impl Hash for HttpDate
impl Hash for ReasonPhrase
impl Hash for DataLocale
impl Hash for Other
impl Hash for icu_locale_core::extensions::private::other::Subtag
impl Hash for Private
impl Hash for Extensions
impl Hash for Fields
impl Hash for icu_locale_core::extensions::transform::key::Key
impl Hash for Transform
impl Hash for icu_locale_core::extensions::transform::value::Value
impl Hash for icu_locale_core::extensions::unicode::attribute::Attribute
impl Hash for Attributes
impl Hash for icu_locale_core::extensions::unicode::key::Key
impl Hash for Keywords
impl Hash for Unicode
impl Hash for SubdivisionId
impl Hash for SubdivisionSuffix
impl Hash for icu_locale_core::extensions::unicode::value::Value
impl Hash for LanguageIdentifier
impl Hash for Locale
impl Hash for CurrencyType
impl Hash for NumberingSystem
impl Hash for RegionOverride
impl Hash for RegionalSubdivision
impl Hash for TimeZoneShortId
impl Hash for LocalePreferences
impl Hash for Language
impl Hash for Region
impl Hash for icu_locale_core::subtags::script::Script
impl Hash for icu_locale_core::subtags::Subtag
impl Hash for Variant
impl Hash for Variants
impl Hash for BidiClass
impl Hash for CanonicalCombiningClass
impl Hash for EastAsianWidth
impl Hash for GeneralCategoryOutOfBoundsError
impl Hash for GraphemeClusterBreak
impl Hash for HangulSyllableType
impl Hash for IndicConjunctBreak
impl Hash for IndicSyllabicCategory
impl Hash for JoiningType
impl Hash for LineBreak
impl Hash for icu_properties::props::Script
impl Hash for SentenceBreak
impl Hash for VerticalOrientation
impl Hash for WordBreak
impl Hash for DataMarkerId
impl Hash for DataMarkerIdHash
impl Hash for DataMarkerInfo
impl Hash for DataMarkerAttributes
impl Hash for Ipv4AddrRange
impl Hash for Ipv6AddrRange
impl Hash for Ipv4Net
impl Hash for Ipv4Subnets
impl Hash for Ipv6Net
impl Hash for Ipv6Subnets
impl Hash for rtentry
impl Hash for bcm_msg_head
impl Hash for bcm_timeval
impl Hash for j1939_filter
impl Hash for __c_anonymous_sockaddr_can_j1939
impl Hash for __c_anonymous_sockaddr_can_tp
impl Hash for can_filter
impl Hash for can_frame
impl Hash for canfd_frame
impl Hash for canxl_frame
impl Hash for termios2
impl Hash for msqid_ds
impl Hash for semid_ds
impl Hash for sigset_t
impl Hash for sysinfo
impl Hash for timex
impl Hash for statvfs
impl Hash for _libc_fpstate
impl Hash for _libc_fpxreg
impl Hash for _libc_xmmreg
impl Hash for clone_args
impl Hash for flock64
impl Hash for flock
impl Hash for ipc_perm
impl Hash for mcontext_t
impl Hash for pthread_attr_t
impl Hash for ptrace_rseq_configuration
impl Hash for shmid_ds
impl Hash for sigaction
impl Hash for siginfo_t
impl Hash for stack_t
impl Hash for stat64
impl Hash for stat
impl Hash for statfs64
impl Hash for statfs
impl Hash for statvfs64
impl Hash for ucontext_t
impl Hash for user
impl Hash for user_fpregs_struct
impl Hash for user_regs_struct
impl Hash for Elf32_Chdr
impl Hash for Elf64_Chdr
impl Hash for __c_anonymous_ptrace_syscall_info_entry
impl Hash for __c_anonymous_ptrace_syscall_info_exit
impl Hash for __c_anonymous_ptrace_syscall_info_seccomp
impl Hash for __exit_status
impl Hash for __timeval
impl Hash for aiocb
impl Hash for cmsghdr
impl Hash for fanotify_event_info_error
impl Hash for fanotify_event_info_pidfd
impl Hash for fpos64_t
impl Hash for fpos_t
impl Hash for glob64_t
impl Hash for iocb
impl Hash for mallinfo2
impl Hash for mallinfo
impl Hash for mbstate_t
impl Hash for msghdr
impl Hash for nl_mmap_hdr
impl Hash for nl_mmap_req
impl Hash for nl_pktinfo
impl Hash for ntptimeval
impl Hash for ptrace_peeksiginfo_args
impl Hash for ptrace_sud_config
impl Hash for ptrace_syscall_info
impl Hash for regex_t
impl Hash for sem_t
impl Hash for seminfo
impl Hash for tcp_info
impl Hash for termios
impl Hash for timespec
impl Hash for utmpx
impl Hash for __c_anonymous__kernel_fsid_t
impl Hash for af_alg_iv
extra_traits only.impl Hash for dmabuf_cmsg
impl Hash for dmabuf_token
impl Hash for dqblk
impl Hash for epoll_params
impl Hash for fanotify_event_info_fid
impl Hash for fanotify_event_info_header
impl Hash for fanotify_event_metadata
impl Hash for fanotify_response
impl Hash for fanout_args
impl Hash for ff_condition_effect
impl Hash for ff_constant_effect
impl Hash for ff_effect
impl Hash for ff_envelope
impl Hash for ff_periodic_effect
impl Hash for ff_ramp_effect
impl Hash for ff_replay
impl Hash for ff_rumble_effect
impl Hash for ff_trigger
impl Hash for genlmsghdr
impl Hash for hwtstamp_config
impl Hash for in6_ifreq
impl Hash for inotify_event
impl Hash for input_absinfo
impl Hash for input_event
impl Hash for input_id
impl Hash for input_keymap_entry
impl Hash for input_mask
impl Hash for iw_discarded
impl Hash for iw_encode_ext
impl Hash for iw_freq
impl Hash for iw_michaelmicfailure
impl Hash for iw_missed
impl Hash for iw_mlme
impl Hash for iw_param
impl Hash for iw_pmkid_cand
impl Hash for iw_pmksa
impl Hash for iw_point
impl Hash for iw_priv_args
impl Hash for iw_quality
impl Hash for iw_range
impl Hash for iw_scan_req
impl Hash for iw_statistics
impl Hash for iw_thrspy
impl Hash for mnt_ns_info
impl Hash for mount_attr
impl Hash for mq_attr
impl Hash for msginfo
impl Hash for nlattr
impl Hash for nlmsgerr
impl Hash for nlmsghdr
impl Hash for open_how
impl Hash for pidfd_info
impl Hash for posix_spawn_file_actions_t
impl Hash for posix_spawnattr_t
impl Hash for pthread_barrier_t
impl Hash for pthread_barrierattr_t
impl Hash for pthread_cond_t
impl Hash for pthread_condattr_t
impl Hash for pthread_mutex_t
impl Hash for pthread_mutexattr_t
impl Hash for pthread_rwlock_t
impl Hash for pthread_rwlockattr_t
impl Hash for ptp_clock_caps
impl Hash for ptp_clock_time
impl Hash for ptp_extts_event
impl Hash for ptp_extts_request
impl Hash for ptp_pin_desc
impl Hash for ptp_sys_offset
impl Hash for ptp_sys_offset_extended
impl Hash for ptp_sys_offset_precise
impl Hash for sched_attr
impl Hash for sctp_authinfo
impl Hash for sctp_initmsg
impl Hash for sctp_nxtinfo
impl Hash for sctp_prinfo
impl Hash for sctp_rcvinfo
impl Hash for sctp_sndinfo
impl Hash for sctp_sndrcvinfo
impl Hash for seccomp_data
impl Hash for seccomp_notif
impl Hash for seccomp_notif_addfd
impl Hash for seccomp_notif_resp
impl Hash for seccomp_notif_sizes
impl Hash for signalfd_siginfo
impl Hash for sock_extended_err
impl Hash for sockaddr_alg
impl Hash for sockaddr_nl
impl Hash for sockaddr_pkt
impl Hash for sockaddr_vm
impl Hash for sockaddr_xdp
impl Hash for tls12_crypto_info_aes_ccm_128
impl Hash for tls12_crypto_info_aes_gcm_128
impl Hash for tls12_crypto_info_aes_gcm_256
impl Hash for tls12_crypto_info_aria_gcm_128
impl Hash for tls12_crypto_info_aria_gcm_256
impl Hash for tls12_crypto_info_chacha20_poly1305
impl Hash for tls12_crypto_info_sm4_ccm
impl Hash for tls12_crypto_info_sm4_gcm
impl Hash for tls_crypto_info
impl Hash for tpacket2_hdr
impl Hash for tpacket3_hdr
impl Hash for tpacket_auxdata
impl Hash for tpacket_bd_ts
impl Hash for tpacket_hdr
impl Hash for tpacket_hdr_v1
impl Hash for tpacket_hdr_variant1
impl Hash for tpacket_req3
impl Hash for tpacket_req
impl Hash for tpacket_rollover_stats
impl Hash for tpacket_stats
impl Hash for tpacket_stats_v3
impl Hash for uinput_abs_setup
impl Hash for uinput_ff_erase
impl Hash for uinput_ff_upload
impl Hash for uinput_setup
impl Hash for uinput_user_dev
impl Hash for xdp_desc
impl Hash for xdp_mmap_offsets
impl Hash for xdp_mmap_offsets_v1
impl Hash for xdp_options
impl Hash for xdp_ring_offset
impl Hash for xdp_ring_offset_v1
impl Hash for xdp_statistics
impl Hash for xdp_statistics_v1
impl Hash for xdp_umem_reg
impl Hash for xdp_umem_reg_v1
impl Hash for xsk_tx_metadata_completion
impl Hash for xsk_tx_metadata_request
impl Hash for Elf32_Ehdr
impl Hash for Elf32_Phdr
impl Hash for Elf32_Shdr
impl Hash for Elf32_Sym
impl Hash for Elf64_Ehdr
impl Hash for Elf64_Phdr
impl Hash for Elf64_Shdr
impl Hash for Elf64_Sym
impl Hash for __c_anonymous_elf32_rel
impl Hash for __c_anonymous_elf32_rela
impl Hash for __c_anonymous_elf64_rel
impl Hash for __c_anonymous_elf64_rela
impl Hash for __c_anonymous_ifru_map
impl Hash for arpd_request
impl Hash for cpu_set_t
impl Hash for dirent64
impl Hash for dirent
impl Hash for dl_phdr_info
impl Hash for fsid_t
impl Hash for glob_t
impl Hash for in6_pktinfo
impl Hash for itimerspec
impl Hash for mntent
impl Hash for option
impl Hash for packet_mreq
impl Hash for passwd
impl Hash for regmatch_t
impl Hash for rlimit64
impl Hash for sembuf
impl Hash for spwd
impl Hash for ucred
impl Hash for Dl_info
impl Hash for addrinfo
impl Hash for arphdr
impl Hash for arpreq
impl Hash for arpreq_old
impl Hash for epoll_event
extra_traits and non-L4Re only.impl Hash for fd_set
impl Hash for file_clone_range
impl Hash for if_nameindex
impl Hash for ifaddrs
impl Hash for in6_rtmsg
impl Hash for in_addr
impl Hash for in_pktinfo
impl Hash for ip_mreq
impl Hash for ip_mreq_source
impl Hash for ip_mreqn
impl Hash for lconv
impl Hash for mmsghdr
impl Hash for sched_param
impl Hash for sigevent
extra_traits and non-L4Re only.impl Hash for sock_filter
impl Hash for sock_fprog
impl Hash for sockaddr
impl Hash for sockaddr_in6
impl Hash for sockaddr_in
impl Hash for sockaddr_ll
impl Hash for sockaddr_storage
impl Hash for sockaddr_un
impl Hash for statx
impl Hash for statx_timestamp
impl Hash for tm
impl Hash for utsname
impl Hash for group
impl Hash for hostent
impl Hash for in6_addr
impl Hash for iovec
impl Hash for ipv6_mreq
impl Hash for itimerval
impl Hash for linger
impl Hash for pollfd
impl Hash for protoent
impl Hash for rlimit
impl Hash for rusage
impl Hash for servent
impl Hash for sigval
impl Hash for timeval
impl Hash for tms
impl Hash for utimbuf
impl Hash for winsize
impl Hash for CodeActionKind
impl Hash for SemanticTokenModifier
impl Hash for SemanticTokenType
impl Hash for TokenFormat
impl Hash for FileChangeType
impl Hash for FileEvent
impl Hash for PositionEncodingKind
impl Hash for WatchKind
impl Hash for Mime
impl Hash for StreamResult
impl Hash for Token
impl Hash for Dir
impl Hash for Entry
impl Hash for OwningIter
impl Hash for AtFlags
impl Hash for FallocateFlags
impl Hash for FdFlag
impl Hash for OFlag
impl Hash for RenameFlags
impl Hash for SealFlag
impl Hash for SpliceFFlags
impl Hash for InterfaceAddress
impl Hash for InterfaceAddressIterator
impl Hash for DeleteModuleFlags
impl Hash for ModuleInitFlags
impl Hash for MntFlags
impl Hash for nix::mount::linux::MsFlags
impl Hash for MQ_OFlag
impl Hash for MqAttr
impl Hash for InterfaceFlags
impl Hash for PollFd
impl Hash for PollFlags
impl Hash for OpenptyResult
impl Hash for PtyMaster
impl Hash for CpuSet
impl Hash for CloneFlags
impl Hash for EpollCreateFlags
impl Hash for EpollEvent
impl Hash for EpollFlags
impl Hash for EfdFlags
impl Hash for AddWatchFlags
impl Hash for InitFlags
impl Hash for WatchDescriptor
impl Hash for MemFdCreateFlag
impl Hash for MRemapFlags
impl Hash for MapFlags
impl Hash for MlockAllFlags
impl Hash for nix::sys::mman::MsFlags
impl Hash for ProtFlags
impl Hash for Persona
impl Hash for Options
impl Hash for Dqblk
impl Hash for QuotaValidFlags
impl Hash for Usage
impl Hash for FdSet
impl Hash for SigEvent
impl Hash for SaFlags
impl Hash for SigAction
impl Hash for SigSet
impl Hash for SignalIterator
impl Hash for SfdFlags
impl Hash for SignalFd
impl Hash for AlgAddr
impl Hash for LinkAddr
impl Hash for NetlinkAddr
impl Hash for nix::sys::socket::addr::Ipv4Addr
impl Hash for nix::sys::socket::addr::Ipv6Addr
impl Hash for SockaddrIn6
impl Hash for SockaddrIn
impl Hash for UnixAddr
impl Hash for VsockAddr
impl Hash for AcceptConn
impl Hash for BindToDevice
impl Hash for Broadcast
impl Hash for DontRoute
impl Hash for Ip6tOriginalDst
impl Hash for IpAddMembership
impl Hash for IpDropMembership
impl Hash for IpFreebind
impl Hash for IpMtu
impl Hash for IpMulticastLoop
impl Hash for IpMulticastTtl
impl Hash for IpTos
impl Hash for IpTransparent
impl Hash for Ipv4OrigDstAddr
impl Hash for Ipv4PacketInfo
impl Hash for Ipv4RecvErr
impl Hash for Ipv4Ttl
impl Hash for Ipv6AddMembership
impl Hash for Ipv6DontFrag
impl Hash for Ipv6DropMembership
impl Hash for Ipv6OrigDstAddr
impl Hash for Ipv6RecvErr
impl Hash for Ipv6RecvPacketInfo
impl Hash for Ipv6TClass
impl Hash for Ipv6Ttl
impl Hash for Ipv6V6Only
impl Hash for KeepAlive
impl Hash for Linger
impl Hash for Mark
impl Hash for OobInline
impl Hash for OriginalDst
impl Hash for PassCred
impl Hash for PeerCredentials
impl Hash for Priority
impl Hash for RcvBuf
impl Hash for RcvBufForce
impl Hash for ReceiveTimeout
impl Hash for ReceiveTimestamp
impl Hash for ReceiveTimestampns
impl Hash for ReuseAddr
impl Hash for ReusePort
impl Hash for RxqOvfl
impl Hash for SendTimeout
impl Hash for SndBuf
impl Hash for SndBufForce
impl Hash for SockType
impl Hash for SocketError
impl Hash for TcpCongestion
impl Hash for TcpKeepCount
impl Hash for TcpKeepIdle
impl Hash for TcpKeepInterval
impl Hash for TcpMaxSeg
impl Hash for TcpNoDelay
impl Hash for TcpRepair
impl Hash for TcpUserTimeout
impl Hash for Timestamping
impl Hash for TxTime
impl Hash for UdpGroSegment
impl Hash for UdpGsoSegment
impl Hash for MsgFlags
impl Hash for SockFlag
impl Hash for TimestampingFlag
impl Hash for Mode
impl Hash for SFlag
impl Hash for FsFlags
impl Hash for Statvfs
impl Hash for SysInfo
impl Hash for ControlFlags
impl Hash for InputFlags
impl Hash for LocalFlags
impl Hash for OutputFlags
impl Hash for TimeSpec
impl Hash for TimeVal
impl Hash for TimerSetTimeFlags
impl Hash for TimerFlags
impl Hash for RemoteIoVec
impl Hash for UtsName
impl Hash for WaitPidFlag
impl Hash for nix::time::ClockId
impl Hash for UContext
impl Hash for AccessFlags
impl Hash for Gid
impl Hash for Pid
impl Hash for nix::unistd::Uid
impl Hash for BigInt
impl Hash for BigUint
impl Hash for TimeDiff
impl Hash for CMSOptions
impl Hash for Nid
impl Hash for OcspFlag
impl Hash for KeyIvPair
impl Hash for Pkcs7Flags
impl Hash for ExtensionContext
impl Hash for ShutdownState
impl Hash for SslMode
impl Hash for SslOptions
impl Hash for SslSessionCacheMode
impl Hash for SslVerifyMode
impl Hash for X509CheckFlags
impl Hash for X509VerifyFlags
impl Hash for plist::date::Date
impl Hash for plist::integer::Integer
impl Hash for plist::uid::Uid
impl Hash for PotentialCodePoint
impl Hash for rcgen::certificate::Attribute
impl Hash for CustomExtension
impl Hash for rcgen::csr::PublicKey
impl Hash for SignatureAlgorithm
The Hash trait is not derived, but implemented according to impl of the PartialEq trait
impl Hash for BmpString
impl Hash for Ia5String
impl Hash for PrintableString
impl Hash for TeletexString
impl Hash for UniversalString
impl Hash for SerialNumber
impl Hash for LazyStateID
impl Hash for Transition
impl Hash for NonMaxUsize
impl Hash for regex_automata::util::primitives::PatternID
impl Hash for SmallIndex
impl Hash for regex_automata::util::primitives::StateID
impl Hash for HalfMatch
impl Hash for regex_automata::util::search::Match
impl Hash for regex_automata::util::search::Span
impl Hash for rustls_pki_types::server_name::Ipv4Addr
impl Hash for rustls_pki_types::server_name::Ipv6Addr
impl Hash for UnixTime
impl Hash for Handle
impl Hash for serde_json::map::Map<String, Value>
impl Hash for Number
impl Hash for SigId
impl Hash for SmolStr
impl Hash for socket2::sockaddr::SockAddr
impl Hash for socket2::sockaddr::SockAddr
impl Hash for TransactionId
impl Hash for ErrorCode
impl Hash for Color
impl Hash for FontStyle
impl Hash for Style
impl Hash for Scope
impl Hash for ContextId
impl Hash for time::date::Date
impl Hash for time::duration::Duration
impl Hash for ComponentRange
impl Hash for OffsetDateTime
impl Hash for PrimitiveDateTime
impl Hash for Time
impl Hash for UtcDateTime
impl Hash for UtcOffset
impl Hash for AnyDelimiterCodec
impl Hash for BytesCodec
impl Hash for LinesCodec
impl Hash for tokio::net::unix::ucred::UCred
impl Hash for tokio::runtime::id::Id
impl Hash for tokio::runtime::task::id::Id
impl Hash for SignalKind
impl Hash for tokio::time::instant::Instant
impl Hash for Identifier
impl Hash for Field
impl Hash for tracing_core::metadata::Level
impl Hash for tracing_core::metadata::LevelFilter
impl Hash for tracing_core::span::Id
impl Hash for tracing::span::Span
impl Hash for FiveTuple
impl Hash for ChannelNumber
impl Hash for Protocol
impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Z0
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for OpaqueOrigin
impl Hash for Url
URLs hash like their serialization.
impl Hash for uuid::error::Error
impl Hash for Braced
impl Hash for Hyphenated
impl Hash for Simple
impl Hash for Urn
impl Hash for NonNilUuid
impl Hash for Uuid
impl Hash for Timestamp
impl Hash for webrtc::ice_transport::ice_server::RTCIceServer
impl Hash for ASN1Time
impl Hash for x25519_dalek::x25519::PublicKey
impl Hash for TaggedDerValue
impl Hash for yasna::models::oid::ObjectIdentifier
impl Hash for GeneralizedTime
impl Hash for UTCTime
impl Hash for Tag
impl Hash for CharULE
impl Hash for Index8
impl Hash for Index16
impl Hash for Index32
impl Hash for __c_anonymous_ptrace_syscall_info_data
extra_traits only.impl Hash for SockaddrStorage
impl Hash for dyn ComInterface
impl<'a> Hash for ValueKey<'a>
impl<'a> Hash for Component<'a>
impl<'a> Hash for datex_core::stdlib::path::Prefix<'a>
impl<'a> Hash for Item<'a>
impl<'a> Hash for FcntlArg<'a>
impl<'a> Hash for PrefixDeclaration<'a>
impl<'a> Hash for ServerName<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a> Hash for Oid<'a>
impl<'a> Hash for Metadata<'a>
impl<'a> Hash for MetadataBuilder<'a>
impl<'a> Hash for Name<'a>
impl<'a> Hash for LocalName<'a>
impl<'a> Hash for Namespace<'a>
impl<'a> Hash for quick_xml::name::Prefix<'a>
impl<'a> Hash for QName<'a>
impl<'a> Hash for DnsName<'a>
impl<'a> Hash for CertificateDer<'a>
impl<'a> Hash for CertificateRevocationListDer<'a>
impl<'a> Hash for CertificateSigningRequestDer<'a>
impl<'a> Hash for Der<'a>
impl<'a> Hash for EchConfigListBytes<'a>
impl<'a> Hash for SubjectPublicKeyInfoDer<'a>
impl<'a> Hash for TrustAnchor<'a>
impl<'d> Hash for Iter<'d>
impl<'ns> Hash for ResolveResult<'ns>
impl<A> Hash for ArrayString<A>
impl<A> Hash for ArrayVec<A>
impl<A> Hash for SmallVec<A>
impl<A, B> Hash for EitherOrBoth<A, B>
impl<B> Hash for Cow<'_, B>
impl<B> Hash for BitSet<B>where
B: BitBlock,
impl<B> Hash for BitVec<B>where
B: BitBlock,
impl<B, C> Hash for ControlFlow<B, C>
impl<DataStruct> Hash for ErasedMarker<DataStruct>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> Hash for Fwhere
F: FnPtr,
impl<Idx> Hash for datex_core::stdlib::ops::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::ops::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::ops::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::ops::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for datex_core::stdlib::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
impl<K, V> Hash for ringmap::map::slice::Slice<K, V>
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<K, V, S> Hash for LinkedHashMap<K, V, S>
impl<K, V, S> Hash for LiteMap<K, V, S>
impl<K, V, S> Hash for RingMap<K, V, S>
impl<L, R> Hash for Either<L, R>
impl<O> Hash for F32<O>where
O: Hash,
impl<O> Hash for F64<O>where
O: Hash,
impl<O> Hash for I16<O>where
O: Hash,
impl<O> Hash for I32<O>where
O: Hash,
impl<O> Hash for I64<O>where
O: Hash,
impl<O> Hash for I128<O>where
O: Hash,
impl<O> Hash for Isize<O>where
O: Hash,
impl<O> Hash for U16<O>where
O: Hash,
impl<O> Hash for U32<O>where
O: Hash,
impl<O> Hash for U64<O>where
O: Hash,
impl<O> Hash for U128<O>where
O: Hash,
impl<O> Hash for Usize<O>where
O: Hash,
impl<Ptr> Hash for Pin<Ptr>
impl<S> Hash for Host<S>where
S: Hash,
impl<Size> Hash for EncodedPoint<Size>where
Size: ModulusSize,
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for LocalResult<T>where
T: Hash,
impl<T> Hash for Attr<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for Discriminant<T>
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for Exclusive<T>
impl<T> Hash for Constant<T>where
T: Hash,
impl<T> Hash for AllowStdIo<T>where
T: Hash,
impl<T> Hash for indexmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for Intern<T>
The hash implementation returns the hash of the pointer value, not the hash of the value pointed to. This should be irrelevant, since there is a unique pointer for every value, but it is observable, since you could compare the hash of the pointer with hash of the data itself.
impl<T> Hash for IoVec<T>where
T: Hash,
impl<T> Hash for Complex<T>where
T: Hash,
impl<T> Hash for Ratio<T>
impl<T> Hash for NotNan<T>where
T: PrimitiveFloat,
impl<T> Hash for OrderedFloat<T>where
T: PrimitiveFloat,
impl<T> Hash for ringmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for TryWriteableInfallibleAsWriteable<T>where
T: Hash,
impl<T> Hash for WriteableAsTryWriteableInfallible<T>where
T: Hash,
impl<T> Hash for Unalign<T>
impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, A> Hash for datex_core::stdlib::boxed::Box<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for datex_core::stdlib::vec::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;
let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, E> Hash for Result<T, E>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, S> Hash for RingSet<T, S>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));