pub trait Extend<A> {
// Required method
fn extend<T>(&mut self, iter: T)
where T: IntoIterator<Item = A>;
// Provided methods
fn extend_one(&mut self, item: A) { ... }
fn extend_reserve(&mut self, additional: usize) { ... }
}Expand description
Extend a collection with the contents of an iterator.
Iterators produce a series of values, and collections can also be thought
of as a series of values. The Extend trait bridges this gap, allowing you
to extend a collection by including the contents of that iterator. When
extending a collection with an already existing key, that entry is updated
or, in the case of collections that permit multiple entries with equal
keys, that entry is inserted.
Examples
Basic usage:
// You can extend a String with some chars:
let mut message = String::from("The first three letters are: ");
message.extend(&['a', 'b', 'c']);
assert_eq!("abc", &message[29..32]);Implementing Extend:
// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);
// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
fn new() -> MyCollection {
MyCollection(Vec::new())
}
fn add(&mut self, elem: i32) {
self.0.push(elem);
}
}
// since MyCollection has a list of i32s, we implement Extend for i32
impl Extend<i32> for MyCollection {
// This is a bit simpler with the concrete type signature: we can call
// extend on anything which can be turned into an Iterator which gives
// us i32s. Because we need i32s to put into MyCollection.
fn extend<T: IntoIterator<Item=i32>>(&mut self, iter: T) {
// The implementation is very straightforward: loop through the
// iterator, and add() each element to ourselves.
for elem in iter {
self.add(elem);
}
}
}
let mut c = MyCollection::new();
c.add(5);
c.add(6);
c.add(7);
// let's extend our collection with three more numbers
c.extend(vec![1, 2, 3]);
// we've added these elements onto the end
assert_eq!("MyCollection([5, 6, 7, 1, 2, 3])", format!("{c:?}"));Required Methods
1.0.0 · Sourcefn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = A>,
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = A>,
Extends a collection with the contents of an iterator.
As this is the only required method for this trait, the trait-level docs contain more details.
Examples
// You can extend a String with some chars:
let mut message = String::from("abc");
message.extend(['d', 'e', 'f'].iter());
assert_eq!("abcdef", &message);Provided Methods
Sourcefn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (extend_one)
fn extend_one(&mut self, item: A)
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (extend_one)
fn extend_reserve(&mut self, additional: usize)
extend_one)Reserves capacity in a collection for the given number of additional elements.
The default implementation does nothing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Extend<(String, Value)> for Dictionary
impl Extend<(String, Value)> for Map<String, Value>
impl Extend<AsciiChar> for String
no_global_oom_handling only.impl Extend<Signal> for SigSet
signal only.impl Extend<char> for String
no_global_oom_handling only.impl Extend<u8> for BytesMut
impl Extend<()> for ()
impl Extend<OsString> for OsString
impl Extend<String> for String
no_global_oom_handling only.impl Extend<Bytes> for BytesMut
impl Extend<WatchKind> for WatchKind
impl Extend<AtFlags> for AtFlags
impl Extend<FallocateFlags> for FallocateFlags
impl Extend<FdFlag> for FdFlag
impl Extend<OFlag> for OFlag
impl Extend<RenameFlags> for RenameFlags
impl Extend<SealFlag> for SealFlag
impl Extend<SpliceFFlags> for SpliceFFlags
impl Extend<DeleteModuleFlags> for DeleteModuleFlags
impl Extend<ModuleInitFlags> for ModuleInitFlags
impl Extend<MntFlags> for MntFlags
impl Extend<MsFlags> for nix::mount::linux::MsFlags
impl Extend<MQ_OFlag> for MQ_OFlag
impl Extend<InterfaceFlags> for InterfaceFlags
impl Extend<PollFlags> for PollFlags
impl Extend<CloneFlags> for CloneFlags
impl Extend<EpollCreateFlags> for EpollCreateFlags
impl Extend<EpollFlags> for EpollFlags
impl Extend<EfdFlags> for EfdFlags
impl Extend<AddWatchFlags> for AddWatchFlags
impl Extend<InitFlags> for InitFlags
impl Extend<MemFdCreateFlag> for MemFdCreateFlag
impl Extend<MRemapFlags> for MRemapFlags
impl Extend<MapFlags> for MapFlags
impl Extend<MlockAllFlags> for MlockAllFlags
impl Extend<MsFlags> for nix::sys::mman::MsFlags
impl Extend<ProtFlags> for ProtFlags
impl Extend<Persona> for Persona
impl Extend<Options> for Options
impl Extend<QuotaValidFlags> for QuotaValidFlags
impl Extend<SaFlags> for SaFlags
impl Extend<SfdFlags> for SfdFlags
impl Extend<MsgFlags> for MsgFlags
impl Extend<SockFlag> for SockFlag
impl Extend<TimestampingFlag> for TimestampingFlag
impl Extend<Mode> for Mode
impl Extend<SFlag> for SFlag
impl Extend<FsFlags> for FsFlags
impl Extend<ControlFlags> for ControlFlags
impl Extend<InputFlags> for InputFlags
impl Extend<LocalFlags> for LocalFlags
impl Extend<OutputFlags> for OutputFlags
impl Extend<TimerSetTimeFlags> for TimerSetTimeFlags
impl Extend<TimerFlags> for TimerFlags
impl Extend<WaitPidFlag> for WaitPidFlag
impl Extend<AccessFlags> for AccessFlags
impl Extend<CipherCtxFlags> for CipherCtxFlags
impl Extend<CMSOptions> for CMSOptions
impl Extend<OcspFlag> for OcspFlag
impl Extend<Pkcs7Flags> for Pkcs7Flags
impl Extend<ExtensionContext> for ExtensionContext
impl Extend<ShutdownState> for ShutdownState
impl Extend<SslMode> for SslMode
impl Extend<SslOptions> for SslOptions
impl Extend<SslSessionCacheMode> for SslSessionCacheMode
impl Extend<SslVerifyMode> for SslVerifyMode
impl Extend<X509CheckFlags> for X509CheckFlags
impl Extend<X509VerifyFlags> for X509VerifyFlags
impl Extend<TrustAnchor<'static>> for RootCertStore
impl Extend<FontStyle> for FontStyle
impl<'a> Extend<&'a AsciiChar> for String
no_global_oom_handling only.impl<'a> Extend<&'a char> for String
no_global_oom_handling only.impl<'a> Extend<&'a str> for String
no_global_oom_handling only.impl<'a> Extend<&'a u8> for BytesMut
impl<'a> Extend<&'a u8> for PrefixedPayload
impl<'a> Extend<&'a OsStr> for OsString
impl<'a> Extend<Cow<'a, str>> for String
no_global_oom_handling only.impl<'a> Extend<Cow<'a, OsStr>> for OsString
impl<'a, K, V, A> Extend<(&'a K, &'a V)> for BTreeMap<K, V, A>
impl<'a, K, V, S> Extend<(&'a K, &'a V)> for datex_core::collections::HashMap<K, V, S>
impl<'a, K, V, S> Extend<(&'a K, &'a V)> for IndexMap<K, V, S>
impl<'a, K, V, S> Extend<(&'a K, &'a V)> for LinkedHashMap<K, V, S>
impl<'a, K, V, S> Extend<(&'a K, &'a V)> for RingMap<K, V, S>
impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<'a, T, A> Extend<&'a T> for BTreeSet<T, A>
impl<'a, T, A> Extend<&'a T> for BinaryHeap<T, A>
impl<'a, T, A> Extend<&'a T> for LinkedList<T, A>
impl<'a, T, A> Extend<&'a T> for VecDeque<T, A>
impl<'a, T, A> Extend<&'a T> for datex_core::stdlib::vec::Vec<T, A>
no_global_oom_handling only.Extend implementation that copies elements out of references before pushing them onto the Vec.
This implementation is specialized for slice iterators, where it uses copy_from_slice to
append the entire slice at once.
impl<'a, T, A> Extend<&'a T> for allocator_api2::stable::vec::Vec<T, A>
no_global_oom_handling only.Extend implementation that copies elements out of references before pushing them onto the Vec.
This implementation is specialized for slice iterators, where it uses copy_from_slice to
append the entire slice at once.
impl<'a, T, S> Extend<&'a T> for datex_core::collections::HashSet<T, S>
impl<'a, T, S> Extend<&'a T> for IndexSet<T, S>
impl<'a, T, S> Extend<&'a T> for RingSet<T, S>
impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
impl<A> Extend<<A as Array>::Item> for ArrayVec<A>where
A: Array,
Extend the ArrayVec with an iterator.
Does not extract more items than there is space for. No error occurs if there are more iterator elements.
impl<A> Extend<<A as Array>::Item> for SmallVec<A>where
A: Array,
impl<A> Extend<Box<str, A>> for Stringwhere
A: Allocator,
no_global_oom_handling only.impl<A> Extend<Box<str, A>> for Stringwhere
A: Allocator,
alloc only.impl<B> Extend<bool> for BitVec<B>where
B: BitBlock,
impl<B> Extend<usize> for BitSet<B>where
B: BitBlock,
impl<Fut> Extend<Fut> for FuturesOrdered<Fut>where
Fut: Future,
impl<Fut> Extend<Fut> for FuturesUnordered<Fut>
impl<K, S> Extend<K> for DashSet<K, S>
impl<K, V> Extend<(K, V)> for StreamMap<K, V>
impl<K, V, A> Extend<(K, V)> for BTreeMap<K, V, A>
impl<K, V, S> Extend<(K, V)> for datex_core::collections::HashMap<K, V, S>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<K, V, S> Extend<(K, V)> for DashMap<K, V, S>
impl<K, V, S> Extend<(K, V)> for IndexMap<K, V, S>
impl<K, V, S> Extend<(K, V)> for LinkedHashMap<K, V, S>
impl<K, V, S> Extend<(K, V)> for LiteMap<K, V, S>where
K: Ord,
S: StoreBulkMut<K, V>,
impl<K, V, S> Extend<(K, V)> for RingMap<K, V, S>
impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.
impl<L, R, A> Extend<A> for Either<L, R>
impl<P> Extend<P> for PathBuf
impl<St> Extend<St> for SelectAll<St>
impl<T> Extend<(Option<HeaderName>, T)> for HeaderMap<T>
impl<T> Extend<(HeaderName, T)> for HeaderMap<T>
impl<T, A> Extend<T> for BTreeSet<T, A>
impl<T, A> Extend<T> for BinaryHeap<T, A>
impl<T, A> Extend<T> for LinkedList<T, A>where
A: Allocator,
impl<T, A> Extend<T> for VecDeque<T, A>where
A: Allocator,
impl<T, A> Extend<T> for datex_core::stdlib::vec::Vec<T, A>where
A: Allocator,
no_global_oom_handling only.impl<T, A> Extend<T> for allocator_api2::stable::vec::Vec<T, A>where
A: Allocator,
no_global_oom_handling only.impl<T, ExtendT> Extend<(T₁, T₂, …, Tₙ)> for (ExtendT₁, ExtendT₂, …, ExtendTₙ)where
ExtendT: Extend<T>,
This trait is implemented for tuples up to twelve items long. The impls for
1- and 3- through 12-ary tuples were stabilized after 2-tuples, in 1.85.0.
impl<T, F> Extend<F> for JoinSet<T>
Extend a JoinSet with futures from an iterator.
This is equivalent to calling JoinSet::spawn on each element of the iterator.
Examples
use tokio::task::JoinSet;
#[tokio::main]
async fn main() {
let mut set: JoinSet<_> = (0..5).map(|i| async move { i }).collect();
set.extend((5..10).map(|i| async move { i }));
let mut seen = [false; 10];
while let Some(res) = set.join_next().await {
let idx = res.unwrap();
seen[idx] = true;
}
for i in 0..10 {
assert!(seen[i]);
}
}