pub struct MappedRwLockWriteGuard<'rwlock, T>where
T: 'rwlock + ?Sized,{ /* private fields */ }mapped_lock_guards)Expand description
RAII structure used to release the exclusive write access of a lock when dropped, which can point to a subfield of the protected data.
This structure is created by the map and filter_map methods
on RwLockWriteGuard.
Implementations
Sourceimpl<'rwlock, T> MappedRwLockWriteGuard<'rwlock, T>where
T: ?Sized,
impl<'rwlock, T> MappedRwLockWriteGuard<'rwlock, T>where
T: ?Sized,
Sourcepub fn map<U, F>(
orig: MappedRwLockWriteGuard<'rwlock, T>,
f: F,
) -> MappedRwLockWriteGuard<'rwlock, U>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn map<U, F>( orig: MappedRwLockWriteGuard<'rwlock, T>, f: F, ) -> MappedRwLockWriteGuard<'rwlock, U>
mapped_lock_guards)Makes a MappedRwLockWriteGuard for a component of the borrowed data,
e.g. an enum variant.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as
MappedRwLockWriteGuard::map(...). A method would interfere with
methods of the same name on the contents of the MappedRwLockWriteGuard
used through Deref.
Panics
If the closure panics, the guard will be dropped (unlocked).
Sourcepub fn filter_map<U, F>(
orig: MappedRwLockWriteGuard<'rwlock, T>,
f: F,
) -> Result<MappedRwLockWriteGuard<'rwlock, U>, MappedRwLockWriteGuard<'rwlock, T>>
🔬This is a nightly-only experimental API. (mapped_lock_guards)
pub fn filter_map<U, F>( orig: MappedRwLockWriteGuard<'rwlock, T>, f: F, ) -> Result<MappedRwLockWriteGuard<'rwlock, U>, MappedRwLockWriteGuard<'rwlock, T>>
mapped_lock_guards)Makes a MappedRwLockWriteGuard for a component of the borrowed data.
The original guard is returned as an Err(...) if the closure returns
None.
The RwLock is already locked for writing, so this cannot fail.
This is an associated function that needs to be used as
MappedRwLockWriteGuard::filter_map(...). A method would interfere with
methods of the same name on the contents of the MappedRwLockWriteGuard
used through Deref.
Panics
If the closure panics, the guard will be dropped (unlocked).