pub enum Map {
Dynamic(IndexMap<ValueContainer, ValueContainer, RandomState>),
Structural(Vec<(ValueContainer, ValueContainer)>),
StructuralWithStringKeys(Vec<(String, ValueContainer)>),
}Variants
Dynamic(IndexMap<ValueContainer, ValueContainer, RandomState>)
Structural(Vec<(ValueContainer, ValueContainer)>)
StructuralWithStringKeys(Vec<(String, ValueContainer)>)
Implementations
Sourceimpl Map
impl Map
pub fn new( entries: IndexMap<ValueContainer, ValueContainer, RandomState>, ) -> Self
pub fn is_structural(&self) -> bool
pub fn size(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn get<'a>(
&self,
key: impl Into<ValueKey<'a>>,
) -> Result<&ValueContainer, KeyNotFoundError>
pub fn get<'a>( &self, key: impl Into<ValueKey<'a>>, ) -> Result<&ValueContainer, KeyNotFoundError>
Gets a value in the map by reference. Returns None if the key is not found.
Sourcepub fn has<'a>(&self, key: impl Into<ValueKey<'a>>) -> bool
pub fn has<'a>(&self, key: impl Into<ValueKey<'a>>) -> bool
Checks if the map contains the given key.
Sourcepub fn delete<'a>(
&mut self,
key: impl Into<ValueKey<'a>>,
) -> Result<ValueContainer, MapAccessError>
pub fn delete<'a>( &mut self, key: impl Into<ValueKey<'a>>, ) -> Result<ValueContainer, MapAccessError>
Removes a key from the map, returning the value if it existed.
Sourcepub fn clear(&mut self) -> Result<(), MapAccessError>
pub fn clear(&mut self) -> Result<(), MapAccessError>
Clears all entries in the map, returning an error if the map is not dynamic.