pub enum Map {
Dynamic(IndexMap<ValueContainer, ValueContainer>),
Fixed(Vec<(ValueContainer, ValueContainer)>),
Structural(Vec<(String, ValueContainer)>),
}Variants
Dynamic(IndexMap<ValueContainer, ValueContainer>)
Fixed(Vec<(ValueContainer, ValueContainer)>)
Structural(Vec<(String, ValueContainer)>)
Implementations
Sourceimpl Map
impl Map
pub fn new(entries: IndexMap<ValueContainer, ValueContainer>) -> Self
pub fn is_structural(&self) -> bool
pub fn has_fixed_size(&self) -> bool
pub fn size(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn get(&self, key: &ValueContainer) -> Option<&ValueContainer>
pub fn get(&self, key: &ValueContainer) -> Option<&ValueContainer>
Gets a value in the map by reference. Returns None if the key is not found.
Sourcepub fn get_text(&self, key: &str) -> Option<&ValueContainer>
pub fn get_text(&self, key: &str) -> Option<&ValueContainer>
Gets a value in the map, where the key is a string. Returns None if the key is not found
Sourcepub fn has(&self, key: &ValueContainer) -> bool
pub fn has(&self, key: &ValueContainer) -> bool
Checks if the map contains the given key.
Sourcepub fn remove(
&mut self,
key: &ValueContainer,
) -> Result<ValueContainer, MapAccessError>
pub fn remove( &mut self, key: &ValueContainer, ) -> Result<ValueContainer, MapAccessError>
Removes a key from the map, returning the value if it existed.
Sourcepub fn clear(&mut self) -> Result<(), MapAccessError>
pub fn clear(&mut self) -> Result<(), MapAccessError>
Clears all entries in the map, returning an error if the map is not dynamic.
Sourcepub fn get_owned<T: Into<ValueContainer>>(
&self,
key: T,
) -> Option<&ValueContainer>
pub fn get_owned<T: Into<ValueContainer>>( &self, key: T, ) -> Option<&ValueContainer>
Gets a value in the map, taking ownership of the key.