pub enum ValueContainer {
Value(Value),
Reference(Reference),
}Variants
Implementations
Sourceimpl ValueContainer
impl ValueContainer
pub fn to_value(&self) -> Rc<RefCell<Value>>
pub fn is_type(&self) -> bool
Sourcepub fn actual_value_type(&self) -> TypeDefinition
pub fn actual_value_type(&self) -> TypeDefinition
Returns the actual type of the contained value, resolving references if necessary.
Sourcepub fn actual_container_type(&self) -> Type
pub fn actual_container_type(&self) -> Type
Returns the actual type that describes the value container (e.g. integer or &&mut integer).
pub fn new_value<T: Into<Value>>(value: T) -> ValueContainer
pub fn new_reference<T: Into<Reference>>(value: T) -> ValueContainer
Sourcepub fn cast_to_deserializable<T: DeserializeOwned>(
&self,
) -> Result<T, DeserializationError>
pub fn cast_to_deserializable<T: DeserializeOwned>( &self, ) -> Result<T, DeserializationError>
Casts the contained Value or Reference to the desired type T using serde deserialization.
Sourcepub fn from_serializable<T: Serialize>(
value: &T,
) -> Result<ValueContainer, SerializationError>
pub fn from_serializable<T: Serialize>( value: &T, ) -> Result<ValueContainer, SerializationError>
Creates a ValueContainer from a serializable value T using serde serialization.
Sourcepub fn maybe_reference(&self) -> Option<&Reference>
pub fn maybe_reference(&self) -> Option<&Reference>
Returns the contained Reference if it is a Reference, otherwise returns None.
Sourcepub fn with_maybe_reference<F, R>(&self, f: F) -> Option<R>
pub fn with_maybe_reference<F, R>(&self, f: F) -> Option<R>
Runs a closure with the contained Reference if it is a Reference, otherwise returns None.
Sourcepub fn reference_unchecked(&self) -> &Reference
pub fn reference_unchecked(&self) -> &Reference
Returns a reference to the contained Reference, panics if it is not a Reference.
Sourcepub fn try_get_property<'a>(
&self,
key: impl Into<ValueKey<'a>>,
) -> Result<ValueContainer, AccessError>
pub fn try_get_property<'a>( &self, key: impl Into<ValueKey<'a>>, ) -> Result<ValueContainer, AccessError>
Tries to get a property from the contained Value or Reference.
pub fn try_set_property<'a>( &mut self, source_id: TransceiverId, dif_update_data_or_memory: impl Into<DIFUpdateDataOrMemory<'a>>, key: impl Into<ValueKey<'a>>, val: ValueContainer, ) -> Result<(), AccessError>