pub enum ValueContainer {
Value(Value),
Reference(Reference),
}Variants
Implementations
Sourceimpl ValueContainer
impl ValueContainer
pub fn to_value(&self) -> Rc<RefCell<Value>>
pub fn is_type(&self) -> bool
Sourcepub fn allowed_type(&self) -> TypeContainer
pub fn allowed_type(&self) -> TypeContainer
Returns the allowed type of the value container
Sourcepub fn actual_type(&self) -> TypeContainer
pub fn actual_type(&self) -> TypeContainer
Returns the actual type of the contained value, resolving references if necessary.
pub fn new_value<T: Into<Value>>(value: T) -> ValueContainer
pub fn new_reference<T: Into<Reference>>(value: T) -> ValueContainer
Sourcepub fn maybe_reference(&self) -> Option<&Reference>
pub fn maybe_reference(&self) -> Option<&Reference>
Returns the contained Reference if it is a Reference, otherwise returns None.
Sourcepub fn with_maybe_reference<F, R>(&self, f: F) -> Option<R>
pub fn with_maybe_reference<F, R>(&self, f: F) -> Option<R>
Runs a closure with the contained Reference if it is a Reference, otherwise returns None.
Sourcepub fn reference_unchecked(&self) -> &Reference
pub fn reference_unchecked(&self) -> &Reference
Returns a reference to the contained Reference, panics if it is not a Reference.
Sourcepub fn upgrade_combined_value_to_reference(self) -> ValueContainer
pub fn upgrade_combined_value_to_reference(self) -> ValueContainer
Upgrades the ValueContainer to a ValueContainer::Reference if it is a ValueContainer::Value and if the contained value is a combined value, not a primitive value like integer, text, etc.