ThinBox

Struct ThinBox 

pub struct ThinBox<T>
where T: ?Sized,
{ /* private fields */ }
🔬This is a nightly-only experimental API. (thin_box)
ThinBox.

A thin pointer for heap allocation, regardless of T.

Examples

#![feature(thin_box)]
use std::boxed::ThinBox;

let five = ThinBox::new(5);
let thin_slice = ThinBox::<[i32]>::new_unsize([1, 2, 3, 4]);

let size_of_ptr = size_of::<*const ()>();
assert_eq!(size_of_ptr, size_of_val(&five));
assert_eq!(size_of_ptr, size_of_val(&thin_slice));

Implementations

Source

impl<T> ThinBox<T>

pub fn new(value: T) -> ThinBox<T>

🔬This is a nightly-only experimental API. (thin_box)

Moves a type to the heap with its Metadata stored in the heap allocation instead of on the stack.

Examples
#![feature(thin_box)]
use std::boxed::ThinBox;

let five = ThinBox::new(5);
pub fn try_new(value: T) -> Result<ThinBox<T>, AllocError>

🔬This is a nightly-only experimental API. (thin_box)

Moves a type to the heap with its Metadata stored in the heap allocation instead of on the stack. Returns an error if allocation fails, instead of aborting.

Examples
#![feature(allocator_api)]
#![feature(thin_box)]
use std::boxed::ThinBox;

let five = ThinBox::try_new(5)?;
Source

impl<Dyn> ThinBox<Dyn>
where Dyn: ?Sized,

pub fn new_unsize<T>(value: T) -> ThinBox<Dyn>
where T: Unsize<Dyn>,

🔬This is a nightly-only experimental API. (thin_box)

Moves a type to the heap with its Metadata stored in the heap allocation instead of on the stack.

Examples
#![feature(thin_box)]
use std::boxed::ThinBox;

let thin_slice = ThinBox::<[i32]>::new_unsize([1, 2, 3, 4]);