pub trait AsRef<T>where
T: ?Sized,{
// Required method
fn as_ref(&self) -> &T;
}Expand description
Used to do a cheap reference-to-reference conversion.
This trait is similar to AsMut which is used for converting between mutable references.
If you need to do a costly conversion it is better to implement From with type
&T or write a custom function.
Relation to Borrow
AsRef has the same signature as Borrow, but Borrow is different in a few aspects:
- Unlike
AsRef,Borrowhas a blanket impl for anyT, and can be used to accept either a reference or a value. (See also note onAsRef’s reflexibility below.) Borrowalso requires thatHash,EqandOrdfor a borrowed value are equivalent to those of the owned value. For this reason, if you want to borrow only a single field of a struct you can implementAsRef, but notBorrow.
Note: This trait must not fail. If the conversion can fail, use a
dedicated method which returns an Option<T> or a Result<T, E>.
Generic Implementations
AsRef auto-dereferences if the inner type is a reference or a mutable reference
(e.g.: foo.as_ref() will work the same if foo has type &mut Foo or &&mut Foo).
Note that due to historic reasons, the above currently does not hold generally for all
dereferenceable types, e.g. foo.as_ref() will not work the same as
Box::new(foo).as_ref(). Instead, many smart pointers provide an as_ref implementation which
simply returns a reference to the pointed-to value (but do not perform a cheap
reference-to-reference conversion for that value). However, AsRef::as_ref should not be
used for the sole purpose of dereferencing; instead ‘Deref coercion’ can be used:
let x = Box::new(5i32);
// Avoid this:
// let y: &i32 = x.as_ref();
// Better just write:
let y: &i32 = &x;Types which implement Deref should consider implementing AsRef<T> as follows:
impl<T> AsRef<T> for SomeType
where
T: ?Sized,
<SomeType as Deref>::Target: AsRef<T>,
{
fn as_ref(&self) -> &T {
self.deref().as_ref()
}
}Reflexivity
Ideally, AsRef would be reflexive, i.e. there would be an impl<T: ?Sized> AsRef<T> for T
with as_ref simply returning its argument unchanged.
Such a blanket implementation is currently not provided due to technical restrictions of
Rust’s type system (it would be overlapping with another existing blanket implementation for
&T where T: AsRef<U> which allows AsRef to auto-dereference, see “Generic Implementations”
above).
A trivial implementation of AsRef<T> for T must be added explicitly for a particular type T
where needed or desired. Note, however, that not all types from std contain such an
implementation, and those cannot be added by external code due to orphan rules.
Examples
By using trait bounds we can accept arguments of different types as long as they can be
converted to the specified type T.
For example: By creating a generic function that takes an AsRef<str> we express that we
want to accept all references that can be converted to &str as an argument.
Since both String and &str implement AsRef<str> we can accept both as input argument.
fn is_hello<T: AsRef<str>>(s: T) {
assert_eq!("hello", s.as_ref());
}
let s = "hello";
is_hello(s);
let s = "hello".to_string();
is_hello(s);Required Methods
Implementors
impl AsRef<str> for DecimalTypeVariant
impl AsRef<str> for IntegerTypeVariant
impl AsRef<str> for Signal
impl AsRef<str> for str
impl AsRef<str> for String
impl AsRef<str> for Graphemes
impl AsRef<str> for der::asn1::ia5_string::allocation::Ia5String
impl AsRef<str> for der::asn1::printable_string::allocation::PrintableString
impl AsRef<str> for der::asn1::teletex_string::allocation::TeletexString
impl AsRef<str> for HeaderName
impl AsRef<str> for Method
impl AsRef<str> for Authority
impl AsRef<str> for Scheme
impl AsRef<str> for Mime
impl AsRef<str> for OpensslString
impl AsRef<str> for OpensslStringRef
impl AsRef<str> for rcgen::string_types::Ia5String
impl AsRef<str> for rcgen::string_types::PrintableString
impl AsRef<str> for rcgen::string_types::TeletexString
impl AsRef<str> for DnsName<'_>
impl AsRef<str> for SmolStr
impl AsRef<str> for Field
impl AsRef<str> for Url
Return the serialization of this URL.
impl AsRef<CStr> for CStr
impl AsRef<CStr> for CString
impl AsRef<LocalWaker> for Waker
impl AsRef<ByteStr> for str
impl AsRef<ByteStr> for ByteString
impl AsRef<ByteStr> for ByteStr
impl AsRef<OsStr> for Component<'_>
impl AsRef<OsStr> for str
impl AsRef<OsStr> for String
impl AsRef<OsStr> for OsStr
impl AsRef<OsStr> for OsString
impl AsRef<OsStr> for Components<'_>
impl AsRef<OsStr> for std::path::Iter<'_>
impl AsRef<OsStr> for Path
impl AsRef<OsStr> for PathBuf
impl AsRef<OsStr> for Intern<str>
impl AsRef<OsStr> for Intern<Path>
impl AsRef<Path> for Cow<'_, OsStr>
impl AsRef<Path> for Component<'_>
impl AsRef<Path> for str
impl AsRef<Path> for String
impl AsRef<Path> for OsStr
impl AsRef<Path> for OsString
impl AsRef<Path> for Components<'_>
impl AsRef<Path> for std::path::Iter<'_>
impl AsRef<Path> for Path
impl AsRef<Path> for PathBuf
impl AsRef<Path> for Intern<str>
impl AsRef<Path> for Intern<OsStr>
impl AsRef<Graphemes> for Graphemes
impl AsRef<sigset_t> for SigSet
impl AsRef<aiocb> for AioFsync
impl AsRef<timespec> for TimeSpec
impl AsRef<sockaddr_alg> for AlgAddr
impl AsRef<sockaddr_nl> for NetlinkAddr
impl AsRef<sockaddr_vm> for VsockAddr
impl AsRef<sockaddr_in6> for SockaddrIn6
impl AsRef<sockaddr_in> for SockaddrIn
impl AsRef<sockaddr_ll> for LinkAddr
impl AsRef<sockaddr_un> for UnixAddr
impl AsRef<rusage> for Usage
impl AsRef<timeval> for TimeVal
impl AsRef<Asn1BitStringRef> for Asn1BitString
impl AsRef<Asn1EnumeratedRef> for Asn1Enumerated
impl AsRef<Asn1GeneralizedTimeRef> for Asn1GeneralizedTime
impl AsRef<Asn1IntegerRef> for Asn1Integer
impl AsRef<Asn1ObjectRef> for Asn1Object
impl AsRef<Asn1OctetStringRef> for Asn1OctetString
impl AsRef<Asn1StringRef> for Asn1String
impl AsRef<Asn1TimeRef> for Asn1Time
impl AsRef<BigNumContextRef> for BigNumContext
impl AsRef<BigNumRef> for BigNum
impl AsRef<CipherCtxRef> for CipherCtx
impl AsRef<CmsContentInfoRef> for CmsContentInfo
impl AsRef<ConfRef> for Conf
impl AsRef<DsaSigRef> for DsaSig
impl AsRef<EcGroupRef> for EcGroup
impl AsRef<EcPointRef> for EcPoint
impl AsRef<EcdsaSigRef> for EcdsaSig
impl AsRef<LibCtxRef> for LibCtx
impl AsRef<MdCtxRef> for MdCtx
impl AsRef<OcspBasicResponseRef> for OcspBasicResponse
impl AsRef<OcspCertIdRef> for OcspCertId
impl AsRef<OcspOneReqRef> for OcspOneReq
impl AsRef<OcspRequestRef> for OcspRequest
impl AsRef<OcspResponseRef> for OcspResponse
impl AsRef<Pkcs7Ref> for Pkcs7
impl AsRef<Pkcs7SignedRef> for Pkcs7Signed
impl AsRef<Pkcs7SignerInfoRef> for Pkcs7SignerInfo
impl AsRef<Pkcs12Ref> for Pkcs12
impl AsRef<ProviderRef> for Provider
impl AsRef<SrtpProtectionProfileRef> for SrtpProtectionProfile
impl AsRef<SslContextRef> for SslContext
impl AsRef<SslRef> for Ssl
impl AsRef<SslSessionRef> for SslSession
impl AsRef<OpensslStringRef> for OpensslString
impl AsRef<X509StoreBuilderRef> for X509StoreBuilder
impl AsRef<X509StoreRef> for X509Store
impl AsRef<AccessDescriptionRef> for AccessDescription
impl AsRef<DistPointNameRef> for DistPointName
impl AsRef<DistPointRef> for DistPoint
impl AsRef<GeneralNameRef> for GeneralName
impl AsRef<X509AlgorithmRef> for X509Algorithm
impl AsRef<X509CrlRef> for X509Crl
impl AsRef<X509ExtensionRef> for X509Extension
impl AsRef<X509NameEntryRef> for X509NameEntry
impl AsRef<X509NameRef> for X509Name
impl AsRef<X509ObjectRef> for X509Object
impl AsRef<X509Ref> for X509
impl AsRef<X509Ref> for X509Ref
impl AsRef<X509ReqRef> for X509Req
impl AsRef<X509RevokedRef> for X509Revoked
impl AsRef<X509StoreContextRef> for X509StoreContext
impl AsRef<X509VerifyParamRef> for X509VerifyParam
impl AsRef<Scalar> for p256::arithmetic::scalar::Scalar
impl AsRef<Scalar> for p384::arithmetic::scalar::Scalar
impl AsRef<TcpStream> for tokio::net::tcp::split::ReadHalf<'_>
impl AsRef<TcpStream> for tokio::net::tcp::split::WriteHalf<'_>
impl AsRef<TcpStream> for tokio::net::tcp::split_owned::OwnedReadHalf
impl AsRef<TcpStream> for tokio::net::tcp::split_owned::OwnedWriteHalf
impl AsRef<UnixStream> for tokio::net::unix::split::ReadHalf<'_>
impl AsRef<UnixStream> for tokio::net::unix::split::WriteHalf<'_>
impl AsRef<UnixStream> for tokio::net::unix::split_owned::OwnedReadHalf
impl AsRef<UnixStream> for tokio::net::unix::split_owned::OwnedWriteHalf
impl AsRef<Semaphore> for PollSemaphore
impl AsRef<Interval> for IntervalStream
impl AsRef<Uuid> for Braced
impl AsRef<Uuid> for Hyphenated
impl AsRef<Uuid> for Simple
impl AsRef<Uuid> for Urn
impl AsRef<Uuid> for Uuid
impl AsRef<DataChannel> for PollDataChannel
impl AsRef<Stream> for PollStream
impl AsRef<[u8; 4]> for Ipv4Addr
impl AsRef<[u8; 12]> for Nonce
impl AsRef<[u8; 16]> for Ipv6Addr
impl AsRef<[u8]> for str
impl AsRef<[u8]> for String
impl AsRef<[u8]> for ByteString
impl AsRef<[u8]> for ByteStr
impl AsRef<[u8]> for Bytes
impl AsRef<[u8]> for BytesMut
impl AsRef<[u8]> for Graphemes
impl AsRef<[u8]> for const_oid::ObjectIdentifier
impl AsRef<[u8]> for der::asn1::bmp_string::BmpString
impl AsRef<[u8]> for der::asn1::ia5_string::allocation::Ia5String
impl AsRef<[u8]> for der::asn1::octet_string::allocating::OctetString
impl AsRef<[u8]> for OctetStringRef<'_>
impl AsRef<[u8]> for der::asn1::printable_string::allocation::PrintableString
impl AsRef<[u8]> for der::asn1::teletex_string::allocation::TeletexString
impl AsRef<[u8]> for der::document::Document
impl AsRef<[u8]> for HeaderName
impl AsRef<[u8]> for HeaderValue
impl AsRef<[u8]> for ReasonPhrase
impl AsRef<[u8]> for DigestBytes
impl AsRef<[u8]> for OpensslString
impl AsRef<[u8]> for OpensslStringRef
impl AsRef<[u8]> for Data
impl AsRef<[u8]> for SerialNumber
impl AsRef<[u8]> for Literal
impl AsRef<[u8]> for ring::aead::Tag
impl AsRef<[u8]> for ring::agreement::PublicKey
impl AsRef<[u8]> for Digest
impl AsRef<[u8]> for ring::hmac::Tag
impl AsRef<[u8]> for ring::pkcs8::Document
impl AsRef<[u8]> for ring::rsa::public_key::PublicKey
impl AsRef<[u8]> for ring::signature::Signature
impl AsRef<[u8]> for AlgorithmIdentifier
impl AsRef<[u8]> for CertificateDer<'_>
impl AsRef<[u8]> for CertificateRevocationListDer<'_>
impl AsRef<[u8]> for CertificateSigningRequestDer<'_>
impl AsRef<[u8]> for Der<'_>
impl AsRef<[u8]> for EchConfigListBytes<'_>
impl AsRef<[u8]> for SubjectPublicKeyInfoDer<'_>
impl AsRef<[u8]> for AeadKey
impl AsRef<[u8]> for Iv
impl AsRef<[u8]> for Output
impl AsRef<[u8]> for rustls::crypto::hmac::Tag
impl AsRef<[u8]> for OkmBlock
impl AsRef<[u8]> for DistinguishedName
impl AsRef<[u8]> for PrefixedPayload
impl AsRef<[u8]> for rustls::quic::Tag
impl AsRef<[u8]> for Uuid
impl AsRef<[u8]> for x25519_dalek::x25519::PublicKey
impl AsRef<[u8]> for StaticSecret
impl AsRef<[u64; 6]> for p384::arithmetic::scalar::Scalar
impl AsRef<[u64]> for yasna::models::oid::ObjectIdentifier
impl<'a> AsRef<Event<'a>> for Event<'a>
impl<'a> AsRef<str> for datex_core::without_std::string::Drain<'a>
impl<'a> AsRef<str> for ObjectDescriptor<'a>
impl<'a> AsRef<str> for asn1_rs::asn1_types::strings::bmpstring::BmpString<'a>
impl<'a> AsRef<str> for GeneralString<'a>
impl<'a> AsRef<str> for GraphicString<'a>
impl<'a> AsRef<str> for asn1_rs::asn1_types::strings::ia5string::Ia5String<'a>
impl<'a> AsRef<str> for NumericString<'a>
impl<'a> AsRef<str> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>
impl<'a> AsRef<str> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>
impl<'a> AsRef<str> for UniversalString<'a>
impl<'a> AsRef<str> for Utf8String<'a>
impl<'a> AsRef<str> for VideotexString<'a>
impl<'a> AsRef<str> for VisibleString<'a>
impl<'a> AsRef<str> for Ia5StringRef<'a>
impl<'a> AsRef<str> for PrintableStringRef<'a>
impl<'a> AsRef<str> for TeletexStringRef<'a>
impl<'a> AsRef<str> for Utf8StringRef<'a>
impl<'a> AsRef<str> for VideotexStringRef<'a>
impl<'a> AsRef<str> for Name<'a>
impl<'a> AsRef<aiocb> for AioRead<'a>
impl<'a> AsRef<aiocb> for AioWrite<'a>
impl<'a> AsRef<[u8]> for datex_core::without_std::string::Drain<'a>
impl<'a> AsRef<[u8]> for BitString<'a>
impl<'a> AsRef<[u8]> for Integer<'a>
impl<'a> AsRef<[u8]> for asn1_rs::asn1_types::octetstring::OctetString<'a>
impl<'a> AsRef<[u8]> for Sequence<'a>
impl<'a> AsRef<[u8]> for Set<'a>
impl<'a> AsRef<[u8]> for BitStringObject<'a>
impl<'a> AsRef<[u8]> for Ia5StringRef<'a>
impl<'a> AsRef<[u8]> for PrintableStringRef<'a>
impl<'a> AsRef<[u8]> for TeletexStringRef<'a>
impl<'a> AsRef<[u8]> for Utf8StringRef<'a>
impl<'a> AsRef<[u8]> for VideotexStringRef<'a>
impl<'a> AsRef<[u8]> for LocalName<'a>
impl<'a> AsRef<[u8]> for Namespace<'a>
impl<'a> AsRef<[u8]> for Prefix<'a>
impl<'a> AsRef<[u8]> for QName<'a>
impl<'a> AsRef<[u8]> for TbsCertificate<'a>
impl<'a> AsRef<[u8]> for TbsCertList<'a>
impl<'a, T> AsRef<ZeroSlice<T>> for ZeroVec<'a, T>where
T: AsULE,
impl<'a, T> AsRef<T> for EncodeRef<'a, T>
impl<'a, T> AsRef<T> for EncodeValueRef<'a, T>
impl<'a, T> AsRef<[<T as AsULE>::ULE]> for ZeroVec<'a, T>where
T: AsULE,
impl<'a, T, A> AsRef<[T]> for datex_core::without_std::prelude::vec::Drain<'a, T, A>where
A: Allocator,
impl<'a, T, A> AsRef<[T]> for allocator_api2::stable::vec::drain::Drain<'a, T, A>where
A: Allocator,
impl<'a, TagKind, T, E> AsRef<T> for TaggedParser<'a, TagKind, T, E>
impl<A> AsRef<[<A as Array>::Item]> for SmallVec<A>where
A: Array,
impl<A> AsRef<[u8]> for Aad<A>
impl<B> AsRef<[u8]> for ring::agreement::UnparsedPublicKey<B>
impl<B> AsRef<[u8]> for ring::signature::UnparsedPublicKey<B>
impl<C> AsRef<<C as CurveArithmetic>::AffinePoint> for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> AsRef<<C as CurveArithmetic>::AffinePoint> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
impl<C> AsRef<<C as CurveArithmetic>::Scalar> for BlindedScalar<C>where
C: CurveArithmetic,
impl<C> AsRef<<C as CurveArithmetic>::Scalar> for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> AsRef<VerifyingKey<C>> for SigningKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
impl<C> AsRef<[u8]> for ecdsa::der::Signature<C>
impl<C> AsRef<[Limb]> for ScalarPrimitive<C>where
C: Curve,
impl<L, R> AsRef<str> for Either<L, R>
impl<L, R> AsRef<CStr> for Either<L, R>
Requires crate feature std.
impl<L, R> AsRef<OsStr> for Either<L, R>
Requires crate feature std.
impl<L, R> AsRef<Path> for Either<L, R>
Requires crate feature std.