pub trait TryFrom<T>: Sized {
type Error;
// Required method
fn try_from(value: T) -> Result<Self, Self::Error>;
}Expand description
Simple and safe type conversions that may fail in a controlled
way under some circumstances. It is the reciprocal of TryInto.
This is useful when you are doing a type conversion that may
trivially succeed but may also need special handling.
For example, there is no way to convert an i64 into an i32
using the From trait, because an i64 may contain a value
that an i32 cannot represent and so the conversion would lose data.
This might be handled by truncating the i64 to an i32 or by
simply returning i32::MAX, or by some other method. The From
trait is intended for perfect conversions, so the TryFrom trait
informs the programmer when a type conversion could go bad and lets
them decide how to handle it.
Generic Implementations
TryFrom<T> for UimpliesTryInto<U> for Ttry_fromis reflexive, which means thatTryFrom<T> for Tis implemented and cannot fail – the associatedErrortype for callingT::try_from()on a value of typeTisInfallible. When the!type is stabilizedInfallibleand!will be equivalent.
Prefer using TryInto over TryFrom when specifying trait bounds on a generic function
to ensure that types that only implement TryInto can be used as well.
TryFrom<T> can be implemented as follows:
struct GreaterThanZero(i32);
impl TryFrom<i32> for GreaterThanZero {
type Error = &'static str;
fn try_from(value: i32) -> Result<Self, Self::Error> {
if value <= 0 {
Err("GreaterThanZero only accepts values greater than zero!")
} else {
Ok(GreaterThanZero(value))
}
}
}Examples
As described, i32 implements TryFrom<i64>:
let big_number = 1_000_000_000_000i64;
// Silently truncates `big_number`, requires detecting
// and handling the truncation after the fact.
let smaller_number = big_number as i32;
assert_eq!(smaller_number, -727379968);
// Returns an error because `big_number` is too big to
// fit in an `i32`.
let try_smaller_number = i32::try_from(big_number);
assert!(try_smaller_number.is_err());
// Returns `Ok(3)`.
let try_successful_smaller_number = i32::try_from(3);
assert!(try_successful_smaller_number.is_ok());Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl TryFrom<&DatexExpression> for ValueContainer
impl TryFrom<&DatexExpression> for ValueContainer
Sourceimpl TryFrom<&PointerAddress> for CoreLibPointerId
impl TryFrom<&PointerAddress> for CoreLibPointerId
Sourceimpl TryFrom<&str> for InterfaceDirection
impl TryFrom<&str> for InterfaceDirection
type Error = ParseError
Sourceimpl TryFrom<&str> for DecimalTypeVariant
impl TryFrom<&str> for DecimalTypeVariant
type Error = ParseError
Sourceimpl TryFrom<&str> for IntegerTypeVariant
impl TryFrom<&str> for IntegerTypeVariant
type Error = ParseError
Sourceimpl TryFrom<&str> for LogSpecification
impl TryFrom<&str> for LogSpecification
type Error = FlexiLoggerError
Sourceimpl TryFrom<&String> for LogSpecification
impl TryFrom<&String> for LogSpecification
type Error = FlexiLoggerError
Sourceimpl TryFrom<&String> for PathAndQuery
impl TryFrom<&String> for PathAndQuery
type Error = InvalidUri
Sourceimpl TryFrom<&SystemTime> for der::asn1::generalized_time::GeneralizedTime
impl TryFrom<&SystemTime> for der::asn1::generalized_time::GeneralizedTime
Sourceimpl TryFrom<&PrivateKeyInfo<'_>> for SecretDocument
impl TryFrom<&PrivateKeyInfo<'_>> for SecretDocument
Sourceimpl TryFrom<&EcPrivateKey<'_>> for SecretDocument
impl TryFrom<&EcPrivateKey<'_>> for SecretDocument
Sourceimpl TryFrom<&[u8]> for CompressedEdwardsY
impl TryFrom<&[u8]> for CompressedEdwardsY
type Error = TryFromSliceError
Sourceimpl TryFrom<&[u8]> for CompressedRistretto
impl TryFrom<&[u8]> for CompressedRistretto
type Error = TryFromSliceError
Sourceimpl TryFrom<InstructionCode> for AssignmentOperator
impl TryFrom<InstructionCode> for AssignmentOperator
Sourceimpl TryFrom<Error> for InvalidFormatDescription
impl TryFrom<Error> for InvalidFormatDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ParseFromDescription
impl TryFrom<Error> for ParseFromDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for TryFromParsed
impl TryFrom<Error> for TryFromParsed
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ComponentRange
impl TryFrom<Error> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ConversionRange
impl TryFrom<Error> for ConversionRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for DifferentVariant
impl TryFrom<Error> for DifferentVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for InvalidVariant
impl TryFrom<Error> for InvalidVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Format> for ComponentRange
impl TryFrom<Format> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<Parse> for ParseFromDescription
impl TryFrom<Parse> for ParseFromDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Parse> for TryFromParsed
impl TryFrom<Parse> for TryFromParsed
type Error = DifferentVariant
Sourceimpl TryFrom<TryFromParsed> for ComponentRange
impl TryFrom<TryFromParsed> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<BorrowedFormatItem<'_>> for Component
impl TryFrom<BorrowedFormatItem<'_>> for Component
type Error = DifferentVariant
Sourceimpl TryFrom<OwnedFormatItem> for Component
impl TryFrom<OwnedFormatItem> for Component
type Error = DifferentVariant
Sourceimpl TryFrom<OwnedFormatItem> for Vec<OwnedFormatItem>
impl TryFrom<OwnedFormatItem> for Vec<OwnedFormatItem>
type Error = DifferentVariant
1.59.0 (const: unstable) · Sourceimpl TryFrom<char> for u8
Maps a char with code point in U+0000..=U+00FF to a byte in 0x00..=0xFF with same value,
failing if the code point is greater than U+00FF.
impl TryFrom<char> for u8
Maps a char with code point in U+0000..=U+00FF to a byte in 0x00..=0xFF with same value,
failing if the code point is greater than U+00FF.
See impl From<u8> for char for details on the encoding.
type Error = TryFromCharError
1.74.0 (const: unstable) · Sourceimpl TryFrom<char> for u16
Maps a char with code point in U+0000..=U+FFFF to a u16 in 0x0000..=0xFFFF with same value,
failing if the code point is greater than U+FFFF.
impl TryFrom<char> for u16
Maps a char with code point in U+0000..=U+FFFF to a u16 in 0x0000..=0xFFFF with same value,
failing if the code point is greater than U+FFFF.
This corresponds to the UCS-2 encoding, as specified in ISO/IEC 10646:2003.
type Error = TryFromCharError
Sourceimpl TryFrom<f32> for BigDecimal
impl TryFrom<f32> for BigDecimal
type Error = ParseBigDecimalError
Sourceimpl TryFrom<f64> for BigDecimal
impl TryFrom<f64> for BigDecimal
type Error = ParseBigDecimalError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i8> for NonZero<i8>
impl TryFrom<i8> for NonZero<i8>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i16> for NonZero<i16>
impl TryFrom<i16> for NonZero<i16>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i32> for NonZero<i32>
impl TryFrom<i32> for NonZero<i32>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i64> for NonZero<i64>
impl TryFrom<i64> for NonZero<i64>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i128> for NonZero<i128>
impl TryFrom<i128> for NonZero<i128>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<isize> for NonZero<isize>
impl TryFrom<isize> for NonZero<isize>
type Error = TryFromIntError
Sourceimpl TryFrom<u8> for InstructionCode
impl TryFrom<u8> for InstructionCode
Sourceimpl TryFrom<u8> for TypeSpaceInstructionCode
impl TryFrom<u8> for TypeSpaceInstructionCode
Sourceimpl TryFrom<u8> for ReferenceMutability
impl TryFrom<u8> for ReferenceMutability
Sourceimpl TryFrom<u8> for BigDecimalType
impl TryFrom<u8> for BigDecimalType
Sourceimpl TryFrom<u8> for DecimalTypeVariant
impl TryFrom<u8> for DecimalTypeVariant
Sourceimpl TryFrom<u8> for IntegerTypeVariant
impl TryFrom<u8> for IntegerTypeVariant
Sourceimpl TryFrom<u8> for Weekday
Any weekday can be represented as an integer from 0 to 6, which equals to
Weekday::num_days_from_monday in this implementation.
Do not heavily depend on this though; use explicit methods whenever possible.
impl TryFrom<u8> for Weekday
Any weekday can be represented as an integer from 0 to 6, which equals to
Weekday::num_days_from_monday in this implementation.
Do not heavily depend on this though; use explicit methods whenever possible.
type Error = OutOfRange
Sourceimpl TryFrom<u8> for GeneralCategory
impl TryFrom<u8> for GeneralCategory
1.46.0 (const: unstable) · Sourceimpl TryFrom<u8> for NonZero<u8>
impl TryFrom<u8> for NonZero<u8>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u16> for NonZero<u16>
impl TryFrom<u16> for NonZero<u16>
type Error = TryFromIntError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::PatternID
impl TryFrom<u16> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::StateID
impl TryFrom<u16> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u16> for StatusCode
impl TryFrom<u16> for StatusCode
type Error = InvalidStatusCode
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::PatternID
impl TryFrom<u16> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for SmallIndex
impl TryFrom<u16> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::StateID
impl TryFrom<u16> for regex_automata::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u32> for InternalSlot
impl TryFrom<u32> for InternalSlot
1.46.0 (const: unstable) · Sourceimpl TryFrom<u32> for NonZero<u32>
impl TryFrom<u32> for NonZero<u32>
type Error = TryFromIntError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::PatternID
impl TryFrom<u32> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::StateID
impl TryFrom<u32> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::PatternID
impl TryFrom<u32> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for SmallIndex
impl TryFrom<u32> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::StateID
impl TryFrom<u32> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u64> for NonZero<u64>
impl TryFrom<u64> for NonZero<u64>
type Error = TryFromIntError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::PatternID
impl TryFrom<u64> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::StateID
impl TryFrom<u64> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::PatternID
impl TryFrom<u64> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for SmallIndex
impl TryFrom<u64> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::StateID
impl TryFrom<u64> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u128> for NonZero<u128>
impl TryFrom<u128> for NonZero<u128>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<usize> for NonZero<usize>
impl TryFrom<usize> for NonZero<usize>
type Error = TryFromIntError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::PatternID
impl TryFrom<usize> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::StateID
impl TryFrom<usize> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::PatternID
impl TryFrom<usize> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for SmallIndex
impl TryFrom<usize> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::StateID
impl TryFrom<usize> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u8>
impl TryFrom<NonZero<i8>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u16>
impl TryFrom<NonZero<i8>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u32>
impl TryFrom<NonZero<i8>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u64>
impl TryFrom<NonZero<i8>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u128>
impl TryFrom<NonZero<i8>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<usize>
impl TryFrom<NonZero<i8>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<i8>
impl TryFrom<NonZero<i16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u8>
impl TryFrom<NonZero<i16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u16>
impl TryFrom<NonZero<i16>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u32>
impl TryFrom<NonZero<i16>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u64>
impl TryFrom<NonZero<i16>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u128>
impl TryFrom<NonZero<i16>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<usize>
impl TryFrom<NonZero<i16>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i8>
impl TryFrom<NonZero<i32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i16>
impl TryFrom<NonZero<i32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<isize>
impl TryFrom<NonZero<i32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u8>
impl TryFrom<NonZero<i32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u16>
impl TryFrom<NonZero<i32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u32>
impl TryFrom<NonZero<i32>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u64>
impl TryFrom<NonZero<i32>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u128>
impl TryFrom<NonZero<i32>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<usize>
impl TryFrom<NonZero<i32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i8>
impl TryFrom<NonZero<i64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i16>
impl TryFrom<NonZero<i64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i32>
impl TryFrom<NonZero<i64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<isize>
impl TryFrom<NonZero<i64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u8>
impl TryFrom<NonZero<i64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u16>
impl TryFrom<NonZero<i64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u32>
impl TryFrom<NonZero<i64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u64>
impl TryFrom<NonZero<i64>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u128>
impl TryFrom<NonZero<i64>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<usize>
impl TryFrom<NonZero<i64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i8>
impl TryFrom<NonZero<i128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i16>
impl TryFrom<NonZero<i128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i32>
impl TryFrom<NonZero<i128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i64>
impl TryFrom<NonZero<i128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<isize>
impl TryFrom<NonZero<i128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u8>
impl TryFrom<NonZero<i128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u16>
impl TryFrom<NonZero<i128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u32>
impl TryFrom<NonZero<i128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u64>
impl TryFrom<NonZero<i128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u128>
impl TryFrom<NonZero<i128>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<usize>
impl TryFrom<NonZero<i128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i8>
impl TryFrom<NonZero<isize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i16>
impl TryFrom<NonZero<isize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i32>
impl TryFrom<NonZero<isize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i64>
impl TryFrom<NonZero<isize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i128>
impl TryFrom<NonZero<isize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u8>
impl TryFrom<NonZero<isize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u16>
impl TryFrom<NonZero<isize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u32>
impl TryFrom<NonZero<isize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u64>
impl TryFrom<NonZero<isize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u128>
impl TryFrom<NonZero<isize>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<usize>
impl TryFrom<NonZero<isize>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u8>> for NonZero<i8>
impl TryFrom<NonZero<u8>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i8>
impl TryFrom<NonZero<u16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i16>
impl TryFrom<NonZero<u16>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<isize>
impl TryFrom<NonZero<u16>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<u8>
impl TryFrom<NonZero<u16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i8>
impl TryFrom<NonZero<u32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i16>
impl TryFrom<NonZero<u32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i32>
impl TryFrom<NonZero<u32>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<isize>
impl TryFrom<NonZero<u32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u8>
impl TryFrom<NonZero<u32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u16>
impl TryFrom<NonZero<u32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<usize>
impl TryFrom<NonZero<u32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i8>
impl TryFrom<NonZero<u64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i16>
impl TryFrom<NonZero<u64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i32>
impl TryFrom<NonZero<u64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i64>
impl TryFrom<NonZero<u64>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<isize>
impl TryFrom<NonZero<u64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u8>
impl TryFrom<NonZero<u64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u16>
impl TryFrom<NonZero<u64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u32>
impl TryFrom<NonZero<u64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<usize>
impl TryFrom<NonZero<u64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i8>
impl TryFrom<NonZero<u128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i16>
impl TryFrom<NonZero<u128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i32>
impl TryFrom<NonZero<u128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i64>
impl TryFrom<NonZero<u128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i128>
impl TryFrom<NonZero<u128>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<isize>
impl TryFrom<NonZero<u128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u8>
impl TryFrom<NonZero<u128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u16>
impl TryFrom<NonZero<u128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u32>
impl TryFrom<NonZero<u128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u64>
impl TryFrom<NonZero<u128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<usize>
impl TryFrom<NonZero<u128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i8>
impl TryFrom<NonZero<usize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i16>
impl TryFrom<NonZero<usize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i32>
impl TryFrom<NonZero<usize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i64>
impl TryFrom<NonZero<usize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i128>
impl TryFrom<NonZero<usize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<isize>
impl TryFrom<NonZero<usize>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u8>
impl TryFrom<NonZero<usize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u16>
impl TryFrom<NonZero<usize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u32>
impl TryFrom<NonZero<usize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u64>
impl TryFrom<NonZero<usize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u128>
impl TryFrom<NonZero<usize>> for NonZero<u128>
type Error = TryFromIntError
Sourceimpl TryFrom<String> for ServerName<'static>
impl TryFrom<String> for ServerName<'static>
type Error = InvalidDnsNameError
Sourceimpl TryFrom<String> for der::asn1::printable_string::allocation::PrintableString
impl TryFrom<String> for der::asn1::printable_string::allocation::PrintableString
Sourceimpl TryFrom<String> for der::asn1::teletex_string::allocation::TeletexString
impl TryFrom<String> for der::asn1::teletex_string::allocation::TeletexString
Sourceimpl TryFrom<String> for HeaderName
impl TryFrom<String> for HeaderName
type Error = InvalidHeaderName
Sourceimpl TryFrom<String> for HeaderValue
impl TryFrom<String> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl TryFrom<String> for PathAndQuery
impl TryFrom<String> for PathAndQuery
type Error = InvalidUri
Sourceimpl TryFrom<Vec<u8>> for HeaderName
impl TryFrom<Vec<u8>> for HeaderName
type Error = InvalidHeaderName
Sourceimpl TryFrom<Vec<u8>> for HeaderValue
impl TryFrom<Vec<u8>> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl TryFrom<Vec<u8>> for PathAndQuery
impl TryFrom<Vec<u8>> for PathAndQuery
type Error = InvalidUri
Sourceimpl TryFrom<ByteString> for String
impl TryFrom<ByteString> for String
type Error = FromUtf8Error
Sourceimpl TryFrom<TcpListener> for TcpListener
impl TryFrom<TcpListener> for TcpListener
Sourceimpl TryFrom<UnixDatagram> for UnixDatagram
impl TryFrom<UnixDatagram> for UnixDatagram
Sourceimpl TryFrom<UnixListener> for UnixListener
impl TryFrom<UnixListener> for UnixListener
Sourceimpl TryFrom<UnixStream> for UnixStream
impl TryFrom<UnixStream> for UnixStream
Sourceimpl TryFrom<SystemTime> for der::asn1::generalized_time::GeneralizedTime
impl TryFrom<SystemTime> for der::asn1::generalized_time::GeneralizedTime
Sourceimpl TryFrom<NullString> for String
impl TryFrom<NullString> for String
type Error = FromUtf8Error
Sourceimpl TryFrom<NullWideString> for String
impl TryFrom<NullWideString> for String
type Error = FromUtf16Error
Sourceimpl TryFrom<Value> for CurrencyType
impl TryFrom<Value> for CurrencyType
Sourceimpl TryFrom<Value> for NumberingSystem
impl TryFrom<Value> for NumberingSystem
Sourceimpl TryFrom<Value> for RegionOverride
impl TryFrom<Value> for RegionOverride
Sourceimpl TryFrom<Value> for RegionalSubdivision
impl TryFrom<Value> for RegionalSubdivision
Sourceimpl TryFrom<Value> for TimeZoneShortId
impl TryFrom<Value> for TimeZoneShortId
Sourceimpl TryFrom<PrivateKeyInfo<'_>> for SecretDocument
impl TryFrom<PrivateKeyInfo<'_>> for SecretDocument
Sourceimpl TryFrom<PotentialCodePoint> for char
impl TryFrom<PotentialCodePoint> for char
type Error = CharTryFromError
Sourceimpl TryFrom<EcPrivateKey<'_>> for SecretDocument
impl TryFrom<EcPrivateKey<'_>> for SecretDocument
Sourceimpl TryFrom<Duration> for datex_core::without_std::time::Duration
impl TryFrom<Duration> for datex_core::without_std::time::Duration
type Error = ConversionRange
Sourceimpl TryFrom<Parsed> for OffsetDateTime
impl TryFrom<Parsed> for OffsetDateTime
type Error = TryFromParsed
Sourceimpl TryFrom<Parsed> for PrimitiveDateTime
impl TryFrom<Parsed> for PrimitiveDateTime
type Error = TryFromParsed
Sourceimpl TryFrom<Parsed> for UtcDateTime
impl TryFrom<Parsed> for UtcDateTime
type Error = TryFromParsed
Sourceimpl<'__der> TryFrom<&'__der Any> for der::asn1::generalized_time::GeneralizedTime
impl<'__der> TryFrom<&'__der Any> for der::asn1::generalized_time::GeneralizedTime
Sourceimpl<'__der> TryFrom<&'__der Any> for der::asn1::octet_string::allocating::OctetString
impl<'__der> TryFrom<&'__der Any> for der::asn1::octet_string::allocating::OctetString
Sourceimpl<'__der> TryFrom<&'__der Any> for der::asn1::printable_string::allocation::PrintableString
impl<'__der> TryFrom<&'__der Any> for der::asn1::printable_string::allocation::PrintableString
Sourceimpl<'__der> TryFrom<&'__der Any> for der::asn1::teletex_string::allocation::TeletexString
impl<'__der> TryFrom<&'__der Any> for der::asn1::teletex_string::allocation::TeletexString
Sourceimpl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::generalized_time::GeneralizedTime
impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::generalized_time::GeneralizedTime
Sourceimpl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::octet_string::allocating::OctetString
impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::octet_string::allocating::OctetString
Sourceimpl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::printable_string::allocation::PrintableString
impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::printable_string::allocation::PrintableString
Sourceimpl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::teletex_string::allocation::TeletexString
impl<'__der> TryFrom<AnyRef<'__der>> for der::asn1::teletex_string::allocation::TeletexString
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for BitStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for BitStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for Ia5StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for Ia5StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for OctetStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for OctetStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for PrintableStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for PrintableStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for TeletexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for TeletexStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for Utf8StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for Utf8StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for VideotexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<&'__der Any> for VideotexStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for BitStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for BitStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for Ia5StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Ia5StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for OctetStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for OctetStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for PrintableStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for PrintableStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for TeletexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for TeletexStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for Utf8StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Utf8StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for VideotexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for VideotexStringRef<'a>where
'__der: 'a,
Sourceimpl<'a> TryFrom<&&'a [u8]> for BitStringRef<'a>
Hack for simplifying the custom derive use case.
impl<'a> TryFrom<&&'a [u8]> for BitStringRef<'a>
Hack for simplifying the custom derive use case.
Sourceimpl<'a> TryFrom<&'a str> for ServerName<'a>
Attempt to make a ServerName from a string by parsing as a DNS name or IP address.
impl<'a> TryFrom<&'a str> for ServerName<'a>
Attempt to make a ServerName from a string by parsing as a DNS name or IP address.
type Error = InvalidDnsNameError
Sourceimpl<'a> TryFrom<&'a str> for HeaderName
impl<'a> TryFrom<&'a str> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a str> for HeaderValue
impl<'a> TryFrom<&'a str> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a str> for StatusCode
impl<'a> TryFrom<&'a str> for StatusCode
type Error = InvalidStatusCode
Sourceimpl<'a> TryFrom<&'a str> for PathAndQuery
impl<'a> TryFrom<&'a str> for PathAndQuery
type Error = InvalidUri
Sourceimpl<'a> TryFrom<&'a String> for HeaderName
impl<'a> TryFrom<&'a String> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a String> for HeaderValue
impl<'a> TryFrom<&'a String> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a CertificateDer<'a>> for EndEntityCert<'a>
impl<'a> TryFrom<&'a CertificateDer<'a>> for EndEntityCert<'a>
Sourceimpl<'a> TryFrom<&'a CertificateDer<'a>> for ParsedCertificate<'a>
impl<'a> TryFrom<&'a CertificateDer<'a>> for ParsedCertificate<'a>
Sourceimpl<'a> TryFrom<&'a SubjectPublicKeyInfoDer<'a>> for RawPublicKeyEntity<'a>
impl<'a> TryFrom<&'a SubjectPublicKeyInfoDer<'a>> for RawPublicKeyEntity<'a>
Sourceimpl<'a> TryFrom<&'a [u8]> for ServerName<'a>
impl<'a> TryFrom<&'a [u8]> for ServerName<'a>
type Error = InvalidDnsNameError
Sourceimpl<'a> TryFrom<&'a [u8]> for HeaderName
impl<'a> TryFrom<&'a [u8]> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a [u8]> for HeaderValue
impl<'a> TryFrom<&'a [u8]> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a [u8]> for StatusCode
impl<'a> TryFrom<&'a [u8]> for StatusCode
type Error = InvalidStatusCode
Sourceimpl<'a> TryFrom<&'a [u8]> for PathAndQuery
impl<'a> TryFrom<&'a [u8]> for PathAndQuery
type Error = InvalidUri
Sourceimpl<'a> TryFrom<BorrowedFormatItem<'a>> for &[BorrowedFormatItem<'a>]
impl<'a> TryFrom<BorrowedFormatItem<'a>> for &[BorrowedFormatItem<'a>]
type Error = DifferentVariant
Sourceimpl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
Sourceimpl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>
impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>
Sourceimpl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>
impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>
Sourceimpl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>
impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>
Sourceimpl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>
impl<'a> TryFrom<Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>
Sourceimpl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::generalizedtime::GeneralizedTime
Sourceimpl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>
impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::octetstring::OctetString<'a>
Sourceimpl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>
impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::printablestring::PrintableString<'a>
Sourceimpl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>
impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::teletexstring::TeletexString<'a>
Sourceimpl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>
impl<'a, 'b> TryFrom<&'b Any<'a>> for asn1_rs::asn1_types::strings::universalstring::UniversalString<'a>
Sourceimpl<'a, 'b> TryFrom<&'b AlgorithmIdentifier<'a>> for SignatureAlgorithm<'a>
impl<'a, 'b> TryFrom<&'b AlgorithmIdentifier<'a>> for SignatureAlgorithm<'a>
Sourceimpl<'a, 'b, E, T, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
impl<'a, 'b, E, T, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
Sourceimpl<'a, 'b, T, E, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
impl<'a, 'b, T, E, const CLASS: u8, const TAG: u32> TryFrom<&'b Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
Sourceimpl<'a, 'k, Params, Key> TryFrom<&SubjectPublicKeyInfo<Params, Key>> for Document
impl<'a, 'k, Params, Key> TryFrom<&SubjectPublicKeyInfo<Params, Key>> for Document
Sourceimpl<'a, 'k, Params, Key> TryFrom<SubjectPublicKeyInfo<Params, Key>> for Document
impl<'a, 'k, Params, Key> TryFrom<SubjectPublicKeyInfo<Params, Key>> for Document
Sourceimpl<'a, K, V, S, T> TryFrom<&'a HashMap<K, V, S>> for HeaderMap<T>
Try to convert a HashMap into a HeaderMap.
impl<'a, K, V, S, T> TryFrom<&'a HashMap<K, V, S>> for HeaderMap<T>
Try to convert a HashMap into a HeaderMap.
Examples
use std::collections::HashMap;
use std::convert::TryInto;
use http::HeaderMap;
let mut map = HashMap::new();
map.insert("X-Custom-Header".to_string(), "my value".to_string());
let headers: HeaderMap = (&map).try_into().expect("valid headers");
assert_eq!(headers["X-Custom-Header"], "my value");Sourceimpl<'a, Params> TryFrom<&'a [u8]> for spki::algorithm::AlgorithmIdentifier<Params>
impl<'a, Params> TryFrom<&'a [u8]> for spki::algorithm::AlgorithmIdentifier<Params>
Sourceimpl<'a, Params, Key> TryFrom<&'a [u8]> for SubjectPublicKeyInfo<Params, Key>
impl<'a, Params, Key> TryFrom<&'a [u8]> for SubjectPublicKeyInfo<Params, Key>
Sourceimpl<'a, T> TryFrom<Any<'a>> for asn1_rs::asn1_types::set::set_of::SetOf<T>where
T: FromBer<'a>,
impl<'a, T> TryFrom<Any<'a>> for asn1_rs::asn1_types::set::set_of::SetOf<T>where
T: FromBer<'a>,
Sourceimpl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
impl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Explicit, CLASS, TAG>
Sourceimpl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
impl<'a, T, E, const CLASS: u8, const TAG: u32> TryFrom<Any<'a>> for TaggedValue<T, E, Implicit, CLASS, TAG>
1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &[u8; 2] = <&[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &[u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &mut [u8; 2] = <&mut [u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &mut [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
Sourceimpl<'ber, 'a> TryFrom<Any<'ber>> for PolicyMapping<'a>where
'ber: 'a,
impl<'ber, 'a> TryFrom<Any<'ber>> for PolicyMapping<'a>where
'ber: 'a,
Sourceimpl<'ber, 'a> TryFrom<Any<'ber>> for EcdsaSigValue<'a>where
'ber: 'a,
impl<'ber, 'a> TryFrom<Any<'ber>> for EcdsaSigValue<'a>where
'ber: 'a,
Sourceimpl<'ber, 'a> TryFrom<Any<'ber>> for x509_parser::x509::AlgorithmIdentifier<'a>where
'ber: 'a,
impl<'ber, 'a> TryFrom<Any<'ber>> for x509_parser::x509::AlgorithmIdentifier<'a>where
'ber: 'a,
Sourceimpl<'ns> TryFrom<ResolveResult<'ns>> for Option<Namespace<'ns>>
impl<'ns> TryFrom<ResolveResult<'ns>> for Option<Namespace<'ns>>
type Error = NamespaceError
Sourceimpl<C> TryFrom<&GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
impl<C> TryFrom<&GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Sourceimpl<C> TryFrom<&AffinePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
impl<C> TryFrom<&AffinePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
Sourceimpl<C> TryFrom<&ProjectivePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
impl<C> TryFrom<&ProjectivePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
Sourceimpl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
impl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Sourceimpl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>where
C: PrimeCurveParams,
GenericArray<u8, <C as Curve>::FieldBytesSize>: Copy,
<C as Curve>::FieldBytesSize: ModulusSize,
GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>: Copy,
impl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>where
C: PrimeCurveParams,
GenericArray<u8, <C as Curve>::FieldBytesSize>: Copy,
<C as Curve>::FieldBytesSize: ModulusSize,
GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>: Copy,
Sourceimpl<C> TryFrom<&SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> TryFrom<&SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Sourceimpl<C> TryFrom<&[u8]> for SigningKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
impl<C> TryFrom<&[u8]> for SigningKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Sourceimpl<C> TryFrom<&[u8]> for SignatureWithOid<C>where
C: DigestPrimitive,
<C as DigestPrimitive>::Digest: AssociatedOid,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
NOTE: this implementation assumes the default digest for the given elliptic
curve as defined by hazmat::DigestPrimitive.
impl<C> TryFrom<&[u8]> for SignatureWithOid<C>where
C: DigestPrimitive,
<C as DigestPrimitive>::Digest: AssociatedOid,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
NOTE: this implementation assumes the default digest for the given elliptic
curve as defined by hazmat::DigestPrimitive.
When working with alternative digests, you will need to use e.g.
SignatureWithOid::new_with_digest.
Sourceimpl<C> TryFrom<&[u8]> for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> TryFrom<&[u8]> for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Sourceimpl<C> TryFrom<&[u8]> for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> TryFrom<&[u8]> for NonZeroScalar<C>where
C: CurveArithmetic,
Sourceimpl<C> TryFrom<GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
impl<C> TryFrom<GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Sourceimpl<C> TryFrom<PrivateKeyInfo<'_>> for SigningKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
impl<C> TryFrom<PrivateKeyInfo<'_>> for SigningKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Sourceimpl<C> TryFrom<PrivateKeyInfo<'_>> for SecretKey<C>
impl<C> TryFrom<PrivateKeyInfo<'_>> for SecretKey<C>
Sourceimpl<C> TryFrom<AffinePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
impl<C> TryFrom<AffinePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
Sourceimpl<C> TryFrom<ProjectivePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
impl<C> TryFrom<ProjectivePoint<C>> for PublicKey<C>where
C: PrimeCurveParams,
Sourceimpl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
impl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Sourceimpl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>where
C: PrimeCurveParams,
GenericArray<u8, <C as Curve>::FieldBytesSize>: Copy,
<C as Curve>::FieldBytesSize: ModulusSize,
GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>: Copy,
impl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for AffinePoint<C>where
C: PrimeCurveParams,
GenericArray<u8, <C as Curve>::FieldBytesSize>: Copy,
<C as Curve>::FieldBytesSize: ModulusSize,
GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>: Copy,
Sourceimpl<C> TryFrom<EcPrivateKey<'_>> for SecretKey<C>
impl<C> TryFrom<EcPrivateKey<'_>> for SecretKey<C>
Sourceimpl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for VerifyingKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for VerifyingKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Sourceimpl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Sourceimpl<Size> TryFrom<&[u8]> for EncodedPoint<Size>where
Size: ModulusSize,
impl<Size> TryFrom<&[u8]> for EncodedPoint<Size>where
Size: ModulusSize,
1.43.0 · Sourceimpl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
impl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
Sourceimpl<T, A, const N: usize> TryFrom<Box<[T], A>> for allocator_api2::stable::boxed::Box<[T; N], A>where
A: Allocator,
impl<T, A, const N: usize> TryFrom<Box<[T], A>> for allocator_api2::stable::boxed::Box<[T; N], A>where
A: Allocator,
1.34.0 (const: unstable) · Sourceimpl<T, U> TryFrom<U> for Twhere
U: Into<T>,
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,
type Error = Infallible
1.34.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));type Error = TryFromSliceError
1.59.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));