pub enum FromBytesWithNulError {
InteriorNul {
position: usize,
},
NotNulTerminated,
}Expand description
An error indicating that a nul byte was not in the expected position.
The slice used to create a CStr must have one and only one nul byte,
positioned at the end.
This error is created by the CStr::from_bytes_with_nul method.
See its documentation for more.
Examples
use std::ffi::{CStr, FromBytesWithNulError};
let _: FromBytesWithNulError = CStr::from_bytes_with_nul(b"f\0oo").unwrap_err();Variants
InteriorNul
Data provided contains an interior nul byte at byte position.
NotNulTerminated
Data provided is not nul terminated.