pub trait IntoIterator {
type Item;
type IntoIter: Iterator<Item = Self::Item>;
// Required method
fn into_iter(self) -> Self::IntoIter;
}Expand description
Conversion into an Iterator.
By implementing IntoIterator for a type, you define how it will be
converted to an iterator. This is common for types which describe a
collection of some kind.
One benefit of implementing IntoIterator is that your type will work
with Rust’s for loop syntax.
See also: FromIterator.
Examples
Basic usage:
let v = [1, 2, 3];
let mut iter = v.into_iter();
assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());Implementing IntoIterator for your type:
// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);
// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
fn new() -> MyCollection {
MyCollection(Vec::new())
}
fn add(&mut self, elem: i32) {
self.0.push(elem);
}
}
// and we'll implement IntoIterator
impl IntoIterator for MyCollection {
type Item = i32;
type IntoIter = std::vec::IntoIter<Self::Item>;
fn into_iter(self) -> Self::IntoIter {
self.0.into_iter()
}
}
// Now we can make a new collection...
let mut c = MyCollection::new();
// ... add some stuff to it ...
c.add(0);
c.add(1);
c.add(2);
// ... and then turn it into an Iterator:
for (i, n) in c.into_iter().enumerate() {
assert_eq!(i as i32, n);
}It is common to use IntoIterator as a trait bound. This allows
the input collection type to change, so long as it is still an
iterator. Additional bounds can be specified by restricting on
Item:
fn collect_as_strings<T>(collection: T) -> Vec<String>
where
T: IntoIterator,
T::Item: std::fmt::Debug,
{
collection
.into_iter()
.map(|item| format!("{item:?}"))
.collect()
}Required Associated Types
Required Methods
1.0.0 · Sourcefn into_iter(self) -> Self::IntoIter
fn into_iter(self) -> Self::IntoIter
Creates an iterator from a value.
See the module-level documentation for more.
Examples
let v = [1, 2, 3];
let mut iter = v.into_iter();
assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());Implementors
Sourceimpl IntoIterator for datex_core::values::core_values::map::Map
impl IntoIterator for datex_core::values::core_values::map::Map
type Item = (OwnedMapKey, ValueContainer)
type IntoIter = IntoMapIterator
Sourceimpl IntoIterator for IndexVec
impl IntoIterator for IndexVec
Sourceimpl IntoIterator for List
impl IntoIterator for List
type Item = ValueContainer
type IntoIter = IntoIter<ValueContainer>
Sourceimpl IntoIterator for Value
impl IntoIterator for Value
Sourceimpl IntoIterator for Dir
impl IntoIterator for Dir
Sourceimpl IntoIterator for CipherCtxFlags
impl IntoIterator for CipherCtxFlags
type Item = CipherCtxFlags
type IntoIter = Iter<CipherCtxFlags>
Sourceimpl IntoIterator for CMSOptions
impl IntoIterator for CMSOptions
type Item = CMSOptions
type IntoIter = Iter<CMSOptions>
Sourceimpl IntoIterator for OcspFlag
impl IntoIterator for OcspFlag
Sourceimpl IntoIterator for Pkcs7Flags
impl IntoIterator for Pkcs7Flags
type Item = Pkcs7Flags
type IntoIter = Iter<Pkcs7Flags>
Sourceimpl IntoIterator for ExtensionContext
impl IntoIterator for ExtensionContext
type Item = ExtensionContext
type IntoIter = Iter<ExtensionContext>
Sourceimpl IntoIterator for ShutdownState
impl IntoIterator for ShutdownState
type Item = ShutdownState
type IntoIter = Iter<ShutdownState>
Sourceimpl IntoIterator for SslOptions
impl IntoIterator for SslOptions
type Item = SslOptions
type IntoIter = Iter<SslOptions>
Sourceimpl IntoIterator for SslSessionCacheMode
impl IntoIterator for SslSessionCacheMode
type Item = SslSessionCacheMode
type IntoIter = Iter<SslSessionCacheMode>
Sourceimpl IntoIterator for SslVerifyMode
impl IntoIterator for SslVerifyMode
type Item = SslVerifyMode
type IntoIter = Iter<SslVerifyMode>
Sourceimpl IntoIterator for X509CheckFlags
impl IntoIterator for X509CheckFlags
type Item = X509CheckFlags
type IntoIter = Iter<X509CheckFlags>
Sourceimpl IntoIterator for X509VerifyFlags
impl IntoIterator for X509VerifyFlags
type Item = X509VerifyFlags
type IntoIter = Iter<X509VerifyFlags>
Sourceimpl IntoIterator for Dictionary
impl IntoIterator for Dictionary
Sourceimpl IntoIterator for regex::regexset::bytes::SetMatches
impl IntoIterator for regex::regexset::bytes::SetMatches
Sourceimpl IntoIterator for regex::regexset::string::SetMatches
impl IntoIterator for regex::regexset::string::SetMatches
Sourceimpl IntoIterator for NackPair
Create an iterator over all the packet sequence numbers expressed by this NACK pair.
impl IntoIterator for NackPair
Create an iterator over all the packet sequence numbers expressed by this NACK pair.
Sourceimpl IntoIterator for WalkDir
impl IntoIterator for WalkDir
Sourceimpl<'a> IntoIterator for &'a datex_core::values::core_values::map::Map
impl<'a> IntoIterator for &'a datex_core::values::core_values::map::Map
type Item = (MapKey<'a>, &'a ValueContainer)
type IntoIter = MapIterator<'a>
Sourceimpl<'a> IntoIterator for &'a Utf8Sequence
impl<'a> IntoIterator for &'a Utf8Sequence
Sourceimpl<'a> IntoIterator for &'a List
impl<'a> IntoIterator for &'a List
type Item = &'a ValueContainer
type IntoIter = Iter<'a, ValueContainer>
1.10.0 · Sourceimpl<'a> IntoIterator for &'a UnixListener
impl<'a> IntoIterator for &'a UnixListener
1.6.0 · Sourceimpl<'a> IntoIterator for &'a std::path::Path
impl<'a> IntoIterator for &'a std::path::Path
1.6.0 · Sourceimpl<'a> IntoIterator for &'a PathBuf
impl<'a> IntoIterator for &'a PathBuf
Sourceimpl<'a> IntoIterator for &'a RawPathParams
impl<'a> IntoIterator for &'a RawPathParams
Sourceimpl<'a> IntoIterator for &'a Bytes
impl<'a> IntoIterator for &'a Bytes
Sourceimpl<'a> IntoIterator for &'a BytesMut
impl<'a> IntoIterator for &'a BytesMut
Sourceimpl<'a> IntoIterator for &'a Events
impl<'a> IntoIterator for &'a Events
Sourceimpl<'a> IntoIterator for &'a Interfaces
impl<'a> IntoIterator for &'a Interfaces
Sourceimpl<'a> IntoIterator for &'a SigSet
impl<'a> IntoIterator for &'a SigSet
Sourceimpl<'a> IntoIterator for &'a Dictionary
impl<'a> IntoIterator for &'a Dictionary
Sourceimpl<'a> IntoIterator for &'a regex::regexset::bytes::SetMatches
impl<'a> IntoIterator for &'a regex::regexset::bytes::SetMatches
Sourceimpl<'a> IntoIterator for &'a regex::regexset::string::SetMatches
impl<'a> IntoIterator for &'a regex::regexset::string::SetMatches
Sourceimpl<'a> IntoIterator for &'a BorrowedCertRevocationList<'a>
impl<'a> IntoIterator for &'a BorrowedCertRevocationList<'a>
type Item = Result<BorrowedRevokedCert<'a>, Error>
type IntoIter = DerIterator<'a, BorrowedRevokedCert<'a>>
Sourceimpl<'a> IntoIterator for &'a serde_path_to_error::path::Path
impl<'a> IntoIterator for &'a serde_path_to_error::path::Path
Sourceimpl<'a> IntoIterator for &'a mut datex_core::values::core_values::map::Map
impl<'a> IntoIterator for &'a mut datex_core::values::core_values::map::Map
type Item = (MapKey<'a>, &'a mut ValueContainer)
type IntoIter = MapMutIterator<'a>
Sourceimpl<'a> IntoIterator for &'a mut Dictionary
impl<'a> IntoIterator for &'a mut Dictionary
Sourceimpl<'a> IntoIterator for BerObject<'a>
impl<'a> IntoIterator for BerObject<'a>
Sourceimpl<'a, 'b, T> IntoIterator for &'b GetAll<'a, T>where
'b: 'a,
impl<'a, 'b, T> IntoIterator for &'b GetAll<'a, T>where
'b: 'a,
Sourceimpl<'a, 'b, T> IntoIterator for &'b OccupiedEntry<'a, T>where
'b: 'a,
impl<'a, 'b, T> IntoIterator for &'b OccupiedEntry<'a, T>where
'b: 'a,
Sourceimpl<'a, 'b, T> IntoIterator for &'b mut OccupiedEntry<'a, T>where
'b: 'a,
impl<'a, 'b, T> IntoIterator for &'b mut OccupiedEntry<'a, T>where
'b: 'a,
Sourceimpl<'a, A> IntoIterator for &'a SmallVec<A>where
A: Array,
impl<'a, A> IntoIterator for &'a SmallVec<A>where
A: Array,
Sourceimpl<'a, A> IntoIterator for &'a mut SmallVec<A>where
A: Array,
impl<'a, A> IntoIterator for &'a mut SmallVec<A>where
A: Array,
Sourceimpl<'a, B> IntoIterator for &'a BitSet<B>where
B: BitBlock,
impl<'a, B> IntoIterator for &'a BitSet<B>where
B: BitBlock,
Sourceimpl<'a, B> IntoIterator for &'a BitVec<B>where
B: BitBlock,
impl<'a, B> IntoIterator for &'a BitVec<B>where
B: BitBlock,
Sourceimpl<'a, Fut> IntoIterator for &'a FuturesUnordered<Fut>where
Fut: Unpin,
impl<'a, Fut> IntoIterator for &'a FuturesUnordered<Fut>where
Fut: Unpin,
Sourceimpl<'a, Fut> IntoIterator for &'a mut FuturesUnordered<Fut>where
Fut: Unpin,
impl<'a, Fut> IntoIterator for &'a mut FuturesUnordered<Fut>where
Fut: Unpin,
Sourceimpl<'a, I> IntoIterator for &'a IntoChunks<I>
impl<'a, I> IntoIterator for &'a IntoChunks<I>
Sourceimpl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
impl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
Sourceimpl<'a, K, V> IntoIterator for &'a indexmap::map::slice::Slice<K, V>
impl<'a, K, V> IntoIterator for &'a indexmap::map::slice::Slice<K, V>
Sourceimpl<'a, K, V> IntoIterator for &'a ringmap::map::slice::Slice<K, V>
impl<'a, K, V> IntoIterator for &'a ringmap::map::slice::Slice<K, V>
Sourceimpl<'a, K, V> IntoIterator for &'a mut indexmap::map::slice::Slice<K, V>
impl<'a, K, V> IntoIterator for &'a mut indexmap::map::slice::Slice<K, V>
Sourceimpl<'a, K, V> IntoIterator for &'a mut ringmap::map::slice::Slice<K, V>
impl<'a, K, V> IntoIterator for &'a mut ringmap::map::slice::Slice<K, V>
1.0.0 · Sourceimpl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
impl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
1.0.0 · Sourceimpl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
impl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
1.0.0 · Sourceimpl<'a, K, V, S> IntoIterator for &'a std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a std::collections::hash::map::HashMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a LinkedHashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a LinkedHashMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a LiteMap<K, V, S>where
S: StoreIterable<'a, K, V>,
impl<'a, K, V, S> IntoIterator for &'a LiteMap<K, V, S>where
S: StoreIterable<'a, K, V>,
type Item = (&'a K, &'a V)
type IntoIter = <S as StoreIterable<'a, K, V>>::KeyValueIter
Sourceimpl<'a, K, V, S> IntoIterator for &'a RingMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a RingMap<K, V, S>
1.0.0 · Sourceimpl<'a, K, V, S> IntoIterator for &'a mut std::collections::hash::map::HashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut std::collections::hash::map::HashMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a mut LinkedHashMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut LinkedHashMap<K, V, S>
Sourceimpl<'a, K, V, S> IntoIterator for &'a mut LiteMap<K, V, S>where
S: StoreIterableMut<'a, K, V>,
impl<'a, K, V, S> IntoIterator for &'a mut LiteMap<K, V, S>where
S: StoreIterableMut<'a, K, V>,
type Item = (&'a K, &'a mut V)
type IntoIter = <S as StoreIterableMut<'a, K, V>>::KeyValueIterMut
Sourceimpl<'a, K, V, S> IntoIterator for &'a mut RingMap<K, V, S>
impl<'a, K, V, S> IntoIterator for &'a mut RingMap<K, V, S>
Sourceimpl<'a, K, V, S, A> IntoIterator for &'a hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
Sourceimpl<'a, K, V, S, A> IntoIterator for &'a hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
Sourceimpl<'a, K, V, S, A> IntoIterator for &'a mut hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a mut hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
Sourceimpl<'a, K, V, S, A> IntoIterator for &'a mut hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
impl<'a, K, V, S, A> IntoIterator for &'a mut hashbrown::map::HashMap<K, V, S, A>where
A: Allocator,
Sourceimpl<'a, K: NextKey, T> IntoIterator for &'a FreeHashMap<K, T>
impl<'a, K: NextKey, T> IntoIterator for &'a FreeHashMap<K, T>
Sourceimpl<'a, K: NextKey, T> IntoIterator for &'a mut FreeHashMap<K, T>
impl<'a, K: NextKey, T> IntoIterator for &'a mut FreeHashMap<K, T>
Sourceimpl<'a, St> IntoIterator for &'a SelectAll<St>
impl<'a, St> IntoIterator for &'a SelectAll<St>
Sourceimpl<'a, St> IntoIterator for &'a mut SelectAll<St>
impl<'a, St> IntoIterator for &'a mut SelectAll<St>
1.4.0 · Sourceimpl<'a, T> IntoIterator for &'a Option<T>
impl<'a, T> IntoIterator for &'a Option<T>
1.0.0 · Sourceimpl<'a, T> IntoIterator for &'a [T]
impl<'a, T> IntoIterator for &'a [T]
Sourceimpl<'a, T> IntoIterator for &'a std::sync::mpmc::Receiver<T>
impl<'a, T> IntoIterator for &'a std::sync::mpmc::Receiver<T>
1.1.0 · Sourceimpl<'a, T> IntoIterator for &'a std::sync::mpsc::Receiver<T>
impl<'a, T> IntoIterator for &'a std::sync::mpsc::Receiver<T>
Sourceimpl<'a, T> IntoIterator for &'a HeaderMap<T>
impl<'a, T> IntoIterator for &'a HeaderMap<T>
Sourceimpl<'a, T> IntoIterator for &'a indexmap::set::slice::Slice<T>
impl<'a, T> IntoIterator for &'a indexmap::set::slice::Slice<T>
Sourceimpl<'a, T> IntoIterator for &'a Stack<T>where
T: Stackable,
impl<'a, T> IntoIterator for &'a Stack<T>where
T: Stackable,
Sourceimpl<'a, T> IntoIterator for &'a StackRef<T>where
T: Stackable,
impl<'a, T> IntoIterator for &'a StackRef<T>where
T: Stackable,
Sourceimpl<'a, T> IntoIterator for &'a ringmap::set::slice::Slice<T>
impl<'a, T> IntoIterator for &'a ringmap::set::slice::Slice<T>
Sourceimpl<'a, T> IntoIterator for &'a Slab<T>
impl<'a, T> IntoIterator for &'a Slab<T>
1.4.0 · Sourceimpl<'a, T> IntoIterator for &'a mut Option<T>
impl<'a, T> IntoIterator for &'a mut Option<T>
1.0.0 · Sourceimpl<'a, T> IntoIterator for &'a mut [T]
impl<'a, T> IntoIterator for &'a mut [T]
Sourceimpl<'a, T> IntoIterator for &'a mut HeaderMap<T>
impl<'a, T> IntoIterator for &'a mut HeaderMap<T>
Sourceimpl<'a, T> IntoIterator for &'a mut Stack<T>where
T: Stackable,
impl<'a, T> IntoIterator for &'a mut Stack<T>where
T: Stackable,
Sourceimpl<'a, T> IntoIterator for &'a mut StackRef<T>where
T: Stackable,
impl<'a, T> IntoIterator for &'a mut StackRef<T>where
T: Stackable,
Sourceimpl<'a, T> IntoIterator for &'a mut Slab<T>
impl<'a, T> IntoIterator for &'a mut Slab<T>
Sourceimpl<'a, T> IntoIterator for GetAll<'a, T>
impl<'a, T> IntoIterator for GetAll<'a, T>
Sourceimpl<'a, T> IntoIterator for OccupiedEntry<'a, T>
impl<'a, T> IntoIterator for OccupiedEntry<'a, T>
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
impl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a LinkedList<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a LinkedList<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a VecDeque<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a datex_core::without_std::prelude::Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a datex_core::without_std::prelude::Vec<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a allocator_api2::stable::vec::Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a allocator_api2::stable::vec::Vec<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a hashbrown::table::HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a hashbrown::table::HashTable<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a hashbrown::table::HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a hashbrown::table::HashTable<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, A> IntoIterator for &'a mut datex_core::without_std::prelude::Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut datex_core::without_std::prelude::Vec<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a mut allocator_api2::stable::vec::Vec<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut allocator_api2::stable::vec::Vec<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a mut hashbrown::table::HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut hashbrown::table::HashTable<T, A>where
A: Allocator,
Sourceimpl<'a, T, A> IntoIterator for &'a mut hashbrown::table::HashTable<T, A>where
A: Allocator,
impl<'a, T, A> IntoIterator for &'a mut hashbrown::table::HashTable<T, A>where
A: Allocator,
1.4.0 · Sourceimpl<'a, T, E> IntoIterator for &'a Result<T, E>
impl<'a, T, E> IntoIterator for &'a Result<T, E>
1.4.0 · Sourceimpl<'a, T, E> IntoIterator for &'a mut Result<T, E>
impl<'a, T, E> IntoIterator for &'a mut Result<T, E>
Sourceimpl<'a, T, N> IntoIterator for &'a GenericArray<T, N>where
T: 'a,
N: ArrayLength<T>,
impl<'a, T, N> IntoIterator for &'a GenericArray<T, N>where
T: 'a,
N: ArrayLength<T>,
Sourceimpl<'a, T, N> IntoIterator for &'a mut GenericArray<T, N>where
T: 'a,
N: ArrayLength<T>,
impl<'a, T, N> IntoIterator for &'a mut GenericArray<T, N>where
T: 'a,
N: ArrayLength<T>,
1.0.0 · Sourceimpl<'a, T, S> IntoIterator for &'a std::collections::hash::set::HashSet<T, S>
impl<'a, T, S> IntoIterator for &'a std::collections::hash::set::HashSet<T, S>
Sourceimpl<'a, T, S> IntoIterator for &'a IndexSet<T, S>
impl<'a, T, S> IntoIterator for &'a IndexSet<T, S>
Sourceimpl<'a, T, S> IntoIterator for &'a RingSet<T, S>
impl<'a, T, S> IntoIterator for &'a RingSet<T, S>
Sourceimpl<'a, T, S, A> IntoIterator for &'a hashbrown::set::HashSet<T, S, A>where
A: Allocator,
impl<'a, T, S, A> IntoIterator for &'a hashbrown::set::HashSet<T, S, A>where
A: Allocator,
Sourceimpl<'a, T, S, A> IntoIterator for &'a hashbrown::set::HashSet<T, S, A>where
A: Allocator,
impl<'a, T, S, A> IntoIterator for &'a hashbrown::set::HashSet<T, S, A>where
A: Allocator,
1.0.0 · Sourceimpl<'a, T, const N: usize> IntoIterator for &'a [T; N]
impl<'a, T, const N: usize> IntoIterator for &'a [T; N]
1.0.0 · Sourceimpl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]
impl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]
Sourceimpl<'inp, 'out, T> IntoIterator for InOutBuf<'inp, 'out, T>
impl<'inp, 'out, T> IntoIterator for InOutBuf<'inp, 'out, T>
Sourceimpl<'src> IntoIterator for &'src Graphemes
impl<'src> IntoIterator for &'src Graphemes
Sourceimpl<A> IntoIterator for Range<A>where
A: Step,
impl<A> IntoIterator for Range<A>where
A: Step,
Sourceimpl<A> IntoIterator for RangeFrom<A>where
A: Step,
impl<A> IntoIterator for RangeFrom<A>where
A: Step,
Sourceimpl<A> IntoIterator for RangeInclusive<A>where
A: Step,
impl<A> IntoIterator for RangeInclusive<A>where
A: Step,
Sourceimpl<A> IntoIterator for SmallVec<A>where
A: Array,
impl<A> IntoIterator for SmallVec<A>where
A: Array,
Sourceimpl<B> IntoIterator for BitVec<B>where
B: BitBlock,
impl<B> IntoIterator for BitVec<B>where
B: BitBlock,
Sourceimpl<Fut> IntoIterator for FuturesUnordered<Fut>where
Fut: Unpin,
impl<Fut> IntoIterator for FuturesUnordered<Fut>where
Fut: Unpin,
Sourceimpl<I> IntoIterator for &RcIter<I>where
I: Iterator,
Return an iterator from &RcIter<I> (by simply cloning it).
impl<I> IntoIterator for &RcIter<I>where
I: Iterator,
Return an iterator from &RcIter<I> (by simply cloning it).