Trait UnwindSafe

1.41.0 · Source
pub auto trait UnwindSafe { }
A marker trait which represents “panic safe” types in Rust.

This trait is implemented by default for many types and behaves similarly in terms of inference of implementation to the Send and Sync traits. The purpose of this trait is to encode what types are safe to cross a catch_unwind boundary with no fear of unwind safety.

What is unwind safety?

In Rust a function can “return” early if it either panics or calls a function which transitively panics. This sort of control flow is not always anticipated, and has the possibility of causing subtle bugs through a combination of two critical components:

  1. A data structure is in a temporarily invalid state when the thread panics.
  2. This broken invariant is then later observed.

Typically in Rust, it is difficult to perform step (2) because catching a panic involves either spawning a thread (which in turn makes it difficult to later witness broken invariants) or using the catch_unwind function in this module. Additionally, even if an invariant is witnessed, it typically isn’t a problem in Rust because there are no uninitialized values (like in C or C++).

It is possible, however, for logical invariants to be broken in Rust, which can end up causing behavioral bugs. Another key aspect of unwind safety in Rust is that, in the absence of unsafe code, a panic cannot lead to memory unsafety.

That was a bit of a whirlwind tour of unwind safety, but for more information about unwind safety and how it applies to Rust, see an associated RFC.

What is UnwindSafe?

Now that we’ve got an idea of what unwind safety is in Rust, it’s also important to understand what this trait represents. As mentioned above, one way to witness broken invariants is through the catch_unwind function in this module as it allows catching a panic and then re-using the environment of the closure.

Simply put, a type T implements UnwindSafe if it cannot easily allow witnessing a broken invariant through the use of catch_unwind (catching a panic). This trait is an auto trait, so it is automatically implemented for many types, and it is also structurally composed (e.g., a struct is unwind safe if all of its components are unwind safe).

Note, however, that this is not an unsafe trait, so there is not a succinct contract that this trait is providing. Instead it is intended as more of a “speed bump” to alert users of catch_unwind that broken invariants may be witnessed and may need to be accounted for.

Who implements UnwindSafe?

Types such as &mut T and &RefCell<T> are examples which are not unwind safe. The general idea is that any mutable state which can be shared across catch_unwind is not unwind safe by default. This is because it is very easy to witness a broken invariant outside of catch_unwind as the data is simply accessed as usual.

Types like &Mutex<T>, however, are unwind safe because they implement poisoning by default. They still allow witnessing a broken invariant, but they already provide their own “speed bumps” to do so.

When should UnwindSafe be used?

It is not intended that most types or functions need to worry about this trait. It is only used as a bound on the catch_unwind function and as mentioned above, the lack of unsafe means it is mostly an advisory. The AssertUnwindSafe wrapper struct can be used to force this trait to be implemented for any closed over variables passed to catch_unwind.

Implementors

1.9.0 · Source

impl UnwindSafe for Stderr

1.9.0 · Source

impl UnwindSafe for StderrLock<'_>

1.9.0 · Source

impl UnwindSafe for Stdout

1.9.0 · Source

impl UnwindSafe for StdoutLock<'_>

1.9.0 · Source

impl UnwindSafe for Condvar

1.59.0 · Source

impl UnwindSafe for std::sync::poison::once::Once

Source

impl UnwindSafe for CancellationToken

Source

impl UnwindSafe for Handle

Source

impl UnwindSafe for tokio::runtime::runtime::Runtime

Source

impl UnwindSafe for AbortHandle

Source

impl UnwindSafe for Notify

1.64.0 · Source

impl<K, V, A> UnwindSafe for BTreeMap<K, V, A>

1.36.0 · Source

impl<K, V, S> UnwindSafe for HashMap<K, V, S>
where K: UnwindSafe, V: UnwindSafe, S: UnwindSafe,

1.9.0 · Source

impl<T> !UnwindSafe for &mut T
where T: ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for *const T
where T: RefUnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for *mut T
where T: RefUnwindSafe + ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for &T
where T: RefUnwindSafe + ?Sized,

1.28.0 · Source

impl<T> UnwindSafe for NonZero<T>

1.25.0 · Source

impl<T> UnwindSafe for NonNull<T>
where T: RefUnwindSafe + ?Sized,

Source

impl<T> UnwindSafe for Receiver<T>

Source

impl<T> UnwindSafe for Sender<T>

1.70.0 · Source

impl<T> UnwindSafe for OnceLock<T>
where T: UnwindSafe,

1.9.0 · Source

impl<T> UnwindSafe for Mutex<T>
where T: ?Sized,

1.9.0 · Source

impl<T> UnwindSafe for RwLock<T>
where T: ?Sized,

Source

impl<T> UnwindSafe for ReentrantLock<T>
where T: UnwindSafe + ?Sized,

Source

impl<T> UnwindSafe for once_cell::unsync::OnceCell<T>
where T: UnwindSafe,

Source

impl<T> UnwindSafe for JoinHandle<T>

1.9.0 · Source

impl<T> UnwindSafe for AssertUnwindSafe<T>

1.9.0 · Source

impl<T, A> UnwindSafe for Rc<T, A>

1.9.0 · Source

impl<T, A> UnwindSafe for Arc<T, A>

1.80.0 · Source

impl<T, F> UnwindSafe for LazyLock<T, F>
where T: UnwindSafe, F: UnwindSafe,

Auto implementors



impl !UnwindSafe for StaticValueOrDXB



impl !UnwindSafe for CompilerError



impl !UnwindSafe for IncomingSection



impl !UnwindSafe for Response



impl !UnwindSafe for ExecutionError



impl !UnwindSafe for ExecutionStep



impl !UnwindSafe for InterruptProvider



impl !UnwindSafe for ExecutionContext



impl !UnwindSafe for ScriptExecutionError



impl !UnwindSafe for CoreValue



impl !UnwindSafe for ValueContainer



impl !UnwindSafe for CompilationScope



impl !UnwindSafe for PrecompilerData



impl !UnwindSafe for BlockHandler



impl !UnwindSafe for ScopeContext



impl !UnwindSafe for ComHub



impl !UnwindSafe for BaseInterface



impl !UnwindSafe for HTTPServerNativeInterface



impl !UnwindSafe for TCPClientNativeInterface



impl !UnwindSafe for WebRTCCommon



impl !UnwindSafe for WebRTCNativeInterface



impl !UnwindSafe for WebSocketClientNativeInterface



impl !UnwindSafe for RuntimeExecutionContext



impl !UnwindSafe for LocalExecutionContext



impl !UnwindSafe for RemoteExecutionContext



impl !UnwindSafe for Memory



impl !UnwindSafe for datex_core::runtime::Runtime



impl !UnwindSafe for RuntimeConfig



impl !UnwindSafe for RuntimeConfigInterface



impl !UnwindSafe for RuntimeInternal



impl !UnwindSafe for Array



impl !UnwindSafe for Object



impl !UnwindSafe for Tuple



impl !UnwindSafe for Reference



impl !UnwindSafe for ReferenceData



impl !UnwindSafe for DatexDeserializer



impl !UnwindSafe for DatexSerializer



impl !UnwindSafe for Value



impl UnwindSafe for Apply



impl UnwindSafe for BinaryOperator



impl UnwindSafe for DatexExpression



impl UnwindSafe for ParserError



impl UnwindSafe for Slot



impl UnwindSafe for TupleEntry



impl UnwindSafe for UnaryOperator



impl UnwindSafe for VariableMutType



impl UnwindSafe for VariableType



impl UnwindSafe for VariableModel



impl UnwindSafe for VariableRepresentation



impl UnwindSafe for CryptoError



impl UnwindSafe for ScopeType



impl UnwindSafe for InstructionCode



impl UnwindSafe for InternalSlot



impl UnwindSafe for HeaderParsingError



impl UnwindSafe for BlockType



impl UnwindSafe for DeviceType



impl UnwindSafe for Instruction



impl UnwindSafe for BlockSize



impl UnwindSafe for EncryptionType



impl UnwindSafe for SignatureType



impl UnwindSafe for ComHubError



impl UnwindSafe for InterfacePriority



impl UnwindSafe for ResponseError



impl UnwindSafe for ResponseResolutionStrategy



impl UnwindSafe for ResponseTimeout



impl UnwindSafe for SocketEndpointRegistrationError



impl UnwindSafe for NetworkTraceHopDirection



impl UnwindSafe for ComInterfaceError



impl UnwindSafe for ComInterfaceState



impl UnwindSafe for InterfaceDirection



impl UnwindSafe for ReconnectionConfig



impl UnwindSafe for SocketState



impl UnwindSafe for BaseInterfaceError



impl UnwindSafe for HTTPError



impl UnwindSafe for SerialError



impl UnwindSafe for TCPError



impl UnwindSafe for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common::WebRTCError



impl UnwindSafe for RTCSdpTypeDX



impl UnwindSafe for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common_new::utils::WebRTCError



impl UnwindSafe for URLError



impl UnwindSafe for WebSocketError



impl UnwindSafe for WebSocketServerError



impl UnwindSafe for InvalidProgramError



impl UnwindSafe for Color



impl UnwindSafe for BigDecimalType



impl UnwindSafe for datex_core::values::core_values::decimal::decimal::Decimal



impl UnwindSafe for TypedDecimal



impl UnwindSafe for EndpointInstance



impl UnwindSafe for EndpointType



impl UnwindSafe for InvalidEndpointError



impl UnwindSafe for TypedInteger



impl UnwindSafe for CoreValueType



impl UnwindSafe for ValueError



impl UnwindSafe for AsciiChar



impl UnwindSafe for datex_core::without_std::cmp::Ordering



impl UnwindSafe for TryReserveErrorKind



impl UnwindSafe for Infallible



impl UnwindSafe for FromBytesWithNulError



impl UnwindSafe for c_void



impl UnwindSafe for datex_core::without_std::fmt::Alignment



impl UnwindSafe for DebugAsHex



impl UnwindSafe for datex_core::without_std::fmt::Sign



impl UnwindSafe for AtomicOrdering



impl UnwindSafe for BasicBlock



impl UnwindSafe for UnwindTerminateReason



impl UnwindSafe for IpAddr



impl UnwindSafe for Ipv6MulticastScope



impl UnwindSafe for SocketAddr



impl UnwindSafe for FpCategory



impl UnwindSafe for IntErrorKind



impl UnwindSafe for OneSidedRangeBound



impl UnwindSafe for GetDisjointMutError



impl UnwindSafe for SearchStep



impl UnwindSafe for datex_core::without_std::sync::atomic::Ordering



impl UnwindSafe for DatexParseResult



impl UnwindSafe for Statement



impl UnwindSafe for VirtualSlot



impl UnwindSafe for CompileMetadata



impl UnwindSafe for Variable



impl UnwindSafe for Crypto



impl UnwindSafe for CryptoNative



impl UnwindSafe for DecompileOptions



impl UnwindSafe for BlockId



impl UnwindSafe for DXBBlock



impl UnwindSafe for IncomingEndpointContextId



impl UnwindSafe for IncomingEndpointContextSectionId



impl UnwindSafe for BlockHeader



impl UnwindSafe for FlagsAndTimestamp



impl UnwindSafe for EncryptedHeader



impl UnwindSafe for datex_core::global::protocol_structures::encrypted_header::Flags



impl UnwindSafe for DecimalData



impl UnwindSafe for ExecutionBlockData



impl UnwindSafe for Float32Data



impl UnwindSafe for Float64Data



impl UnwindSafe for FloatAsInt16Data



impl UnwindSafe for FloatAsInt32Data



impl UnwindSafe for InstructionCloseAndStore



impl UnwindSafe for Int8Data



impl UnwindSafe for Int16Data



impl UnwindSafe for Int32Data



impl UnwindSafe for Int64Data



impl UnwindSafe for Int128Data



impl UnwindSafe for ShortTextData



impl UnwindSafe for ShortTextDataRaw



impl UnwindSafe for SlotAddress



impl UnwindSafe for TextData



impl UnwindSafe for TextDataRaw



impl UnwindSafe for UInt8Data



impl UnwindSafe for UInt16Data



impl UnwindSafe for UInt32Data



impl UnwindSafe for UInt64Data



impl UnwindSafe for UInt128Data



impl UnwindSafe for datex_core::global::protocol_structures::routing_header::Flags



impl UnwindSafe for PointerId



impl UnwindSafe for ReceiverEndpoints



impl UnwindSafe for ReceiverEndpointsWithKeys



impl UnwindSafe for ReceiverFlags



impl UnwindSafe for Receivers



impl UnwindSafe for RoutingHeader



impl UnwindSafe for BlockHistoryData



impl UnwindSafe for ComHubOptions



impl UnwindSafe for DynamicEndpointProperties



impl UnwindSafe for ResponseOptions



impl UnwindSafe for NetworkTraceHop



impl UnwindSafe for NetworkTraceHopSocket



impl UnwindSafe for NetworkTraceResult



impl UnwindSafe for TraceOptions



impl UnwindSafe for ComInterfaceInfo



impl UnwindSafe for ComInterfaceSockets



impl UnwindSafe for ComInterfaceUUID



impl UnwindSafe for InterfaceProperties



impl UnwindSafe for ComInterfaceSocket



impl UnwindSafe for ComInterfaceSocketUUID



impl UnwindSafe for BaseInterfaceSetupData



impl UnwindSafe for LocalLoopbackInterface



impl UnwindSafe for SerialInterfaceSetupData



impl UnwindSafe for SerialNativeInterface



impl UnwindSafe for TCPClientInterfaceSetupData



impl UnwindSafe for TCPServerInterfaceSetupData



impl UnwindSafe for TCPServerNativeInterface



impl UnwindSafe for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common::RTCIceServer



impl UnwindSafe for RTCIceCandidateInitDX



impl UnwindSafe for datex_core::network::com_interfaces::default_com_interfaces::webrtc::webrtc_common_new::structures::RTCIceServer



impl UnwindSafe for RTCSessionDescriptionDX



impl UnwindSafe for WebSocketClientInterfaceSetupData



impl UnwindSafe for WebSocketServerInterfaceSetupData



impl UnwindSafe for WebSocketServerNativeInterface



impl UnwindSafe for ExecutionOptions



impl UnwindSafe for GlobalContext



impl UnwindSafe for AnsiCodes



impl UnwindSafe for Time



impl UnwindSafe for TimeNative



impl UnwindSafe for UUID



impl UnwindSafe for Boolean



impl UnwindSafe for Rational



impl UnwindSafe for Endpoint



impl UnwindSafe for EndpointParsingError



impl UnwindSafe for Integer



impl UnwindSafe for Text



impl UnwindSafe for Pointer



impl UnwindSafe for SerializationError



impl UnwindSafe for AllocError



impl UnwindSafe for Global



impl UnwindSafe for Layout



impl UnwindSafe for LayoutError



impl UnwindSafe for TypeId



impl UnwindSafe for CpuidResult



impl UnwindSafe for __m128



impl UnwindSafe for __m128bh



impl UnwindSafe for __m128d



impl UnwindSafe for __m128h



impl UnwindSafe for __m128i



impl UnwindSafe for __m256



impl UnwindSafe for __m256bh



impl UnwindSafe for __m256d



impl UnwindSafe for __m256h



impl UnwindSafe for __m256i



impl UnwindSafe for __m512



impl UnwindSafe for __m512bh



impl UnwindSafe for __m512d



impl UnwindSafe for __m512h



impl UnwindSafe for __m512i



impl UnwindSafe for bf16



impl UnwindSafe for TryFromSliceError



impl UnwindSafe for datex_core::without_std::ascii::EscapeDefault



impl UnwindSafe for BorrowError



impl UnwindSafe for BorrowMutError



impl UnwindSafe for CharTryFromError



impl UnwindSafe for DecodeUtf16Error



impl UnwindSafe for datex_core::without_std::char::EscapeDebug



impl UnwindSafe for datex_core::without_std::char::EscapeDefault



impl UnwindSafe for datex_core::without_std::char::EscapeUnicode



impl UnwindSafe for ParseCharError



impl UnwindSafe for ToLowercase



impl UnwindSafe for ToUppercase



impl UnwindSafe for TryFromCharError



impl UnwindSafe for UnorderedKeyError



impl UnwindSafe for TryReserveError



impl UnwindSafe for CStr



impl UnwindSafe for CString



impl UnwindSafe for FromBytesUntilNulError



impl UnwindSafe for FromVecWithNulError



impl UnwindSafe for IntoStringError



impl UnwindSafe for NulError



impl UnwindSafe for Error



impl UnwindSafe for FormattingOptions



impl UnwindSafe for SipHasher



impl UnwindSafe for ReturnToArg



impl UnwindSafe for UnwindActionArg



impl UnwindSafe for PhantomPinned



impl UnwindSafe for Assume



impl UnwindSafe for AddrParseError



impl UnwindSafe for Ipv4Addr



impl UnwindSafe for Ipv6Addr



impl UnwindSafe for SocketAddrV4



impl UnwindSafe for SocketAddrV6



impl UnwindSafe for ParseFloatError



impl UnwindSafe for ParseIntError



impl UnwindSafe for TryFromIntError



impl UnwindSafe for RangeFull



impl UnwindSafe for String



impl UnwindSafe for datex_core::without_std::ptr::Alignment



impl UnwindSafe for ParseBoolError



impl UnwindSafe for Utf8Error



impl UnwindSafe for FromUtf8Error



impl UnwindSafe for FromUtf16Error



impl UnwindSafe for IntoChars



impl UnwindSafe for AtomicBool



impl UnwindSafe for AtomicI8



impl UnwindSafe for AtomicI16



impl UnwindSafe for AtomicI32



impl UnwindSafe for AtomicI64



impl UnwindSafe for AtomicIsize



impl UnwindSafe for AtomicU8



impl UnwindSafe for AtomicU16



impl UnwindSafe for AtomicU32



impl UnwindSafe for AtomicU64



impl UnwindSafe for AtomicUsize



impl UnwindSafe for LocalWaker



impl UnwindSafe for RawWaker



impl UnwindSafe for RawWakerVTable



impl UnwindSafe for Waker



impl UnwindSafe for Duration



impl UnwindSafe for TryFromFloatSecsError



impl UnwindSafe for Big8x3



impl UnwindSafe for Big32x40



impl UnwindSafe for Decimal



impl UnwindSafe for DecimalSeq



impl UnwindSafe for Decoded



impl UnwindSafe for FullDecoded



impl UnwindSafe for I32NotAllOnes



impl UnwindSafe for I64NotAllOnes



impl UnwindSafe for Nanoseconds



impl UnwindSafe for NonZeroCharInner



impl UnwindSafe for NonZeroI8Inner



impl UnwindSafe for NonZeroI16Inner



impl UnwindSafe for NonZeroI32Inner



impl UnwindSafe for NonZeroI64Inner



impl UnwindSafe for NonZeroI128Inner



impl UnwindSafe for NonZeroIsizeInner



impl UnwindSafe for NonZeroU8Inner



impl UnwindSafe for NonZeroU16Inner



impl UnwindSafe for NonZeroU32Inner



impl UnwindSafe for NonZeroU64Inner



impl UnwindSafe for NonZeroU128Inner



impl UnwindSafe for NonZeroUsizeInner



impl UnwindSafe for Sign



impl UnwindSafe for U32NotAllOnes



impl UnwindSafe for U64NotAllOnes



impl UnwindSafe for UsizeNoHighBit



impl<'a> !UnwindSafe for CompilationContext<'a>



impl<'a> !UnwindSafe for CompileOptions<'a>



impl<'a> !UnwindSafe for ExecutionInput<'a>



impl<'a> !UnwindSafe for Request<'a>



impl<'a> !UnwindSafe for Source<'a>



impl<'a> !UnwindSafe for Formatter<'a>



impl<'a> !UnwindSafe for BorrowedCursor<'a>



impl<'a> !UnwindSafe for ContextBuilder<'a>



impl<'a> UnwindSafe for Utf8Pattern<'a>



impl<'a> UnwindSafe for Arguments<'a>



impl<'a> UnwindSafe for PhantomContravariantLifetime<'a>



impl<'a> UnwindSafe for PhantomCovariantLifetime<'a>



impl<'a> UnwindSafe for PhantomInvariantLifetime<'a>



impl<'a> UnwindSafe for EscapeAscii<'a>



impl<'a> UnwindSafe for CharSearcher<'a>



impl<'a> UnwindSafe for Bytes<'a>



impl<'a> UnwindSafe for CharIndices<'a>



impl<'a> UnwindSafe for Chars<'a>



impl<'a> UnwindSafe for EncodeUtf16<'a>



impl<'a> UnwindSafe for datex_core::without_std::str::EscapeDebug<'a>



impl<'a> UnwindSafe for datex_core::without_std::str::EscapeDefault<'a>



impl<'a> UnwindSafe for datex_core::without_std::str::EscapeUnicode<'a>



impl<'a> UnwindSafe for Lines<'a>



impl<'a> UnwindSafe for LinesAny<'a>



impl<'a> UnwindSafe for SplitAsciiWhitespace<'a>



impl<'a> UnwindSafe for SplitWhitespace<'a>



impl<'a> UnwindSafe for Utf8Chunk<'a>



impl<'a> UnwindSafe for Utf8Chunks<'a>



impl<'a> UnwindSafe for datex_core::without_std::string::Drain<'a>



impl<'a> UnwindSafe for Context<'a>



impl<'a> UnwindSafe for Location<'a>



impl<'a> UnwindSafe for PanicInfo<'a>



impl<'a> UnwindSafe for PanicMessage<'a>



impl<'a> UnwindSafe for Formatted<'a>



impl<'a> UnwindSafe for Part<'a>



impl<'a, 'b> !UnwindSafe for DebugList<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugMap<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugSet<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugStruct<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugTuple<'a, 'b>



impl<'a, 'b> UnwindSafe for CharSliceSearcher<'a, 'b>



impl<'a, 'b> UnwindSafe for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> UnwindSafe for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'f> !UnwindSafe for VaList<'a, 'f>



impl<'a, A> !UnwindSafe for datex_core::without_std::option::IterMut<'a, A>



impl<'a, A> UnwindSafe for datex_core::without_std::option::Iter<'a, A>
where A: RefUnwindSafe,



impl<'a, B> UnwindSafe for Cow<'a, B>
where <B as ToOwned>::Owned: UnwindSafe, B: RefUnwindSafe + ?Sized,



impl<'a, F> UnwindSafe for CharPredicateSearcher<'a, F>
where F: UnwindSafe,



impl<'a, I> !UnwindSafe for ByRefSized<'a, I>



impl<'a, I, A> UnwindSafe for Splice<'a, I, A>



impl<'a, K> UnwindSafe for datex_core::without_std::collections::btree_set::Cursor<'a, K>
where K: RefUnwindSafe,



impl<'a, K, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::CursorMut<'a, K, A>



impl<'a, K, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::CursorMutKey<'a, K, A>



impl<'a, K, V> !UnwindSafe for datex_core::without_std::collections::btree_map::IterMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for RangeMut<'a, K, V>



impl<'a, K, V> !UnwindSafe for ValuesMut<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::without_std::collections::btree_map::Cursor<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::without_std::collections::btree_map::Iter<'a, K, V>



impl<'a, K, V> UnwindSafe for Keys<'a, K, V>



impl<'a, K, V> UnwindSafe for datex_core::without_std::collections::btree_map::Range<'a, K, V>



impl<'a, K, V> UnwindSafe for Values<'a, K, V>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::Entry<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::CursorMut<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::CursorMutKey<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::OccupiedEntry<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for OccupiedError<'a, K, V, A>



impl<'a, K, V, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::VacantEntry<'a, K, V, A>



impl<'a, K, V, R, F, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>



impl<'a, P> UnwindSafe for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::without_std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::without_std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::without_std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::without_std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for datex_core::without_std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, T> !UnwindSafe for datex_core::without_std::collections::linked_list::IterMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::without_std::collections::vec_deque::IterMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::without_std::prelude::vec::PeekMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::without_std::result::IterMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksMut<'a, T>



impl<'a, T> !UnwindSafe for datex_core::without_std::slice::IterMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksMut<'a, T>



impl<'a, T> UnwindSafe for datex_core::without_std::collections::binary_heap::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::collections::btree_set::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::collections::btree_set::Range<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for SymmetricDifference<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Union<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::collections::linked_list::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::collections::vec_deque::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::result::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Chunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for ChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for datex_core::without_std::slice::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Windows<'a, T>
where T: RefUnwindSafe,



impl<'a, T, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::Entry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for DrainSorted<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::without_std::collections::binary_heap::PeekMut<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::OccupiedEntry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::VacantEntry<'a, T, A>



impl<'a, T, A = Global> !UnwindSafe for datex_core::without_std::collections::linked_list::CursorMut<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::without_std::collections::binary_heap::Drain<'a, T, A>



impl<'a, T, A> UnwindSafe for Difference<'a, T, A>



impl<'a, T, A> UnwindSafe for Intersection<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::without_std::collections::linked_list::Cursor<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::without_std::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> UnwindSafe for datex_core::without_std::prelude::vec::Drain<'a, T, A>



impl<'a, T, F, A = Global> !UnwindSafe for datex_core::without_std::collections::linked_list::ExtractIf<'a, T, F, A>



impl<'a, T, F, A = Global> !UnwindSafe for datex_core::without_std::prelude::vec::ExtractIf<'a, T, F, A>



impl<'a, T, P> !UnwindSafe for ChunkByMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitNMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitInclusiveMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitNMut<'a, T, P>



impl<'a, T, P> UnwindSafe for ChunkBy<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::without_std::slice::RSplit<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::without_std::slice::RSplitN<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::without_std::slice::Split<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::without_std::slice::SplitInclusive<'a, T, P>



impl<'a, T, P> UnwindSafe for datex_core::without_std::slice::SplitN<'a, T, P>



impl<'a, T, R, F, A = Global> !UnwindSafe for datex_core::without_std::collections::btree_set::ExtractIf<'a, T, R, F, A>



impl<'a, T, const N: usize> UnwindSafe for ArrayWindows<'a, T, N>
where T: RefUnwindSafe,



impl<'a, const N: usize> UnwindSafe for CharArraySearcher<'a, N>



impl<'b, T> !UnwindSafe for Ref<'b, T>



impl<'b, T> !UnwindSafe for RefMut<'b, T>



impl<'data> !UnwindSafe for BorrowedBuf<'data>



impl<'f> UnwindSafe for VaListImpl<'f>



impl<A> UnwindSafe for Repeat<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RepeatN<A>
where A: UnwindSafe,



impl<A> UnwindSafe for datex_core::without_std::option::IntoIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for IterRange<A>
where A: UnwindSafe,



impl<A> UnwindSafe for IterRangeFrom<A>
where A: UnwindSafe,



impl<A> UnwindSafe for IterRangeInclusive<A>
where A: UnwindSafe,



impl<A, B> UnwindSafe for Chain<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A, B> UnwindSafe for Zip<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<B, C> UnwindSafe for ControlFlow<B, C>
where C: UnwindSafe, B: UnwindSafe,



impl<Dyn> !UnwindSafe for DynMetadata<Dyn>



impl<F> UnwindSafe for datex_core::without_std::fmt::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for PollFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for datex_core::without_std::iter::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for OnceWith<F>
where F: UnwindSafe,



impl<F> UnwindSafe for RepeatWith<F>
where F: UnwindSafe,



impl<G> UnwindSafe for FromCoroutine<G>
where G: UnwindSafe,



impl<H> UnwindSafe for BuildHasherDefault<H>



impl<I> UnwindSafe for FromIter<I>
where I: UnwindSafe,



impl<I> UnwindSafe for DecodeUtf16<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cloned<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Copied<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cycle<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Enumerate<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Flatten<I>



impl<I> UnwindSafe for Fuse<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Intersperse<I>
where <I as Iterator>::Item: Sized + UnwindSafe, I: UnwindSafe,



impl<I> UnwindSafe for Peekable<I>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for Skip<I>
where I: UnwindSafe,



impl<I> UnwindSafe for StepBy<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Take<I>
where I: UnwindSafe,



impl<I, F> UnwindSafe for FilterMap<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Inspect<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Map<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F, const N: usize> UnwindSafe for MapWindows<I, F, N>
where F: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, G> UnwindSafe for IntersperseWith<I, G>
where G: UnwindSafe, <I as Iterator>::Item: UnwindSafe, I: UnwindSafe,



impl<I, P> UnwindSafe for Filter<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for MapWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for SkipWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for TakeWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, St, F> UnwindSafe for Scan<I, St, F>
where I: UnwindSafe, F: UnwindSafe, St: UnwindSafe,



impl<I, U, F> UnwindSafe for FlatMap<I, U, F>



impl<I, const N: usize> UnwindSafe for ArrayChunks<I, N>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::ops::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::ops::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::ops::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for RangeTo<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::range::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::range::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for datex_core::without_std::range::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<K, V, A> UnwindSafe for datex_core::without_std::collections::btree_map::IntoIter<K, V, A>



impl<K, V, A> UnwindSafe for IntoKeys<K, V, A>



impl<K, V, A> UnwindSafe for IntoValues<K, V, A>



impl<Ptr> UnwindSafe for Pin<Ptr>
where Ptr: UnwindSafe,



impl<T> !UnwindSafe for DataChannel<T>



impl<T> !UnwindSafe for DataChannels<T>



impl<T> UnwindSafe for Bound<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Option<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Poll<T>
where T: UnwindSafe,



impl<T> UnwindSafe for ThinBox<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Cell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for datex_core::without_std::cell::OnceCell<T>
where T: UnwindSafe,



impl<T> UnwindSafe for RefCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for SyncUnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for UnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Reverse<T>
where T: UnwindSafe,



impl<T> UnwindSafe for NumBuffer<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Pending<T>



impl<T> UnwindSafe for Ready<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Empty<T>



impl<T> UnwindSafe for datex_core::without_std::iter::Once<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Rev<T>
where T: UnwindSafe,



impl<T> UnwindSafe for PhantomContravariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomCovariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomData<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for PhantomInvariant<T>
where T: ?Sized,



impl<T> UnwindSafe for Discriminant<T>



impl<T> UnwindSafe for ManuallyDrop<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Saturating<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Wrapping<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Yeet<T>
where T: UnwindSafe,



impl<T> UnwindSafe for UnsafePinned<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for datex_core::without_std::result::IntoIter<T>
where T: UnwindSafe,



impl<T> UnwindSafe for AtomicPtr<T>
where T: RefUnwindSafe,



impl<T> UnwindSafe for Exclusive<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for MaybeUninit<T>
where T: UnwindSafe,



impl<T, A = Global> !UnwindSafe for UniqueRc<T, A>



impl<T, A = Global> !UnwindSafe for datex_core::without_std::rc::Weak<T, A>



impl<T, A> UnwindSafe for datex_core::without_std::collections::binary_heap::IntoIter<T, A>



impl<T, A> UnwindSafe for IntoIterSorted<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::without_std::collections::btree_set::IntoIter<T, A>



impl<T, A> UnwindSafe for datex_core::without_std::collections::linked_list::IntoIter<T, A>



impl<T, A> UnwindSafe for BTreeSet<T, A>



impl<T, A> UnwindSafe for BinaryHeap<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for LinkedList<T, A>



impl<T, A> UnwindSafe for VecDeque<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::without_std::collections::vec_deque::IntoIter<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for Box<T, A>
where A: UnwindSafe, T: UnwindSafe + ?Sized,



impl<T, A> UnwindSafe for Vec<T, A>
where A: UnwindSafe, T: UnwindSafe,



impl<T, A> UnwindSafe for datex_core::without_std::prelude::vec::IntoIter<T, A>



impl<T, A> UnwindSafe for UniqueArc<T, A>



impl<T, A> UnwindSafe for datex_core::without_std::sync::Weak<T, A>
where A: UnwindSafe, T: RefUnwindSafe + ?Sized,



impl<T, E> UnwindSafe for Result<T, E>
where T: UnwindSafe, E: UnwindSafe,



impl<T, F> UnwindSafe for LazyCell<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for Successors<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for DropGuard<T, F>
where T: UnwindSafe, F: UnwindSafe,



impl<T, const N: usize> UnwindSafe for datex_core::without_std::array::IntoIter<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Mask<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Simd<T, N>
where T: UnwindSafe,



impl<Y, R> UnwindSafe for CoroutineState<Y, R>
where Y: UnwindSafe, R: UnwindSafe,



impl<const N: usize> UnwindSafe for LaneCount<N>