pub struct RangeFull;new_range_api)Expand description
An unbounded range (..).
RangeFull is primarily used as a slicing index, its shorthand is ...
It cannot serve as an Iterator because it doesnโt have a starting point.
Examples
The .. syntax is a RangeFull:
assert_eq!(.., std::ops::RangeFull);It does not have an IntoIterator implementation, so you canโt use it in
a for loop directly. This wonโt compile:
for i in .. {
// ...
}Used as a slicing index, RangeFull produces the full array as a slice.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]); // This is the `RangeFull`
assert_eq!(arr[ .. 3], [0, 1, 2 ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]);
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Trait Implementations
Sourceimpl Distribution<bool> for RangeFull
impl Distribution<bool> for RangeFull
Sourceimpl Distribution<i128> for RangeFull
impl Distribution<i128> for RangeFull
Sourceimpl Distribution<i16> for RangeFull
impl Distribution<i16> for RangeFull
Sourceimpl Distribution<i32> for RangeFull
impl Distribution<i32> for RangeFull
Sourceimpl Distribution<i64> for RangeFull
impl Distribution<i64> for RangeFull
Sourceimpl Distribution<i8> for RangeFull
impl Distribution<i8> for RangeFull
Sourceimpl Distribution<isize> for RangeFull
impl Distribution<isize> for RangeFull
Sourceimpl Distribution<u128> for RangeFull
impl Distribution<u128> for RangeFull
Sourceimpl Distribution<u16> for RangeFull
impl Distribution<u16> for RangeFull
Sourceimpl Distribution<u32> for RangeFull
impl Distribution<u32> for RangeFull
Sourceimpl Distribution<u64> for RangeFull
impl Distribution<u64> for RangeFull
Sourceimpl Distribution<u8> for RangeFull
impl Distribution<u8> for RangeFull
Sourceimpl Distribution<usize> for RangeFull
impl Distribution<usize> for RangeFull
Sourceimpl Index<RangeFull> for ByteString
impl Index<RangeFull> for ByteString
Sourceimpl Index<RangeFull> for UninitSlice
impl Index<RangeFull> for UninitSlice
Sourcetype Output = UninitSlice
type Output = UninitSlice
Sourceimpl IndexMut<RangeFull> for ByteString
impl IndexMut<RangeFull> for ByteString
Sourceimpl IndexMut<RangeFull> for UninitSlice
impl IndexMut<RangeFull> for UninitSlice
Sourceimpl<T> IntoBounds<T> for RangeFull
impl<T> IntoBounds<T> for RangeFull
Sourceimpl<I> IteratorIndex<I> for RangeFullwhere
I: Iterator,
impl<I> IteratorIndex<I> for RangeFullwhere
I: Iterator,
1.28.0 ยท Sourceimpl<T> RangeBounds<T> for RangeFullwhere
T: ?Sized,
impl<T> RangeBounds<T> for RangeFullwhere
T: ?Sized,
1.15.0 (const: unstable) ยท Sourceimpl<T> SliceIndex<[T]> for RangeFull
impl<T> SliceIndex<[T]> for RangeFull
Sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)Sourceimpl SliceIndex<ByteStr> for RangeFull
impl SliceIndex<ByteStr> for RangeFull
Sourcefn get(
self,
slice: &ByteStr,
) -> Option<&<RangeFull as SliceIndex<ByteStr>>::Output>
fn get( self, slice: &ByteStr, ) -> Option<&<RangeFull as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut ByteStr,
) -> Option<&mut <RangeFull as SliceIndex<ByteStr>>::Output>
fn get_mut( self, slice: &mut ByteStr, ) -> Option<&mut <RangeFull as SliceIndex<ByteStr>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const ByteStr,
) -> *const <RangeFull as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked( self, slice: *const ByteStr, ) -> *const <RangeFull as SliceIndex<ByteStr>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut ByteStr,
) -> *mut <RangeFull as SliceIndex<ByteStr>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut ByteStr, ) -> *mut <RangeFull as SliceIndex<ByteStr>>::Output
slice_index_methods)1.20.0 (const: unstable) ยท Sourceimpl SliceIndex<str> for RangeFull
Implements substring slicing with syntax &self[..] or &mut self[..].
impl SliceIndex<str> for RangeFull
Implements substring slicing with syntax &self[..] or &mut self[..].
Returns a slice of the whole string, i.e., returns &self or &mut self. Equivalent to &self[0 .. len] or &mut self[0 .. len]. Unlike
other indexing operations, this can never panic.
This operation is O(1).
Prior to 1.20.0, these indexing operations were still supported by
direct implementation of Index and IndexMut.
Equivalent to &self[0 .. len] or &mut self[0 .. len].
Sourcefn get(self, slice: &str) -> Option<&<RangeFull as SliceIndex<str>>::Output>
fn get(self, slice: &str) -> Option<&<RangeFull as SliceIndex<str>>::Output>
slice_index_methods)Sourcefn get_mut(
self,
slice: &mut str,
) -> Option<&mut <RangeFull as SliceIndex<str>>::Output>
fn get_mut( self, slice: &mut str, ) -> Option<&mut <RangeFull as SliceIndex<str>>::Output>
slice_index_methods)Sourceunsafe fn get_unchecked(
self,
slice: *const str,
) -> *const <RangeFull as SliceIndex<str>>::Output
unsafe fn get_unchecked( self, slice: *const str, ) -> *const <RangeFull as SliceIndex<str>>::Output
slice_index_methods)Sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str,
) -> *mut <RangeFull as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut( self, slice: *mut str, ) -> *mut <RangeFull as SliceIndex<str>>::Output
slice_index_methods)impl Copy for RangeFull
impl Eq for RangeFull
impl StructuralPartialEq for RangeFull