Modules
- atomic
- Atomic types
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Weak
Weakis a version ofArcthat holds a non-owning reference to the managed allocation.- Exclusive
Experimental Exclusiveprovides only mutable access, also referred to as exclusive access to the underlying value. It provides no immutable, or shared access to the underlying value.- Unique
Arc Experimental - A uniquely owned
Arc.